
#include "pmu-events/pmu-events.h"
#include "util/header.h"
#include "util/pmu.h"
#include <string.h>
#include <stddef.h>

struct compact_pmu_event {
  int offset;
};

static const char *const big_c_string =
/* offset=0 */ "ALINK0_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK0_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=244 */ "ALINK0_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK0_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=497 */ "ALINK1_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK1_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=741 */ "ALINK1_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK1_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=994 */ "ALINK2_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK2_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=1238 */ "ALINK2_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK2_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=1491 */ "ALINK3_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK3_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=1735 */ "ALINK3_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK3_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=1988 */ "ALINK4_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK4_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=2232 */ "ALINK4_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK4_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=2485 */ "ALINK5_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK5_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=2729 */ "ALINK5_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK5_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=2982 */ "ALINK6_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK6_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=3226 */ "ALINK6_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK6_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=3479 */ "ALINK7_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK7_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=3723 */ "ALINK7_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK7_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=3976 */ "AVERAGE_COMPLETED_INSTRUCTION_SET_SIZE\000General\000\000PM_RUN_INST_CMPL / PM_1PLUS_PPC_CMPL\000Average number of completed instructions per instruction group\000\000\000\000\000"
/* offset=4128 */ "BRANCHES_PER_INST\000General\000\000PM_BR_FIN / PM_RUN_INST_CMPL\000Average number of finished branches per completed instruction\000\000\000\000\000"
/* offset=4250 */ "BRANCH_MISPREDICTION_RATE\000Others\000\000PM_BR_MPRED_CMPL / PM_RUN_INST_CMPL\000Percentage of branch mispredictions per completed instruction\000\000\000\000\000"
/* offset=4386 */ "BRU_STALL_CPI\000CPI\000\000PM_EXEC_STALL_BRU / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing in the branch unit\000\000\000\000\000"
/* offset=4544 */ "BR_MPRED_FLUSH_RATE\000Others\000\000PM_FLUSH_MPRED / PM_RUN_INST_CMPL * 100\000Percentage of flushes due to a branch mispredict per completed instruction\000\0001%\000\000\000"
/* offset=4693 */ "COMPLETION_STALL_CPI\000CPI;CPI_STALL_RATIO\000\000PM_CMPL_STALL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction cannot complete because the thread was blocked\000\000\000\000\000"
/* offset=4885 */ "CPI\000\000\0001 / IPC\000\000\000\000\000\000"
/* offset=4904 */ "CPM_CS_32MHZ_CYC\000\000\000hv_24x7@CPM_CS_32MHZ_CYC\\,domain\\=3\\,core\\=?@\000\000\0001MHz\000\0002\000"
/* offset=4979 */ "CYCLES_ATLEAST_ONE_INST_DISPATCHED\000General\000\000PM_1PLUS_PPC_DISP / PM_RUN_CYC * 100\000Percentage of cycles when at least 1 instruction dispatched\000\0001%\000\000\000"
/* offset=5126 */ "CYCLES_PER_COMPLETED_INSTRUCTIONS_SET\000General\000\000PM_CYC / PM_1PLUS_PPC_CMPL\000Average number of cycles per completed instruction group\000\000\000\000\000"
/* offset=5261 */ "CYCLES_PER_INSTRUCTION\000CPI\000\000PM_CYC / PM_INST_CMPL\000Average cycles per completed instruction\000\000\000\000\000"
/* offset=5356 */ "DCACHE_MISS_CPI\000General\000\000DMISS_L3MISS_STALL_CPI / RUN_CPI * 100\000Percentage of cycles stalled due to the NTC instruction waiting for a load miss to resolve from a source beyond the local L2 and local L3\000\0001%\000\000\000"
/* offset=5564 */ "DCache_L2_All\000\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000"
/* offset=5625 */ "DCache_L2_All_Hits\000\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000"
/* offset=5716 */ "DCache_L2_All_Miss\000\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000"
/* offset=5847 */ "DCache_L2_Hits\000\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000"
/* offset=5912 */ "DCache_L2_Misses\000\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000"
/* offset=5979 */ "DERAT_16M_MISS_RATE\000Translation\000\000PM_DERAT_MISS_16M / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses with 16M page size per completed instruction\000\0001%\000\000\000"
/* offset=6133 */ "DERAT_16M_MISS_RATIO\000Translation\000\000PM_DERAT_MISS_16M / PM_DERAT_MISS\000DERAT miss ratio for 16M page size\000\000\000\000\000"
/* offset=6240 */ "DERAT_2M_MISS_RATE\000Translation\000\000PM_DERAT_MISS_2M / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses with 2M page size per completed instruction\000\0001%\000\000\000"
/* offset=6391 */ "DERAT_2M_MISS_RATIO\000Translation\000\000PM_DERAT_MISS_2M / PM_DERAT_MISS\000DERAT miss ratio for 2M page size\000\000\000\000\000"
/* offset=6495 */ "DERAT_4K_MISS_RATE\000Translation\000\000PM_DERAT_MISS_4K / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses with 4k page size per completed instruction\000\0001%\000\000\000"
/* offset=6646 */ "DERAT_4K_MISS_RATIO\000Translation\000\000PM_DERAT_MISS_4K / PM_DERAT_MISS\000DERAT miss ratio for 4K page size\000\000\000\000\000"
/* offset=6750 */ "DERAT_64K_MISS_RATE\000Translation\000\000PM_DERAT_MISS_64K / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses with 64k page size per completed instruction\000\0001%\000\000\000"
/* offset=6904 */ "DERAT_64K_MISS_RATIO\000Translation\000\000PM_DERAT_MISS_64K / PM_DERAT_MISS\000DERAT miss ratio for 64K page size\000\000\000\000\000"
/* offset=7011 */ "DERAT_DTLB_MISS_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DERAT_DTLB_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is recovering from a TLB miss\000\000\000\000\000"
/* offset=7191 */ "DERAT_MISS_RATE\000Translation\000\000PM_DERAT_MISS / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses per completed instruction\000\0001%\000\000\000"
/* offset=7318 */ "DERAT_MISS_RELOAD\000Translation\000\000PM_DTLB_MISS / PM_DERAT_MISS * 100\000Percentage of DERAT misses that resulted in TLB reloads\000\0001%\000\000\000"
/* offset=7446 */ "DERAT_ONLY_MISS_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DERAT_ONLY_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a load or store that suffered a translation miss\000\000\000\000\000"
/* offset=7648 */ "DISPATCHED_BR_MPRED_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled due to a branch mispredict\000\000\000\000\000"
/* offset=7817 */ "DISPATCHED_BR_MPRED_ICMISS_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled due to an icache miss after a branch mispredict\000\000\000\000\000"
/* offset=8021 */ "DISPATCHED_BR_MPRED_IC_L2_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED_IC_L2 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from the local L2 after suffering a branch mispredict\000\000\000\000\000"
/* offset=8259 */ "DISPATCHED_BR_MPRED_IC_L3MISS_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED_IC_L3MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from any source beyond the local L3 after suffering a branch mispredict\000\000\000\000\000"
/* offset=8523 */ "DISPATCHED_BR_MPRED_IC_L3_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED_IC_L3 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from the local L3 after suffering a branch mispredict\000\000\000\000\000"
/* offset=8761 */ "DISPATCHED_CPI\000CPI;CPI_STALL_RATIO\000\000PM_DISP_STALL_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled for any reason\000\000\000\000\000"
/* offset=8920 */ "DISPATCHED_FETCH_CPI\000CPI\000\000PM_DISP_STALL_FETCH / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled because fetch was being held, so there was nothing in the pipeline for this thread\000\000\000\000\000"
/* offset=9139 */ "DISPATCHED_FLUSH_CPI\000CPI\000\000PM_DISP_STALL_FLUSH / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled because there was a flush\000\000\000\000\000"
/* offset=9301 */ "DISPATCHED_HELD_CPI\000CPI\000\000PM_DISP_STALL_HELD_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch for any reason\000\000\000\000\000"
/* offset=9474 */ "DISPATCHED_HELD_HALT_CPI\000CPI\000\000PM_DISP_STALL_HELD_HALT_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because of power management\000\000\000\000\000"
/* offset=9670 */ "DISPATCHED_HELD_OTHER_CPI\000CPI\000\000PM_DISP_STALL_HELD_OTHER_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch for any other reason\000\000\000\000\000"
/* offset=9861 */ "DISPATCHED_HELD_RENAME_CPI\000CPI\000\000PM_DISP_STALL_HELD_RENAME_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the mapper/SRB was full\000\000\000\000\000"
/* offset=10065 */ "DISPATCHED_HELD_STF_MAPPER_CPI\000CPI\000\000PM_DISP_STALL_HELD_STF_MAPPER_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the STF mapper/SRB was full\000\000\000\000\000"
/* offset=10281 */ "DISPATCHED_HELD_XVFC_MAPPER_CPI\000CPI\000\000PM_DISP_STALL_HELD_XVFC_MAPPER_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the XVFC mapper/SRB was full\000\000\000\000\000"
/* offset=10500 */ "DISPATCHED_IC_L2_CPI\000CPI\000\000PM_DISP_STALL_IC_L2 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from the local L2\000\000\000\000\000"
/* offset=10688 */ "DISPATCHED_IC_L3MISS_CPI\000CPI\000\000PM_DISP_STALL_IC_L3MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from any source beyond the local L3\000\000\000\000\000"
/* offset=10902 */ "DISPATCHED_IC_L3_CPI\000CPI\000\000PM_DISP_STALL_IC_L3 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from the local L3\000\000\000\000\000"
/* offset=11090 */ "DISPATCHED_IC_MISS_CPI\000CPI\000\000PM_DISP_STALL_IC_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled due to an icache miss\000\000\000\000\000"
/* offset=11252 */ "DISPATCHED_IERAT_ONLY_MISS_CPI\000CPI\000\000PM_DISP_STALL_IERAT_ONLY_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled waiting to resolve an instruction ERAT miss\000\000\000\000\000"
/* offset=11452 */ "DISPATCHED_ITLB_MISS_CPI\000CPI\000\000PM_DISP_STALL_ITLB_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled waiting to resolve an instruction TLB miss\000\000\000\000\000"
/* offset=11639 */ "DISPATCHED_TRANSLATION_CPI\000CPI\000\000PM_DISP_STALL_TRANSLATION / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled because the MMU was handling a translation miss\000\000\000\000\000"
/* offset=11835 */ "DISPATCH_PER_INST_CMPL\000General\000\000PM_INST_DISP / PM_RUN_INST_CMPL\000Average number of completed instructions dispatched per instruction completed\000\000\000\000\000"
/* offset=11981 */ "DISP_HELD_STALL_ISSQ_FULL_CPI\000CPI\000\000PM_DISP_STALL_HELD_ISSQ_FULL_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch due to issue queue full\000\000\000\000\000"
/* offset=12183 */ "DISP_HELD_STALL_SCOREBOARD_CPI\000CPI\000\000PM_DISP_STALL_HELD_SCOREBOARD_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch while waiting on the scoreboard\000\000\000\000\000"
/* offset=12395 */ "DISP_HELD_STALL_SYNC_CPI\000CPI\000\000PM_DISP_STALL_HELD_SYNC_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because of a synchronizing instruction that requires the ICT to be empty before dispatch\000\000\000\000\000"
/* offset=12652 */ "DL1_MISS_RELOADS\000General\000\000PM_LD_DEMAND_MISS_L1 / PM_LD_MISS_L1 * 100\000Percentage of demand load misses that reloaded the L1 cache\000\0001%\000\000\000"
/* offset=12787 */ "DL1_RELOAD_FROM_L2_MISS\000dL1_Reloads\000\000PM_DATA_FROM_L2MISS / PM_LD_DEMAND_MISS_L1 * 100\000Percentage of demand load misses that reloaded from beyond the local L2\000\0001%\000\000\000"
/* offset=12951 */ "DL1_RELOAD_FROM_L2_MISS_RATE\000dL1_Reloads\000\000PM_DATA_FROM_L2MISS / PM_RUN_INST_CMPL * 100\000Percentage of demand loads that reloaded from beyond the L2 per completed instruction\000\0001%\000\000\000"
/* offset=13130 */ "DL1_RELOAD_FROM_L3_MISS\000dL1_Reloads\000\000PM_DATA_FROM_L3MISS / PM_LD_DEMAND_MISS_L1 * 100\000Percentage of demand load misses that reloaded from beyond the local L3\000\0001%\000\000\000"
/* offset=13294 */ "DL1_RELOAD_FROM_L3_MISS_RATE\000dL1_Reloads\000\000L3_LD_MISS_RATE\000Percentage of demand loads that reloaded from beyond the L3 per completed instruction\000\0001%\000\000\000"
/* offset=13444 */ "DMISS_L21_L31_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a neighbor chiplet's L2 or L3 in the same chip\000\000\000\000\000"
/* offset=13680 */ "DMISS_L2L3_CONFLICT_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3, with an RC dispatch conflict\000\000\000\000\000"
/* offset=13943 */ "DMISS_L2L3_NOCONFLICT_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L2L3_NOCONFLICT / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3, without an RC dispatch conflict\000\000\000\000\000"
/* offset=14213 */ "DMISS_L2L3_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3\000\000\000\000\000"
/* offset=14428 */ "DMISS_L3MISS_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a source beyond the local L2 and local L3\000\000\000\000\000"
/* offset=14657 */ "DMISS_LMEM_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from L4, local memory or OpenCAPI chip\000\000\000\000\000"
/* offset=14874 */ "DMISS_OFF_CHIP_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_OFF_CHIP / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a remote chip (cache, L4, memory or OpenCAPI) in the same group\000\000\000\000\000"
/* offset=15129 */ "DMISS_OFF_NODE_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_OFF_NODE / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a distant chip (cache, L4, memory or OpenCAPI chip)\000\000\000\000\000"
/* offset=15372 */ "DTLB_MISS_RATE\000Others\000\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000Percentage of completed instructions when the DPTEG required for the load/store instruction in execution was missing from the TLB\000\0001%\000\000\000"
/* offset=15569 */ "EXCEPTION_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_EXCEPTION / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction cannot complete because it was interrupted by ANY exception\000\000\000\000\000"
/* offset=15778 */ "EXECUTION_STALL_CPI\000CPI;CPI_STALL_RATIO\000\000PM_EXEC_STALL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting to be finished in one of the execution units\000\000\000\000\000"
/* offset=15978 */ "EXEC_STALL_UNKOWN_CPI\000General\000\000PM_EXEC_STALL_UNKNOWN / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTF instruction is completing and the finish was overlooked\000\000\000\000\000"
/* offset=16164 */ "FIN_AT_DISP_STALL_CPI\000CPI\000\000PM_EXEC_STALL_FIN_AT_DISP / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTF instruction finishes at dispatch\000\000\000\000\000"
/* offset=16327 */ "FLUSH_RATE\000Others\000\000PM_FLUSH / PM_RUN_INST_CMPL * 100\000Percentage of flushes per completed instruction\000\0001%\000\000\000"
/* offset=16434 */ "FX_PER_INST\000General\000\000PM_FX_LSU_FIN / PM_RUN_INST_CMPL\000Average number of simple fixed-point instructions finshed in the store unit per completed instruction\000\000\000\000\000"
/* offset=16594 */ "Frontend_Bound_SMT\000\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000"
/* offset=16757 */ "GROUP_PUMP_RETRY_RATIO_P01\000\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PB_GROUP_PUMP01\\,chip\\=?@ * 100\000\000\0001%\000\0001\000"
/* offset=16880 */ "GROUP_PUMP_RETRY_RATIO_P23\000\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PB_GROUP_PUMP23\\,chip\\=?@ * 100\000\000\0001%\000\0001\000"
/* offset=17003 */ "HWSYNC_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_HWSYNC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a HWSYNC instruction stuck at finish waiting for a response from the L2\000\000\000\000\000"
/* offset=17221 */ "INST_FIN_PER_CMPL\000General\000\000PM_INST_FIN / PM_RUN_INST_CMPL\000Average number of finished instructions per completed instructions\000\000\000\000\000"
/* offset=17350 */ "INST_FROM_L3_MISS\000Instruction_Misses\000\000PM_INST_FROM_L3MISS / PM_L1_ICACHE_MISS * 100\000Percentage of icache misses that were reloaded from beyond the local L3\000\0001%\000\000\000"
/* offset=17512 */ "INST_FROM_L3_MISS_RATE\000Instruction_Misses\000\000PM_INST_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000Percentage of icache reloads from the beyond the L3 per completed instruction\000\0001%\000\000\000"
/* offset=17684 */ "IPC\000General\000\000PM_INST_CMPL / PM_CYC\000Average number of completed instructions per cycle\000\000\000\000\000"
/* offset=17774 */ "IPC\000group1\000\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000"
/* offset=17834 */ "ISSUE_STALL_CPI\000CPI;CPI_STALL_RATIO\000\000PM_ISSUE_STALL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction has been dispatched but not issued for any reason\000\000\000\000\000"
/* offset=18025 */ "L1D_Cache_Fill_BW\000\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000"
/* offset=18093 */ "L1_INST_MISS_RATE\000Instruction_Misses\000\000PM_L1_ICACHE_MISS / PM_RUN_INST_CMPL * 100\000Percentage of completed instructions that were demand fetches that missed the L1 icache\000\0001%\000\000\000"
/* offset=18268 */ "L1_LD_MISS_RATE\000Others\000\000PM_LD_MISS_L1 / PM_RUN_INST_CMPL * 100\000Percentage of completed instructions that were loads that missed the L1\000\0001%\000\000\000"
/* offset=18409 */ "L1_LD_MISS_RATIO\000Others\000\000PM_LD_MISS_L1 / PM_LD_REF_L1 * 100\000Percentage of finished loads that missed in the L1\000\0001%\000\000\000"
/* offset=18526 */ "L2_LD_MISS_RATE\000General\000\000DL1_RELOAD_FROM_L2_MISS_RATE\000Percentage of completed instructions that were a demand load that did not hit in the L1 or L2\000\0001%\000\000\000"
/* offset=18680 */ "L3_INST_MISS_RATE\000General\000\000INST_FROM_L3_MISS_RATE\000Percentage of completed instructions that were demand fetches that reloaded from beyond the L3 icache\000\0001%\000\000\000"
/* offset=18838 */ "L3_LD_MISS_RATE\000General\000\000PM_DATA_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000Percentage of completed instructions that were a demand load that did not hit in the L1, L2, or the L3\000\0001%\000\000\000"
/* offset=19017 */ "LARX_PER_INST\000General\000\000PM_LARX_FIN / PM_RUN_INST_CMPL\000Average number of LARX instructions finshed per completed instruction\000\000\000\000\000"
/* offset=19145 */ "LOADS_PER_INST\000General\000\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000Average number of finished loads per completed instruction\000\000\000\000\000"
/* offset=19264 */ "LOAD_FINISH_STALL_CPI\000CPI\000\000PM_EXEC_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is finishing a load after its data has been reloaded from a data source beyond the local L1, OR when the LSU is processing an L1-hit, OR when the NTF instruction merged with another load in the LMQ\000\000\000\000\000"
/* offset=19604 */ "LOAD_STALL_CPI\000CPI\000\000PM_EXEC_STALL_LOAD / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a load that is executing in the LSU\000\000\000\000\000"
/* offset=19771 */ "LOCAL_NODE_PUMP_RETRY_RATIO_P01\000\000\000hv_24x7@PM_PB_RTY_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PB_LNS_PUMP01\\,chip\\=?@ * 100\000\000\0001%\000\0001\000"
/* offset=19895 */ "LOCAL_NODE_PUMP_RETRY_RATIO_P23\000\000\000hv_24x7@PM_PB_RTY_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PB_LNS_PUMP23\\,chip\\=?@ * 100\000\000\0001%\000\0001\000"
/* offset=20019 */ "LSU_PER_INST\000General\000\000PM_LSU_FIN / PM_RUN_INST_CMPL\000Average number of instructions finished in the LSU per completed instruction\000\000\000\000\000"
/* offset=20152 */ "LSU_STALL_CPI\000CPI\000\000PM_EXEC_STALL_LSU / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing in the LSU\000\000\000\000\000"
/* offset=20302 */ "LWSYNC_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_LWSYNC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a LWSYNC instruction waiting to complete\000\000\000\000\000"
/* offset=20489 */ "M1\000\000\000ipc + M2\000\000\000\000\000\000"
/* offset=20508 */ "M2\000\000\000ipc + M1\000\000\000\000\000\000"
/* offset=20527 */ "M3\000\000\0001 / M3\000\000\000\000\000\000"
/* offset=20544 */ "MEM_ECC_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_MEM_ECC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is stuck at finish waiting for the non-speculative finish of either a STCX instruction waiting for its result or a load waiting for non-critical sectors of data and ECC\000\000\000\000\000"
/* offset=20858 */ "Memory-bandwidth-MCS\000memory-bandwidth\000\000nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT23@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT23@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT23@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000"
/* offset=21284 */ "Memory_RD_BW_Chip\000Memory_BW\000\000hv_24x7@PM_MCS01_128B_RD_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS01_128B_RD_DISP_PORT23\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_RD_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_RD_DISP_PORT23\\,chip\\=?@\000\000\0001.6e-2MB\000\0001\000"
/* offset=21521 */ "Memory_RD_BW_Chip\000Memory_BW\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000"
/* offset=21795 */ "Memory_WR_BW_Chip\000Memory_BW\000\000hv_24x7@PM_MCS01_128B_WR_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS01_128B_WR_DISP_PORT23\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_WR_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_WR_DISP_PORT23\\,chip\\=?@\000\000\0001.6e-2MB\000\0001\000"
/* offset=22032 */ "Memory_WR_BW_Chip\000Memory_BW\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000"
/* offset=22301 */ "NTC_FLUSH_STALL_CPI\000CPI\000\000PM_EXEC_STALL_NTC_FLUSH / PM_RUN_INST_CMPL\000Average cycles per completed instruction spent executing an NTC instruction that gets flushed some time after dispatch\000\000\000\000\000"
/* offset=22492 */ "PTESYNC_PER_INST\000General\000\000PM_PTESYNC_FIN / PM_RUN_INST_CMPL\000Average number of PTESYNC instructions finshed per completed instruction\000\000\000\000\000"
/* offset=22629 */ "PTESYNC_STALL_CPI\000CPI\000\000PM_EXEC_STALL_PTESYNC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing a PTESYNC instruction\000\000\000\000\000"
/* offset=22798 */ "PowerBUS_Frequency\000\000\000hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0002.56e-7GHz\000\0001\000"
/* offset=22864 */ "PowerBUS_Frequency\000\000\000hv_24x7@PM_PB_CYC\\,chip\\=?@\000\000\0002.5e-7GHz\000\0001\000"
/* offset=22928 */ "REMOTE_NODE_PUMPS_RETRIES_RATIO_P01\000\000\000hv_24x7@PM_PB_RTY_RNS_PUMP01\\,chip\\=?@ / (1 + hv_24x7@PM_PB_RNS_PUMP01\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=23062 */ "REMOTE_NODE_PUMPS_RETRIES_RATIO_P23\000\000\000hv_24x7@PM_PB_RTY_RNS_PUMP23\\,chip\\=?@ / (1 + hv_24x7@PM_PB_RNS_PUMP23\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=23196 */ "RUN_CPI\000General\000\000PM_RUN_CYC / PM_RUN_INST_CMPL\000Average number of run cycles per completed instruction\000\000\000\000\000"
/* offset=23302 */ "RUN_CYCLES_RATE\000General\000\000PM_RUN_CYC / PM_CYC * 100\000Percentage of cycles that are run cycles\000\0001%\000\000\000"
/* offset=23400 */ "RUN_IPC\000General\000\000PM_RUN_INST_CMPL / PM_RUN_CYC\000Average number of completed instructions per run cycle\000\000\000\000\000"
/* offset=23506 */ "SIMPLE_FX_STALL_CPI\000CPI\000\000PM_EXEC_STALL_SIMPLE_FX / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a simple fixed point instruction that is executing in the LSU\000\000\000\000\000"
/* offset=23709 */ "SPECIAL_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_SPECIAL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction required special handling before completion\000\000\000\000\000"
/* offset=23898 */ "STCX_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_STCX / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a STCX instruction waiting for resolution from the nest\000\000\000\000\000"
/* offset=24096 */ "STORES_PER_INST\000General\000\000PM_ST_FIN / PM_RUN_INST_CMPL\000Average number of finished stores per completed instruction\000\000\000\000\000"
/* offset=24214 */ "STORE_MISS_STALL_CPI\000CPI\000\000PM_EXEC_STALL_STORE_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a store whose cache line was not resident in the L1 and had to wait for allocation of the missing line into the L1\000\000\000\000\000"
/* offset=24472 */ "STORE_PIPE_STALL_CPI\000CPI\000\000PM_EXEC_STALL_STORE_PIPE / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is in the store unit outside of handling store misses or other special store operations\000\000\000\000\000"
/* offset=24700 */ "STORE_STALL_CPI\000CPI\000\000PM_EXEC_STALL_STORE / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a store that is executing in the LSU\000\000\000\000\000"
/* offset=24870 */ "STXC_PER_INST\000General\000\000PM_STCX_FIN / PM_RUN_INST_CMPL\000Average number of STCX instructions finshed per completed instruction\000\000\000\000\000"
/* offset=24998 */ "TAKEN_BRANCHES\000General\000\000PM_BR_TAKEN_CMPL / PM_BR_FIN * 100\000Percentage of finished branches that were taken\000\0001%\000\000\000"
/* offset=25111 */ "TLBIEL_STALL_CPI\000CPI\000\000PM_EXEC_STALL_TLBIEL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing a TLBIEL instruction\000\000\000\000\000"
/* offset=25277 */ "TLBIE_PER_INST\000General\000\000PM_TLBIE_FIN / PM_RUN_INST_CMPL\000Average number of TLBIE instructions finished in the LSU per completed instruction\000\000\000\000\000"
/* offset=25420 */ "TLBIE_STALL_CPI\000CPI\000\000PM_EXEC_STALL_TLBIE / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a TLBIE instruction waiting for a response from the L2\000\000\000\000\000"
/* offset=25608 */ "TOTAL_DATA_BANDWIDTH_TRANSFERRED_OVER_PB_PCI0\000\000\000hv_24x7@PM_PCI0_32B_INOUT\\,chip\\=?@\000\000\0003.28e-2MB\000\0001\000"
/* offset=25707 */ "TOTAL_DATA_BANDWIDTH_TRANSFERRED_OVER_PB_PCI1\000\000\000hv_24x7@PM_PCI1_32B_INOUT\\,chip\\=?@\000\000\0003.28e-2MB\000\0001\000"
/* offset=25806 */ "TOTAL_GROUP_PUMPS_P01\000\000\000hv_24x7@PM_PB_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=25905 */ "TOTAL_GROUP_PUMPS_P23\000\000\000hv_24x7@PM_PB_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=26004 */ "TOTAL_GROUP_PUMPS_RETRIES_P01\000\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=26115 */ "TOTAL_GROUP_PUMPS_RETRIES_P23\000\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=26226 */ "TOTAL_INT_PB_BW\000\000\000hv_24x7@PM_PB_INT_DATA_XFER\\,chip\\=?@\000\000\0002.09MB\000\0001\000"
/* offset=26294 */ "TOTAL_LOCAL_NODE_PUMPS_P01\000\000\000hv_24x7@PM_PB_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=26396 */ "TOTAL_LOCAL_NODE_PUMPS_P23\000\000\000hv_24x7@PM_PB_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=26498 */ "TOTAL_LOCAL_NODE_PUMPS_RETRIES_P01\000\000\000hv_24x7@PM_PB_RTY_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=26612 */ "TOTAL_LOCAL_NODE_PUMPS_RETRIES_P23\000\000\000hv_24x7@PM_PB_RTY_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=26726 */ "TOTAL_MCS_READ_BW_MC0_CHAN01\000\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000"
/* offset=26828 */ "TOTAL_MCS_READ_BW_MC1_CHAN01\000\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000"
/* offset=26930 */ "TOTAL_MCS_READ_BW_MC2_CHAN01\000\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000"
/* offset=27032 */ "TOTAL_MCS_READ_BW_MC3_CHAN01\000\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000"
/* offset=27134 */ "TOTAL_MCS_WRITE_BW_MC0_CHAN01\000\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000"
/* offset=27235 */ "TOTAL_MCS_WRITE_BW_MC1_CHAN01\000\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000"
/* offset=27336 */ "TOTAL_MCS_WRITE_BW_MC2_CHAN01\000\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000"
/* offset=27437 */ "TOTAL_MCS_WRITE_BW_MC3_CHAN01\000\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000"
/* offset=27538 */ "TOTAL_NEAR_NODE_PUMPS_P01\000\000\000hv_24x7@PM_PB_NNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=27639 */ "TOTAL_NEAR_NODE_PUMPS_P23\000\000\000hv_24x7@PM_PB_NNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=27740 */ "TOTAL_REMOTE_NODE_PUMPS_P01\000\000\000hv_24x7@PM_PB_RNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=27843 */ "TOTAL_REMOTE_NODE_PUMPS_P23\000\000\000hv_24x7@PM_PB_RNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=27946 */ "TOTAL_VECTOR_GROUP_PUMPS_P01\000\000\000hv_24x7@PM_PB_VG_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=28049 */ "TOTAL_VECTOR_GROUP_PUMPS_P23\000\000\000hv_24x7@PM_PB_VG_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=28152 */ "TOTAL_VECTOR_GROUP_PUMPS_RETRIES_P01\000\000\000hv_24x7@PM_PB_RTY_VG_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=28267 */ "TOTAL_VECTOR_GROUP_PUMPS_RETRIES_P23\000\000\000hv_24x7@PM_PB_RTY_VG_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000"
/* offset=28382 */ "TRANSLATION_STALL_CPI\000CPI\000\000PM_EXEC_STALL_TRANSLATION / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting to be finished in one of the execution units\000\000\000\000\000"
/* offset=28580 */ "VEC_GROUP_PUMP_RETRY_RATIO_P01\000\000\000hv_24x7@PM_PB_RTY_VG_PUMP01\\,chip\\=?@ / (1 + hv_24x7@PM_PB_VG_PUMP01\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=28707 */ "VEC_GROUP_PUMP_RETRY_RATIO_P23\000\000\000hv_24x7@PM_PB_RTY_VG_PUMP23\\,chip\\=?@ / (1 + hv_24x7@PM_PB_VG_PUMP23\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=28834 */ "VSU_PER_INST\000General\000\000PM_VSU_FIN / PM_RUN_INST_CMPL\000Average number of instructions finished in the VSU per completed instruction\000\000\000\000\000"
/* offset=28967 */ "VSU_STALL_CPI\000CPI\000\000PM_EXEC_STALL_VSU / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing in the VSU\000\000\000\000\000"
/* offset=29117 */ "XLINK0_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK0_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=29361 */ "XLINK0_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK0_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=29614 */ "XLINK1_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK1_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=29858 */ "XLINK1_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK1_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=30111 */ "XLINK2_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK2_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=30355 */ "XLINK2_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK2_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=30608 */ "XLINK3_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK3_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=30852 */ "XLINK3_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK3_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=31105 */ "XLINK4_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK4_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=31349 */ "XLINK4_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK4_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=31602 */ "XLINK5_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK5_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=31846 */ "XLINK5_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK5_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=32099 */ "XLINK6_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK6_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=32343 */ "XLINK6_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK6_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=32596 */ "XLINK7_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK7_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000"
/* offset=32840 */ "XLINK7_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK7_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000"
/* offset=33093 */ "any_centaur_ld_hit_ratio\000\000\000PM_DATA_FROM_MEMORY / PM_LD_REF_L1\000Fraction of hits on any Centaur (local, remote, or distant) on either L4 or DRAM per L1 load ref\000\000\000\000\000"
/* offset=33256 */ "any_pump_mpred_percent\000bus_stats\000\000PM_PUMP_MPRED * 100 / (PM_PUMP_CPRED + PM_PUMP_MPRED)\000Percent of chip+group+sys pumps that were incorrectly predicted\000\000\000\000\000"
/* offset=33412 */ "any_sync_stall_cpi\000\000\000PM_CMPLU_STALL_ANY_SYNC / PM_RUN_INST_CMPL\000ANY_SYNC_STALL_CPI\000\000\000\000\000"
/* offset=33499 */ "average_completed_instruction_set_size\000\000\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000Avg. more than 1 instructions completed\000\000\000\000\000"
/* offset=33617 */ "average_dl1miss_latency\000latency\000\000PM_MRK_LD_MISS_L1_CYC / PM_MRK_LD_MISS_L1\000average L1 miss latency using marked events\000\000\000\000\000"
/* offset=33740 */ "average_il1_miss_latency\000latency\000\000PM_IC_DEMAND_CYC / PM_IC_DEMAND_REQ\000Average icache miss latency\000\000\000\000\000"
/* offset=33842 */ "average_sync_cyc\000latency\000\000PM_LSU_SRQ_SYNC_CYC / PM_LSU_SRQ_SYNC\000average service time for SYNC\000\000\000\000\000"
/* offset=33940 */ "avg_lmq_life_time\000latency\000\000PM_LSU_LMQ_S0_VALID / PM_LSU_LMQ_S0_ALLOC\000Cycles LMQ slot0 was active on an average\000\000\000\000\000"
/* offset=34055 */ "avg_lrq_life_time_even\000latency\000\000PM_LSU_LRQ_S0_VALID / PM_LSU_LRQ_S0_ALLOC\000Average number of cycles LRQ stays active for one load.  Slot 0 is VALID ONLY FOR EVEN THREADS\000\000\000\000\000"
/* offset=34228 */ "avg_lrq_life_time_odd\000latency\000\000PM_LSU_LRQ_S43_VALID / PM_LSU_LRQ_S43_ALLOC\000Average number of cycles LRQ stays active for one load.  Slot 43 is valid ONLY FOR ODD THREADS\000\000\000\000\000"
/* offset=34402 */ "avg_srq_life_time_even\000latency\000\000PM_LSU_SRQ_S0_VALID / PM_LSU_SRQ_S0_ALLOC\000Average number of cycles SRQ stays active for one load.  Slot 0 is VALID ONLY FOR EVEN THREADS\000\000\000\000\000"
/* offset=34575 */ "avg_srq_life_time_odd\000latency\000\000PM_LSU_SRQ_S39_VALID / PM_LSU_SRQ_S39_ALLOC\000Average number of cycles SRQ stays active for one load.  Slot 39 is valid ONLY FOR ODD THREADS\000\000\000\000\000"
/* offset=34749 */ "avg_stores_gathered\000l2_stats\000\000PM_ST_CMPL / (PM_L2_ST / 2)\000Average number of stores that gather in the store buffer before being sent to an L2 RC machine\000\000\000\000\000"
/* offset=34906 */ "base_completion_cpi\000\000\000PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000Base Completion Cycles\000\000\000\000\000"
/* offset=34992 */ "bc_8_branch_ratio_percent\000branch_prediction\000\000PM_BR_BC_8_CONV / PM_BRU_FIN * 100\000% of finished branches that were treated as BC+8\000\000\000\000\000"
/* offset=35125 */ "bc_8_not_converted_branch_ratio_percent\000branch_prediction\000\000PM_BR_BC_8 / PM_BRU_FIN * 100\000% of finished branches that were pairable but not treated as BC+8\000\000\000\000\000"
/* offset=35284 */ "bkill_latency\000latency\000\000bkill_ratio_percent\000Marked background kill latency, measured in L2\000\000\000\000\000"
/* offset=35378 */ "bkill_ratio_percent\000\000\000PM_MRK_FAB_RSP_BKILL_CYC / PM_MRK_FAB_RSP_BKILL\000Marked background kill latency, measured in L2\000\000\000\000\000"
/* offset=35499 */ "bp_l1_btb_correct\000\000branch\000L1 BTB Correction\000event=0x8a\000\000\000\000\000\000\000"
/* offset=35560 */ "bp_l2_btb_correct\000\000branch\000L2 BTB Correction\000event=0x8b\000\000\000\000\000\000\000"
/* offset=35621 */ "br_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_CMPL / (PM_BR_PRED_BR0 + PM_BR_PRED_BR1) * 100\000Percent of mispredicted branches out of all predicted (correctly and incorrectly) branches that completed\000\000\000\000\000"
/* offset=35834 */ "br_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_CMPL / PM_BR_PRED * 100\000\000\000\000\000\000"
/* offset=35919 */ "br_mpred_flush_rate_percent\000general\000\000PM_FLUSH_BR_MPRED / PM_RUN_INST_CMPL * 100\000Branch Mispredict flushes per instruction\000\000\000\000\000"
/* offset=36045 */ "br_mpred_flush_rate_percent\000general\000\000PM_FLUSH_MPRED / PM_RUN_INST_CMPL * 100\000Branch Mispredict flushes per instruction\000\000\000\000\000"
/* offset=36168 */ "branch_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_CMPL / PM_RUN_INST_CMPL * 100\000% of Branch miss predictions per instruction\000\000\000\000\000"
/* offset=36309 */ "branches_per_inst\000\000\000PM_BRU_FIN / PM_RUN_INST_CMPL\000% Branches per instruction\000\000\000\000\000"
/* offset=36390 */ "branches_per_inst\000instruction_mix\000\000PM_BRU_FIN / PM_RUN_INST_CMPL\000% Branches per instruction\000\000\000\000\000"
/* offset=36486 */ "bru_cru_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_BRU_CRU / PM_RUN_INST_CMPL\000Cycles stalled due to CRU or BRU operations\000\000\000\000\000"
/* offset=36609 */ "bru_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_BRU / PM_RUN_INST_CMPL\000Completion stall due to a Branch Unit\000\000\000\000\000"
/* offset=36718 */ "bru_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_BRU / PM_RUN_INST_CMPL\000Cycles stalled due to ISU Branch Operations\000\000\000\000\000"
/* offset=36833 */ "cache_miss_cycles\000group1\000\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000"
/* offset=36901 */ "ccache_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_CCACHE / PM_RUN_INST_CMPL * 100\000Count cache branch misprediction per instruction\000\000\000\000\000"
/* offset=37048 */ "ccache_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_CCACHE / (PM_BR_PRED_CCACHE_BR0 + PM_BR_PRED_CCACHE_BR1) * 100\000Percent of count catch mispredictions out of all completed branches that required count cache predictionn\000\000\000\000\000"
/* offset=37281 */ "ccache_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_CCACHE / PM_BR_PRED_CCACHE * 100\000Count cache branch misprediction\000\000\000\000\000"
/* offset=37411 */ "chip_pump_cpred_percent\000bus_stats\000\000PM_CHIP_PUMP_CPRED * 100 / PM_L2_CHIP_PUMP\000Percent of chip pumps that were correctly predicted as chip pumps the first time\000\000\000\000\000"
/* offset=37574 */ "completion_cpi\000\000\000PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000Cycles in which at least one instruction completes in this thread\000\000\000\000\000"
/* offset=37698 */ "completion_cpi\000cpi_breakdown\000\000PM_GRP_CMPL / PM_RUN_INST_CMPL\000Cycles in which a Group Completed\000\000\000\000\000"
/* offset=37797 */ "coq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_COQ_FULL / PM_RUN_INST_CMPL\000Cycles stalled by CO queue full\000\000\000\000\000"
/* offset=37910 */ "cpi\000general\000\000PM_CYC / PM_INST_CMPL\000Cycles per instruction\000\000\000\000\000"
/* offset=37972 */ "cr_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_CR / PM_RUN_INST_CMPL * 100\000CR MisPredictions per Instruction\000\000\000\000\000"
/* offset=38096 */ "cru_stall_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_BRU_CRU - PM_CMPLU_STALL_BRU) / PM_RUN_INST_CMPL\000Cycles stalled due to CRU Operations\000\000\000\000\000"
/* offset=38231 */ "crypto_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_CRYPTO / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was routed to the crypto execution pipe and was waiting to finish\000\000\000\000\000"
/* offset=38415 */ "custom_secs\000\000\000PM_RUN_CYC\000cycles\000\000\000\000\000"
/* offset=38451 */ "cyc_grp_completed_percent\000general\000\000PM_GRP_CMPL / PM_CYC * 100\000Percentage Cycles a group completed\000\000\000\000\000"
/* offset=38553 */ "cyc_grp_dispatched_percent\000general\000\000PM_1PLUS_PPC_DISP / PM_CYC * 100\000Percentage Cycles a group dispatched\000\000\000\000\000"
/* offset=38663 */ "cyc_per_group\000general\000\000PM_CYC / PM_1PLUS_PPC_CMPL\000Cycles per group\000\000\000\000\000"
/* offset=38734 */ "cycles_atleast_one_inst_dispatched_percent\000\000\000PM_1PLUS_PPC_DISP / PM_CYC * 100\000Percentage Cycles at least one instruction dispatched\000\000\000\000\000"
/* offset=38870 */ "cycles_per_completed_instructions_set\000\000\000PM_CYC / PM_1PLUS_PPC_CMPL\000Cycles per instruction group\000\000\000\000\000"
/* offset=38970 */ "dcache_miss_cpi\000\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000"
/* offset=39031 */ "dcache_miss_cpi_percent\000estimated_dcache_miss_cpi\000\000lsu_stall_dcache_miss_cpi / run_cpi * 100\000dL1 miss portion of CPI\000\000\000\000\000"
/* offset=39152 */ "dcache_miss_stall_cpi\000cpi_breakdown\000\000lsu_stall_dcache_miss_cpi\000Finish stall because the NTF instruction was a load that missed the L1 and was waiting for the data to return from the nest\000\000\000\000\000"
/* offset=39343 */ "dclaim_latency\000latency\000\000PM_MRK_FAB_RSP_DCLAIM_CYC / PM_MRK_FAB_RSP_DCLAIM\000Marked dclaim latency, measured in L2\000\000\000\000\000"
/* offset=39459 */ "derat_16g_miss_rate_percent\000translation\000\000100 * PM_DERAT_MISS_16G / PM_RUN_INST_CMPL\000% DERAT miss ratio for 16G page per inst\000\000\000\000\000"
/* offset=39588 */ "derat_16g_miss_ratio\000translation\000\000PM_DERAT_MISS_16G / PM_LSU_DERAT_MISS\000DERAT miss ratio for 16G page\000\000\000\000\000"
/* offset=39694 */ "derat_16m_miss_rate_percent\000translation\000\000PM_DERAT_MISS_16M * 100 / PM_RUN_INST_CMPL\000% DERAT miss rate for 16M page per inst\000\000\000\000\000"
/* offset=39822 */ "derat_16m_miss_ratio\000translation\000\000PM_DERAT_MISS_16M / PM_LSU_DERAT_MISS\000DERAT miss ratio for 16M page\000\000\000\000\000"
/* offset=39928 */ "derat_4k_miss_rate_percent\000translation\000\000PM_DERAT_MISS_4K * 100 / PM_RUN_INST_CMPL\000% DERAT miss rate for 4K page per inst\000\000\000\000\000"
/* offset=40053 */ "derat_4k_miss_ratio\000translation\000\000PM_DERAT_MISS_4K / PM_LSU_DERAT_MISS\000DERAT miss ratio for 4K page\000\000\000\000\000"
/* offset=40156 */ "derat_64k_miss_rate_percent\000translation\000\000PM_DERAT_MISS_64K * 100 / PM_RUN_INST_CMPL\000% DERAT miss ratio for 64K page per inst\000\000\000\000\000"
/* offset=40285 */ "derat_64k_miss_ratio\000translation\000\000PM_DERAT_MISS_64K / PM_LSU_DERAT_MISS\000DERAT miss ratio for 64K page\000\000\000\000\000"
/* offset=40391 */ "derat_miss_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_LSU_DERAT_MISS * 100 / PM_RUN_INST_CMPL\000DERAT Miss Rate (per run  instruction)(%)\000\000\000\000\000"
/* offset=40535 */ "derat_miss_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_LSU_DERAT_MISS * 100 / PM_RUN_INST_CMPL\000DERAT Miss Rate (per run instruction)(%)\000\000\000\000\000"
/* offset=40678 */ "derat_miss_ratio\000translation\000\000PM_LSU_DERAT_MISS / PM_LSU_DERAT_MISS\000DERAT miss ratio\000\000\000\000\000"
/* offset=40767 */ "derat_miss_reload_percent\000pteg_reloads_percent_per_ref\000\000PM_DTLB_MISS * 100 / PM_LSU_DERAT_MISS\000% of DERAT misses that result in an ERAT reload\000\000\000\000\000"
/* offset=40914 */ "dflong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DFLONG / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a multi-cycle instruction issued to the Decimal Floating Point execution pipe and waiting to finish\000\000\000\000\000"
/* offset=41136 */ "dfu_other_stall_cpi\000cpi_breakdown\000\000dfu_stall_cpi - dflong_stall_cpi\000Stalls due to short latency decimal floating ops\000\000\000\000\000"
/* offset=41257 */ "dfu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DFU / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was issued to the Decimal Floating Point execution pipe and waiting to finish\000\000\000\000\000"
/* offset=41447 */ "disp_flush_rate_percent\000general\000\000PM_FLUSH_DISP / PM_RUN_INST_CMPL * 100\000GCT empty cycles\000\000\000\000\000"
/* offset=41540 */ "dispatch_blocked.any\000\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=0x9,period=200000,umask=0x20\000\000\000\000\000\000\000"
/* offset=41674 */ "distant_centaur_ld_hit_ratio\000\000\000(PM_DATA_FROM_DMEM + PM_DATA_FROM_DL4) / PM_LD_REF_L1\000Fraction of hits on a distant chip's Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000"
/* offset=41837 */ "dl1_miss_reloads_percent\000dl1_reloads_percent_per_ref\000\000PM_L1_DCACHE_RELOAD_VALID * 100 / PM_LD_MISS_L1\000% of DL1 misses that result in a cache reload\000\000\000\000\000"
/* offset=41989 */ "dl1_reload_from_dl2l3_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L2 or L3 (Modified)\000\000\000\000\000"
/* offset=42167 */ "dl1_reload_from_dl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000"
/* offset=42347 */ "dl1_reload_from_dl2l3_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L2 or L3 (Shared)\000\000\000\000\000"
/* offset=42523 */ "dl1_reload_from_dl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000"
/* offset=42701 */ "dl1_reload_from_dl4_percent\000\000\000PM_DATA_FROM_DL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L4\000\000\000\000\000"
/* offset=42823 */ "dl1_reload_from_dl4_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L4\000\000\000\000\000"
/* offset=42972 */ "dl1_reload_from_dl4_rate_percent\000\000\000PM_DATA_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L4 per Inst\000\000\000\000\000"
/* offset=43095 */ "dl1_reload_from_dl4_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L4 per Inst\000\000\000\000\000"
/* offset=43246 */ "dl1_reload_from_dmem_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant Memory\000\000\000\000\000"
/* offset=43401 */ "dl1_reload_from_dmem_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant Memory per Inst\000\000\000\000\000"
/* offset=43558 */ "dl1_reload_from_l21_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L21_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L2, other core\000\000\000\000\000"
/* offset=43723 */ "dl1_reload_from_l21_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000"
/* offset=43894 */ "dl1_reload_from_l21_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L21_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L2, other core\000\000\000\000\000"
/* offset=44059 */ "dl1_reload_from_l21_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000"
/* offset=44230 */ "dl1_reload_from_l2_lhs_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L2 with a Load-Hit-Store conflict\000\000\000\000\000"
/* offset=44431 */ "dl1_reload_from_l2_lhs_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST * 100 / PM_RUN_INST_CMPL\000Percentage of L2 load hits per instruction where the L2 experienced a Load-Hit-Store conflict\000\000\000\000\000"
/* offset=44658 */ "dl1_reload_from_l2_miss_percent\000\000\000PM_DATA_FROM_L2MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads that came from the L3 and beyond\000\000\000\000\000"
/* offset=44800 */ "dl1_reload_from_l2_miss_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads from sources beyond the local L2\000\000\000\000\000"
/* offset=44969 */ "dl1_reload_from_l2_miss_rate_percent\000dl1_reloads_percent_per_inst\000\000l2_ld_miss_rate_percent\000% of DL1 reloads from L2 per Inst\000\000\000\000\000"
/* offset=45098 */ "dl1_reload_from_l2_no_conflict_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2_NO_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L2 with no conflicts\000\000\000\000\000"
/* offset=45284 */ "dl1_reload_from_l2_no_conflict_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L2_NO_CONFLICT * 100 / PM_RUN_INST_CMPL\000Percentage of L2 load hits per instruction where the L2 did not experience a conflict\000\000\000\000\000"
/* offset=45501 */ "dl1_reload_from_l2_other_conflict_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L2 with some conflict other than Load-Hit-Store\000\000\000\000\000"
/* offset=45725 */ "dl1_reload_from_l2_other_conflict_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER * 100 / PM_RUN_INST_CMPL\000Percentage of L2 load hits per instruction where the L2 experienced some conflict other than Load-Hit-Store\000\000\000\000\000"
/* offset=45975 */ "dl1_reload_from_l2_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from L2\000\000\000\000\000"
/* offset=46110 */ "dl1_reload_from_l2_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L2 * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from L2 per Inst\000\000\000\000\000"
/* offset=46251 */ "dl1_reload_from_l31_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L31_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L3, other core\000\000\000\000\000"
/* offset=46416 */ "dl1_reload_from_l31_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3 M state, other core per Inst\000\000\000\000\000"
/* offset=46595 */ "dl1_reload_from_l31_rate_percent\000\000\000(PM_DATA_FROM_L31_MOD + PM_DATA_FROM_L31_SHR) * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000"
/* offset=46759 */ "dl1_reload_from_l31_rate_percent\000\000\000dl1_reload_from_l31_mod_rate_percent + dl1_reload_from_l31_shr_rate_percent\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000"
/* offset=46928 */ "dl1_reload_from_l31_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L31_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L3, other core\000\000\000\000\000"
/* offset=47093 */ "dl1_reload_from_l31_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3 S tate, other core per Inst\000\000\000\000\000"
/* offset=47271 */ "dl1_reload_from_l3_conflict_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3_DISP_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L3 where the load collided with a pending prefetch\000\000\000\000\000"
/* offset=47486 */ "dl1_reload_from_l3_conflict_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L3_DISP_CONFLICT * 100 / PM_RUN_INST_CMPL\000Percentage of L3 load hits per instruction where the load collided with a pending prefetch\000\000\000\000\000"
/* offset=47707 */ "dl1_reload_from_l3_mepf_percent\000\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L3 where the lines were brought into the L3 by a prefetch operation\000\000\000\000\000"
/* offset=47899 */ "dl1_reload_from_l3_mepf_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads that came from L3 and were brought into the L3 by a prefetch\000\000\000\000\000"
/* offset=48097 */ "dl1_reload_from_l3_mepf_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads that came from the L3 and were brought into the L3 by a prefetch, per instruction completed\000\000\000\000\000"
/* offset=48323 */ "dl1_reload_from_l3_mepf_rate_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000Percentage of L3 load hits per instruction where the line was brought into the L3 by a prefetch operation\000\000\000\000\000"
/* offset=48545 */ "dl1_reload_from_l3_miss_percent\000\000\000PM_DATA_FROM_L3MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads from beyond the local L3\000\000\000\000\000"
/* offset=48679 */ "dl1_reload_from_l3_miss_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads from sources beyond the local L3\000\000\000\000\000"
/* offset=48848 */ "dl1_reload_from_l3_miss_rate_percent\000dl1_reloads_percent_per_inst\000\000l3_ld_miss_rate_percent\000% of DL1 reloads from L3 per Inst\000\000\000\000\000"
/* offset=48977 */ "dl1_reload_from_l3_no_conflict_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3_NO_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L3 without conflicts\000\000\000\000\000"
/* offset=49163 */ "dl1_reload_from_l3_no_conflict_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L3_NO_CONFLICT * 100 / PM_RUN_INST_CMPL\000Percentage of L3 load hits per instruction where the L3 did not experience a conflict\000\000\000\000\000"
/* offset=49380 */ "dl1_reload_from_l3_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads from L3\000\000\000\000\000"
/* offset=49515 */ "dl1_reload_from_l3_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L3 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from L3 per Inst\000\000\000\000\000"
/* offset=49656 */ "dl1_reload_from_ll4_percent\000\000\000PM_DATA_FROM_LL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Local L4\000\000\000\000\000"
/* offset=49776 */ "dl1_reload_from_ll4_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_LL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Local L4\000\000\000\000\000"
/* offset=49923 */ "dl1_reload_from_ll4_rate_percent\000\000\000PM_DATA_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Local L4 per Inst\000\000\000\000\000"
/* offset=50044 */ "dl1_reload_from_ll4_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Local L4 per Inst\000\000\000\000\000"
/* offset=50193 */ "dl1_reload_from_lmem_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_LMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Local Memory\000\000\000\000\000"
/* offset=50346 */ "dl1_reload_from_lmem_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Local Memory per Inst\000\000\000\000\000"
/* offset=50501 */ "dl1_reload_from_rl2l3_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L2 or L3 (Modified)\000\000\000\000\000"
/* offset=50678 */ "dl1_reload_from_rl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000"
/* offset=50853 */ "dl1_reload_from_rl2l3_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L2 or L3 (Shared)\000\000\000\000\000"
/* offset=51028 */ "dl1_reload_from_rl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000"
/* offset=51203 */ "dl1_reload_from_rl4_percent\000\000\000PM_DATA_FROM_RL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L4\000\000\000\000\000"
/* offset=51324 */ "dl1_reload_from_rl4_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L4\000\000\000\000\000"
/* offset=51472 */ "dl1_reload_from_rl4_rate_percent\000\000\000PM_DATA_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000"
/* offset=51598 */ "dl1_reload_from_rl4_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000"
/* offset=51752 */ "dl1_reload_from_rmem_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote Memory\000\000\000\000\000"
/* offset=51906 */ "dl1_reload_from_rmem_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000"
/* offset=52062 */ "dl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL2L3_MOD * PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2l3 distant MOD miss rates with measured DL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=52333 */ "dl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL2L3_MOD / PM_RUN_INST_CMPL * dl2l3_mod_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2l3 distant MOD miss rates with measured DL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=52580 */ "dl2l3_mod_latency\000latency\000\000PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD\000Marked L2L3 remote Load latency\000\000\000\000\000"
/* offset=52703 */ "dl2l3_mod_ld_hit_ratio\000\000\000PM_DATA_FROM_DL2L3_MOD / PM_LD_REF_L1\000Fraction of hits of a line in the M (exclusive) state on the L2 or L3 of a core on a distant chip per L1 load ref\000\000\000\000\000"
/* offset=52884 */ "dl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL2L3_SHR * PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2l3 distant SHR miss rates with measured DL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=53155 */ "dl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL2L3_SHR / PM_RUN_INST_CMPL * dl2l3_shr_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2l3 distant SHR miss rates with measured DL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=53402 */ "dl2l3_shr_latency\000latency\000\000PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR\000Marked L2L3 distant Load latency\000\000\000\000\000"
/* offset=53526 */ "dl2l3_shr_ld_hit_ratio\000\000\000PM_DATA_FROM_DL2L3_SHR / PM_LD_REF_L1\000Fraction of hits of a line in the S state on the L2 or L3 of a core on a distant chip per L1 load ref\000\000\000\000\000"
/* offset=53695 */ "dl4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL4 * PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4 / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of distant L4 miss rates with measured DL4 latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=53929 */ "dl4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL4 / PM_RUN_INST_CMPL * dl4_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of distant L4 miss rates with measured DL4 latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=54145 */ "dl4_latency\000latency\000\000PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4\000Distant L4 average load latency\000\000\000\000\000"
/* offset=54250 */ "dl4_ld_hit_ratio\000\000\000PM_DATA_FROM_DL4 / PM_LD_REF_L1\000Fraction of hits on a distant Centaur's cache per L1 load ref\000\000\000\000\000"
/* offset=54367 */ "dmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DMEM * PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of distant memory miss rates with measured DMEM latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=54610 */ "dmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DMEM / PM_RUN_INST_CMPL * dmem_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of distant memory miss rates with measured DMEM latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=54834 */ "dmem_latency\000latency\000\000PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM\000Marked Dmem Load latency\000\000\000\000\000"
/* offset=54935 */ "dmem_ld_hit_ratio\000\000\000PM_DATA_FROM_DMEM / PM_LD_REF_L1\000Fraction of hits on a distant Centaur's DRAM per L1 load ref\000\000\000\000\000"
/* offset=55053 */ "dmiss_distant_stall_cpi\000cpi_breakdown\000\000dmiss_non_local_stall_cpi - dmiss_remote_stall_cpi\000Completion stall by Dcache miss which resolved off node memory/cache\000\000\000\000\000"
/* offset=55216 */ "dmiss_l21_l31_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000\000\000\000\000"
/* offset=55387 */ "dmiss_l2l3_conflict_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000\000\000\000\000"
/* offset=55571 */ "dmiss_l2l3_noconflict_stall_cpi\000cpi_breakdown\000\000dmiss_l2l3_stall_cpi - dmiss_l2l3_conflict_stall_cpi\000Completion stall due to cache miss that resolves in the L2 or L3 without conflict\000\000\000\000\000"
/* offset=55757 */ "dmiss_l2l3_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000Completion stall by Dcache miss which resolved in L2/L3\000\000\000\000\000"
/* offset=55898 */ "dmiss_l3miss_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000Completion stall due to cache miss resolving missed the L3\000\000\000\000\000"
/* offset=56046 */ "dmiss_lmem_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000Completion stall due to cache miss that resolves in local memory\000\000\000\000\000"
/* offset=56196 */ "dmiss_non_local_stall_cpi\000cpi_breakdown\000\000dmiss_l3miss_stall_cpi - dmiss_l21_l31_stall_cpi - dmiss_lmem_stall_cpi\000Completion stall by Dcache miss which resolved outside of local memory\000\000\000\000\000"
/* offset=56384 */ "dmiss_remote_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_REMOTE / PM_RUN_INST_CMPL\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000\000\000\000\000"
/* offset=56555 */ "dp_other_stall_cpi\000cpi_breakdown\000\000dp_stall_cpi - dplong_stall_cpi\000Stalls due to short latency double precision ops\000\000\000\000\000"
/* offset=56674 */ "dp_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DP / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a scalar instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000"
/* offset=56968 */ "dplong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DPLONG / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000"
/* offset=57282 */ "dpteg_from_l2_rate_percent\000\000\000PM_DPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000Rate of DERAT reloads from L2\000\000\000\000\000"
/* offset=57387 */ "dpteg_from_l3_rate_percent\000\000\000PM_DPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000Rate of DERAT reloads from L3\000\000\000\000\000"
/* offset=57492 */ "dslb_miss_rate_percent\000translation\000\000PM_DSLB_MISS * 100 / PM_RUN_INST_CMPL\000% DSLB_Miss_Rate per inst\000\000\000\000\000"
/* offset=57596 */ "dtlb_miss_rate_percent\000general\000\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000% DTLB miss rate per inst\000\000\000\000\000"
/* offset=57696 */ "eieio_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_EIEIO / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction is an EIEIO waiting for response from L2\000\000\000\000\000"
/* offset=57853 */ "eist_trans\000\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000,umask=0x0\000\000\000\000\000\000\000"
/* offset=57980 */ "emq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_EMQ_FULL / PM_RUN_INST_CMPL\000Finish stall because the next to finish instruction suffered an ERAT miss and the EMQ was full\000\000\000\000\000"
/* offset=58156 */ "emq_stall_cpi\000cpi_breakdown\000\000erat_miss_stall_cpi + emq_full_stall_cpi\000\000\000\000\000\000"
/* offset=58231 */ "erat_miss_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load or store that suffered a translation miss\000\000\000\000\000"
/* offset=58408 */ "erat_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_ERAT_MISS * 100 / PM_RUN_INST_CMPL\000ERAT miss reject ratio\000\000\000\000\000"
/* offset=58522 */ "erat_reject_ratio_percent\000lsu_rejects\000\000PM_LSU_REJECT_ERAT_MISS * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000ERAT miss reject ratio\000\000\000\000\000"
/* offset=58649 */ "estimated_dl1miss_latency\000latency\000\000PM_MRK_LD_MISS_L1_CYC / PM_MRK_LD_MISS_L1\000average L1 miss latency using marked events\000\000\000\000\000"
/* offset=58774 */ "event-hyphen\000uncore_cbox\000uncore\000UNC_CBO_HYPHEN. Unit: uncore_cbox \000event=0xe0,umask=0x00\000\000\000\000\000\000UNC_CBO_HYPHEN\000"
/* offset=58883 */ "event-two-hyph\000uncore_cbox\000uncore\000UNC_CBO_TWO_HYPH. Unit: uncore_cbox \000event=0xc0,umask=0x00\000\000\000\000\000\000UNC_CBO_TWO_HYPH\000"
/* offset=58998 */ "exception_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_EXCEPTION / PM_RUN_INST_CMPL\000Cycles in which the NTC instruction is not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000\000\000\000\000"
/* offset=59250 */ "exec_unit_other_stall_cpi\000cpi_breakdown\000\000exec_unit_stall_cpi - scalar_stall_cpi - vector_stall_cpi\000Completion stall due to execution units for other reasons\000\000\000\000\000"
/* offset=59411 */ "exec_unit_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_EXEC_UNIT / PM_RUN_INST_CMPL\000Completion stall due to execution units (FXU/VSU/CRU)\000\000\000\000\000"
/* offset=59548 */ "expansion_overhead_cpi\000\000\000completion_cpi - base_completion_cpi\000Overhead of expansion cycles\000\000\000\000\000"
/* offset=59643 */ "exposed_dl1miss_latency\000latency\000\000PM_MRK_LD_MISS_EXPOSED_CYC / PM_MRK_LD_MISS_EXPOSED\000estimated exposed miss latency for dL1 misses, ie load miss when we were NTC\000\000\000\000\000"
/* offset=59809 */ "finish_to_cmpl_cpi\000\000\000PM_NTC_ALL_FIN / PM_RUN_INST_CMPL\000Cycles in which the oldest instruction is finished and ready to complete for waiting to get through the completion pipe\000\000\000\000\000"
/* offset=59988 */ "fixed_in_lsu_per_inst\000\000\000PM_LSU_FX_FIN / PM_RUN_INST_CMPL\000Total Fixed point operations executded in the Load/Store Unit following a load/store operation\000\000\000\000\000"
/* offset=60144 */ "fixed_per_inst\000\000\000PM_FXU_FIN / PM_RUN_INST_CMPL\000Total Fixed point operations\000\000\000\000\000"
/* offset=60224 */ "fixed_per_inst\000instruction_mix\000\000(PM_FXU0_FIN + PM_FXU1_FIN) / PM_RUN_INST_CMPL\000Total Fixed point operations\000\000\000\000\000"
/* offset=60336 */ "flush_any_thread_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FLUSH_ANY_THREAD / PM_RUN_INST_CMPL\000Cycles in which the NTC instruction is not allowed to complete because any of the 4 threads in the same core suffered a flush, which blocks completion\000\000\000\000\000"
/* offset=60584 */ "flush_rate_percent\000general\000\000PM_FLUSH * 100 / PM_RUN_INST_CMPL\000Flush rate (%)\000\000\000\000\000"
/* offset=60665 */ "flush_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FLUSH / PM_RUN_INST_CMPL\000Cycles stalled by flushes\000\000\000\000\000"
/* offset=60766 */ "fxlong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000Completion stall due to a long latency scalar fixed point instruction (division, square root)\000\000\000\000\000"
/* offset=60937 */ "fxu0_balance\000instruction_mix\000\000PM_FXU0_FIN / (PM_FXU0_FIN + PM_FXU1_FIN)\000FXU0 balance\000\000\000\000\000"
/* offset=61026 */ "fxu0_fin\000instruction_mix\000\000PM_FXU0_FIN / PM_RUN_CYC\000Fraction of cycles that FXU0 is in use\000\000\000\000\000"
/* offset=61120 */ "fxu0_only_busy\000instruction_mix\000\000PM_FXU0_BUSY_FXU1_IDLE / PM_CYC\000FXU0 only Busy\000\000\000\000\000"
/* offset=61203 */ "fxu1_fin\000instruction_mix\000\000PM_FXU1_FIN / PM_RUN_CYC\000Fraction of cycles that FXU1 is in use\000\000\000\000\000"
/* offset=61297 */ "fxu1_only_busy\000instruction_mix\000\000PM_FXU1_BUSY_FXU0_IDLE / PM_CYC\000FXU1 only Busy\000\000\000\000\000"
/* offset=61380 */ "fxu_all_busy\000\000\000PM_FXU_BUSY / PM_CYC\000All FXU Busy\000\000\000\000\000"
/* offset=61433 */ "fxu_all_idle\000\000\000PM_FXU_IDLE / PM_CYC\000All FXU Idle\000\000\000\000\000"
/* offset=61486 */ "fxu_both_busy\000instruction_mix\000\000PM_FXU_BUSY / PM_CYC\000Both FXU Busy\000\000\000\000\000"
/* offset=61556 */ "fxu_both_idle\000instruction_mix\000\000PM_FXU_IDLE / PM_CYC\000Both FXU Idle\000\000\000\000\000"
/* offset=61626 */ "fxu_multi_cyc_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000Cycles stalled by FXU Multi-Cycle Instructions\000\000\000\000\000"
/* offset=61751 */ "fxu_other_stall_cpi\000cpi_breakdown\000\000fxu_stall_cpi - fxlong_stall_cpi\000Stalls due to short latency integer ops\000\000\000\000\000"
/* offset=61863 */ "fxu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL\000Cycles stalled by FXU\000\000\000\000\000"
/* offset=61956 */ "fxu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL\000Finish stall due to a scalar fixed point or CR instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000\000\000\000\000"
/* offset=62175 */ "fxu_stall_other_cpi\000cpi_breakdown\000\000fxu_stall_cpi - fxu_multi_cyc_cpi\000Other cycles stalled by FXU\000\000\000\000\000"
/* offset=62276 */ "gct_empty_br_mpred_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL\000Cycles GCT empty due to Branch Mispredicts\000\000\000\000\000"
/* offset=62403 */ "gct_empty_br_mpred_ic_miss_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000Cycles GCT empty due to Branch Mispredicts and Icache Misses\000\000\000\000\000"
/* offset=62563 */ "gct_empty_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_CYC / PM_RUN_INST_CMPL\000GCT empty cycles\000\000\000\000\000"
/* offset=62650 */ "gct_empty_disp_held_cpi\000cpi_breakdown\000\000(PM_GCT_NOSLOT_DISP_HELD_MAP + PM_GCT_NOSLOT_DISP_HELD_SRQ + PM_GCT_NOSLOT_DISP_HELD_ISSQ + PM_GCT_NOSLOT_DISP_HELD_OTHER) / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held\000\000\000\000\000"
/* offset=62876 */ "gct_empty_disp_held_issq_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held due to issue queue\000\000\000\000\000"
/* offset=63032 */ "gct_empty_disp_held_map_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_DISP_HELD_MAP / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held due to maps\000\000\000\000\000"
/* offset=63179 */ "gct_empty_disp_held_other_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_DISP_HELD_OTHER / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held due to syncs and other effects\000\000\000\000\000"
/* offset=63349 */ "gct_empty_disp_held_srq_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_DISP_HELD_SRQ / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held due to SRQ\000\000\000\000\000"
/* offset=63495 */ "gct_empty_ic_miss_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL\000Cycles stalled by GCT empty due to Icache misses\000\000\000\000\000"
/* offset=63626 */ "gct_empty_ic_miss_l2l3_cpi\000cpi_breakdown\000\000(PM_GCT_NOSLOT_IC_MISS - PM_GCT_NOSLOT_IC_L3MISS) / PM_RUN_INST_CMPL\000Cycles stalled by GCT empty due to Icache misses that resolve in the local L2 or L3\000\000\000\000\000"
/* offset=63825 */ "gct_empty_ic_miss_l3miss_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_IC_L3MISS / PM_RUN_INST_CMPL\000Cycles stalled by GCT empty due to Icache misses that resolve off-chip\000\000\000\000\000"
/* offset=63987 */ "gct_empty_other_cpi\000cpi_breakdown\000\000gct_empty_cpi - gct_empty_ic_miss_cpi - gct_empty_br_mpred_cpi - gct_empty_br_mpred_ic_miss_cpi - (gct_empty_disp_held_map_cpi + gct_empty_disp_held_srq_cpi + gct_empty_disp_held_issq_cpi + gct_empty_disp_held_other_cpi)\000Other GCT empty cycles\000\000\000\000\000"
/* offset=64270 */ "gct_empty_percent\000\000\000PM_GCT_NOSLOT_CYC / PM_RUN_CYC * 100\000GCT empty cycles\000\000\000\000\000"
/* offset=64348 */ "gct_util_11to14_slots_percent\000general\000\000PM_GCT_UTIL_11_14_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (11 to 14) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000"
/* offset=64545 */ "gct_util_15to17_slots_percent\000general\000\000PM_GCT_UTIL_15_17_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (15 to 17) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000"
/* offset=64742 */ "gct_util_18plus_slots_percent\000general\000\000PM_GCT_UTIL_18_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization 18+ as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000"
/* offset=64929 */ "gct_util_1to2_slots_percent\000general\000\000PM_GCT_UTIL_1_2_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (1 to 2) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000"
/* offset=65120 */ "gct_util_3to6_slots_percent\000general\000\000PM_GCT_UTIL_3_6_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (3 to 6) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000"
/* offset=65311 */ "gct_util_7to10_slots_percent\000general\000\000PM_GCT_UTIL_7_10_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (7 to 10) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000"
/* offset=65505 */ "group_pump_cpred_percent\000bus_stats\000\000PM_GRP_PUMP_CPRED * 100 / PM_L2_GROUP_PUMP\000Percent of group pumps that were correctly predicted as group pumps the first time\000\000\000\000\000"
/* offset=65671 */ "group_size\000general\000\000inst_per_group\000Avg. group size\000\000\000\000\000"
/* offset=65726 */ "hwsync_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_HWSYNC / PM_RUN_INST_CMPL\000Cycles stalled by heavyweight syncs\000\000\000\000\000"
/* offset=65839 */ "icache_miss_cycles\000\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000"
/* offset=65903 */ "icache_miss_reload\000instruction_stats_percent_per_ref\000\000(PM_L1_ICACHE_MISS - PM_IC_PREF_WRITE) / PM_L1_ICACHE_MISS\000Icache Fetchs per Icache Miss\000\000\000\000\000"
/* offset=66050 */ "icache_pref_percent\000instruction_stats_percent_per_ref\000\000PM_IC_PREF_WRITE * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads due to prefetch\000\000\000\000\000"
/* offset=66188 */ "ict_noslot_br_mpred_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to branch mispred\000\000\000\000\000"
/* offset=66346 */ "ict_noslot_br_mpred_icmiss_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to Icache Miss and branch mispred\000\000\000\000\000"
/* offset=66534 */ "ict_noslot_cyc_other_cpi\000cpi_breakdown\000\000nothing_dispatched_cpi - ict_noslot_ic_miss_cpi - ict_noslot_br_mpred_icmiss_cpi - ict_noslot_br_mpred_cpi - ict_noslot_disp_held_cpi\000Instruction Completion Table other stalls\000\000\000\000\000"
/* offset=66754 */ "ict_noslot_disp_held_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD / PM_RUN_INST_CMPL\000Cycles in which the NTC instruciton is held at dispatch for any reason\000\000\000\000\000"
/* offset=66912 */ "ict_noslot_disp_held_hb_full_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD_HB_FULL / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to dispatch holds because the History Buffer was full. Could be GPR/VSR/VMR/FPR/CR/XVF\000\000\000\000\000"
/* offset=67157 */ "ict_noslot_disp_held_issq_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to dispatch hold on this thread due to Issue q full, BRQ full, XVCF Full, Count cache, Link, Tar full\000\000\000\000\000"
/* offset=67411 */ "ict_noslot_disp_held_other_cpi\000cpi_breakdown\000\000ict_noslot_disp_held_cpi - ict_noslot_disp_held_hb_full_cpi - ict_noslot_disp_held_sync_cpi - ict_noslot_disp_held_tbegin_cpi - ict_noslot_disp_held_issq_cpi\000ICT_NOSLOT_DISP_HELD_OTHER_CPI\000\000\000\000\000"
/* offset=67650 */ "ict_noslot_disp_held_sync_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD_SYNC / PM_RUN_INST_CMPL\000Dispatch held due to a synchronizing instruction at dispatch\000\000\000\000\000"
/* offset=67808 */ "ict_noslot_disp_held_tbegin_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD_TBEGIN / PM_RUN_INST_CMPL\000the NTC instruction is being held at dispatch because it is a tbegin instruction and there is an older tbegin in the pipeline that must complete before the younger tbegin can dispatch\000\000\000\000\000"
/* offset=68093 */ "ict_noslot_ic_l2_cpi\000cpi_breakdown\000\000ict_noslot_ic_miss_cpi - ict_noslot_ic_l3_cpi - ict_noslot_ic_l3miss_cpi\000ICT_NOSLOT_IC_L2_CPI\000\000\000\000\000"
/* offset=68227 */ "ict_noslot_ic_l3_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_IC_L3 / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to icache misses that were sourced from the local L3\000\000\000\000\000"
/* offset=68414 */ "ict_noslot_ic_l3miss_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_IC_L3MISS / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to icache misses that were sourced from beyond the local L3. The source could be local/remote/distant memory or another core's cache\000\000\000\000\000"
/* offset=68689 */ "ict_noslot_ic_miss_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to Icache Miss\000\000\000\000\000"
/* offset=68842 */ "inst_from_dl2l3_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant L2 or L3 (Modified)\000\000\000\000\000"
/* offset=69011 */ "inst_from_dl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000"
/* offset=69195 */ "inst_from_dl2l3_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant L2 or L3 (Shared)\000\000\000\000\000"
/* offset=69362 */ "inst_from_dl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000"
/* offset=69544 */ "inst_from_dl4_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DL4 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant L4\000\000\000\000\000"
/* offset=69684 */ "inst_from_dl4_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant L4 per Inst\000\000\000\000\000"
/* offset=69839 */ "inst_from_dmem_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DMEM * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant Memory\000\000\000\000\000"
/* offset=69985 */ "inst_from_dmem_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant Memory per Inst\000\000\000\000\000"
/* offset=70146 */ "inst_from_l21_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L21_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L2, other core\000\000\000\000\000"
/* offset=70306 */ "inst_from_l21_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000"
/* offset=70481 */ "inst_from_l21_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L21_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L2, other core\000\000\000\000\000"
/* offset=70641 */ "inst_from_l21_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000"
/* offset=70816 */ "inst_from_l2_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L2 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from L2\000\000\000\000\000"
/* offset=70946 */ "inst_from_l2_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L2 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from L2 per Inst\000\000\000\000\000"
/* offset=71091 */ "inst_from_l31_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L31_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L3, other core\000\000\000\000\000"
/* offset=71251 */ "inst_from_l31_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L3, other core per Inst\000\000\000\000\000"
/* offset=71426 */ "inst_from_l31_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L31_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L3, other core\000\000\000\000\000"
/* offset=71586 */ "inst_from_l31_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L3 other core per Inst\000\000\000\000\000"
/* offset=71760 */ "inst_from_l3_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L3 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from L3\000\000\000\000\000"
/* offset=71890 */ "inst_from_l3_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L3 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from L3 per Inst\000\000\000\000\000"
/* offset=72035 */ "inst_from_ll4_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_LL4 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Local L4\000\000\000\000\000"
/* offset=72173 */ "inst_from_ll4_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Local L4 per Inst\000\000\000\000\000"
/* offset=72326 */ "inst_from_lmem_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_LMEM * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Local Memory\000\000\000\000\000"
/* offset=72470 */ "inst_from_lmem_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Local Memory per Inst\000\000\000\000\000"
/* offset=72629 */ "inst_from_rl2l3_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote L2 or L3 (Modified)\000\000\000\000\000"
/* offset=72797 */ "inst_from_rl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote L2 or L3 (Modified) per Inst\000\000\000\000\000"
/* offset=72980 */ "inst_from_rl2l3_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote L2 or L3 (Shared)\000\000\000\000\000"
/* offset=73146 */ "inst_from_rl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote L2 or L3 (Shared) per Inst\000\000\000\000\000"
/* offset=73327 */ "inst_from_rl4_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RL4 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote L4\000\000\000\000\000"
/* offset=73466 */ "inst_from_rl4_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote L4 per Inst\000\000\000\000\000"
/* offset=73620 */ "inst_from_rmem_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RMEM * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote Memory\000\000\000\000\000"
/* offset=73765 */ "inst_from_rmem_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote Memory per Inst\000\000\000\000\000"
/* offset=73925 */ "inst_per_group\000general\000\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000Instructions per group\000\000\000\000\000"
/* offset=74009 */ "ipc\000general\000\000PM_INST_CMPL / PM_CYC\000Instructions per cycles\000\000\000\000\000"
/* offset=74072 */ "ipteg_from_l2_rate_percent\000\000\000PM_IPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from L2\000\000\000\000\000"
/* offset=74177 */ "ipteg_from_l3_rate_percent\000\000\000PM_IPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from L3\000\000\000\000\000"
/* offset=74282 */ "ipteg_from_ll4_rate_percent\000\000\000PM_IPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from local memory\000\000\000\000\000"
/* offset=74399 */ "ipteg_from_lmem_rate_percent\000\000\000PM_IPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from local memory\000\000\000\000\000"
/* offset=74518 */ "islb_miss_rate_percent\000translation\000\000PM_ISLB_MISS * 100 / PM_RUN_INST_CMPL\000% ISLB miss rate per inst\000\000\000\000\000"
/* offset=74622 */ "issue_hold_cpi\000cpi_breakdown\000\000ntc_issue_held_darq_full_cpi + ntc_issue_held_arb_cpi + ntc_issue_held_other_cpi\000\000\000\000\000\000"
/* offset=74738 */ "itlb_miss_rate_percent\000general\000\000PM_ITLB_MISS / PM_RUN_INST_CMPL * 100\000% ITLB miss rate per inst\000\000\000\000\000"
/* offset=74838 */ "l1_inst_miss_rate_percent\000instruction_misses_percent_per_inst\000\000PM_L1_ICACHE_MISS * 100 / PM_RUN_INST_CMPL\000Instruction Cache Miss Rate (Per run Instruction)(%)\000\000\000\000\000"
/* offset=75001 */ "l1_ld_hit_ratio\000\000\000(PM_LD_REF_L1 - PM_LD_MISS_L1) / PM_LD_REF_L1\000Fraction of L1 hits per load ref\000\000\000\000\000"
/* offset=75102 */ "l1_ld_miss_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_LD_MISS_L1 * 100 / PM_RUN_INST_CMPL\000Percentage of L1 demand load misses per run instruction\000\000\000\000\000"
/* offset=75255 */ "l1_ld_miss_ratio\000\000\000PM_LD_MISS_L1 / PM_LD_REF_L1\000Fraction of L1 load misses per L1 load ref\000\000\000\000\000"
/* offset=75350 */ "l1_ld_miss_ratio_percent\000general\000\000PM_LD_MISS_L1 / PM_LD_REF_L1 * 100\000Percentage of L1 load misses per L1 load ref\000\000\000\000\000"
/* offset=75468 */ "l1_ld_miss_ratio_percent\000general\000\000l1_ld_miss_ratio * 100\000Percentage of L1 load misses per L1 load ref\000\000\000\000\000"
/* offset=75574 */ "l1_prefetch_rate_percent\000prefetch\000\000PM_L1_PREF / PM_RUN_INST_CMPL * 100\000L1 Prefetches issued by the prefetch machine per instruction (per thread)\000\000\000\000\000"
/* offset=75723 */ "l1_st_miss_rate_percent\000general\000\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000Percentage of L1 store misses per run instruction\000\000\000\000\000"
/* offset=75849 */ "l1_st_miss_rate_percent\000general\000\000l2_st_miss_rate_percent\000Percentage of L1 store misses per run instruction\000\000\000\000\000"
/* offset=75960 */ "l1_st_miss_ratio_percent\000general\000\000PM_ST_MISS_L1 / PM_ST_FIN * 100\000Percentage of L1 store misses per L1 store ref\000\000\000\000\000"
/* offset=76077 */ "l21_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L21_MOD * PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl21 MOD miss rates with measured L21 MOD latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=76329 */ "l21_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L21_MOD / PM_RUN_INST_CMPL * l21_mod_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl21 MOD miss rates with measured L21 MOD latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=76559 */ "l21_mod_latency\000latency\000\000PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD\000Average load latency for all marked demand loads that came from L2.1 in the M state\000\000\000\000\000"
/* offset=76728 */ "l21_mod_latency\000latency\000\000PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD\000Marked L21 Load latency\000\000\000\000\000"
/* offset=76837 */ "l21_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L21_SHR * PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl21 SHR miss rates with measured L21 SHR latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=77089 */ "l21_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L21_SHR / PM_RUN_INST_CMPL * l21_shr_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl21 SHR miss rates with measured L21 SHR latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=77319 */ "l21_shr_latency\000latency\000\000PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR\000Average load latency for all marked demand loads that came from L2.1 in the S state\000\000\000\000\000"
/* offset=77488 */ "l21_shr_latency\000latency\000\000PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR\000Marked L21 Load latency\000\000\000\000\000"
/* offset=77597 */ "l2_1_ld_hit_ratio\000\000\000(PM_DATA_FROM_L21_MOD + PM_DATA_FROM_L21_SHR) / PM_LD_REF_L1\000Fraction of hits on another core's L2 on the same chip per L1 load ref\000\000\000\000\000"
/* offset=77753 */ "l2_1_mod_ld_hit_ratio\000\000\000PM_DATA_FROM_L21_MOD / PM_LD_REF_L1\000Fraction of hits of a line in the M (exclusive) state on another core's L2 on the same chip per L1 load ref\000\000\000\000\000"
/* offset=77925 */ "l2_1_shr_ld_hit_ratio\000\000\000PM_DATA_FROM_L21_SHR / PM_LD_REF_L1\000Fraction of hits of a line in the S state on another core's L2 on the same chip per L1 load ref\000\000\000\000\000"
/* offset=78085 */ "l2_co_usage\000\000\000PM_CO_USAGE / PM_RUN_CYC * 16\000Average number of Castout machines used.  1 of 16 CO machines is sampled every L2 cycle\000\000\000\000\000"
/* offset=78221 */ "l2_co_usage\000\000\000PM_CO_USAGE / PM_RUN_CYC * 16\000Average number of Castout machines used. 1 of 16 CO machines is sampled every L2 cycle\000\000\000\000\000"
/* offset=78356 */ "l2_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L2 * PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2 / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2 miss rates with measured L2 latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=78578 */ "l2_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L2 / PM_RUN_INST_CMPL * l2_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2 miss rates with measured L2 latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=78783 */ "l2_dem_ld_disp_percent\000l2_stats\000\000PM_L1_DCACHE_RELOAD_VALID / (PM_L2_LD / 2) * 100\000Demand load misses as a % of L2 LD dispatches (per thread)\000\000\000\000\000"
/* offset=78928 */ "l2_disp_conflict_ldhitst_latency\000latency\000\000PM_MRK_DATA_FROM_L2_DISP_CONFLICT_LDHITST_CYC / PM_MRK_DATA_FROM_L2_DISP_CONFLICT_LDHITST\000Average load latency for all marked demand loads that came from the L2 and suffered a conflict at RC machine dispatch time due to load-hit-store\000\000\000\000\000"
/* offset=79209 */ "l2_disp_conflict_other_latency\000latency\000\000PM_MRK_DATA_FROM_L2_DISP_CONFLICT_OTHER_CYC / PM_MRK_DATA_FROM_L2_DISP_CONFLICT_OTHER\000Average load latency for all marked demand loads that came from the L2 and suffered a conflict at RC machine dispatch time NOT due load-hit-store\000\000\000\000\000"
/* offset=79485 */ "l2_inst_miss_rate_percent\000general\000\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000"
/* offset=79615 */ "l2_instr_commands_percent\000\000\000PM_ISIDE_DISP * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000Percent of instruction reads out of all L2 commands\000\000\000\000\000"
/* offset=79759 */ "l2_latency\000latency\000\000PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2\000Average load latency for all marked demand loads that came from the L2\000\000\000\000\000"
/* offset=79900 */ "l2_latency\000latency\000\000PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2\000Marked L2 Load latency\000\000\000\000\000"
/* offset=79993 */ "l2_ld_commands_percent\000\000\000PM_L2_LD * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000Percent of loads out of all L2 commands\000\000\000\000\000"
/* offset=80117 */ "l2_ld_hit_ratio\000\000\000PM_DATA_FROM_L2 / PM_LD_REF_L1\000Fraction of L2 load hits per L1 load ref\000\000\000\000\000"
/* offset=80211 */ "l2_ld_miss_rate_percent\000general\000\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 dmand  Load Miss Rate (per run instruction)(%)\000\000\000\000\000"
/* offset=80343 */ "l2_ld_miss_rate_percent\000general\000\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 dmand Load Miss Rate (per run instruction)(%)\000\000\000\000\000"
/* offset=80474 */ "l2_ld_miss_ratio\000\000\000PM_DATA_FROM_L2MISS / PM_LD_REF_L1\000Fraction of L2 load misses per L1 load ref\000\000\000\000\000"
/* offset=80575 */ "l2_lhs_ld_hit_ratio\000\000\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST / PM_LD_REF_L1\000Fraction of L2 load hits per L1 load ref where the L2 experienced a Load-Hit-Store conflict\000\000\000\000\000"
/* offset=80746 */ "l2_mepf_latency\000latency\000\000PM_MRK_DATA_FROM_L2_MEPF_CYC / PM_MRK_DATA_FROM_L2\000Average load latency for all marked demand loads that were satisfied by lines prefetched into the L3.  This information is forwarded from the L3\000\000\000\000\000"
/* offset=80971 */ "l2_no_conflict_latency\000latency\000\000PM_MRK_DATA_FROM_L2_NO_CONFLICT_CYC / PM_MRK_DATA_FROM_L2\000Average load latency for all marked demand loads that came from the L2 and suffered no conflicts\000\000\000\000\000"
/* offset=81162 */ "l2_no_conflict_ld_hit_ratio\000\000\000PM_DATA_FROM_L2_NO_CONFLICT / PM_LD_REF_L1\000Fraction of L2 load hits per L1 load ref where the L2 did not experience a conflict\000\000\000\000\000"
/* offset=81323 */ "l2_other_conflict_ld_hit_ratio\000\000\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER / PM_LD_REF_L1\000Fraction of L2 load hits per L1 load ref where the L2 experienced some conflict other than Load-Hit-Store\000\000\000\000\000"
/* offset=81517 */ "l2_pteg_miss_rate_percent\000general\000\000PM_DPTEG_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000"
/* offset=81645 */ "l2_rc_st_disp_fail_rate_percent\000\000\000l2_st_disp_fail_rate_percent\000Rate of L2 store dispatches that failed per core\000\000\000\000\000"
/* offset=81761 */ "l2_rc_usage\000\000\000PM_RC_USAGE / PM_RUN_CYC * 16\000Average number of Read/Claim machines used.  1 of 16 RC machines is sampled every L2 cycle\000\000\000\000\000"
/* offset=81900 */ "l2_rc_usage\000\000\000PM_RC_USAGE / PM_RUN_CYC * 16\000Average number of Read/Claim machines used. 1 of 16 RC machines is sampled every L2 cycle\000\000\000\000\000"
/* offset=82038 */ "l2_sn_usage\000\000\000PM_SN_USAGE / PM_RUN_CYC * 8\000Average number of Snoop machines used.  1 of 8 SN machines is sampled every L2 cycle\000\000\000\000\000"
/* offset=82170 */ "l2_sn_usage\000\000\000PM_SN_USAGE / PM_RUN_CYC * 8\000Average number of Snoop machines used. 1 of 8 SN machines is sampled every L2 cycle\000\000\000\000\000"
/* offset=82301 */ "l2_st_commands_percent\000\000\000PM_L2_ST * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000Percent of stores out of all L2 commands\000\000\000\000\000"
/* offset=82426 */ "l2_st_disp_fail_rate_percent\000\000\000100 * (PM_L2_RCST_DISP_FAIL_ADDR + PM_L2_RCST_DISP_FAIL_OTHER) / 2 / PM_RUN_INST_CMPL\000Rate of L2 store dispatches that failed per core\000\000\000\000\000"
/* offset=82596 */ "l2_st_disp_rate_percent\000\000\000100 * PM_L2_RCST_DISP / 2 / PM_RUN_INST_CMPL\000Rate of L2 dispatches per core\000\000\000\000\000"
/* offset=82702 */ "l2_st_miss_rate_percent\000general\000\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000Percentage of L2 store misses per run instruction\000\000\000\000\000"
/* offset=82828 */ "l2_st_miss_ratio_percent\000l2_stats\000\000PM_L2_ST_MISS / PM_L2_ST * 100\000L2  Store misses  as a % of total L2  Store dispatches (per thread)\000\000\000\000\000"
/* offset=82966 */ "l2_st_miss_ratio_percent\000l2_stats\000\000PM_L2_ST_MISS / PM_L2_ST * 100\000L2 Store misses as a % of total L2 Store dispatches (per thread)\000\000\000\000\000"
/* offset=83101 */ "l2_st_wr_util\000l2_stats\000\000PM_L2_ST_DISP / 2 * 4 / PM_RUN_CYC * 100\000L2 stores that require a cache write (4 pclks per disp attempt) % of pclks\000\000\000\000\000"
/* offset=83245 */ "l2_store_miss_ratio_percent\000l2_stats\000\000PM_L2_ST_MISS / (PM_L2_ST / 2)\000Percentage of L2 store misses per drained store.  A drained store may contain multiple individual stores if they target the same line\000\000\000\000\000"
/* offset=83452 */ "l2miss_latency\000latency\000\000PM_MRK_DATA_FROM_L2MISS_CYC / PM_MRK_DATA_FROM_L2MISS\000Average load latency for all marked demand loads that came from the L3 and beyond\000\000\000\000\000"
/* offset=83616 */ "l31_latency\000\000\000(PM_MRK_DATA_FROM_L31_SHR_CYC + PM_MRK_DATA_FROM_L31_MOD_CYC) / (PM_MRK_DATA_FROM_L31_SHR + PM_MRK_DATA_FROM_L31_MOD)\000Marked L31 Load latency\000\000\000\000\000"
/* offset=83776 */ "l31_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L31_MOD * PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl31 MOD miss rates with measured L31 MOD latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=84028 */ "l31_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L31_MOD / PM_RUN_INST_CMPL * l31_mod_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl31 MOD miss rates with measured L31 MOD latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=84258 */ "l31_mod_latency\000latency\000\000PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD\000Marked L31 Load latency\000\000\000\000\000"
/* offset=84367 */ "l31_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L31_SHR * PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl31 SHR miss rates with measured L31 SHR latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=84619 */ "l31_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L31_SHR / PM_RUN_INST_CMPL * l31_shr_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl31 SHR miss rates with measured L31 SHR latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=84849 */ "l31_shr_latency\000latency\000\000PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR\000Marked L31 Load latency\000\000\000\000\000"
/* offset=84958 */ "l3_1_ld_hit_ratio\000\000\000(PM_DATA_FROM_L31_MOD + PM_DATA_FROM_L31_SHR) / PM_LD_REF_L1\000Fraction of hits on another core's L3 on the same chip per L1 load ref\000\000\000\000\000"
/* offset=85114 */ "l3_1_mod_ld_hit_ratio\000\000\000PM_DATA_FROM_L31_MOD / PM_LD_REF_L1\000Fraction of hits of a line in the M (exclusive) state on another core's L3 on the same chip per L1 load ref\000\000\000\000\000"
/* offset=85286 */ "l3_1_shr_ld_hit_ratio\000\000\000PM_DATA_FROM_L31_SHR / PM_LD_REF_L1\000Fraction of hits of a line in the S state on another core's L3 on the same chip per L1 load ref\000\000\000\000\000"
/* offset=85446 */ "l3_cache_rd\000\000cache\000L3 cache access, read\000event=0x40\000\000\000\000\000\000Attributable Level 3 cache access, read\000"
/* offset=85543 */ "l3_conflict_ld_hit_ratio\000\000\000PM_DATA_FROM_L3_DISP_CONFLICT / PM_LD_REF_L1\000Fraction of L3 load hits per load ref where the demand load collided with a pending prefetch\000\000\000\000\000"
/* offset=85712 */ "l3_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L3 * PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3 / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl3 miss rates with measured L3 latency as a % of dcache miss cpi\000\000\000\000\000"
/* offset=85935 */ "l3_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L3 / PM_RUN_INST_CMPL * l3_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl3 miss rates with measured L3 latency as a % of dcache miss cpi\000\000\000\000\000"
/* offset=86141 */ "l3_inst_miss_rate_percent\000general\000\000PM_INST_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000L3 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000"
/* offset=86271 */ "l3_latency\000latency\000\000PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3\000Average load latency for all marked demand loads that came from the L3\000\000\000\000\000"
/* offset=86412 */ "l3_latency\000latency\000\000PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3\000Marked L3 Load latency\000\000\000\000\000"
/* offset=86505 */ "l3_ld_hit_ratio\000\000\000PM_DATA_FROM_L3 / PM_LD_REF_L1\000Fraction of L3 load hits per L1 load ref\000\000\000\000\000"
/* offset=86599 */ "l3_ld_miss_rate_percent\000general\000\000PM_DATA_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000L3 demand Load Miss Rate (per run instruction)(%)\000\000\000\000\000"
/* offset=86731 */ "l3_ld_miss_ratio\000\000\000PM_DATA_FROM_L3MISS / PM_LD_REF_L1\000Fraction of L3 load misses per L1 load ref\000\000\000\000\000"
/* offset=86832 */ "l3_no_conflict_latency\000latency\000\000PM_MRK_DATA_FROM_L3_NO_CONFLICT_CYC / PM_MRK_DATA_FROM_L2\000Average load latency for all marked demand loads that came from the L3 and suffered no conflicts\000\000\000\000\000"
/* offset=87023 */ "l3_no_conflict_ld_hit_ratio\000\000\000PM_DATA_FROM_L3_NO_CONFLICT / PM_LD_REF_L1\000Fraction of L3 load hits per load ref where the L3 did not experience a conflict\000\000\000\000\000"
/* offset=87181 */ "l3_pteg_miss_rate_percent\000general\000\000PM_DPTEG_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000L3 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000"
/* offset=87309 */ "l3miss_latency\000latency\000\000PM_MRK_DATA_FROM_L3MISS_CYC / PM_MRK_DATA_FROM_L3MISS\000Average load latency for all marked demand loads that come from beyond the L3\000\000\000\000\000"
/* offset=87469 */ "l3other_ld_hit_ratio\000\000\000(PM_DATA_FROM_L3 - PM_DATA_FROM_L3_MEPF) / PM_LD_REF_L1\000Fraction of L3 hits on lines that were not in the MEPF state per L1 load ref\000\000\000\000\000"
/* offset=87629 */ "l3pref_latency\000latency\000\000PM_MRK_DATA_FROM_L3_MEPF_CYC / PM_MRK_DATA_FROM_L3_MEPF\000Average latency for marked reloads that hit in the L3 on the MEPF state.  i.e. lines that were prefetched into the L3\000\000\000\000\000"
/* offset=87831 */ "l3pref_ld_hit_ratio\000\000\000PM_DATA_FROM_L3_MEPF / PM_LD_REF_L1\000Fraction of L3 hits on lines that were recently prefetched into the L3 (MEPF state) per L1 load ref\000\000\000\000\000"
/* offset=87993 */ "l4_locality\000memory\000\000PM_DATA_FROM_LL4 * 100 / (PM_DATA_FROM_LL4 + PM_DATA_FROM_RL4 + PM_DATA_FROM_DL4)\000L4 locality(%)\000\000\000\000\000"
/* offset=88114 */ "larx_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LARX / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a larx waiting to be satisfied\000\000\000\000\000"
/* offset=88263 */ "ld_ll4_per_ld_dmem\000memory\000\000PM_DATA_FROM_LL4 / PM_DATA_FROM_DL4\000Ratio of reloads from local L4 to distant L4\000\000\000\000\000"
/* offset=88375 */ "ld_ll4_per_ld_mem\000memory\000\000PM_DATA_FROM_LL4 / (PM_DATA_FROM_DL4 + PM_DATA_FROM_RL4)\000Ratio of reloads from local L4 to remote+distant L4\000\000\000\000\000"
/* offset=88514 */ "ld_ll4_per_ld_rl4\000memory\000\000PM_DATA_FROM_LL4 / PM_DATA_FROM_RL4\000Ratio of reloads from local L4 to remote L4\000\000\000\000\000"
/* offset=88624 */ "ld_lmem_per_ld_dmem\000memory\000\000PM_DATA_FROM_LMEM / PM_DATA_FROM_DMEM\000Number of loads from local memory per loads from distant memory\000\000\000\000\000"
/* offset=88758 */ "ld_lmem_per_ld_mem\000memory\000\000PM_DATA_FROM_LMEM / (PM_DATA_FROM_DMEM + PM_DATA_FROM_RMEM)\000Number of loads from local memory per loads from remote and distant memory\000\000\000\000\000"
/* offset=88924 */ "ld_lmem_per_ld_rmem\000memory\000\000PM_DATA_FROM_LMEM / PM_DATA_FROM_RMEM\000Number of loads from local memory per loads from remote memory\000\000\000\000\000"
/* offset=89057 */ "ld_rmem_per_ld_dmem\000memory\000\000PM_DATA_FROM_RMEM / PM_DATA_FROM_DMEM\000Number of loads from remote memory per loads from distant memory\000\000\000\000\000"
/* offset=89192 */ "lhs_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_LHS * 100 / PM_RUN_INST_CMPL\000LHS reject ratio\000\000\000\000\000"
/* offset=89293 */ "lhs_reject_ratio_percent\000lsu_rejects\000\000PM_LSU_REJECT_LHS * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000LHS reject ratio\000\000\000\000\000"
/* offset=89407 */ "lhs_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LHS / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load that hit on an older store and it was waiting for store data\000\000\000\000\000"
/* offset=89591 */ "ll4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_LL4 / PM_RUN_INST_CMPL * ll4_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of Local L4 miss rates with measured LL4 latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=89805 */ "ll4_latency\000latency\000\000PM_MRK_DATA_FROM_LL4_CYC / PM_MRK_DATA_FROM_LL4\000Local L4 average load latency\000\000\000\000\000"
/* offset=89908 */ "ll4_ld_hit_ratio\000\000\000PM_DATA_FROM_LL4 / PM_LD_REF_L1\000Fraction of hits on a local Centaur's cache per L1 load ref\000\000\000\000\000"
/* offset=90023 */ "lmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_LMEM * PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of Local memory miss rates with measured LMEM latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=90264 */ "lmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_LMEM / PM_RUN_INST_CMPL * lmem_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of Local memory miss rates with measured LMEM latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=90486 */ "lmem_latency\000latency\000\000PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM\000Marked Lmem Load latency\000\000\000\000\000"
/* offset=90587 */ "lmem_ld_hit_ratio\000\000\000PM_DATA_FROM_LMEM / PM_LD_REF_L1\000Fraction of hits on a local Centaur's DRAM per L1 load ref\000\000\000\000\000"
/* offset=90703 */ "lmq_full_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_RUN_INST_CMPL\000ERAT miss reject ratio\000\000\000\000\000"
/* offset=90820 */ "lmq_full_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_RUN_INST_CMPL\000LMQ full reject ratio\000\000\000\000\000"
/* offset=90936 */ "lmq_full_reject_ratio_percent\000lsu_rejects\000\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_LD_REF_L1\000ERAT miss reject ratio\000\000\000\000\000"
/* offset=91050 */ "lmq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LMQ_FULL / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load that missed in the L1 and the LMQ was unable to accept this load miss request because it was full\000\000\000\000\000"
/* offset=91281 */ "load_finish_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load instruction with all its dependencies satisfied just going through the LSU pipe to finish\000\000\000\000\000"
/* offset=91510 */ "loads_per_inst\000\000\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000PCT instruction loads\000\000\000\000\000"
/* offset=91585 */ "loads_per_inst\000instruction_mix\000\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000PCT instruction loads\000\000\000\000\000"
/* offset=91675 */ "local_centaur_ld_hit_ratio\000\000\000(PM_DATA_FROM_LMEM + PM_DATA_FROM_LL4) / PM_LD_REF_L1\000Fraction of hits on a local Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000"
/* offset=91827 */ "lrq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LRQ_FULL / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load that was held in LSAQ because the LRQ was full\000\000\000\000\000"
/* offset=92007 */ "lrq_other_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LRQ_OTHER / PM_RUN_INST_CMPL\000Finish stall due to LRQ miscellaneous reasons, lost arbitration to LMQ slot, bank collisions, set prediction cleanup, set prediction multihit and others\000\000\000\000\000"
/* offset=92243 */ "lrq_stall_cpi\000cpi_breakdown\000\000lmq_full_stall_cpi + st_fwd_stall_cpi + lhs_stall_cpi + lsu_mfspr_stall_cpi + larx_stall_cpi + lrq_other_stall_cpi\000\000\000\000\000\000"
/* offset=92392 */ "lsaq_arb_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSAQ_ARB / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load or store that was held in LSAQ because an older instruction from SRQ or LRQ won arbitration to the LSU pipe when this instruction tried to launch\000\000\000\000\000"
/* offset=92671 */ "lsaq_stall_cpi\000cpi_breakdown\000\000lrq_full_stall_cpi + srq_full_stall_cpi + lsaq_arb_stall_cpi\000\000\000\000\000\000"
/* offset=92767 */ "lstack_mispredict_rate_percent\000branch_prediction\000\000(PM_BR_MPRED_TA - PM_BR_MPRED_CCACHE) / PM_RUN_INST_CMPL * 100\000Link stack branch misprediction\000\000\000\000\000"
/* offset=92916 */ "lstack_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_LSTACK / PM_RUN_INST_CMPL * 100\000Link stack branch misprediction\000\000\000\000\000"
/* offset=93046 */ "lstack_misprediction_percent\000branch_prediction\000\000(PM_BR_MPRED_TA - PM_BR_MPRED_CCACHE) / (PM_BR_PRED_LSTACK_BR0 + PM_BR_PRED_LSTACK_BR1) * 100\000Percent of link stack mispredictions out of all completed branches that required link stack prediction\000\000\000\000\000"
/* offset=93295 */ "lstack_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_LSTACK / PM_BR_PRED_LSTACK * 100\000Link stack branch misprediction\000\000\000\000\000"
/* offset=93424 */ "lsu_fin_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU_FIN / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was an LSU op (other than a load or a store) with all its dependencies met and just going through the LSU pipe to finish\000\000\000\000\000"
/* offset=93665 */ "lsu_flush_next_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU_FLUSH_NEXT / PM_RUN_INST_CMPL\000Completion stall of one cycle because the LSU requested to flush the next iop in the sequence. It takes 1 cycle for the ISU to process this request before the LSU instruction is allowed to complete\000\000\000\000\000"
/* offset=93956 */ "lsu_mfspr_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU_MFSPR / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a mfspr instruction targeting an LSU SPR and it was waiting for the register data to be returned\000\000\000\000\000"
/* offset=94181 */ "lsu_other_stall_cpi\000cpi_breakdown\000\000lsu_stall_cpi - lsu_fin_stall_cpi - store_finish_stall_cpi - srq_stall_cpi - load_finish_stall_cpi + lsu_stall_dcache_miss_cpi - lrq_stall_cpi + emq_stall_cpi - lsaq_stall_cpi\000Completion LSU stall for other reasons\000\000\000\000\000"
/* offset=94435 */ "lsu_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT * 100 / PM_RUN_INST_CMPL\000LSU reject ratio\000\000\000\000\000"
/* offset=94532 */ "lsu_reject_ratio_percent\000lsu_rejects\000\000PM_LSU_REJECT * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000LSU reject ratio\000\000\000\000\000"
/* offset=94642 */ "lsu_stall_avg_cyc_per_l1hit_stfw\000\000\000(PM_CMPLU_STALL_LSU - PM_CMPLU_STALL_REJECT - PM_CMPLU_STALL_DCACHE_MISS - PM_CMPLU_STALL_STORE) / (PM_LD_REF_L1 - PM_LD_MISS_L1)\000Cycles stalled by Other LSU Operations\000\000\000\000\000"
/* offset=94850 */ "lsu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL\000Completion stall by LSU instruction\000\000\000\000\000"
/* offset=94957 */ "lsu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL\000Cycles stalled by LSU\000\000\000\000\000"
/* offset=95050 */ "lsu_stall_dcache_miss_cpi\000\000\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses\000\000\000\000\000"
/* offset=95161 */ "lsu_stall_dcache_miss_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses\000\000\000\000\000"
/* offset=95285 */ "lsu_stall_dcache_miss_distant_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_DMISS_L3MISS - PM_CMPLU_STALL_DMISS_LMEM - PM_CMPLU_STALL_DMISS_L21_L31 - PM_CMPLU_STALL_DMISS_REMOTE) / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in distant interventions and memory\000\000\000\000\000"
/* offset=95559 */ "lsu_stall_dcache_miss_l21l31_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in remote or distant caches\000\000\000\000\000"
/* offset=95734 */ "lsu_stall_dcache_miss_l2l3_conflict_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3, where there was a conflict\000\000\000\000\000"
/* offset=95944 */ "lsu_stall_dcache_miss_l2l3_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3\000\000\000\000\000"
/* offset=96108 */ "lsu_stall_dcache_miss_l2l3_noconflict_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_DMISS_L2L3 - PM_CMPLU_STALL_DMISS_L2L3_CONFLICT) / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3, where there was no conflict\000\000\000\000\000"
/* offset=96351 */ "lsu_stall_dcache_miss_l3miss_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in other core's caches or memory\000\000\000\000\000"
/* offset=96530 */ "lsu_stall_dcache_miss_lmem_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in local memory or local L4\000\000\000\000\000"
/* offset=96700 */ "lsu_stall_dcache_miss_remote_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_REMOTE / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in remote interventions and memory\000\000\000\000\000"
/* offset=96881 */ "lsu_stall_erat_miss_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL\000Cycles stalled by ERAT Translation rejects\000\000\000\000\000"
/* offset=97011 */ "lsu_stall_ld_fin_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000Cycles stalled by LSU load finishes\000\000\000\000\000"
/* offset=97133 */ "lsu_stall_lhs_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_REJECT_LHS / PM_RUN_INST_CMPL\000Cycles stalled by LHS rejects\000\000\000\000\000"
/* offset=97245 */ "lsu_stall_lmq_full_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_REJ_LMQ_FULL / PM_RUN_INST_CMPL\000Cycles stalled by LMQ Full rejects\000\000\000\000\000"
/* offset=97369 */ "lsu_stall_other_cpi\000cpi_breakdown\000\000lsu_stall_cpi - lsu_stall_dcache_miss_cpi - lsu_stall_reject_cpi - lsu_stall_store_cpi - lsu_stall_ld_fin_cpi - lsu_stall_st_fwd_cpi\000Cycles stalled by Other LSU Operations\000\000\000\000\000"
/* offset=97580 */ "lsu_stall_reject_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_REJECT / PM_RUN_INST_CMPL\000Cycles stalled by LSU Rejects\000\000\000\000\000"
/* offset=97691 */ "lsu_stall_reject_other_cpi\000cpi_breakdown\000\000lsu_stall_reject_cpi - lsu_stall_lhs_cpi - lsu_stall_erat_miss_cpi - lsu_stall_lmq_full_cpi\000Cycles stalled by Other LSU Rejects\000\000\000\000\000"
/* offset=97865 */ "lsu_stall_st_fwd_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000Cycles stalled by LSU store forwarding\000\000\000\000\000"
/* offset=97985 */ "lsu_stall_store_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE / PM_RUN_INST_CMPL\000Cycles stalled by LSU Stores\000\000\000\000\000"
/* offset=98093 */ "lwsync_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LWSYNC / PM_RUN_INST_CMPL\000Cycles stalled by lightweight syncs\000\000\000\000\000"
/* offset=98206 */ "mcs01-read\000memory-bandwidth\000\000nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000"
/* offset=98340 */ "mcs01-write\000memory-bandwidth\000\000nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000"
/* offset=98475 */ "mcs23-read\000memory-bandwidth\000\000nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000"
/* offset=98609 */ "mcs23-write\000memory-bandwidth\000\000nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000"
/* offset=98744 */ "mem_ecc_delay_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_MEM_ECC_DELAY / PM_RUN_INST_CMPL\000\000\000\000\000\000"
/* offset=98836 */ "mem_locality_percent\000memory\000\000(PM_DATA_FROM_LL4 + PM_DATA_FROM_LMEM) * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_LL4 + PM_DATA_FROM_RMEM + PM_DATA_FROM_RL4 + PM_DATA_FROM_DMEM + PM_DATA_FROM_DL4)\000Memory locality\000\000\000\000\000"
/* offset=99049 */ "mem_locality_percent\000memory\000\000PM_DATA_FROM_LMEM * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_RMEM + PM_DATA_FROM_DMEM)\000Memory locality\000\000\000\000\000"
/* offset=99184 */ "mtfpscr_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_MTFPSCR / PM_RUN_INST_CMPL\000Completion stall because the ISU is updating the register and notifying the Effective Address Table (EAT)\000\000\000\000\000"
/* offset=99369 */ "nested_tbegin_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NESTED_TBEGIN / PM_RUN_INST_CMPL\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tbegin. This is a short delay, and it includes ROT\000\000\000\000\000"
/* offset=99595 */ "nested_tend_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NESTED_TEND / PM_RUN_INST_CMPL\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tend and decrement the TEXASR nested level. This is a short delay\000\000\000\000\000"
/* offset=99832 */ "no_ntf_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NO_NTF / PM_RUN_INST_CMPL\000Cycles stalled by nops (nothing next to finish)\000\000\000\000\000"
/* offset=99957 */ "nothing_dispatched_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_CYC / PM_RUN_INST_CMPL\000Number of cycles the Instruction Completion Table has no itags assigned to this thread\000\000\000\000\000"
/* offset=100123 */ "ntc_disp_fin_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NTC_DISP_FIN / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was one that must finish at dispatch\000\000\000\000\000"
/* offset=100290 */ "ntc_fin_cpi\000cpi_breakdown\000\000PM_NTC_FIN / PM_RUN_INST_CMPL\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. This event is used to account for cycles in which work is being completed in the CPI stack\000\000\000\000\000"
/* offset=100513 */ "ntc_flush_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NTC_FLUSH / PM_RUN_INST_CMPL\000Completion stall due to ntc flush\000\000\000\000\000"
/* offset=100630 */ "ntc_issue_held_arb_cpi\000cpi_breakdown\000\000PM_NTC_ISSUE_HELD_ARB / PM_RUN_INST_CMPL\000The NTC instruction is being held at dispatch because it lost arbitration onto the issue pipe to another instruction (from the same thread or a different thread)\000\000\000\000\000"
/* offset=100875 */ "ntc_issue_held_darq_full_cpi\000cpi_breakdown\000\000PM_NTC_ISSUE_HELD_DARQ_FULL / PM_RUN_INST_CMPL\000The NTC instruction is being held at dispatch because there are no slots in the DARQ for it\000\000\000\000\000"
/* offset=101062 */ "ntc_issue_held_other_cpi\000cpi_breakdown\000\000PM_NTC_ISSUE_HELD_OTHER / PM_RUN_INST_CMPL\000The NTC instruction is being held at dispatch during regular pipeline cycles, or because the VSU is busy with multi-cycle instructions, or because of a write-back collision with VSU\000\000\000\000\000"
/* offset=101331 */ "ntcg_all_fin_cpi\000cpi_breakdown\000\000PM_NTCG_ALL_FIN / PM_RUN_INST_CMPL\000\000\000\000\000\000"
/* offset=101403 */ "ntcg_flush_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NTCG_FLUSH / PM_RUN_INST_CMPL\000\000\000\000\000\000"
/* offset=101483 */ "off_chip_cache_latency\000latency\000\000PM_MRK_DATA_FROM_OFF_CHIP_CACHE_CYC / PM_MRK_DATA_FROM_OFF_CHIP_CACHE\000Latency for marked reloads that hit in the L2 or L3 of any other core on a different chip\000\000\000\000\000"
/* offset=101679 */ "off_chip_cache_ld_hit_ratio\000\000\000PM_DATA_FROM_OFF_CHIP_CACHE / PM_LD_REF_L1\000Fraction of hits on another core's L2 or L3 on a different chip (remote or distant) per L1 load ref\000\000\000\000\000"
/* offset=101856 */ "on_chip_cache_latency\000latency\000\000PM_MRK_DATA_FROM_ON_CHIP_CACHE_CYC / PM_MRK_DATA_FROM_ON_CHIP_CACHE\000Latency for marked reloads that hit in the L2 or L3 of any other core on the same chip\000\000\000\000\000"
/* offset=102046 */ "on_chip_cache_ld_hit_ratio\000\000\000PM_DATA_FROM_ON_CHIP_CACHE / PM_LD_REF_L1\000Fraction of hits on another core's L2 or L3 on the same chip per L1 load ref\000\000\000\000\000"
/* offset=102198 */ "other_block_stall_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_THRD - PM_CMPLU_STALL_LWSYNC - PM_CMPLU_STALL_HWSYNC - PM_CMPLU_STALL_MEM_ECC_DELAY - PM_CMPLU_STALL_FLUSH - PM_CMPLU_STALL_COQ_FULL) / PM_RUN_INST_CMPL\000Other thread block stall cycles\000\000\000\000\000"
/* offset=102440 */ "other_cpi\000cpi_breakdown\000\000run_cpi - completion_cpi - thread_block_stall_cpi - stall_cpi - nothing_dispatched_cpi\000Cycles unaccounted for\000\000\000\000\000"
/* offset=102579 */ "other_cpi\000cpi_breakdown\000\000run_cpi - stall_cpi - gct_empty_cpi - ntcg_all_fin_cpi - thread_block_stall_cpi - completion_cpi\000Cycles unaccounted for\000\000\000\000\000"
/* offset=102728 */ "other_stall_cpi\000cpi_breakdown\000\000stall_cpi - bru_cru_stall_cpi - fxu_stall_cpi - vsu_stall_cpi - lsu_stall_cpi - ntcg_flush_cpi - no_ntf_stall_cpi\000Stall cycles unaccounted for\000\000\000\000\000"
/* offset=102906 */ "other_stall_cpi\000cpi_breakdown\000\000stall_cpi - ntc_disp_fin_stall_cpi - ntc_flush_stall_cpi - lsu_stall_cpi - exec_unit_stall_cpi - bru_stall_cpi\000Completion stall for other reasons\000\000\000\000\000"
/* offset=103087 */ "other_thread_cmpl_stall\000\000\000thread_block_stall_cpi - exception_stall_cpi - any_sync_stall_cpi - sync_pmu_int_stall_cpi - spec_finish_stall_cpi - flush_any_thread_stall_cpi - lsu_flush_next_stall_cpi - nested_tbegin_stall_cpi - nested_tend_stall_cpi - mtfpscr_stall_cpi\000Completion stall because a different thread was using the completion pipe\000\000\000\000\000"
/* offset=103432 */ "paste_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_PASTE / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a paste waiting for response from L2\000\000\000\000\000"
/* offset=103589 */ "pm_1flop_cmpl\000\000pmc\000One floating point instruction completed (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg)\000event=0x45050\000\000\000\000\000\000\000"
/* offset=103733 */ "pm_1flop_cmpl\000\000pmc\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation completed\000event=0x45050\000\000\000\000\000\000\000"
/* offset=103865 */ "pm_1lpar_cyc\000\000other\000Number of cycles in single lpar mode. All threads in the core are assigned to the same lpar\000event=0x1f05e\000\000\000\000\000\000\000"
/* offset=103997 */ "pm_1plus_ppc_cmpl\000\000frontend\0001 or more ppc insts finished\000event=0x100f2\000\000\000\000\000\000\000"
/* offset=104074 */ "pm_1plus_ppc_cmpl\000\000frontend\000Cycles in which at least one instruction is completed by this thread\000event=0x100f2\000\000\000\000\000\000\000"
/* offset=104191 */ "pm_1plus_ppc_cmpl\000\000pipeline\0001 or more ppc insts finished\000event=0x100f2\000\000\000\000\000\0001 or more ppc insts finished (completed)\000"
/* offset=104308 */ "pm_1plus_ppc_disp\000\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\000\000\000\000\000Cycles at least one Instr Dispatched. Could be a group with only microcode. Issue HW016521\000"
/* offset=104483 */ "pm_1plus_ppc_disp\000\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\000\000\000\000\000\000"
/* offset=104568 */ "pm_2flop_cmpl\000\000pipeline\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg \000event=0x4d052\000\000\000\000\000\000\000"
/* offset=104691 */ "pm_2flop_cmpl\000\000pipeline\000Double Precision vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg completed\000event=0x4d052\000\000\000\000\000\000\000"
/* offset=104836 */ "pm_2lpar_cyc\000\000other\000Cycles in 2-lpar mode. Threads 0-3 belong to Lpar0 and threads 4-7 belong to Lpar1\000event=0x2006e\000\000\000\000\000\000Number of cycles in 2 lpar mode\000"
/* offset=104990 */ "pm_4flop_cmpl\000\000pmc\0004 FLOP instruction completed\000event=0x45052\000\000\000\000\000\000\000"
/* offset=105058 */ "pm_4flop_cmpl\000\000pmc\000Four floating point instructions completed (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg)\000event=0x45052\000\000\000\000\000\000\000"
/* offset=105204 */ "pm_4lpar_cyc\000\000other\000Number of cycles in 4 LPAR mode. Threads 0-1 belong to lpar0, threads 2-3 belong to lpar1, threads 4-5 belong to lpar2, and threads 6-7 belong to lpar3\000event=0x4e05e\000\000\000\000\000\000\000"
/* offset=105396 */ "pm_8flop_cmpl\000\000pmc\0008 FLOP instruction completed\000event=0x4d054\000\000\000\000\000\000\000"
/* offset=105464 */ "pm_8flop_cmpl\000\000pmc\000Four Double Precision vector instructions completed\000event=0x4d054\000\000\000\000\000\000\000"
/* offset=105555 */ "pm_adjunct_cyc\000\000others\000Cycles in which the thread is in Adjunct state. MSR[S HV PR] bits = 011\000event=0x10066\000\000\000\000\000\000\000"
/* offset=105670 */ "pm_adjunct_inst_cmpl\000\000others\000PowerPC instructions that completed while the thread is in Adjunct state\000event=0x2e010\000\000\000\000\000\000\000"
/* offset=105792 */ "pm_all_chip_pump_cpred\000\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for all data types ( demand load,data,inst prefetch,inst fetch,xlate (I or d)\000"
/* offset=106161 */ "pm_all_grp_pump_cpred\000\000other\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x520050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=106534 */ "pm_all_grp_pump_mpred\000\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x620052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=106995 */ "pm_all_grp_pump_mpred_rty\000\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=107434 */ "pm_all_pump_cpred\000\000other\000Pump prediction correct. Counts across all types of pumps for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=107760 */ "pm_all_pump_mpred\000\000other\000Pump misprediction. Counts across all types of pumps for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x640052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=108076 */ "pm_all_sys_pump_cpred\000\000other\000Initial and Final Pump Scope was system pump for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x630050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=108416 */ "pm_all_sys_pump_mpred\000\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x630052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=108959 */ "pm_all_sys_pump_mpred_rty\000\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x640050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=109359 */ "pm_any_thrd_run_cyc\000\000other\000Cycles in which at least one thread has the run latch set\000event=0x100fa\000\000\000\000\000\000\000"
/* offset=109464 */ "pm_any_thrd_run_cyc\000\000pipeline\000One of threads in run_cycles\000event=0x100fa\000\000\000\000\000\000Any thread in run_cycles (was one thread in run_cycles)\000"
/* offset=109598 */ "pm_back_br_cmpl\000\000frontend\000Branch instruction completed with a target address less than current instruction address\000event=0x2505e\000\000\000\000\000\000\000"
/* offset=109733 */ "pm_back_br_cmpl\000\000other\000Branch instruction completed with a target address less than current instruction address\000event=0x2505e\000\000\000\000\000\000\000"
/* offset=109865 */ "pm_bank_conflict\000\000other\000Read blocked due to interleave conflict.  The ifar logic will detect an interleave conflict and kill the data that was read that cycle\000event=0x4880\000\000\000\000\000\000\000"
/* offset=110043 */ "pm_bank_conflict\000\000other\000Read blocked due to interleave conflict. The ifar logic will detect an interleave conflict and kill the data that was read that cycle\000event=0x4082\000\000\000\000\000\000\000"
/* offset=110220 */ "pm_bfu_busy\000\000other\000Cycles in which all 4 Binary Floating Point units are busy. The BFU is running at capacity\000event=0x3005c\000\000\000\000\000\000\000"
/* offset=110350 */ "pm_br_2path\000\000frontend\000two path branch\000event=0x20036\000\000\000\000\000\000\000"
/* offset=110408 */ "pm_br_2path\000\000pmc\000Branches that are not strongly biased\000event=0x20036\000\000\000\000\000\000\000"
/* offset=110483 */ "pm_br_bc_8\000\000other\000Pairable BC+8 branch that has not been converted to a Resolve Finished in the BRU pipeline\000event=0x5086\000\000\000\000\000\000\000"
/* offset=110611 */ "pm_br_bc_8_conv\000\000other\000Pairable BC+8 branch that was converted to a Resolve Finished in the BRU pipeline\000event=0x5084\000\000\000\000\000\000\000"
/* offset=110735 */ "pm_br_cmpl\000\000frontend\000Branch Instruction completed\000event=0x40060\000\000\000\000\000\000\000"
/* offset=110805 */ "pm_br_cmpl\000\000other\000Any Branch instruction completed\000event=0x4d05e\000\000\000\000\000\000\000"
/* offset=110876 */ "pm_br_cmpl\000\000others\000A branch completed. All branches are included\000event=0x4d05e\000\000\000\000\000\000\000"
/* offset=110961 */ "pm_br_corect_pred_taken_cmpl\000\000other\000Conditional Branch Completed in which the HW correctly predicted the direction as taken.  Counted at completion time\000event=0x489c\000\000\000\000\000\000\000"
/* offset=111133 */ "pm_br_fin\000\000pipeline\000A branch instruction finished. Includes predicted/mispredicted/unconditional\000event=0x10068\000\000\000\000\000\000\000"
/* offset=111250 */ "pm_br_mpred_ccache\000\000other\000Conditional Branch Completed that was Mispredicted due to the Count Cache Target Prediction\000event=0x40ac\000\000\000\000\000\000\000"
/* offset=111387 */ "pm_br_mpred_cmpl\000\000cache\000A mispredicted branch completed. Includes direction and target\000event=0x400f6\000\000\000\000\000\000\000"
/* offset=111494 */ "pm_br_mpred_cmpl\000\000cache\000Number of Branch Mispredicts\000event=0x400f6\000\000\000\000\000\000\000"
/* offset=111567 */ "pm_br_mpred_cmpl\000\000frontend\000Number of Branch Mispredicts\000event=0x400f6\000\000\000\000\000\000\000"
/* offset=111643 */ "pm_br_mpred_cr\000\000other\000Conditional Branch Completed that was Mispredicted due to the BHT Direction Prediction (taken/not taken)\000event=0x40b8\000\000\000\000\000\000\000"
/* offset=111789 */ "pm_br_mpred_lstack\000\000other\000Conditional Branch Completed that was Mispredicted due to the Link Stack Target Prediction\000event=0x40ae\000\000\000\000\000\000\000"
/* offset=111925 */ "pm_br_mpred_lstack\000\000other\000Conditional Branch Completed that was Mispredicted due to the Link Stack Target Prediction\000event=0x48ac\000\000\000\000\000\000\000"
/* offset=112061 */ "pm_br_mpred_pcache\000\000other\000Conditional Branch Completed that was Mispredicted due to pattern cache prediction\000event=0x48b0\000\000\000\000\000\000\000"
/* offset=112189 */ "pm_br_mpred_ta\000\000other\000Conditional Branch Completed that was Mispredicted due to the Target Address Prediction from the Count Cache or Link Stack. Only XL-form branches that resolved Taken set this event\000event=0x40ba\000\000\000\000\000\000\000"
/* offset=112411 */ "pm_br_mpred_taken_cr\000\000other\000A Conditional Branch that resolved to taken was mispredicted as not taken (due to the BHT Direction Prediction)\000event=0x40b8\000\000\000\000\000\000\000"
/* offset=112570 */ "pm_br_mpred_taken_ta\000\000other\000Conditional Branch Completed that was Mispredicted due to the Target Address Prediction from the Count Cache or Link Stack.  Only XL-form branches that resolved Taken set this event\000event=0x48b8\000\000\000\000\000\000\000"
/* offset=112799 */ "pm_br_mrk_2path\000\000other\000marked two path branch\000event=0x10138\000\000\000\000\000\000\000"
/* offset=112865 */ "pm_br_pred\000\000other\000Conditional Branch Executed in which the HW predicted the Direction or Target.  Includes taken and not taken and is counted at execution time\000event=0x409c\000\000\000\000\000\000\000"
/* offset=113044 */ "pm_br_pred_br0\000\000other\000Conditional Branch Completed on BR0 (1st branch in group) in which the HW predicted the Direction or Target\000event=0x409c\000\000\000\000\000\000\000"
/* offset=113193 */ "pm_br_pred_br1\000\000other\000Conditional Branch Completed on BR1 (2nd branch in group) in which the HW predicted the Direction or Target. Note: BR1 can only be used in Single Thread Mode. In all of the SMT modes, only one branch can complete, thus BR1 is unused\000event=0x409e\000\000\000\000\000\000\000"
/* offset=113467 */ "pm_br_pred_br_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) OR if_pc_br0_br_pred(1)\000event=0x489c\000\000\000\000\000\000IFU\000"
/* offset=113649 */ "pm_br_pred_ccache\000\000other\000Conditional Branch Completed that used the Count Cache for Target Prediction\000event=0x40a4\000\000\000\000\000\000\000"
/* offset=113770 */ "pm_br_pred_ccache_br0\000\000other\000Conditional Branch Completed on BR0 that used the Count Cache for Target Prediction\000event=0x40a4\000\000\000\000\000\000\000"
/* offset=113902 */ "pm_br_pred_ccache_br1\000\000other\000Conditional Branch Completed on BR1 that used the Count Cache for Target Prediction\000event=0x40a6\000\000\000\000\000\000\000"
/* offset=114034 */ "pm_br_pred_ccache_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) AND if_pc_br0_pred_type\000event=0x48a4\000\000\000\000\000\000IFU\000"
/* offset=114220 */ "pm_br_pred_cr_br0\000\000other\000Conditional Branch Completed on BR0 that had its direction predicted. I-form branches do not set this event. In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b0\000\000\000\000\000\000\000"
/* offset=114519 */ "pm_br_pred_cr_br1\000\000other\000Conditional Branch Completed on BR1 that had its direction predicted. I-form branches do not set this event. In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b2\000\000\000\000\000\000\000"
/* offset=114818 */ "pm_br_pred_cr_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(1)='1'\000event=0x48b0\000\000\000\000\000\000IFU\000"
/* offset=114980 */ "pm_br_pred_lstack\000\000other\000Conditional Branch Completed  that used the Link Stack for Target Prediction\000event=0x40a8\000\000\000\000\000\000\000"
/* offset=115101 */ "pm_br_pred_lstack_br0\000\000other\000Conditional Branch Completed on BR0 that used the Link Stack for Target Prediction\000event=0x40a8\000\000\000\000\000\000\000"
/* offset=115232 */ "pm_br_pred_lstack_br1\000\000other\000Conditional Branch Completed on BR1 that used the Link Stack for Target Prediction\000event=0x40aa\000\000\000\000\000\000\000"
/* offset=115363 */ "pm_br_pred_lstack_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) AND (not if_pc_br0_pred_type)\000event=0x48a8\000\000\000\000\000\000IFU\000"
/* offset=115555 */ "pm_br_pred_pcache\000\000other\000Conditional branch completed that used pattern cache prediction\000event=0x48a0\000\000\000\000\000\000\000"
/* offset=115663 */ "pm_br_pred_ta\000\000other\000Conditional Branch Completed that had its target address predicted. Only XL-form branches set this event.  This equal the sum of CCACHE, LSTACK, and PCACHE\000event=0x40b4\000\000\000\000\000\000\000"
/* offset=115859 */ "pm_br_pred_ta_br0\000\000other\000Conditional Branch Completed on BR0 that had its target address predicted. Only XL-form branches set this event\000event=0x40b4\000\000\000\000\000\000\000"
/* offset=116015 */ "pm_br_pred_ta_br1\000\000other\000Conditional Branch Completed on BR1 that had its target address predicted. Only XL-form branches set this event\000event=0x40b6\000\000\000\000\000\000\000"
/* offset=116171 */ "pm_br_pred_ta_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0)='1'\000event=0x48b4\000\000\000\000\000\000IFU\000"
/* offset=116333 */ "pm_br_pred_taken_cr\000\000other\000Conditional Branch that had its direction predicted. I-form branches do not set this event.  In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b0\000\000\000\000\000\000\000"
/* offset=116618 */ "pm_br_taken_cmpl\000\000frontend\000Branch Taken instruction completed\000event=0x200fa\000\000\000\000\000\000\000"
/* offset=116700 */ "pm_br_taken_cmpl\000\000frontend\000New event for Branch Taken\000event=0x200fa\000\000\000\000\000\000\000"
/* offset=116774 */ "pm_br_uncond\000\000other\000Unconditional Branch Completed. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was covenrted to a Resolve\000event=0x40a0\000\000\000\000\000\000\000"
/* offset=117030 */ "pm_br_uncond_br0\000\000other\000Unconditional Branch Completed on BR0. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was coverted to a Resolve\000event=0x40a0\000\000\000\000\000\000\000"
/* offset=117296 */ "pm_br_uncond_br1\000\000other\000Unconditional Branch Completed on BR1. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was coverted to a Resolve\000event=0x40a2\000\000\000\000\000\000\000"
/* offset=117562 */ "pm_br_uncond_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred=00 AND if_pc_br0_completed\000event=0x48a0\000\000\000\000\000\000IFU\000"
/* offset=117743 */ "pm_bru_fin\000\000frontend\000Branch Instruction Finished\000event=0x10068\000\000\000\000\000\000\000"
/* offset=117812 */ "pm_bru_fin\000\000pipeline\000Branch Instruction Finished\000event=0x10068\000\000\000\000\000\000\000"
/* offset=117881 */ "pm_btac_bad_result\000\000other\000BTAC thinks branch will be taken but it is either predicted not-taken by the BHT, or the target address is wrong (less common).  In both cases, a redirect will happen\000event=0x50b0\000\000\000\000\000\000\000"
/* offset=118093 */ "pm_btac_good_result\000\000other\000BTAC predicts a taken branch and the BHT agrees, and the target address is correct\000event=0x58b0\000\000\000\000\000\000\000"
/* offset=118222 */ "pm_castout_issued\000\000other\000Castouts issued\000event=0x3094\000\000\000\000\000\000\000"
/* offset=118282 */ "pm_castout_issued_gpr\000\000other\000Castouts issued GPR\000event=0x3096\000\000\000\000\000\000\000"
/* offset=118350 */ "pm_chip_pump_cpred\000\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for all data types ( demand load,data,inst prefetch,inst fetch,xlate (I or d)\000"
/* offset=118725 */ "pm_chip_pump_cpred\000\000pipeline\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10050\000\000\000\000\000\000\000"
/* offset=118926 */ "pm_clb_held\000\000other\000CLB (control logic block - indicates quadword fetch block) Hold: Any Reason\000event=0x208c\000\000\000\000\000\000\000"
/* offset=119040 */ "pm_clb_held\000\000other\000CLB Hold: Any Reason\000event=0x2090\000\000\000\000\000\000\000"
/* offset=119099 */ "pm_cmpl_stall\000\000pipeline\000Cycles in which the oldest instruction in the pipeline cannot complete because the thread was blocked for any reason\000event=0x4c018\000\000\000\000\000\000\000"
/* offset=119260 */ "pm_cmpl_stall_exception\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000event=0x3003a\000\000\000\000\000\000\000"
/* offset=119503 */ "pm_cmpl_stall_hwsync\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a hwsync waiting for response from L2 before completing\000event=0x4d01a\000\000\000\000\000\000\000"
/* offset=119669 */ "pm_cmpl_stall_lwsync\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a lwsync waiting to complete\000event=0x1e05a\000\000\000\000\000\000\000"
/* offset=119808 */ "pm_cmpl_stall_mem_ecc\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000event=0x30028\000\000\000\000\000\000\000"
/* offset=120057 */ "pm_cmpl_stall_special\000\000pipeline\000Cycles in which the oldest instruction in the pipeline required special handling before completing\000event=0x2c014\000\000\000\000\000\000\000"
/* offset=120208 */ "pm_cmpl_stall_stcx\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a stcx waiting for resolution from the nest before completing\000event=0x2d01c\000\000\000\000\000\000\000"
/* offset=120378 */ "pm_cmplu_stall\000\000pipeline\000Completion stall\000event=0x4000a\000\000\000\000\000\000\000"
/* offset=120440 */ "pm_cmplu_stall\000\000pipeline\000Nothing completed and ICT not empty\000event=0x1e054\000\000\000\000\000\000\000"
/* offset=120521 */ "pm_cmplu_stall_any_sync\000\000other\000Cycles in which the NTC sync instruction (isync, lwsync or hwsync) is not allowed to complete\000event=0x1e05a\000\000\000\000\000\000\000"
/* offset=120666 */ "pm_cmplu_stall_bru\000\000pipeline\000Completion stall due to a Branch Unit\000event=0x4d018\000\000\000\000\000\000\000"
/* offset=120753 */ "pm_cmplu_stall_bru\000\000pmc\000Completion stall due to a Branch Unit\000event=0x4d018\000\000\000\000\000\000\000"
/* offset=120835 */ "pm_cmplu_stall_bru_cru\000\000other\000Completion stall due to IFU\000event=0x2d018\000\000\000\000\000\000\000"
/* offset=120913 */ "pm_cmplu_stall_coq_full\000\000other\000Completion stall due to CO q full\000event=0x30026\000\000\000\000\000\000\000"
/* offset=120998 */ "pm_cmplu_stall_crypto\000\000pmc\000Finish stall because the NTF instruction was routed to the crypto execution pipe and was waiting to finish\000event=0x4c01e\000\000\000\000\000\000\000"
/* offset=121152 */ "pm_cmplu_stall_dcache_miss\000\000pipeline\000Completion stall by Dcache miss\000event=0x2c012\000\000\000\000\000\000\000"
/* offset=121241 */ "pm_cmplu_stall_dcache_miss\000\000pmc\000Finish stall because the NTF instruction was a load that missed the L1 and was waiting for the data to return from the nest\000event=0x2c012\000\000\000\000\000\000\000"
/* offset=121417 */ "pm_cmplu_stall_dflong\000\000pipeline\000Finish stall because the NTF instruction was a multi-cycle instruction issued to the Decimal Floating Point execution pipe and waiting to finish. Includes decimal floating point instructions + 128 bit binary floating point instructions. Qualified by multicycle\000event=0x1005a\000\000\000\000\000\000\000"
/* offset=121730 */ "pm_cmplu_stall_dfu\000\000pipeline\000Finish stall because the NTF instruction was issued to the Decimal Floating Point execution pipe and waiting to finish. Includes decimal floating point instructions + 128 bit binary floating point instructions. Not qualified by multicycle\000event=0x2d012\000\000\000\000\000\000\000"
/* offset=122018 */ "pm_cmplu_stall_dmiss_l21_l31\000\000pipeline\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000event=0x2c018\000\000\000\000\000\000\000"
/* offset=122157 */ "pm_cmplu_stall_dmiss_l2l3\000\000cache\000Completion stall by Dcache miss which resolved in L2/L3\000event=0x1003c\000\000\000\000\000\000\000"
/* offset=122266 */ "pm_cmplu_stall_dmiss_l2l3\000\000pipeline\000Completion stall by Dcache miss which resolved in L2/L3\000event=0x2c016\000\000\000\000\000\000\000"
/* offset=122378 */ "pm_cmplu_stall_dmiss_l2l3_conflict\000\000cache\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000event=0x4c016\000\000\000\000\000\000\000"
/* offset=122521 */ "pm_cmplu_stall_dmiss_l2l3_conflict\000\000pipeline\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000event=0x4c016\000\000\000\000\000\000Completion stall due to cache miss resolving in core's L2/L3 with a conflict\000"
/* offset=122743 */ "pm_cmplu_stall_dmiss_l3miss\000\000other\000Completion stall due to cache miss resolving missed the L3\000event=0x4c01a\000\000\000\000\000\000\000"
/* offset=122857 */ "pm_cmplu_stall_dmiss_l3miss\000\000pipeline\000Completion stall due to cache miss resolving missed the L3\000event=0x4c01a\000\000\000\000\000\000\000"
/* offset=122974 */ "pm_cmplu_stall_dmiss_lmem\000\000other\000Completion stall due to cache miss that resolves in local memory\000event=0x30038\000\000\000\000\000\000\000"
/* offset=123092 */ "pm_cmplu_stall_dmiss_lmem\000\000pipeline\000Completion stall due to cache miss that resolves in local memory\000event=0x4c018\000\000\000\000\000\000Completion stall due to cache miss resolving in core's Local Memory\000"
/* offset=123280 */ "pm_cmplu_stall_dmiss_remote\000\000marked\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000event=0x2c01c\000\000\000\000\000\000\000"
/* offset=123418 */ "pm_cmplu_stall_dmiss_remote\000\000pipeline\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000event=0x2c01c\000\000\000\000\000\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000"
/* offset=123637 */ "pm_cmplu_stall_dp\000\000marked\000Finish stall because the NTF instruction was a scalar instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Not qualified multicycle. Qualified by NOT vector\000event=0x1005c\000\000\000\000\000\000\000"
/* offset=123959 */ "pm_cmplu_stall_dplong\000\000pipeline\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Qualified by NOT vector AND multicycle\000event=0x3405c\000\000\000\000\000\000\000"
/* offset=124288 */ "pm_cmplu_stall_eieio\000\000marked\000Finish stall because the NTF instruction is an EIEIO waiting for response from L2\000event=0x4d01a\000\000\000\000\000\000\000"
/* offset=124419 */ "pm_cmplu_stall_emq_full\000\000pipeline\000Finish stall because the next to finish instruction suffered an ERAT miss and the EMQ was full\000event=0x30004\000\000\000\000\000\000\000"
/* offset=124568 */ "pm_cmplu_stall_erat_miss\000\000pipeline\000Completion stall due to LSU reject ERAT miss\000event=0x4c012\000\000\000\000\000\000\000"
/* offset=124668 */ "pm_cmplu_stall_erat_miss\000\000pipeline\000Finish stall because the NTF instruction was a load or store that suffered a translation miss\000event=0x4c012\000\000\000\000\000\000\000"
/* offset=124817 */ "pm_cmplu_stall_exception\000\000marked\000Cycles in which the NTC instruction is not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000event=0x3003a\000\000\000\000\000\000\000"
/* offset=125039 */ "pm_cmplu_stall_exec_unit\000\000other\000Completion stall due to execution units (FXU/VSU/CRU)\000event=0x2d018\000\000\000\000\000\000\000"
/* offset=125145 */ "pm_cmplu_stall_flush\000\000other\000completion stall due to flush by own thread\000event=0x30038\000\000\000\000\000\000\000"
/* offset=125237 */ "pm_cmplu_stall_flush_any_thread\000\000cache\000Cycles in which the NTC instruction is not allowed to complete because any of the 4 threads in the same core suffered a flush, which blocks completion\000event=0x1e056\000\000\000\000\000\000\000"
/* offset=125447 */ "pm_cmplu_stall_fxlong\000\000cache\000Completion stall due to a long latency scalar fixed point instruction (division, square root)\000event=0x4d016\000\000\000\000\000\000\000"
/* offset=125590 */ "pm_cmplu_stall_fxlong\000\000pipeline\000Completion stall due to a long latency fixed point instruction\000event=0x4d016\000\000\000\000\000\000\000"
/* offset=125705 */ "pm_cmplu_stall_fxu\000\000cache\000Finish stall due to a scalar fixed point or CR instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000event=0x2d016\000\000\000\000\000\000\000"
/* offset=125899 */ "pm_cmplu_stall_fxu\000\000pipeline\000Completion stall due to FXU\000event=0x2d016\000\000\000\000\000\000\000"
/* offset=125976 */ "pm_cmplu_stall_hwsync\000\000pipeline\000completion stall due to hwsync\000event=0x30036\000\000\000\000\000\000\000"
/* offset=126059 */ "pm_cmplu_stall_larx\000\000cache\000Finish stall because the NTF instruction was a larx waiting to be satisfied\000event=0x1002a\000\000\000\000\000\000\000"
/* offset=126182 */ "pm_cmplu_stall_lhs\000\000cache\000Finish stall because the NTF instruction was a load that hit on an older store and it was waiting for store data\000event=0x2c01a\000\000\000\000\000\000\000"
/* offset=126341 */ "pm_cmplu_stall_lmq_full\000\000cache\000Finish stall because the NTF instruction was a load that missed in the L1 and the LMQ was unable to accept this load miss request because it was full\000event=0x4c014\000\000\000\000\000\000\000"
/* offset=126542 */ "pm_cmplu_stall_load_finish\000\000cache\000Finish stall because the NTF instruction was a load instruction with all its dependencies satisfied just going through the LSU pipe to finish\000event=0x4d014\000\000\000\000\000\000\000"
/* offset=126738 */ "pm_cmplu_stall_load_finish\000\000pipeline\000Completion stall due to a Load finish\000event=0x4d014\000\000\000\000\000\000\000"
/* offset=126833 */ "pm_cmplu_stall_lrq_full\000\000other\000Finish stall because the NTF instruction was a load that was held in LSAQ (load-store address queue) because the LRQ (load-reorder queue) was full\000event=0x2d014\000\000\000\000\000\000\000"
/* offset=127031 */ "pm_cmplu_stall_lrq_other\000\000frontend\000Finish stall due to LRQ miscellaneous reasons, lost arbitration to LMQ slot, bank collisions, set prediction cleanup, set prediction multihit and others\000event=0x10004\000\000\000\000\000\000\000"
/* offset=127239 */ "pm_cmplu_stall_lsaq_arb\000\000frontend\000Finish stall because the NTF instruction was a load or store that was held in LSAQ because an older instruction from SRQ or LRQ won arbitration to the LSU pipe when this instruction tried to launch\000event=0x4e016\000\000\000\000\000\000\000"
/* offset=127491 */ "pm_cmplu_stall_lsu\000\000frontend\000Completion stall by LSU instruction\000event=0x2c010\000\000\000\000\000\000\000"
/* offset=127576 */ "pm_cmplu_stall_lsu\000\000pipeline\000Completion stall by LSU instruction\000event=0x2c010\000\000\000\000\000\000\000"
/* offset=127661 */ "pm_cmplu_stall_lsu_fin\000\000frontend\000Finish stall because the NTF instruction was an LSU op (other than a load or a store) with all its dependencies met and just going through the LSU pipe to finish\000event=0x1003a\000\000\000\000\000\000\000"
/* offset=127876 */ "pm_cmplu_stall_lsu_flush_next\000\000frontend\000Completion stall of one cycle because the LSU requested to flush the next iop in the sequence. It takes 1 cycle for the ISU to process this request before the LSU instruction is allowed to complete\000event=0x2e01a\000\000\000\000\000\000\000"
/* offset=128134 */ "pm_cmplu_stall_lsu_mfspr\000\000frontend\000Finish stall because the NTF instruction was a mfspr instruction targeting an LSU SPR and it was waiting for the register data to be returned\000event=0x34056\000\000\000\000\000\000\000"
/* offset=128331 */ "pm_cmplu_stall_lwsync\000\000pipeline\000completion stall due to isync/lwsync\000event=0x10036\000\000\000\000\000\000\000"
/* offset=128420 */ "pm_cmplu_stall_mem_ecc_delay\000\000other\000Completion stall due to mem ECC delay\000event=0x30028\000\000\000\000\000\000\000"
/* offset=128514 */ "pm_cmplu_stall_mtfpscr\000\000frontend\000Completion stall because the ISU is updating the register and notifying the Effective Address Table (EAT)\000event=0x4e012\000\000\000\000\000\000\000"
/* offset=128673 */ "pm_cmplu_stall_nested_tbegin\000\000other\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tbegin. This is a short delay, and it includes ROT\000event=0x1e05c\000\000\000\000\000\000\000"
/* offset=128864 */ "pm_cmplu_stall_nested_tend\000\000marked\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tend and decrement the TEXASR nested level. This is a short delay\000event=0x3003c\000\000\000\000\000\000\000"
/* offset=129069 */ "pm_cmplu_stall_no_ntf\000\000other\000Completion stall due to nop\000event=0x2e01c\000\000\000\000\000\000\000"
/* offset=129146 */ "pm_cmplu_stall_ntc_disp_fin\000\000marked\000Finish stall because the NTF instruction was one that must finish at dispatch\000event=0x4e018\000\000\000\000\000\000\000"
/* offset=129280 */ "pm_cmplu_stall_ntc_flush\000\000marked\000Completion stall due to ntc flush\000event=0x2e01e\000\000\000\000\000\000\000"
/* offset=129367 */ "pm_cmplu_stall_ntcg_flush\000\000other\000Completion stall due to ntcg flush\000event=0x2e01e\000\000\000\000\000\000Completion stall due to reject (load hit store)\000"
/* offset=129502 */ "pm_cmplu_stall_other_cmpl\000\000marked\000Instructions the core completed while this tread was stalled\000event=0x30006\000\000\000\000\000\000\000"
/* offset=129617 */ "pm_cmplu_stall_other_cmpl\000\000pipeline\000Instructions core completed while this tread was stalled\000event=0x30006\000\000\000\000\000\000Instructions core completed while this thread was stalled\000"
/* offset=129787 */ "pm_cmplu_stall_paste\000\000marked\000Finish stall because the NTF instruction was a paste waiting for response from L2\000event=0x2c016\000\000\000\000\000\000\000"
/* offset=129918 */ "pm_cmplu_stall_pm\000\000marked\000Finish stall because the NTF instruction was issued to the Permute execution pipe and waiting to finish. Includes permute and decimal fixed point instructions (128 bit BCD arithmetic) + a few 128 bit fixpoint add/subtract instructions with carry. Not qualified by vector or multicycle\000event=0x3000a\000\000\000\000\000\000\000"
/* offset=130249 */ "pm_cmplu_stall_rej_lmq_full\000\000other\000Completion stall due to LSU reject LMQ full\000event=0x4c014\000\000\000\000\000\000\000"
/* offset=130348 */ "pm_cmplu_stall_reject\000\000other\000Completion stall due to LSU reject\000event=0x4c010\000\000\000\000\000\000\000"
/* offset=130432 */ "pm_cmplu_stall_reject_lhs\000\000other\000Completion stall due to reject (load hit store)\000event=0x2c01a\000\000\000\000\000\000\000"
/* offset=130533 */ "pm_cmplu_stall_scalar\000\000other\000Completion stall due to VSU scalar instruction\000event=0x4d010\000\000\000\000\000\000\000"
/* offset=130629 */ "pm_cmplu_stall_scalar_long\000\000other\000Completion stall due to VSU scalar long latency instruction\000event=0x2d010\000\000\000\000\000\000\000"
/* offset=130743 */ "pm_cmplu_stall_slb\000\000marked\000Finish stall because the NTF instruction was awaiting L2 response for an SLB\000event=0x1e052\000\000\000\000\000\000\000"
/* offset=130867 */ "pm_cmplu_stall_spec_finish\000\000marked\000Finish stall while waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000event=0x30028\000\000\000\000\000\000\000"
/* offset=131079 */ "pm_cmplu_stall_srq_full\000\000other\000Finish stall because the NTF instruction was a store that was held in LSAQ because the SRQ was full\000event=0x30016\000\000\000\000\000\000\000"
/* offset=131230 */ "pm_cmplu_stall_st_fwd\000\000frontend\000Completion stall due to store forward\000event=0x4c01c\000\000\000\000\000\000\000"
/* offset=131320 */ "pm_cmplu_stall_st_fwd\000\000pipeline\000Completion stall due to store forward\000event=0x4c01c\000\000\000\000\000\000\000"
/* offset=131410 */ "pm_cmplu_stall_stcx\000\000frontend\000Finish stall because the NTF instruction was a stcx waiting for response from L2\000event=0x2d01c\000\000\000\000\000\000\000"
/* offset=131541 */ "pm_cmplu_stall_store\000\000other\000Completion stall by stores this includes store agen finishes in pipe LS0/LS1 and store data finishes in LS2/LS3\000event=0x2c014\000\000\000\000\000\000\000"
/* offset=131701 */ "pm_cmplu_stall_store_data\000\000frontend\000Finish stall because the next to finish instruction was a store waiting on data\000event=0x30026\000\000\000\000\000\000\000"
/* offset=131837 */ "pm_cmplu_stall_store_fin_arb\000\000frontend\000Finish stall because the NTF instruction was a store waiting for a slot in the store finish pipe. This means the instruction is ready to finish but there are instructions ahead of it, using the finish pipe\000event=0x30014\000\000\000\000\000\000\000"
/* offset=132102 */ "pm_cmplu_stall_store_finish\000\000frontend\000Finish stall because the NTF instruction was a store with all its dependencies met, just waiting to go through the LSU pipe to finish\000event=0x2c014\000\000\000\000\000\000\000"
/* offset=132294 */ "pm_cmplu_stall_store_pipe_arb\000\000frontend\000Finish stall because the NTF instruction was a store waiting for the next relaunch opportunity after an internal reject. This means the instruction is ready to relaunch and tried once but lost arbitration\000event=0x4c010\000\000\000\000\000\000\000"
/* offset=132559 */ "pm_cmplu_stall_sync_pmu_int\000\000frontend\000Cycles in which the NTC instruction is waiting for a synchronous PMU interrupt\000event=0x2c01e\000\000\000\000\000\000\000"
/* offset=132696 */ "pm_cmplu_stall_tend\000\000frontend\000Finish stall because the NTF instruction was a tend instruction awaiting response from L2\000event=0x1e050\000\000\000\000\000\000\000"
/* offset=132836 */ "pm_cmplu_stall_thrd\000\000other\000Completion Stalled because the thread was blocked\000event=0x1001c\000\000\000\000\000\000\000"
/* offset=132933 */ "pm_cmplu_stall_thrd\000\000pipeline\000Completion Stalled due to thread conflict. Group ready to complete but it was another thread's turn\000event=0x1001c\000\000\000\000\000\000Completion stall due to thread conflict\000"
/* offset=133122 */ "pm_cmplu_stall_tlbie\000\000translation\000Finish stall because the NTF instruction was a tlbie waiting for response from L2\000event=0x2e01c\000\000\000\000\000\000\000"
/* offset=133258 */ "pm_cmplu_stall_vdp\000\000translation\000Finish stall because the NTF instruction was a vector instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Not qualified multicycle. Qualified by vector\000event=0x4405c\000\000\000\000\000\000\000"
/* offset=133582 */ "pm_cmplu_stall_vdplong\000\000translation\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Qualified by NOT vector AND multicycle\000event=0x3c05a\000\000\000\000\000\000\000"
/* offset=133915 */ "pm_cmplu_stall_vector\000\000other\000Completion stall due to VSU vector instruction\000event=0x2d014\000\000\000\000\000\000\000"
/* offset=134011 */ "pm_cmplu_stall_vector_long\000\000other\000Completion stall due to VSU vector long instruction\000event=0x4d012\000\000\000\000\000\000\000"
/* offset=134117 */ "pm_cmplu_stall_vfxlong\000\000translation\000Completion stall due to a long latency vector fixed point instruction (division, square root)\000event=0x2e018\000\000\000\000\000\000\000"
/* offset=134267 */ "pm_cmplu_stall_vfxu\000\000translation\000Finish stall due to a vector fixed point instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000event=0x3c05c\000\000\000\000\000\000\000"
/* offset=134462 */ "pm_cmplu_stall_vsu\000\000other\000Completion stall due to VSU instruction\000event=0x2d012\000\000\000\000\000\000\000"
/* offset=134548 */ "pm_co0_alloc\000\000other\000CO mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16083\000\000\000\000\000\0000.0\000"
/* offset=134673 */ "pm_co0_busy\000\000other\000CO mach 0 Busy. Used by PMU to sample ave CO lifetime (mach0 used as sample point)\000event=0x3608c\000\000\000\000\000\000\000"
/* offset=134795 */ "pm_co0_busy\000\000other\000CO mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16082\000\000\000\000\000\000\000"
/* offset=134916 */ "pm_co_disp_fail\000\000other\000CO dispatch failed due to all CO machines being busy\000event=0x16886\000\000\000\000\000\000\000"
/* offset=135012 */ "pm_co_tm_sc_footprint\000\000other\000L2 did a cleanifdirty CO to the L3 (ie created an SC line in the L3) OR L2 TM_store hit dirty HPC line and L3 indicated SC line formed in L3 on RDR bus\000event=0x26086\000\000\000\000\000\000\000"
/* offset=135213 */ "pm_co_usage\000\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each CO machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x2688c\000\000\000\000\000\000\000"
/* offset=135432 */ "pm_co_usage\000\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 CO machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x3608a\000\000\000\000\000\000\000"
/* offset=135653 */ "pm_cru_fin\000\000other\000IFU Finished a (non-branch) instruction\000event=0x40066\000\000\000\000\000\000\000"
/* offset=135731 */ "pm_cyc\000\000others\000Processor cycles\000event=0x100f0\000\000\000\000\000\000\000"
/* offset=135783 */ "pm_cyc\000\000pipeline\000Cycles\000event=0x1e\000\000\000\000\000\000\000"
/* offset=135824 */ "pm_cyc\000\000translation\000Processor cycles\000event=0x1e\000\000\000\000\000\000\000"
/* offset=135878 */ "pm_darq0_0_3_entries\000\000marked\000Cycles in which 3 or less DARQ entries (out of 12) are in use\000event=0x4d04a\000\000\000\000\000\000\000"
/* offset=135989 */ "pm_darq0_10_12_entries\000\000marked\000Cycles in which 10 or more DARQ entries (out of 12) are in use\000event=0x1d058\000\000\000\000\000\000\000"
/* offset=136103 */ "pm_darq0_4_6_entries\000\000marked\000Cycles in which 4, 5, or 6 DARQ entries (out of 12) are in use\000event=0x3504e\000\000\000\000\000\000\000"
/* offset=136215 */ "pm_darq0_7_9_entries\000\000marked\000Cycles in which 7,8, or 9 DARQ entries (out of 12) are in use\000event=0x2e050\000\000\000\000\000\000\000"
/* offset=136326 */ "pm_darq1_0_3_entries\000\000marked\000Cycles in which 3 or fewer DARQ1 entries (out of 12) are in use\000event=0x4c122\000\000\000\000\000\000\000"
/* offset=136439 */ "pm_darq1_10_12_entries\000\000other\000Cycles in which 10 or  more DARQ1 entries (out of 12) are in use\000event=0x20058\000\000\000\000\000\000\000"
/* offset=136554 */ "pm_darq1_4_6_entries\000\000memory\000Cycles in which 4, 5, or 6 DARQ1 entries (out of 12) are in use\000event=0x3e050\000\000\000\000\000\000\000"
/* offset=136667 */ "pm_darq1_7_9_entries\000\000memory\000Cycles in which 7 to 9 DARQ1 entries (out of 12) are in use\000event=0x2005a\000\000\000\000\000\000\000"
/* offset=136776 */ "pm_darq_store_reject\000\000marked\000The DARQ attempted to transmit a store into an LSAQ or SRQ entry but It was rejected. Divide by PM_DARQ_STORE_XMIT to get reject ratio\000event=0x4405e\000\000\000\000\000\000\000"
/* offset=136960 */ "pm_darq_store_xmit\000\000marked\000The DARQ attempted to transmit a store into an LSAQ or SRQ entry. Includes rejects. Not qualified by thread, so it includes counts for the whole core\000event=0x30064\000\000\000\000\000\000\000"
/* offset=137157 */ "pm_data_all_chip_pump_cpred\000\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for either demand loads or data prefetch\000event=0x61c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for a demand load\000"
/* offset=137434 */ "pm_data_all_from_dl2l3_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either demand loads or data prefetch\000event=0x64c048\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=137904 */ "pm_data_all_from_dl2l3_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either demand loads or data prefetch\000event=0x63c048\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=138370 */ "pm_data_all_from_dl4\000\000other\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either demand loads or data prefetch\000event=0x63c04c\000\000\000\000\000\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=138748 */ "pm_data_all_from_dmem\000\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either demand loads or data prefetch\000event=0x64c04c\000\000\000\000\000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=139129 */ "pm_data_all_from_l21_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either demand loads or data prefetch\000event=0x64c046\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=139513 */ "pm_data_all_from_l21_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either demand loads or data prefetch\000event=0x63c046\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=139893 */ "pm_data_all_from_l2\000\000other\000The processor's data cache was reloaded from local core's L2 due to either demand loads or data prefetch\000event=0x61c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=140188 */ "pm_data_all_from_l2_disp_conflict_ldhitst\000\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either demand loads or data prefetch\000event=0x63c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=140563 */ "pm_data_all_from_l2_disp_conflict_other\000\000other\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either demand loads or data prefetch\000event=0x64c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=140924 */ "pm_data_all_from_l2_mepf\000\000other\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either demand loads or data prefetch\000event=0x62c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=141314 */ "pm_data_all_from_l2_no_conflict\000\000other\000The processor's data cache was reloaded from local core's L2 without conflict due to either demand loads or data prefetch\000event=0x61c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=141655 */ "pm_data_all_from_l2miss_mod\000\000other\000The processor's data cache was reloaded from a location other than the local core's L2 due to either demand loads or data prefetch\000event=0x61c04e\000\000\000\000\000\000The processor's data cache was reloaded from a location other than the local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=142010 */ "pm_data_all_from_l31_eco_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either demand loads or data prefetch\000event=0x64c044\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=142406 */ "pm_data_all_from_l31_eco_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either demand loads or data prefetch\000event=0x63c044\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=142798 */ "pm_data_all_from_l31_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either demand loads or data prefetch\000event=0x62c044\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=143182 */ "pm_data_all_from_l31_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either demand loads or data prefetch\000event=0x61c046\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=143562 */ "pm_data_all_from_l3\000\000other\000The processor's data cache was reloaded from local core's L3 due to either demand loads or data prefetch\000event=0x64c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=143857 */ "pm_data_all_from_l3_disp_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either demand loads or data prefetch\000event=0x63c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=144212 */ "pm_data_all_from_l3_mepf\000\000other\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either demand loads or data prefetch\000event=0x62c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=144602 */ "pm_data_all_from_l3_no_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 without conflict due to either demand loads or data prefetch\000event=0x61c044\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=144943 */ "pm_data_all_from_l3miss_mod\000\000other\000The processor's data cache was reloaded from a location other than the local core's L3 due to either demand loads or data prefetch\000event=0x64c04e\000\000\000\000\000\000The processor's data cache was reloaded from a location other than the local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=145298 */ "pm_data_all_from_ll4\000\000other\000The processor's data cache was reloaded from the local chip's L4 cache due to either demand loads or data prefetch\000event=0x61c04c\000\000\000\000\000\000The processor's data cache was reloaded from the local chip's L4 cache due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=145614 */ "pm_data_all_from_lmem\000\000other\000The processor's data cache was reloaded from the local chip's Memory due to either demand loads or data prefetch\000event=0x62c048\000\000\000\000\000\000The processor's data cache was reloaded from the local chip's Memory due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=145927 */ "pm_data_all_from_memory\000\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either demand loads or data prefetch\000event=0x62c04c\000\000\000\000\000\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=146314 */ "pm_data_all_from_off_chip_cache\000\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either demand loads or data prefetch\000event=0x64c04a\000\000\000\000\000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=146773 */ "pm_data_all_from_on_chip_cache\000\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either demand loads or data prefetch\000event=0x61c048\000\000\000\000\000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=147185 */ "pm_data_all_from_rl2l3_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either demand loads or data prefetch\000event=0x62c046\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=147647 */ "pm_data_all_from_rl2l3_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either demand loads or data prefetch\000event=0x61c04a\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=148105 */ "pm_data_all_from_rl4\000\000other\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either demand loads or data prefetch\000event=0x62c04a\000\000\000\000\000\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=148477 */ "pm_data_all_from_rmem\000\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either demand loads or data prefetch\000event=0x63c04a\000\000\000\000\000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=148858 */ "pm_data_all_grp_pump_cpred\000\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for either demand loads or data prefetch\000event=0x62c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for a demand load\000"
/* offset=149115 */ "pm_data_all_grp_pump_mpred\000\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for either demand loads or data prefetch\000event=0x62c052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=149544 */ "pm_data_all_grp_pump_mpred_rty\000\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for either demand loads or data prefetch\000event=0x61c052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor a demand load\000"
/* offset=149881 */ "pm_data_all_pump_cpred\000\000other\000Pump prediction correct. Counts across all types of pumps for either demand loads or data prefetch\000event=0x61c054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumps for a demand load\000"
/* offset=150106 */ "pm_data_all_pump_mpred\000\000other\000Pump misprediction. Counts across all types of pumps for either demand loads or data prefetch\000event=0x64c052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor a demand load\000"
/* offset=150320 */ "pm_data_all_sys_pump_cpred\000\000other\000Initial and Final Pump Scope was system pump (prediction=correct) for either demand loads or data prefetch\000event=0x63c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for a demand load\000"
/* offset=150579 */ "pm_data_all_sys_pump_mpred\000\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for either demand loads or data prefetch\000event=0x63c052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=151090 */ "pm_data_all_sys_pump_mpred_rty\000\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for either demand loads or data prefetch\000event=0x64c050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for a demand load\000"
/* offset=151388 */ "pm_data_chip_pump_cpred\000\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for a demand load\000event=0x1c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for a demand load\000"
/* offset=151638 */ "pm_data_chip_pump_cpred\000\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for a demand load\000event=0x1c050\000\000\000\000\000\000\000"
/* offset=151772 */ "pm_data_from_dl2l3_mod\000\000cache\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x4c048\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=152214 */ "pm_data_from_dl2l3_mod\000\000memory\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x4c048\000\000\000\000\000\000\000"
/* offset=152431 */ "pm_data_from_dl2l3_shr\000\000cache\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x3c048\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=152869 */ "pm_data_from_dl2l3_shr\000\000memory\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x3c048\000\000\000\000\000\000\000"
/* offset=153084 */ "pm_data_from_dl4\000\000cache\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a demand load\000event=0x3c04c\000\000\000\000\000\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=153434 */ "pm_data_from_dl4\000\000pipeline\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a demand load\000event=0x3c04c\000\000\000\000\000\000\000"
/* offset=153604 */ "pm_data_from_dmem\000\000memory\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a demand load\000event=0x4c04c\000\000\000\000\000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=153958 */ "pm_data_from_dmem\000\000pipeline\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a demand load\000event=0x4c04c\000\000\000\000\000\000\000"
/* offset=154130 */ "pm_data_from_l21_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a demand load\000event=0x4c046\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=154486 */ "pm_data_from_l21_mod\000\000translation\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a demand load\000event=0x4c046\000\000\000\000\000\000\000"
/* offset=154664 */ "pm_data_from_l21_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a demand load\000event=0x3c046\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=155016 */ "pm_data_from_l21_shr\000\000translation\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a demand load\000event=0x3c046\000\000\000\000\000\000\000"
/* offset=155192 */ "pm_data_from_l2\000\000cache\000The processor's data cache was reloaded from local core's L2 due to a demand load\000event=0x1c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=155459 */ "pm_data_from_l2\000\000marked\000The processor's data cache was reloaded from local core's L2 due to a demand load\000event=0x1c042\000\000\000\000\000\000\000"
/* offset=155585 */ "pm_data_from_l2_disp_conflict_ldhitst\000\000cache\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a demand load\000event=0x3c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=155932 */ "pm_data_from_l2_disp_conflict_ldhitst\000\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a demand load\000event=0x3c040\000\000\000\000\000\000\000"
/* offset=156108 */ "pm_data_from_l2_disp_conflict_other\000\000cache\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a demand load\000event=0x4c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=156441 */ "pm_data_from_l2_disp_conflict_other\000\000memory\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a demand load\000event=0x4c040\000\000\000\000\000\000\000"
/* offset=156610 */ "pm_data_from_l2_mepf\000\000cache\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to a demand load\000event=0x2c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=156972 */ "pm_data_from_l2_mepf\000\000memory\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to a demand load\000event=0x2c040\000\000\000\000\000\000\000"
/* offset=157148 */ "pm_data_from_l2_no_conflict\000\000cache\000The processor's data cache was reloaded from local core's L2 without conflict due to a demand load\000event=0x1c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=157461 */ "pm_data_from_l2_no_conflict\000\000memory\000The processor's data cache was reloaded from local core's L2 without conflict due to a demand load\000event=0x1c040\000\000\000\000\000\000\000"
/* offset=157616 */ "pm_data_from_l2miss\000\000cache\000Demand LD - L2 Miss (not L2 hit)\000event=0x200fe\000\000\000\000\000\000\000"
/* offset=157696 */ "pm_data_from_l2miss\000\000translation\000Demand LD - L2 Miss (not L2 hit)\000event=0x200fe\000\000\000\000\000\000\000"
/* offset=157782 */ "pm_data_from_l2miss\000\000translation\000The processor's data cache was reloaded from a source other than the local core's L1 or L2 due to a demand miss\000event=0x200fe\000\000\000\000\000\000\000"
/* offset=157947 */ "pm_data_from_l2miss_mod\000\000cache\000The processor's data cache was reloaded from a location other than the local core's L2 due to a demand load\000event=0x1c04e\000\000\000\000\000\000The processor's data cache was reloaded from a location other than the local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=158274 */ "pm_data_from_l2miss_mod\000\000translation\000The processor's data cache was reloaded from a location other than the local core's L2 due to a demand load\000event=0x1c04e\000\000\000\000\000\000\000"
/* offset=158439 */ "pm_data_from_l31_eco_mod\000\000frontend\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a demand load\000event=0x4c044\000\000\000\000\000\000\000"
/* offset=158622 */ "pm_data_from_l31_eco_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a demand load\000event=0x4c044\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=158990 */ "pm_data_from_l31_eco_shr\000\000marked\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a demand load\000event=0x3c044\000\000\000\000\000\000\000"
/* offset=159169 */ "pm_data_from_l31_eco_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a demand load\000event=0x3c044\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=159533 */ "pm_data_from_l31_mod\000\000marked\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a demand load\000event=0x2c044\000\000\000\000\000\000\000"
/* offset=159706 */ "pm_data_from_l31_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a demand load\000event=0x2c044\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=160062 */ "pm_data_from_l31_shr\000\000marked\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a demand load\000event=0x1c046\000\000\000\000\000\000\000"
/* offset=160233 */ "pm_data_from_l31_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a demand load\000event=0x1c046\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=160585 */ "pm_data_from_l3\000\000cache\000The processor's data cache was reloaded from local core's L3 due to a demand load\000event=0x4c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=160852 */ "pm_data_from_l3\000\000memory\000The processor's data cache was reloaded from local core's L3 due to a demand load\000event=0x4c042\000\000\000\000\000\000\000"
/* offset=160978 */ "pm_data_from_l3_disp_conflict\000\000cache\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a demand load\000event=0x3c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=161305 */ "pm_data_from_l3_disp_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a demand load\000event=0x3c042\000\000\000\000\000\000\000"
/* offset=161467 */ "pm_data_from_l3_mepf\000\000cache\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to a demand load\000event=0x2c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=161829 */ "pm_data_from_l3_mepf\000\000frontend\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to a demand load\000event=0x2c042\000\000\000\000\000\000\000"
/* offset=162007 */ "pm_data_from_l3_no_conflict\000\000cache\000The processor's data cache was reloaded from local core's L3 without conflict due to a demand load\000event=0x1c044\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=162320 */ "pm_data_from_l3_no_conflict\000\000frontend\000The processor's data cache was reloaded from local core's L3 without conflict due to a demand load\000event=0x1c044\000\000\000\000\000\000\000"
/* offset=162477 */ "pm_data_from_l3miss\000\000cache\000Demand LD - L3 Miss (not L2 hit and not L3 hit)\000event=0x300fe\000\000\000\000\000\000\000"
/* offset=162572 */ "pm_data_from_l3miss\000\000marked\000Demand LD - L3 Miss (not L2 hit and not L3 hit)\000event=0x300fe\000\000\000\000\000\000\000"
/* offset=162668 */ "pm_data_from_l3miss\000\000marked\000The processor's data cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss\000event=0x300fe\000\000\000\000\000\000\000"
/* offset=162833 */ "pm_data_from_l3miss_mod\000\000cache\000The processor's data cache was reloaded from a location other than the local core's L3 due to a demand load\000event=0x4c04e\000\000\000\000\000\000The processor's data cache was reloaded from a location other than the local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=163160 */ "pm_data_from_l3miss_mod\000\000marked\000The processor's data cache was reloaded from a location other than the local core's L3 due to a demand load\000event=0x4c04e\000\000\000\000\000\000\000"
/* offset=163320 */ "pm_data_from_ll4\000\000cache\000The processor's data cache was reloaded from the local chip's L4 cache due to a demand load\000event=0x1c04c\000\000\000\000\000\000The processor's data cache was reloaded from the local chip's L4 cache due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=163608 */ "pm_data_from_ll4\000\000other\000The processor's data cache was reloaded from the local chip's L4 cache due to a demand load\000event=0x1c04c\000\000\000\000\000\000\000"
/* offset=163744 */ "pm_data_from_lmem\000\000marked\000The processor's data cache was reloaded from the local chip's Memory due to a demand load\000event=0x2c048\000\000\000\000\000\000\000"
/* offset=163880 */ "pm_data_from_lmem\000\000memory\000The processor's data cache was reloaded from the local chip's Memory due to a demand load\000event=0x2c048\000\000\000\000\000\000The processor's data cache was reloaded from the local chip's Memory due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=164166 */ "pm_data_from_mem\000\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x400fe\000\000\000\000\000\000Data cache reload from memory (including L4)\000"
/* offset=164380 */ "pm_data_from_memory\000\000marked\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x400fe\000\000\000\000\000\000\000"
/* offset=164554 */ "pm_data_from_memory\000\000marked\000The processor's data cache was reloaded from local, remote, or distant memory due to a demand miss\000event=0x400fe\000\000\000\000\000\000\000"
/* offset=164701 */ "pm_data_from_memory\000\000memory\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x2c04c\000\000\000\000\000\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=165061 */ "pm_data_from_off_chip_cache\000\000cache\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a demand load\000event=0x4c04a\000\000\000\000\000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=165492 */ "pm_data_from_off_chip_cache\000\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a demand load\000event=0x4c04a\000\000\000\000\000\000\000"
/* offset=165706 */ "pm_data_from_on_chip_cache\000\000cache\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a demand load\000event=0x1c048\000\000\000\000\000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=166090 */ "pm_data_from_on_chip_cache\000\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a demand load\000event=0x1c048\000\000\000\000\000\000\000"
/* offset=166280 */ "pm_data_from_rl2l3_mod\000\000cache\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x2c046\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=166714 */ "pm_data_from_rl2l3_mod\000\000pipeline\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x2c046\000\000\000\000\000\000\000"
/* offset=166929 */ "pm_data_from_rl2l3_shr\000\000cache\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x1c04a\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=167359 */ "pm_data_from_rl2l3_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x1c04a\000\000\000\000\000\000\000"
/* offset=167569 */ "pm_data_from_rl4\000\000marked\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a demand load\000event=0x2c04a\000\000\000\000\000\000\000"
/* offset=167734 */ "pm_data_from_rl4\000\000memory\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a demand load\000event=0x2c04a\000\000\000\000\000\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=168079 */ "pm_data_from_rmem\000\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a demand load\000event=0x3c04a\000\000\000\000\000\000\000"
/* offset=168249 */ "pm_data_from_rmem\000\000memory\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a demand load\000event=0x3c04a\000\000\000\000\000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=168603 */ "pm_data_grp_pump_cpred\000\000memory\000Initial and Final Pump Scope was group pump (prediction=correct) for a demand load\000event=0x2c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for a demand load\000"
/* offset=168833 */ "pm_data_grp_pump_cpred\000\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for a demand load\000event=0x2c050\000\000\000\000\000\000\000"
/* offset=168966 */ "pm_data_grp_pump_mpred\000\000marked\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for a demand load\000event=0x2c052\000\000\000\000\000\000\000"
/* offset=169118 */ "pm_data_grp_pump_mpred\000\000memory\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for a demand load\000event=0x2c052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=169520 */ "pm_data_grp_pump_mpred_rty\000\000marked\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for a demand load\000event=0x1c052\000\000\000\000\000\000\000"
/* offset=169665 */ "pm_data_grp_pump_mpred_rty\000\000memory\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for a demand load\000event=0x1c052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor a demand load\000"
/* offset=169975 */ "pm_data_pump_cpred\000\000marked\000Pump prediction correct. Counts across all types of pumps for a demand load\000event=0x1c054\000\000\000\000\000\000\000"
/* offset=170098 */ "pm_data_pump_cpred\000\000memory\000Pump prediction correct. Counts across all types of pumps for a demand load\000event=0x1c054\000\000\000\000\000\000\000"
/* offset=170221 */ "pm_data_pump_mpred\000\000marked\000Pump misprediction. Counts across all types of pumps for a demand load\000event=0x4c052\000\000\000\000\000\000\000"
/* offset=170339 */ "pm_data_pump_mpred\000\000memory\000Pump misprediction. Counts across all types of pumps for a demand load\000event=0x4c052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor a demand load\000"
/* offset=170526 */ "pm_data_store\000\000other\000All ops that drain from s2q to L2 containing data\000event=0xf0a0\000\000\000\000\000\000\000"
/* offset=170616 */ "pm_data_sys_pump_cpred\000\000marked\000Initial and Final Pump Scope was system pump (prediction=correct) for a demand load\000event=0x3c050\000\000\000\000\000\000\000"
/* offset=170751 */ "pm_data_sys_pump_cpred\000\000memory\000Initial and Final Pump Scope was system pump (prediction=correct) for a demand load\000event=0x3c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for a demand load\000"
/* offset=170983 */ "pm_data_sys_pump_mpred\000\000marked\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for a demand load\000event=0x3c052\000\000\000\000\000\000\000"
/* offset=171218 */ "pm_data_sys_pump_mpred\000\000memory\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for a demand load\000event=0x3c052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=171702 */ "pm_data_sys_pump_mpred_rty\000\000marked\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for a demand load\000event=0x4c050\000\000\000\000\000\000\000"
/* offset=171854 */ "pm_data_sys_pump_mpred_rty\000\000memory\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for a demand load\000event=0x4c050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for a demand load\000"
/* offset=172125 */ "pm_data_tablewalk_cyc\000\000cache\000Tablwalk Cycles (could be 1 or 2 active)\000event=0x3001a\000\000\000\000\000\000Data Tablewalk Active\000"
/* offset=172236 */ "pm_data_tablewalk_cyc\000\000other\000Data Tablewalk Cycles.  Could be 1 or 2 active tablewalks. Includes data prefetches\000event=0x3001a\000\000\000\000\000\000\000"
/* offset=172369 */ "pm_dc_collisions\000\000other\000DATA Cache collisions\000event=0xe0bc\000\000\000\000\000\000DATA Cache collisions42\000"
/* offset=172457 */ "pm_dc_dealloc_no_conf\000\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0xf8ac\000\000\000\000\000\000\000"
/* offset=172734 */ "pm_dc_pref_conf\000\000other\000A demand load referenced a line in an active prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software. Includes forwards and backwards streams\000event=0xf0a8\000\000\000\000\000\000\000"
/* offset=172976 */ "pm_dc_pref_cons_alloc\000\000other\000Prefetch stream allocated in the conservative phase by either the hardware prefetch mechanism or software prefetch. The sum of this pair subtracted from the total number of allocs will give the total allocs in normal phase\000event=0xf0b4\000\000\000\000\000\000\000"
/* offset=173247 */ "pm_dc_pref_fuzzy_conf\000\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0xf8a8\000\000\000\000\000\000\000"
/* offset=173524 */ "pm_dc_pref_hw_alloc\000\000other\000Prefetch stream allocated by the hardware prefetch mechanism\000event=0xf0a4\000\000\000\000\000\000\000"
/* offset=173631 */ "pm_dc_pref_stream_alloc\000\000other\000Stream marked valid. The stream could have been allocated through the hardware prefetch mechanism or through software. This is combined ls0 and ls1\000event=0x1e050\000\000\000\000\000\000\000"
/* offset=173830 */ "pm_dc_pref_stream_conf\000\000other\000A demand load referenced a line in an active prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software. Combine up + down\000event=0x2e050\000\000\000\000\000\000\000"
/* offset=174058 */ "pm_dc_pref_stream_fuzzy_conf\000\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0x4e050\000\000\000\000\000\000\000"
/* offset=174343 */ "pm_dc_pref_stream_strided_conf\000\000other\000A demand load referenced a line in an active strided prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software\000event=0x3e050\000\000\000\000\000\000\000"
/* offset=174568 */ "pm_dc_pref_strided_conf\000\000other\000A demand load referenced a line in an active strided prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software\000event=0xf0ac\000\000\000\000\000\000\000"
/* offset=174785 */ "pm_dc_pref_sw_alloc\000\000other\000Prefetch stream allocated by software prefetching\000event=0xf8a4\000\000\000\000\000\000\000"
/* offset=174881 */ "pm_dc_pref_xcons_alloc\000\000other\000Prefetch stream allocated in the Ultra conservative phase by either the hardware prefetch mechanism or software prefetch\000event=0xf8b4\000\000\000\000\000\000\000"
/* offset=175051 */ "pm_decode_fusion_const_gen\000\000other\00032-bit constant generation\000event=0x48b4\000\000\000\000\000\000\000"
/* offset=175131 */ "pm_decode_fusion_ld_st_disp\000\000other\00032-bit displacement D-form and 16-bit displacement X-form\000event=0x48a8\000\000\000\000\000\000\000"
/* offset=175243 */ "pm_decode_hold_ict_full\000\000other\000Counts the number of cycles in which the IFU was not able to decode and transmit one or more instructions because all itags were in use.  This means the ICT is full for this thread\000event=0x58a8\000\000\000\000\000\000\000"
/* offset=175474 */ "pm_derat_miss\000\000memory\000DERAT Reloaded to satisfy a DERAT miss. All page sizes are counted by this event. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x200f6\000\000\000\000\000\000\000"
/* offset=175737 */ "pm_derat_miss_16g\000\000translation\000Data ERAT Miss (Data TLB Access) page size 16G\000event=0x4c054\000\000\000\000\000\000\000"
/* offset=175835 */ "pm_derat_miss_16g_1g\000\000other\000Data ERAT Miss (Data TLB Access) page size 16G (hpt mode) or 1G (radix mode)\000event=0x4c054\000\000\000\000\000\000\000"
/* offset=175960 */ "pm_derat_miss_16m\000\000memory\000Data ERAT Miss (Data TLB Access) page size 16M. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c054\000\000\000\000\000\000\000"
/* offset=176193 */ "pm_derat_miss_16m\000\000translation\000Data ERAT Miss (Data TLB Access) page size 16M\000event=0x3c054\000\000\000\000\000\000\000"
/* offset=176291 */ "pm_derat_miss_16m_2m\000\000pipeline\000Data ERAT Miss (Data TLB Access) page size 16M (HPT mode) or 2M (Radix mode)\000event=0x3c054\000\000\000\000\000\000\000"
/* offset=176419 */ "pm_derat_miss_2m\000\000pipeline\000Data ERAT Miss (Data TLB Access) page size 2M. Implies radix translation. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c05a\000\000\000\000\000\000\000"
/* offset=176679 */ "pm_derat_miss_4k\000\000memory\000Data ERAT Miss (Data TLB Access) page size 4K. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c056\000\000\000\000\000\000\000"
/* offset=176910 */ "pm_derat_miss_4k\000\000pipeline\000Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1c056\000\000\000\000\000\000\000"
/* offset=177003 */ "pm_derat_miss_4k\000\000translation\000Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1c056\000\000\000\000\000\000\000"
/* offset=177099 */ "pm_derat_miss_64k\000\000memory\000Data ERAT Miss (Data TLB Access) page size 64K. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c054\000\000\000\000\000\000\000"
/* offset=177332 */ "pm_derat_miss_64k\000\000pipeline\000Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2c054\000\000\000\000\000\000\000"
/* offset=177427 */ "pm_derat_miss_64k\000\000translation\000Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2c054\000\000\000\000\000\000\000"
/* offset=177525 */ "pm_dfu\000\000other\000Finish DFU (all finish)\000event=0xb0ba\000\000\000\000\000\000\000"
/* offset=177582 */ "pm_dfu_busy\000\000pipeline\000Cycles in which all 4 Decimal Floating Point units are busy. The DFU is running at capacity\000event=0x4d04c\000\000\000\000\000\000\000"
/* offset=177716 */ "pm_dfu_dcffix\000\000other\000Convert from fixed opcode finish (dcffix,dcffixq)\000event=0xb0be\000\000\000\000\000\000\000"
/* offset=177806 */ "pm_dfu_denbcd\000\000other\000BCD->DPD opcode finish (denbcd, denbcdq)\000event=0xb0bc\000\000\000\000\000\000\000"
/* offset=177887 */ "pm_dfu_mc\000\000other\000Finish DFU multicycle\000event=0xb0b8\000\000\000\000\000\000\000"
/* offset=177945 */ "pm_disp_clb_held_bal\000\000other\000Dispatch/CLB Hold: Balance Flush\000event=0x288c\000\000\000\000\000\000\000"
/* offset=178025 */ "pm_disp_clb_held_bal\000\000other\000Dispatch/CLB Hold: Balance\000event=0x2092\000\000\000\000\000\000\000"
/* offset=178099 */ "pm_disp_clb_held_res\000\000other\000Dispatch/CLB Hold: Resource\000event=0x2094\000\000\000\000\000\000\000"
/* offset=178174 */ "pm_disp_clb_held_sb\000\000other\000Dispatch/CLB Hold: Scoreboard\000event=0x2090\000\000\000\000\000\000\000"
/* offset=178250 */ "pm_disp_clb_held_sb\000\000other\000Dispatch/CLB Hold: Scoreboard\000event=0x20a8\000\000\000\000\000\000\000"
/* offset=178326 */ "pm_disp_clb_held_sync\000\000other\000Dispatch/CLB Hold: Sync type instruction\000event=0x2098\000\000\000\000\000\000\000"
/* offset=178415 */ "pm_disp_clb_held_tlbie\000\000other\000Dispatch Hold: Due to TLBIE\000event=0x2096\000\000\000\000\000\000\000"
/* offset=178492 */ "pm_disp_clb_held_tlbie\000\000other\000Dispatch Hold: Due to TLBIE\000event=0x2890\000\000\000\000\000\000\000"
/* offset=178569 */ "pm_disp_held\000\000pipeline\000Dispatch Held\000event=0x10006\000\000\000\000\000\000\000"
/* offset=178626 */ "pm_disp_held_hb_full\000\000marked\000Dispatch held due to History Buffer full. Could be GPR/VSR/VMR/FPR/CR/XVF; CR; XVF (XER/VSCR/FPSCR)\000event=0x3d05c\000\000\000\000\000\000\000"
/* offset=178775 */ "pm_disp_held_iq_full\000\000other\000Dispatch held due to Issue q full\000event=0x20006\000\000\000\000\000\000\000"
/* offset=178857 */ "pm_disp_held_issq_full\000\000other\000Dispatch held due to Issue q full. Includes issue queue and branch queue\000event=0x20006\000\000\000\000\000\000\000"
/* offset=178980 */ "pm_disp_held_map_full\000\000other\000Dispatch for this thread was held because the Mappers were full\000event=0x1002a\000\000\000\000\000\000Dispatch held due to Mapper full\000"
/* offset=179125 */ "pm_disp_held_srq_full\000\000other\000Dispatch held due SRQ no room\000event=0x30018\000\000\000\000\000\000\000"
/* offset=179204 */ "pm_disp_held_sync_hold\000\000pipeline\000Dispatch held due to SYNC hold\000event=0x4003c\000\000\000\000\000\000\000"
/* offset=179288 */ "pm_disp_held_tbegin\000\000other\000This outer tbegin transaction cannot be dispatched until the previous tend instruction completes\000event=0x28b0\000\000\000\000\000\000\000"
/* offset=179431 */ "pm_disp_hold_gct_full\000\000other\000Dispatch Hold Due to no space in the GCT\000event=0x30a6\000\000\000\000\000\000\000"
/* offset=179520 */ "pm_disp_ss0_2_instr_cyc\000\000others\000Cycles in which Superslice 0 dispatches either 1 or 2 instructions\000event=0x1f056\000\000\000\000\000\000\000"
/* offset=179639 */ "pm_disp_ss0_4_instr_cyc\000\000others\000Cycles in which Superslice 0 dispatches either 3 or 4 instructions\000event=0x3f054\000\000\000\000\000\000\000"
/* offset=179758 */ "pm_disp_ss0_8_instr_cyc\000\000others\000Cycles in which Superslice 0 dispatches either 5, 6, 7 or 8 instructions\000event=0x3f056\000\000\000\000\000\000\000"
/* offset=179883 */ "pm_disp_ss1_2_instr_cyc\000\000others\000Cycles in which Superslice 1 dispatches either 1 or 2 instructions\000event=0x2f054\000\000\000\000\000\000\000"
/* offset=180002 */ "pm_disp_ss1_4_instr_cyc\000\000others\000Cycles in which Superslice 1 dispatches either 3 or 4 instructions\000event=0x2f056\000\000\000\000\000\000\000"
/* offset=180121 */ "pm_disp_stall_br_mpred\000\000frontend\000Cycles when dispatch was stalled for this thread due to a mispredicted branch\000event=0x4d01e\000\000\000\000\000\000\000"
/* offset=180252 */ "pm_disp_stall_br_mpred_ic_l2\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from the local L2 after suffering a branch mispredict\000event=0x1003a\000\000\000\000\000\000\000"
/* offset=180432 */ "pm_disp_stall_br_mpred_ic_l3\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from the local L3 after suffering a branch mispredict\000event=0x2c01e\000\000\000\000\000\000\000"
/* offset=180612 */ "pm_disp_stall_br_mpred_ic_l3miss\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from sources beyond the local L3 after suffering a mispredicted branch\000event=0x4c010\000\000\000\000\000\000\000"
/* offset=180813 */ "pm_disp_stall_br_mpred_icmiss\000\000frontend\000Cycles when dispatch was stalled after a mispredicted branch resulted in an instruction cache miss\000event=0x34058\000\000\000\000\000\000\000"
/* offset=180972 */ "pm_disp_stall_cyc\000\000frontend\000Cycles the ICT has no itags assigned to this thread (no instructions were dispatched during these cycles)\000event=0x100f8\000\000\000\000\000\000\000"
/* offset=181126 */ "pm_disp_stall_fetch\000\000frontend\000Cycles when dispatch was stalled for this thread because Fetch was being held\000event=0x2e018\000\000\000\000\000\000\000"
/* offset=181254 */ "pm_disp_stall_flush\000\000frontend\000Cycles when dispatch was stalled because of a flush that happened to an instruction(s) that was not yet NTC. PM_EXEC_STALL_NTC_FLUSH only includes instructions that were flushed after becoming NTC\000event=0x30004\000\000\000\000\000\000\000"
/* offset=181501 */ "pm_disp_stall_held_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch for any reason\000event=0x4e01a\000\000\000\000\000\000\000"
/* offset=181625 */ "pm_disp_stall_held_halt_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because of power management\000event=0x1d05e\000\000\000\000\000\000\000"
/* offset=181767 */ "pm_disp_stall_held_issq_full_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch due to Issue queue full. Includes issue queue and branch queue\000event=0x20006\000\000\000\000\000\000\000"
/* offset=181949 */ "pm_disp_stall_held_other_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch for any other reason\000event=0x10006\000\000\000\000\000\000\000"
/* offset=182085 */ "pm_disp_stall_held_rename_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because the mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR and XVFC\000event=0x3d05c\000\000\000\000\000\000\000"
/* offset=182290 */ "pm_disp_stall_held_scoreboard_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch while waiting on the Scoreboard. This event combines VSCR and FPSCR together\000event=0x30018\000\000\000\000\000\000\000"
/* offset=182487 */ "pm_disp_stall_held_stf_mapper_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because the STF mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR\000event=0x1e050\000\000\000\000\000\000\000"
/* offset=182691 */ "pm_disp_stall_held_sync_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because of a synchronizing instruction that requires the ICT to be empty before dispatch\000event=0x4003c\000\000\000\000\000\000\000"
/* offset=182894 */ "pm_disp_stall_held_xvfc_mapper_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because the XVFC mapper/SRB was full\000event=0x2e01a\000\000\000\000\000\000\000"
/* offset=183052 */ "pm_disp_stall_ic_l2\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from the local L2\000event=0x10064\000\000\000\000\000\000\000"
/* offset=183187 */ "pm_disp_stall_ic_l3\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from the local L3\000event=0x3e052\000\000\000\000\000\000\000"
/* offset=183322 */ "pm_disp_stall_ic_l3miss\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from any source beyond the local L3\000event=0x4e010\000\000\000\000\000\000\000"
/* offset=183479 */ "pm_disp_stall_ic_miss\000\000frontend\000Cycles when dispatch was stalled for this thread due to an Icache Miss\000event=0x2d01a\000\000\000\000\000\000\000"
/* offset=183602 */ "pm_disp_stall_ierat_only_miss\000\000frontend\000Cycles when dispatch was stalled while waiting to resolve an instruction ERAT miss\000event=0x2c016\000\000\000\000\000\000\000"
/* offset=183745 */ "pm_disp_stall_itlb_miss\000\000frontend\000Cycles when dispatch was stalled while waiting to resolve an instruction TLB miss\000event=0x3000a\000\000\000\000\000\000\000"
/* offset=183881 */ "pm_disp_stall_translation\000\000frontend\000Cycles when dispatch was stalled for this thread because the MMU was handling a translation miss\000event=0x10038\000\000\000\000\000\000\000"
/* offset=184034 */ "pm_disp_starved\000\000marked\000Dispatched Starved\000event=0x30008\000\000\000\000\000\000\000"
/* offset=184097 */ "pm_disp_wt\000\000other\000Dispatched Starved\000event=0x30008\000\000\000\000\000\000Dispatched Starved (not held, nothing to dispatch)\000"
/* offset=184204 */ "pm_dp_qp_flop_cmpl\000\000translation\000Double-Precion or Quad-Precision instruction completed\000event=0x4d05c\000\000\000\000\000\000\000"
/* offset=184311 */ "pm_dpp_flop_cmpl\000\000translation\000Double-Precision or Quad-Precision instructions completed\000event=0x4d05c\000\000\000\000\000\000\000"
/* offset=184419 */ "pm_dpteg_from_dl2l3_mod\000\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e048\000\000\000\000\000\000\000"
/* offset=184750 */ "pm_dpteg_from_dl2l3_mod\000\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request\000event=0x4e048\000\000\000\000\000\000\000"
/* offset=184982 */ "pm_dpteg_from_dl2l3_shr\000\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e048\000\000\000\000\000\000\000"
/* offset=185311 */ "pm_dpteg_from_dl2l3_shr\000\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request\000event=0x3e048\000\000\000\000\000\000\000"
/* offset=185541 */ "pm_dpteg_from_dl4\000\000memory\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a data side request\000event=0x3e04c\000\000\000\000\000\000\000"
/* offset=185719 */ "pm_dpteg_from_dl4\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e04c\000\000\000\000\000\000\000"
/* offset=186001 */ "pm_dpteg_from_dmem\000\000memory\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a data side request\000event=0x4e04c\000\000\000\000\000\000\000"
/* offset=186181 */ "pm_dpteg_from_dmem\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04c\000\000\000\000\000\000\000"
/* offset=186465 */ "pm_dpteg_from_l21_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a data side request\000event=0x4e046\000\000\000\000\000\000\000"
/* offset=186647 */ "pm_dpteg_from_l21_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e046\000\000\000\000\000\000\000"
/* offset=186931 */ "pm_dpteg_from_l21_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a data side request\000event=0x3e046\000\000\000\000\000\000\000"
/* offset=187111 */ "pm_dpteg_from_l21_shr\000\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e046\000\000\000\000\000\000\000"
/* offset=187393 */ "pm_dpteg_from_l2\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e042\000\000\000\000\000\000\000"
/* offset=187628 */ "pm_dpteg_from_l2\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 due to a data side request\000event=0x1e042\000\000\000\000\000\000\000"
/* offset=187769 */ "pm_dpteg_from_l2_disp_conflict_ldhitst\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a data side request\000event=0x3e040\000\000\000\000\000\000\000"
/* offset=187955 */ "pm_dpteg_from_l2_disp_conflict_other\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a data side request\000event=0x4e040\000\000\000\000\000\000\000"
/* offset=188133 */ "pm_dpteg_from_l2_mepf\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e040\000\000\000\000\000\000\000"
/* offset=188418 */ "pm_dpteg_from_l2_mepf\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a data side request\000event=0x2e040\000\000\000\000\000\000\000"
/* offset=188610 */ "pm_dpteg_from_l2_no_conflict\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e040\000\000\000\000\000\000\000"
/* offset=188876 */ "pm_dpteg_from_l2_no_conflict\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a data side request\000event=0x1e040\000\000\000\000\000\000\000"
/* offset=189046 */ "pm_dpteg_from_l2miss\000\000other\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04e\000\000\000\000\000\000\000"
/* offset=189310 */ "pm_dpteg_from_l2miss\000\000translation\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a data side request\000event=0x1e04e\000\000\000\000\000\000\000"
/* offset=189481 */ "pm_dpteg_from_l31_eco_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e044\000\000\000\000\000\000\000"
/* offset=189770 */ "pm_dpteg_from_l31_eco_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a data side request\000event=0x4e044\000\000\000\000\000\000\000"
/* offset=189960 */ "pm_dpteg_from_l31_eco_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e044\000\000\000\000\000\000\000"
/* offset=190248 */ "pm_dpteg_from_l31_eco_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a data side request\000event=0x3e044\000\000\000\000\000\000\000"
/* offset=190436 */ "pm_dpteg_from_l31_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e044\000\000\000\000\000\000\000"
/* offset=190718 */ "pm_dpteg_from_l31_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a data side request\000event=0x2e044\000\000\000\000\000\000\000"
/* offset=190900 */ "pm_dpteg_from_l31_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e046\000\000\000\000\000\000\000"
/* offset=191180 */ "pm_dpteg_from_l31_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a data side request\000event=0x1e046\000\000\000\000\000\000\000"
/* offset=191360 */ "pm_dpteg_from_l3\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e042\000\000\000\000\000\000\000"
/* offset=191597 */ "pm_dpteg_from_l3\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 due to a data side request\000event=0x4e042\000\000\000\000\000\000\000"
/* offset=191738 */ "pm_dpteg_from_l3_disp_conflict\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e042\000\000\000\000\000\000\000"
/* offset=192012 */ "pm_dpteg_from_l3_disp_conflict\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a data side request\000event=0x3e042\000\000\000\000\000\000\000"
/* offset=192190 */ "pm_dpteg_from_l3_mepf\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e042\000\000\000\000\000\000\000"
/* offset=192478 */ "pm_dpteg_from_l3_mepf\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a data side request\000event=0x2e042\000\000\000\000\000\000\000"
/* offset=192670 */ "pm_dpteg_from_l3_no_conflict\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e044\000\000\000\000\000\000\000"
/* offset=192934 */ "pm_dpteg_from_l3_no_conflict\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a data side request\000event=0x1e044\000\000\000\000\000\000\000"
/* offset=193104 */ "pm_dpteg_from_l3miss\000\000cache\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a data side request\000event=0x4e04e\000\000\000\000\000\000\000"
/* offset=193269 */ "pm_dpteg_from_l3miss\000\000pmc\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04e\000\000\000\000\000\000\000"
/* offset=193531 */ "pm_dpteg_from_ll4\000\000pmc\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04c\000\000\000\000\000\000\000"
/* offset=193774 */ "pm_dpteg_from_ll4\000\000translation\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a data side request\000event=0x1e04c\000\000\000\000\000\000\000"
/* offset=193926 */ "pm_dpteg_from_lmem\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e048\000\000\000\000\000\000\000"
/* offset=194171 */ "pm_dpteg_from_lmem\000\000translation\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a data side request\000event=0x2e048\000\000\000\000\000\000\000"
/* offset=194322 */ "pm_dpteg_from_memory\000\000pmc\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e04c\000\000\000\000\000\000\000"
/* offset=194602 */ "pm_dpteg_from_memory\000\000translation\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a data side request\000event=0x2e04c\000\000\000\000\000\000\000"
/* offset=194791 */ "pm_dpteg_from_off_chip_cache\000\000other\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04a\000\000\000\000\000\000\000"
/* offset=195113 */ "pm_dpteg_from_off_chip_cache\000\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a data side request\000event=0x4e04a\000\000\000\000\000\000\000"
/* offset=195342 */ "pm_dpteg_from_on_chip_cache\000\000other\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e048\000\000\000\000\000\000\000"
/* offset=195640 */ "pm_dpteg_from_on_chip_cache\000\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a data side request\000event=0x1e048\000\000\000\000\000\000\000"
/* offset=195845 */ "pm_dpteg_from_rl2l3_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e046\000\000\000\000\000\000\000"
/* offset=196169 */ "pm_dpteg_from_rl2l3_mod\000\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request\000event=0x2e046\000\000\000\000\000\000\000"
/* offset=196397 */ "pm_dpteg_from_rl2l3_shr\000\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04a\000\000\000\000\000\000\000"
/* offset=196719 */ "pm_dpteg_from_rl2l3_shr\000\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request\000event=0x1e04a\000\000\000\000\000\000\000"
/* offset=196945 */ "pm_dpteg_from_rl4\000\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e04a\000\000\000\000\000\000\000"
/* offset=197218 */ "pm_dpteg_from_rl4\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a data side request\000event=0x2e04a\000\000\000\000\000\000\000"
/* offset=197398 */ "pm_dpteg_from_rmem\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e04a\000\000\000\000\000\000\000"
/* offset=197679 */ "pm_dpteg_from_rmem\000\000memory\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a data side request\000event=0x3e04a\000\000\000\000\000\000\000"
/* offset=197859 */ "pm_dside_l2memacc\000\000other\000Valid when first beat of data comes in for an D-side fetch where data came EXCLUSIVELY from memory (excluding hpcread64 accesses), i.e., total memory accesses by RCs\000event=0x36092\000\000\000\000\000\000\000"
/* offset=198070 */ "pm_dside_mru_touch\000\000other\000D-side L2 MRU touch commands sent to the L2\000event=0x26884\000\000\000\000\000\000\000"
/* offset=198160 */ "pm_dside_other_64b_l2memacc\000\000other\000Valid when first beat of data comes in for an D-side fetch where data came EXCLUSIVELY from memory that was for hpc_read64, (RC had to fetch other 64B of a line from MC) i.e., number of times RC had to go to memory to get 'missing' 64B\000event=0x36892\000\000\000\000\000\000\000"
/* offset=198451 */ "pm_dslb_miss\000\000cache\000Data SLB Miss - Total of all segment sizes\000event=0xd094\000\000\000\000\000\000Data SLB Miss - Total of all segment sizesData SLB misses\000"
/* offset=198590 */ "pm_dslb_miss\000\000pipeline\000gate_and(sd_pc_c0_comp_valid AND sd_pc_c0_comp_thread(0:1)=tid,sd_pc_c0_comp_ppc_count(0:3)) + gate_and(sd_pc_c1_comp_valid AND sd_pc_c1_comp_thread(0:1)=tid,sd_pc_c1_comp_ppc_count(0:3))\000event=0xd0a8\000\000\000\000\000\000\000"
/* offset=198820 */ "pm_dtlb_hit\000\000frontend\000The PTE required by the instruction was resident in the TLB (data TLB access). When MMCR1[16]=0 this event counts only demand hits. When MMCR1[16]=1 this event includes demand and prefetch. Applies to both HPT and RPT\000event=0x1f054\000\000\000\000\000\000\000"
/* offset=199080 */ "pm_dtlb_miss\000\000memory\000The DPTEG required for the load/store instruction in execution was missing from the TLB. It includes pages of all sizes for demand and prefetch activity\000event=0x300fc\000\000\000\000\000\000\000"
/* offset=199274 */ "pm_dtlb_miss\000\000pipeline\000Data PTEG reload\000event=0x300fc\000\000\000\000\000\000\000"
/* offset=199334 */ "pm_dtlb_miss\000\000translation\000Data PTEG reload\000event=0x300fc\000\000\000\000\000\000Data PTEG Reloaded (DTLB Miss)\000"
/* offset=199427 */ "pm_dtlb_miss_16g\000\000memory\000Data TLB reload (after a miss) page size 16G. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c058\000\000\000\000\000\000\000"
/* offset=199643 */ "pm_dtlb_miss_16g\000\000translation\000Data TLB Miss page size 16G\000event=0x1c058\000\000\000\000\000\000\000"
/* offset=199721 */ "pm_dtlb_miss_16m\000\000memory\000Data TLB reload (after a miss) page size 16M. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c056\000\000\000\000\000\000\000"
/* offset=199937 */ "pm_dtlb_miss_16m\000\000translation\000Data TLB Miss page size 16M\000event=0x4c056\000\000\000\000\000\000\000"
/* offset=200015 */ "pm_dtlb_miss_1g\000\000memory\000Data TLB reload (after a miss) page size 1G. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c05a\000\000\000\000\000\000\000"
/* offset=200265 */ "pm_dtlb_miss_2m\000\000memory\000Data TLB reload (after a miss) page size 2M. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c05c\000\000\000\000\000\000\000"
/* offset=200515 */ "pm_dtlb_miss_4k\000\000memory\000Data TLB reload (after a miss) page size 4K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c056\000\000\000\000\000\000\000"
/* offset=200729 */ "pm_dtlb_miss_4k\000\000translation\000Data TLB Miss page size 4k\000event=0x2c056\000\000\000\000\000\000\000"
/* offset=200805 */ "pm_dtlb_miss_64k\000\000memory\000Data TLB reload (after a miss) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c056\000\000\000\000\000\000\000"
/* offset=201021 */ "pm_dtlb_miss_64k\000\000translation\000Data TLB Miss page size 64K\000event=0x3c056\000\000\000\000\000\000\000"
/* offset=201099 */ "pm_dummy1_remove_me\000\000pipeline\000Space holder for L2_PC_PM_MK_LDST_SCOPE_PRED_STATUS\000event=0x40062\000\000\000\000\000\000\000"
/* offset=201201 */ "pm_dummy2_remove_me\000\000pipeline\000Space holder for LS_PC_RELOAD_RA\000event=0x40064\000\000\000\000\000\000\000"
/* offset=201284 */ "pm_eat_force_mispred\000\000other\000XL-form branch was mispredicted due to the predicted target address missing from EAT.  The EAT forces a mispredict in this case since there is no predicated target to validate.  This is a rare case that may occur when the EAT is full and a branch is issued\000event=0x50a8\000\000\000\000\000\000\000"
/* offset=201588 */ "pm_eat_force_mispred\000\000other\000XL-form branch was mispredicted due to the predicted target address missing from EAT. The EAT forces a mispredict in this case since there is no predicated target to validate. This is a rare case that may occur when the EAT is full and a branch is issue\000event=0x50a8\000\000\000\000\000\000\000"
/* offset=201889 */ "pm_eat_full_cyc\000\000other\000Cycles No room in EAT\000event=0x4084\000\000\000\000\000\000Cycles No room in EATSet on bank conflict and case where no ibuffers available\000"
/* offset=202031 */ "pm_eat_full_cyc\000\000other\000Cycles No room in EAT\000event=0x4084\000\000\000\000\000\000\000"
/* offset=202095 */ "pm_ee_off_ext_int\000\000other\000CyclesMSR[EE] is off and external interrupts are active\000event=0x2080\000\000\000\000\000\000\000"
/* offset=202195 */ "pm_ee_off_ext_int\000\000other\000Ee off and external interrupt\000event=0x2080\000\000\000\000\000\000\000"
/* offset=202269 */ "pm_exec_stall\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting to finish in one of the execution units (BRU, LSU, VSU). Only cycles between issue and finish are counted in this category\000event=0x30008\000\000\000\000\000\000\000"
/* offset=202503 */ "pm_exec_stall_bru\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the Branch unit\000event=0x4d018\000\000\000\000\000\000\000"
/* offset=202639 */ "pm_exec_stall_derat_dtlb_miss\000\000memory\000Cycles in which the oldest instruction in the pipeline suffered a TLB miss and waited for it resolve\000event=0x30016\000\000\000\000\000\000\000"
/* offset=202798 */ "pm_exec_stall_derat_only_miss\000\000pipeline\000Cycles in which the oldest instruction in the pipeline suffered an ERAT miss and waited for it resolve\000event=0x4c012\000\000\000\000\000\000\000"
/* offset=202961 */ "pm_exec_stall_dmiss_l21_l31\000\000cache\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from another core's L2 or L3 on the same chip\000event=0x1e054\000\000\000\000\000\000\000"
/* offset=203156 */ "pm_exec_stall_dmiss_l2l3\000\000cache\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from either the local L2 or local L3\000event=0x1003c\000\000\000\000\000\000\000"
/* offset=203339 */ "pm_exec_stall_dmiss_l2l3_conflict\000\000cache\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local L2 or local L3, with a dispatch conflict\000event=0x4c016\000\000\000\000\000\000\000"
/* offset=203550 */ "pm_exec_stall_dmiss_l2l3_noconflict\000\000cache\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local L2 or local L3, without a dispatch conflict\000event=0x34054\000\000\000\000\000\000\000"
/* offset=203766 */ "pm_exec_stall_dmiss_l3miss\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a source beyond the local L2 or local L3\000event=0x2c018\000\000\000\000\000\000\000"
/* offset=203963 */ "pm_exec_stall_dmiss_lmem\000\000others\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local memory, local OpenCapp cache, or local OpenCapp memory\000event=0x30038\000\000\000\000\000\000\000"
/* offset=204180 */ "pm_exec_stall_dmiss_off_chip\000\000marked\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a remote chip\000event=0x2c01c\000\000\000\000\000\000\000"
/* offset=204350 */ "pm_exec_stall_dmiss_off_node\000\000others\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a distant chip\000event=0x4c01a\000\000\000\000\000\000\000"
/* offset=204521 */ "pm_exec_stall_fin_at_disp\000\000pipeline\000Cycles in which the oldest instruction in the pipeline finished at dispatch and did not require execution in the LSU, BRU or VSU\000event=0x10058\000\000\000\000\000\000\000"
/* offset=204706 */ "pm_exec_stall_load\000\000cache\000Cycles in which the oldest instruction in the pipeline was a load instruction executing in the Load Store Unit\000event=0x4d014\000\000\000\000\000\000\000"
/* offset=204863 */ "pm_exec_stall_load_finish\000\000cache\000Cycles in which the oldest instruction in the pipeline was finishing a load after its data was reloaded from a data source beyond the local L1; cycles in which the LSU was processing an L1-hit; cycles in which the NTF instruction merged with another load in the LMQ; cycles in which the NTF instruction is waiting for a data reload for a load miss, but the data comes back with a non-NTF instruction\000event=0x34056\000\000\000\000\000\000\000"
/* offset=205316 */ "pm_exec_stall_lsu\000\000frontend\000Cycles in which the oldest instruction in the pipeline was executing in the Load Store Unit. This does not include simple fixed point instructions\000event=0x2c010\000\000\000\000\000\000\000"
/* offset=205511 */ "pm_exec_stall_ntc_flush\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in any unit before it was flushed. Note that if the flush of the oldest instruction happens after finish, the cycles from dispatch to issue will be included in PM_DISP_STALL and the cycles from issue to finish will be included in PM_EXEC_STALL and its corresponding children. This event will also count cycles when the previous NTF instruction is still completing and the new NTF instruction is stalled at dispatch\000event=0x2e01e\000\000\000\000\000\000\000"
/* offset=206049 */ "pm_exec_stall_ptesync\000\000cache\000Cycles in which the oldest instruction in the pipeline was a PTESYNC instruction executing in the Load Store Unit\000event=0x4d016\000\000\000\000\000\000\000"
/* offset=206212 */ "pm_exec_stall_simple_fx\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a simple fixed point instruction executing in the Load Store Unit\000event=0x30036\000\000\000\000\000\000\000"
/* offset=206391 */ "pm_exec_stall_store\000\000frontend\000Cycles in which the oldest instruction in the pipeline was a store instruction executing in the Load Store Unit\000event=0x30014\000\000\000\000\000\000\000"
/* offset=206553 */ "pm_exec_stall_store_miss\000\000frontend\000Cycles in which the oldest instruction in the pipeline was a store whose cache line was not resident in the L1 and was waiting for allocation of the missing line into the L1\000event=0x30026\000\000\000\000\000\000\000"
/* offset=206782 */ "pm_exec_stall_store_pipe\000\000memory\000Cycles in which the oldest instruction in the pipeline was executing in the store unit. This does not include cycles spent handling store misses, PTESYNC instructions or TLBIE instructions\000event=0x1e056\000\000\000\000\000\000\000"
/* offset=207024 */ "pm_exec_stall_tlbie\000\000translation\000Cycles in which the oldest instruction in the pipeline was a TLBIE instruction executing in the Load Store Unit\000event=0x2e01c\000\000\000\000\000\000\000"
/* offset=207189 */ "pm_exec_stall_tlbiel\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a TLBIEL instruction executing in the Load Store Unit. TLBIEL instructions have lower overhead than TLBIE instructions because they don't get set to the nest\000event=0x4d01c\000\000\000\000\000\000\000"
/* offset=207457 */ "pm_exec_stall_translation\000\000frontend\000Cycles in which the oldest instruction in the pipeline suffered a TLB miss or ERAT miss and waited for it to resolve\000event=0x10004\000\000\000\000\000\000\000"
/* offset=207630 */ "pm_exec_stall_unknown\000\000pipeline\000Cycles in which the oldest instruction in the pipeline completed without an ntf_type pulse. The ntf_pulse was missed by the ISU because the NTF finishes and completions came too close together\000event=0x4e012\000\000\000\000\000\000\000"
/* offset=207875 */ "pm_exec_stall_vsu\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the VSU (includes FXU, VSU, CRU)\000event=0x2d018\000\000\000\000\000\000\000"
/* offset=208028 */ "pm_ext_int\000\000pipeline\000external interrupt\000event=0x200f8\000\000\000\000\000\000\000"
/* offset=208088 */ "pm_fav_tbegin\000\000other\000Dispatch time Favored tbegin\000event=0x20b4\000\000\000\000\000\000\000"
/* offset=208157 */ "pm_flop\000\000other\000Floating Point Operation Finished\000event=0x100f4\000\000\000\000\000\000Floating Point Operations Finished\000"
/* offset=208260 */ "pm_flop_cmpl\000\000others\000Floating Point Operations Completed. Includes any type. It counts once for each 1, 2, 4 or 8 flop instruction. Use PM_1|2|4|8_FLOP_CMPL events to count flops\000event=0x100f4\000\000\000\000\000\000\000"
/* offset=208459 */ "pm_flop_cmpl\000\000pipeline\000Floating Point Operation Finished\000event=0x4505e\000\000\000\000\000\000\000"
/* offset=208536 */ "pm_flop_sum_scalar\000\000other\000flops summary scalar instructions\000event=0xa0ae\000\000\000\000\000\000\000"
/* offset=208615 */ "pm_flop_sum_vec\000\000other\000flops summary vector instructions\000event=0xa0ac\000\000\000\000\000\000\000"
/* offset=208691 */ "pm_flush\000\000pipeline\000Flush (any type)\000event=0x400f8\000\000\000\000\000\000\000"
/* offset=208747 */ "pm_flush_br_mpred\000\000other\000Flush caused by branch mispredict\000event=0x2084\000\000\000\000\000\000\000"
/* offset=208825 */ "pm_flush_completion\000\000floating point\000The instruction that was next to complete did not complete because it suffered a flush\000event=0x30012\000\000\000\000\000\000\000"
/* offset=208968 */ "pm_flush_completion\000\000frontend\000The instruction that was next to complete (oldest in the pipeline) did not complete because it suffered a flush\000event=0x30012\000\000\000\000\000\000\000"
/* offset=209130 */ "pm_flush_completion\000\000pipeline\000Completion Flush\000event=0x30012\000\000\000\000\000\000\000"
/* offset=209197 */ "pm_flush_disp\000\000other\000Dispatch flush\000event=0x2082\000\000\000\000\000\000\000"
/* offset=209252 */ "pm_flush_disp\000\000other\000Dispatch flush\000event=0x2880\000\000\000\000\000\000\000"
/* offset=209307 */ "pm_flush_disp_sb\000\000other\000Dispatch Flush: Scoreboard\000event=0x2088\000\000\000\000\000\000\000"
/* offset=209377 */ "pm_flush_disp_sb\000\000other\000Dispatch Flush: Scoreboard\000event=0x208c\000\000\000\000\000\000\000"
/* offset=209447 */ "pm_flush_disp_sync\000\000other\000Dispatch Flush: Sync\000event=0x2088\000\000\000\000\000\000\000"
/* offset=209513 */ "pm_flush_disp_tlbie\000\000other\000Dispatch Flush: TLBIE\000event=0x208a\000\000\000\000\000\000\000"
/* offset=209581 */ "pm_flush_disp_tlbie\000\000other\000Dispatch Flush: TLBIE\000event=0x2888\000\000\000\000\000\000\000"
/* offset=209649 */ "pm_flush_hb_restore_cyc\000\000other\000Cycles in which no new instructions can be dispatched to the ICT after a flush.  History buffer recovery\000event=0x2084\000\000\000\000\000\000\000"
/* offset=209804 */ "pm_flush_lsu\000\000other\000Flush initiated by LSU\000event=0x208e\000\000\000\000\000\000\000"
/* offset=209866 */ "pm_flush_lsu\000\000other\000LSU flushes.  Includes all lsu flushes\000event=0x58a4\000\000\000\000\000\000\000"
/* offset=209944 */ "pm_flush_mpred\000\000other\000Branch mispredict flushes.  Includes target and address misprecition\000event=0x50a4\000\000\000\000\000\000\000"
/* offset=210054 */ "pm_flush_mpred\000\000pipeline\000A flush occurred due to a mispredicted branch. Includes target and direction\000event=0x1005a\000\000\000\000\000\000\000"
/* offset=210176 */ "pm_flush_partial\000\000other\000Partial flush\000event=0x2086\000\000\000\000\000\000\000"
/* offset=210233 */ "pm_fma_cmpl\000\000other\000two flops operation completed (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only. \000event=0x45054\000\000\000\000\000\000\000"
/* offset=210361 */ "pm_fma_cmpl\000\000others\000Two floating point instructions completed (FMA class of instructions: fmadd, fnmadd, fmsub, fnmsub). Scalar instructions only\000event=0x45054\000\000\000\000\000\000\000"
/* offset=210527 */ "pm_fpu0_fconv\000\000other\000Convert instruction executed\000event=0xa0b0\000\000\000\000\000\000\000"
/* offset=210596 */ "pm_fpu0_fest\000\000other\000Estimate instruction executed\000event=0xa0b8\000\000\000\000\000\000\000"
/* offset=210665 */ "pm_fpu0_frsp\000\000other\000Round to single precision instruction executed\000event=0xa0b4\000\000\000\000\000\000\000"
/* offset=210751 */ "pm_fpu1_fconv\000\000other\000Convert instruction executed\000event=0xa0b2\000\000\000\000\000\000\000"
/* offset=210820 */ "pm_fpu1_fest\000\000other\000Estimate instruction executed\000event=0xa0ba\000\000\000\000\000\000\000"
/* offset=210889 */ "pm_fpu1_frsp\000\000other\000Round to single precision instruction executed\000event=0xa0b6\000\000\000\000\000\000\000"
/* offset=210975 */ "pm_freq_down\000\000pipeline\000Power Management: Below Threshold B\000event=0x3000c\000\000\000\000\000\000Frequency is being slewed down due to Power Management\000"
/* offset=211108 */ "pm_freq_down\000\000pmc\000Power Management: Below Threshold B\000event=0x3000c\000\000\000\000\000\000\000"
/* offset=211182 */ "pm_freq_up\000\000marked\000Power Management: Above Threshold A\000event=0x4000c\000\000\000\000\000\000\000"
/* offset=211257 */ "pm_freq_up\000\000pipeline\000Power Management: Above Threshold A\000event=0x4000c\000\000\000\000\000\000Frequency is being slewed up due to Power Management\000"
/* offset=211386 */ "pm_fusion_toc_grp0_1\000\000other\000One pair of instructions fused with TOC in Group0\000event=0x50b0\000\000\000\000\000\000\000"
/* offset=211483 */ "pm_fusion_toc_grp0_2\000\000other\000Two pairs of instructions fused with TOCin Group0\000event=0x50ae\000\000\000\000\000\000\000"
/* offset=211580 */ "pm_fusion_toc_grp0_3\000\000other\000Three pairs of instructions fused with TOC in Group0\000event=0x50ac\000\000\000\000\000\000\000"
/* offset=211680 */ "pm_fusion_toc_grp1_1\000\000other\000One pair of instructions fused with TOX in Group1\000event=0x50b2\000\000\000\000\000\000\000"
/* offset=211777 */ "pm_fusion_vsx_grp0_1\000\000other\000One pair of instructions fused with VSX in Group0\000event=0x50b8\000\000\000\000\000\000\000"
/* offset=211874 */ "pm_fusion_vsx_grp0_2\000\000other\000Two pairs of instructions fused with VSX in Group0\000event=0x50b6\000\000\000\000\000\000\000"
/* offset=211972 */ "pm_fusion_vsx_grp0_3\000\000other\000Three pairs of instructions fused with VSX in Group0\000event=0x50b4\000\000\000\000\000\000\000"
/* offset=212072 */ "pm_fusion_vsx_grp1_1\000\000other\000One pair of instructions fused with VSX in Group1\000event=0x50ba\000\000\000\000\000\000\000"
/* offset=212169 */ "pm_fx_lsu_fin\000\000pipeline\000Simple fixed point instruction issued to the store unit. Measured at finish time\000event=0x1006a\000\000\000\000\000\000\000"
/* offset=212294 */ "pm_fxu0_busy_fxu1_idle\000\000other\000fxu0 busy and fxu1 idle\000event=0x3000e\000\000\000\000\000\000\000"
/* offset=212368 */ "pm_fxu0_fin\000\000other\000The fixed point unit Unit 0 finished an instruction. Instructions that finish may not necessary complete\000event=0x10004\000\000\000\000\000\000FXU0 Finished\000"
/* offset=212525 */ "pm_fxu1_busy_fxu0_idle\000\000other\000fxu0 idle and fxu1 busy\000event=0x4000e\000\000\000\000\000\000\000"
/* offset=212599 */ "pm_fxu1_fin\000\000other\000FXU1 Finished\000event=0x40004\000\000\000\000\000\000\000"
/* offset=212652 */ "pm_fxu_1plus_busy\000\000marked\000At least one of the 4 FXU units is busy\000event=0x3000e\000\000\000\000\000\000\000"
/* offset=212738 */ "pm_fxu_busy\000\000floating point\000fxu0 busy and fxu1 busy\000event=0x2000e\000\000\000\000\000\000\000"
/* offset=212810 */ "pm_fxu_busy\000\000pipeline\000Cycles in which all 4 FXUs are busy. The FXU is running at capacity\000event=0x2000e\000\000\000\000\000\000\000"
/* offset=212920 */ "pm_fxu_fin\000\000pipeline\000The fixed point unit Unit finished an instruction. Instructions that finish may not necessary complete\000event=0x40004\000\000\000\000\000\000\000"
/* offset=213064 */ "pm_fxu_idle\000\000floating point\000fxu0 idle and fxu1 idle\000event=0x1000e\000\000\000\000\000\000\000"
/* offset=213136 */ "pm_fxu_idle\000\000pipeline\000Cycles in which FXU0, FXU1, FXU2, and FXU3 are all idle\000event=0x24052\000\000\000\000\000\000\000"
/* offset=213234 */ "pm_fxu_issue\000\000pipeline\000A fixed point instruction was issued to the VSU\000event=0x40004\000\000\000\000\000\000\000"
/* offset=213325 */ "pm_gct_empty_cyc\000\000other\000No itags assigned either thread (GCT Empty)\000event=0x20008\000\000\000\000\000\000\000"
/* offset=213413 */ "pm_gct_merge\000\000other\000Group dispatched on a merged GCT empty. GCT entries can be merged only within the same thread\000event=0x30a4\000\000\000\000\000\000\000"
/* offset=213546 */ "pm_gct_noslot_br_mpred\000\000other\000Gct empty for this thread due to branch mispred\000event=0x4d01e\000\000\000\000\000\000\000"
/* offset=213644 */ "pm_gct_noslot_br_mpred_icmiss\000\000other\000Gct empty for this thread due to Icache Miss and branch mispred\000event=0x4d01a\000\000\000\000\000\000\000"
/* offset=213765 */ "pm_gct_noslot_cyc\000\000other\000No itags assigned\000event=0x100f8\000\000\000\000\000\000Pipeline empty (No itags assigned , no GCT slots used)\000"
/* offset=213882 */ "pm_gct_noslot_disp_held_issq\000\000other\000Gct empty for this thread due to dispatch hold on this thread due to Issue q full\000event=0x2d01e\000\000\000\000\000\000\000"
/* offset=214020 */ "pm_gct_noslot_disp_held_map\000\000other\000Gct empty for this thread due to dispatch hold on this thread due to Mapper full\000event=0x4d01c\000\000\000\000\000\000\000"
/* offset=214156 */ "pm_gct_noslot_disp_held_other\000\000other\000Gct empty for this thread due to dispatch hold on this thread due to sync\000event=0x2e010\000\000\000\000\000\000\000"
/* offset=214287 */ "pm_gct_noslot_disp_held_srq\000\000other\000Gct empty for this thread due to dispatch hold on this thread due to SRQ full\000event=0x2d01c\000\000\000\000\000\000\000"
/* offset=214420 */ "pm_gct_noslot_ic_l3miss\000\000other\000Gct empty for this thread due to icache l3 miss\000event=0x4e010\000\000\000\000\000\000\000"
/* offset=214519 */ "pm_gct_noslot_ic_miss\000\000other\000Gct empty for this thread due to Icache Miss\000event=0x2d01a\000\000\000\000\000\000\000"
/* offset=214613 */ "pm_gct_util_11_14_entries\000\000other\000GCT Utilization 11-14 entries\000event=0x20a2\000\000\000\000\000\000\000"
/* offset=214695 */ "pm_gct_util_15_17_entries\000\000other\000GCT Utilization 15-17 entries\000event=0x20a4\000\000\000\000\000\000\000"
/* offset=214777 */ "pm_gct_util_18_entries\000\000other\000GCT Utilization 18+ entries\000event=0x20a6\000\000\000\000\000\000\000"
/* offset=214854 */ "pm_gct_util_1_2_entries\000\000other\000GCT Utilization 1-2 entries\000event=0x209c\000\000\000\000\000\000\000"
/* offset=214932 */ "pm_gct_util_3_6_entries\000\000other\000GCT Utilization 3-6 entries\000event=0x209e\000\000\000\000\000\000\000"
/* offset=215010 */ "pm_gct_util_7_10_entries\000\000other\000GCT Utilization 7-10 entries\000event=0x20a0\000\000\000\000\000\000\000"
/* offset=215090 */ "pm_grp_br_mpred_nonspec\000\000other\000Group experienced non-speculative branch redirect\000event=0x1000a\000\000\000\000\000\000Group experienced Non-speculative br mispredicct\000"
/* offset=215239 */ "pm_grp_cmpl\000\000other\000group completed\000event=0x30004\000\000\000\000\000\000\000"
/* offset=215294 */ "pm_grp_disp\000\000other\000group dispatch\000event=0x3000a\000\000\000\000\000\000dispatch_success (Group Dispatched)\000"
/* offset=215383 */ "pm_grp_ic_miss_nonspec\000\000other\000Group experienced non-speculative I cache miss\000event=0x1000c\000\000\000\000\000\000Group experi enced Non-specu lative I cache miss\000"
/* offset=215528 */ "pm_grp_mrk\000\000other\000Instruction Marked\000event=0x10130\000\000\000\000\000\000Instruction marked in idu\000"
/* offset=215610 */ "pm_grp_non_full_group\000\000other\000GROUPs where we did not have 6 non branch instructions in the group(ST mode), in SMT mode 3 non branches\000event=0x509c\000\000\000\000\000\000\000"
/* offset=215763 */ "pm_grp_pump_cpred\000\000marked\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20050\000\000\000\000\000\000\000"
/* offset=215976 */ "pm_grp_pump_cpred\000\000memory\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20050\000\000\000\000\000\000\000"
/* offset=216189 */ "pm_grp_pump_mpred\000\000memory\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=216656 */ "pm_grp_pump_mpred\000\000pipeline\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20052\000\000\000\000\000\000\000"
/* offset=216875 */ "pm_grp_pump_mpred_rty\000\000memory\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=217320 */ "pm_grp_pump_mpred_rty\000\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10052\000\000\000\000\000\000\000"
/* offset=217529 */ "pm_grp_term_2nd_branch\000\000other\000There were enough instructions in the Ibuffer, but 2nd branch ends group\000event=0x50a4\000\000\000\000\000\000\000"
/* offset=217651 */ "pm_grp_term_fpu_after_br\000\000other\000There were enough instructions in the Ibuffer, but FPU OP IN same group after a branch terminates a group, cant do partial flushes\000event=0x50a6\000\000\000\000\000\000\000"
/* offset=217833 */ "pm_grp_term_noinst\000\000other\000Do not fill every slot in the group, Not enough instructions in the Ibuffer. This includes cases where the group started with enough instructions, but some got knocked out by a cache miss or branch redirect (which would also empty the Ibuffer)\000event=0x509e\000\000\000\000\000\000\000"
/* offset=218122 */ "pm_grp_term_other\000\000other\000There were enough instructions in the Ibuffer, but the group terminated early for some other reason, most likely due to a First or Last\000event=0x50a0\000\000\000\000\000\000\000"
/* offset=218302 */ "pm_grp_term_slot_limit\000\000other\000There were enough instructions in the Ibuffer, but 3 src RA/RB/RC , 2 way crack caused a group termination\000event=0x50a2\000\000\000\000\000\000\000"
/* offset=218458 */ "pm_hv_cyc\000\000pipeline\000Cycles in which msr_hv is high. Note that this event does not take msr_pr into consideration\000event=0x2000a\000\000\000\000\000\000\000"
/* offset=218591 */ "pm_hv_cyc\000\000pipeline\000Cycles in which msr_hv is high. Note that this event does not take msr_pr into consideration\000event=0x2000a\000\000\000\000\000\000cycles in hypervisor mode\000"
/* offset=218749 */ "pm_hwsync\000\000other\000A hwsync instruction was decoded and transferred\000event=0xd0b0\000\000\000\000\000\000\000"
/* offset=218834 */ "pm_hypervisor_cyc\000\000pipeline\000Cycles when the thread is in Hypervisor state. MSR[S HV PR]=010\000event=0x2000a\000\000\000\000\000\000\000"
/* offset=218946 */ "pm_hypervisor_inst_cmpl\000\000others\000PowerPC instructions that completed while the thread is in hypervisor state\000event=0x4d022\000\000\000\000\000\000\000"
/* offset=219074 */ "pm_ibuf_full_cyc\000\000other\000Cycles No room in ibuff\000event=0x4086\000\000\000\000\000\000Cycles No room in ibufffully qualified transfer (if5 valid)\000"
/* offset=219200 */ "pm_ibuf_full_cyc\000\000other\000Cycles No room in ibuff\000event=0x4884\000\000\000\000\000\000\000"
/* offset=219267 */ "pm_ic_demand_cyc\000\000frontend\000Cycles when a demand ifetch was pending\000event=0x10018\000\000\000\000\000\000Demand ifetch pending\000"
/* offset=219375 */ "pm_ic_demand_cyc\000\000pipeline\000Cycles in which an instruction reload is pending to satisfy a demand miss\000event=0x10018\000\000\000\000\000\000\000"
/* offset=219496 */ "pm_ic_demand_cyc\000\000pipeline\000Icache miss demand cycles\000event=0x10018\000\000\000\000\000\000\000"
/* offset=219569 */ "pm_ic_demand_l2_bht_redirect\000\000other\000L2 I cache demand request due to BHT redirect, branch redirect ( 2 bubbles 3 cycles)\000event=0x4098\000\000\000\000\000\000\000"
/* offset=219709 */ "pm_ic_demand_l2_br_redirect\000\000other\000L2 I cache demand request due to branch Mispredict ( 15 cycle path)\000event=0x409a\000\000\000\000\000\000\000"
/* offset=219831 */ "pm_ic_demand_l2_br_redirect\000\000other\000L2 I cache demand request due to branch Mispredict ( 15 cycle path)\000event=0x4898\000\000\000\000\000\000\000"
/* offset=219953 */ "pm_ic_demand_req\000\000other\000Demand Instruction fetch request\000event=0x4088\000\000\000\000\000\000\000"
/* offset=220029 */ "pm_ic_invalidate\000\000other\000Ic line invalidated\000event=0x508a\000\000\000\000\000\000\000"
/* offset=220092 */ "pm_ic_invalidate\000\000other\000Ic line invalidated\000event=0x5888\000\000\000\000\000\000\000"
/* offset=220155 */ "pm_ic_miss_cmpl\000\000pipeline\000Non-speculative icache miss, counted at completion\000event=0x45058\000\000\000\000\000\000\000"
/* offset=220252 */ "pm_ic_miss_icbi\000\000other\000threaded version, IC Misses where we got EA dir hit but no sector valids were on. ICBI took line out\000event=0x5094\000\000\000\000\000\000\000"
/* offset=220395 */ "pm_ic_pref_cancel_hit\000\000other\000Prefetch Canceled due to icache hit\000event=0x4092\000\000\000\000\000\000\000"
/* offset=220479 */ "pm_ic_pref_cancel_hit\000\000other\000Prefetch Canceled due to icache hit\000event=0x4890\000\000\000\000\000\000\000"
/* offset=220563 */ "pm_ic_pref_cancel_l2\000\000other\000L2 Squashed a demand or prefetch request\000event=0x4094\000\000\000\000\000\000\000"
/* offset=220651 */ "pm_ic_pref_cancel_l2\000\000other\000L2 Squashed request\000event=0x4094\000\000\000\000\000\000\000"
/* offset=220718 */ "pm_ic_pref_cancel_page\000\000other\000Prefetch Canceled due to page boundary\000event=0x4090\000\000\000\000\000\000\000"
/* offset=220806 */ "pm_ic_pref_req\000\000other\000Instruction prefetch requests\000event=0x408a\000\000\000\000\000\000\000"
/* offset=220877 */ "pm_ic_pref_req\000\000other\000Instruction prefetch requests\000event=0x4888\000\000\000\000\000\000\000"
/* offset=220948 */ "pm_ic_pref_write\000\000other\000Instruction prefetch written into IL1\000event=0x408e\000\000\000\000\000\000\000"
/* offset=221029 */ "pm_ic_pref_write\000\000other\000Instruction prefetch written into IL1\000event=0x488c\000\000\000\000\000\000\000"
/* offset=221110 */ "pm_ic_reload_private\000\000other\000Reloading line was brought in private for a specific thread.  Most lines are brought in shared for all eight threads.  If RA does not match then invalidates and then brings it shared to other thread. In P7 line brought in private , then line was invalidat\000event=0x4894\000\000\000\000\000\000\000"
/* offset=221413 */ "pm_ic_reload_private\000\000other\000Reloading line was brought in private for a specific thread. Most lines are brought in shared for all eight thrreads. If RA does not match then invalidates and then brings it shared to other thread. In P7 line brought in private , then line was invalidat\000event=0x4096\000\000\000\000\000\000\000"
/* offset=221715 */ "pm_ict_empty_cyc\000\000pipeline\000Cycles in which the ICT is completely empty. No itags are assigned to any thread\000event=0x20008\000\000\000\000\000\000\000"
/* offset=221843 */ "pm_ict_noslot_br_mpred\000\000pipeline\000Ict empty for this thread due to branch mispred\000event=0x4d01e\000\000\000\000\000\000\000"
/* offset=221944 */ "pm_ict_noslot_br_mpred_icmiss\000\000pipeline\000Ict empty for this thread due to Icache Miss and branch mispred\000event=0x34058\000\000\000\000\000\000\000"
/* offset=222068 */ "pm_ict_noslot_cyc\000\000pipeline\000Number of cycles the ICT has no itags assigned to this thread\000event=0x100f8\000\000\000\000\000\000\000"
/* offset=222178 */ "pm_ict_noslot_disp_held\000\000pipeline\000Cycles in which the NTC instruction is held at dispatch for any reason\000event=0x4e01a\000\000\000\000\000\000\000"
/* offset=222303 */ "pm_ict_noslot_disp_held_hb_full\000\000other\000Ict empty for this thread due to dispatch holds because the History Buffer was full. Could be GPR/VSR/VMR/FPR/CR/XVF; CR; XVF (XER/VSCR/FPSCR)\000event=0x30018\000\000\000\000\000\000\000"
/* offset=222505 */ "pm_ict_noslot_disp_held_issq\000\000other\000Ict empty for this thread due to dispatch hold on this thread due to Issue q full, BRQ full, XVCF Full, Count cache, Link, Tar full\000event=0x2d01e\000\000\000\000\000\000\000"
/* offset=222693 */ "pm_ict_noslot_disp_held_sync\000\000pipeline\000Dispatch held due to a synchronizing instruction at dispatch\000event=0x4d01c\000\000\000\000\000\000\000"
/* offset=222813 */ "pm_ict_noslot_disp_held_tbegin\000\000pipeline\000the NTC instruction is being held at dispatch because it is a tbegin instruction and there is an older tbegin in the pipeline that must complete before the younger tbegin can dispatch\000event=0x10064\000\000\000\000\000\000\000"
/* offset=223058 */ "pm_ict_noslot_ic_l3\000\000pipeline\000Ict empty for this thread due to icache misses that were sourced from the local L3\000event=0x3e052\000\000\000\000\000\000\000"
/* offset=223191 */ "pm_ict_noslot_ic_l3miss\000\000pipeline\000Ict empty for this thread due to icache misses that were sourced from beyond the local L3. The source could be local/remote/distant memory or another core's cache\000event=0x4e010\000\000\000\000\000\000\000"
/* offset=223408 */ "pm_ict_noslot_ic_miss\000\000pipeline\000Ict empty for this thread due to Icache Miss\000event=0x2d01a\000\000\000\000\000\000\000"
/* offset=223505 */ "pm_ierat_miss\000\000frontend\000IERAT Reloaded to satisfy an IERAT miss. All page sizes are counted by this event\000event=0x100f6\000\000\000\000\000\000\000"
/* offset=223631 */ "pm_ierat_reload\000\000frontend\000Number of I-ERAT reloads\000event=0x100f6\000\000\000\000\000\000IERAT Reloaded (Miss)\000"
/* offset=223723 */ "pm_ierat_reload\000\000pipeline\000Number of I-ERAT reloads\000event=0x100f6\000\000\000\000\000\000\000"
/* offset=223794 */ "pm_ierat_reload_16m\000\000frontend\000IERAT Reloaded (Miss) for a 16M page\000event=0x4006a\000\000\000\000\000\000\000"
/* offset=223881 */ "pm_ierat_reload_16m\000\000pipeline\000IERAT Reloaded (Miss) for a 16M page\000event=0x4006a\000\000\000\000\000\000\000"
/* offset=223968 */ "pm_ierat_reload_4k\000\000frontend\000IERAT Miss (Not implemented as DI on POWER6)\000event=0x20064\000\000\000\000\000\000IERAT Reloaded (Miss) for a 4k page\000"
/* offset=224097 */ "pm_ierat_reload_4k\000\000other\000IERAT reloaded (after a miss) for 4K pages\000event=0x20064\000\000\000\000\000\000\000"
/* offset=224186 */ "pm_ierat_reload_64k\000\000frontend\000IERAT Reloaded (Miss) for a 64k page\000event=0x3006a\000\000\000\000\000\000\000"
/* offset=224273 */ "pm_ierat_reload_64k\000\000other\000IERAT Reloaded (Miss) for a 64k page\000event=0x3006a\000\000\000\000\000\000\000"
/* offset=224357 */ "pm_ifetch_throttle\000\000pipeline\000Cycles in which Instruction fetch throttle was active\000event=0x3405e\000\000\000\000\000\000Cycles instruction fecth was throttled in IFU\000"
/* offset=224505 */ "pm_ifu_l2_touch\000\000other\000L2 touch to update MRU on a line\000event=0x5088\000\000\000\000\000\000\000"
/* offset=224580 */ "pm_inst_all_chip_pump_cpred\000\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for instruction fetches and prefetches\000event=0x514050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for an instruction fetch\000"
/* offset=224862 */ "pm_inst_all_from_dl2l3_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to instruction fetches and prefetches\000event=0x544048\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=225350 */ "pm_inst_all_from_dl2l3_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to instruction fetches and prefetches\000event=0x534048\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=225834 */ "pm_inst_all_from_dl4\000\000other\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to instruction fetches and prefetches\000event=0x53404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=226230 */ "pm_inst_all_from_dmem\000\000other\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to instruction fetches and prefetches\000event=0x54404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=226629 */ "pm_inst_all_from_l21_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to instruction fetches and prefetches\000event=0x544046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=227031 */ "pm_inst_all_from_l21_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to instruction fetches and prefetches\000event=0x534046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=227429 */ "pm_inst_all_from_l2\000\000other\000The processor's Instruction cache was reloaded from local core's L2 due to instruction fetches and prefetches\000event=0x514042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=227742 */ "pm_inst_all_from_l2_disp_conflict_ldhitst\000\000other\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to instruction fetches and prefetches\000event=0x534040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=228135 */ "pm_inst_all_from_l2_disp_conflict_other\000\000other\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to instruction fetches and prefetches\000event=0x544040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=228514 */ "pm_inst_all_from_l2_mepf\000\000other\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to instruction fetches and prefetches\000event=0x524040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=228924 */ "pm_inst_all_from_l2_no_conflict\000\000other\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to instruction fetches and prefetches\000event=0x514040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=229283 */ "pm_inst_all_from_l2miss\000\000other\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to instruction fetches and prefetches\000event=0x51404e\000\000\000\000\000\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=229652 */ "pm_inst_all_from_l31_eco_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to instruction fetches and prefetches\000event=0x544044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=230066 */ "pm_inst_all_from_l31_eco_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to instruction fetches and prefetches\000event=0x534044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=230476 */ "pm_inst_all_from_l31_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to instruction fetches and prefetches\000event=0x524044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=230878 */ "pm_inst_all_from_l31_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to instruction fetches and prefetches\000event=0x514046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=231276 */ "pm_inst_all_from_l3\000\000other\000The processor's Instruction cache was reloaded from local core's L3 due to instruction fetches and prefetches\000event=0x544042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=231589 */ "pm_inst_all_from_l3_disp_conflict\000\000other\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to instruction fetches and prefetches\000event=0x534042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=231962 */ "pm_inst_all_from_l3_mepf\000\000other\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to instruction fetches and prefetches\000event=0x524042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=232372 */ "pm_inst_all_from_l3_no_conflict\000\000other\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to instruction fetches and prefetches\000event=0x514044\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=232731 */ "pm_inst_all_from_l3miss_mod\000\000other\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x54404e\000\000\000\000\000\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=233089 */ "pm_inst_all_from_ll4\000\000other\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to instruction fetches and prefetches\000event=0x51404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=233423 */ "pm_inst_all_from_lmem\000\000other\000The processor's Instruction cache was reloaded from the local chip's Memory due to instruction fetches and prefetches\000event=0x524048\000\000\000\000\000\000The processor's Instruction cache was reloaded from the local chip's Memory due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=233754 */ "pm_inst_all_from_memory\000\000other\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to instruction fetches and prefetches\000event=0x52404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=234159 */ "pm_inst_all_from_off_chip_cache\000\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to instruction fetches and prefetches\000event=0x54404a\000\000\000\000\000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=234636 */ "pm_inst_all_from_on_chip_cache\000\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to instruction fetches and prefetches\000event=0x514048\000\000\000\000\000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=235066 */ "pm_inst_all_from_rl2l3_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to instruction fetches and prefetches\000event=0x524046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=235546 */ "pm_inst_all_from_rl2l3_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to instruction fetches and prefetches\000event=0x51404a\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=236022 */ "pm_inst_all_from_rl4\000\000other\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to instruction fetches and prefetches\000event=0x52404a\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=236412 */ "pm_inst_all_from_rmem\000\000other\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to instruction fetches and prefetches\000event=0x53404a\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=236811 */ "pm_inst_all_grp_pump_cpred\000\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for instruction fetches and prefetches\000event=0x524050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for an instruction fetch\000"
/* offset=237073 */ "pm_inst_all_grp_pump_mpred\000\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for instruction fetches and prefetches\000event=0x524052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=237500 */ "pm_inst_all_grp_pump_mpred_rty\000\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for instruction fetches and prefetches\000event=0x514052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor an instruction fetch\000"
/* offset=237842 */ "pm_inst_all_pump_cpred\000\000other\000Pump prediction correct. Counts across all types of pumps for instruction fetches and prefetches\000event=0x514054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumpsfor an instruction fetch\000"
/* offset=238071 */ "pm_inst_all_pump_mpred\000\000other\000Pump misprediction. Counts across all types of pumps for instruction fetches and prefetches\000event=0x544052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor an instruction fetch\000"
/* offset=238290 */ "pm_inst_all_sys_pump_cpred\000\000other\000Initial and Final Pump Scope was system pump (prediction=correct) for instruction fetches and prefetches\000event=0x534050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for an instruction fetch\000"
/* offset=238554 */ "pm_inst_all_sys_pump_mpred\000\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for instruction fetches and prefetches\000event=0x534052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=239063 */ "pm_inst_all_sys_pump_mpred_rty\000\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for instruction fetches and prefetches\000event=0x544050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for an instruction fetch\000"
/* offset=239366 */ "pm_inst_chip_pump_cpred\000\000frontend\000Initial and Final Pump Scope was chip pump (prediction=correct) for an instruction fetch\000event=0x14050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for an instruction fetch\000"
/* offset=239632 */ "pm_inst_chip_pump_cpred\000\000pipeline\000Initial and Final Pump Scope was chip pump (prediction=correct) for an instruction fetch\000event=0x14050\000\000\000\000\000\000\000"
/* offset=239775 */ "pm_inst_cmpl\000\000frontend\000Number of PowerPC Instructions that completed\000event=0x2\000\000\000\000\000\000PPC Instructions Finished (completed)\000"
/* offset=239897 */ "pm_inst_cmpl\000\000pipeline\000Number of PowerPC Instructions that completed\000event=0x2\000\000\000\000\000\000\000"
/* offset=239982 */ "pm_inst_cmpl\000\000pipeline\000PowerPC instructions completed\000event=0x100fe\000\000\000\000\000\000\000"
/* offset=240056 */ "pm_inst_disp\000\000frontend\000PPC Dispatched\000event=0x200f2\000\000\000\000\000\000\000"
/* offset=240114 */ "pm_inst_disp\000\000other\000# PPC Dispatched\000event=0x200f2\000\000\000\000\000\000\000"
/* offset=240171 */ "pm_inst_disp\000\000others\000PowerPC instructions dispatched\000event=0x200f2\000\000\000\000\000\000\000"
/* offset=240244 */ "pm_inst_fin\000\000others\000Instructions finished\000event=0x40030\000\000\000\000\000\000\000"
/* offset=240306 */ "pm_inst_from_dl2l3_mod\000\000frontend\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x44048\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=240793 */ "pm_inst_from_dl2l3_mod\000\000marked\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x44048\000\000\000\000\000\000\000"
/* offset=241039 */ "pm_inst_from_dl2l3_shr\000\000frontend\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x34048\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=241522 */ "pm_inst_from_dl2l3_shr\000\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x34048\000\000\000\000\000\000\000"
/* offset=241766 */ "pm_inst_from_dl4\000\000frontend\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x3404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=242161 */ "pm_inst_from_dl4\000\000marked\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x3404c\000\000\000\000\000\000\000"
/* offset=242358 */ "pm_inst_from_dmem\000\000frontend\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x4404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=242756 */ "pm_inst_from_dmem\000\000marked\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x4404c\000\000\000\000\000\000\000"
/* offset=242955 */ "pm_inst_from_l1\000\000other\000Instruction fetches from L1.  L1 instruction hit\000event=0x4080\000\000\000\000\000\000\000"
/* offset=243046 */ "pm_inst_from_l1\000\000other\000Instruction fetches from L1\000event=0x4080\000\000\000\000\000\000\000"
/* offset=243116 */ "pm_inst_from_l21_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x44046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=243514 */ "pm_inst_from_l21_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x44046\000\000\000\000\000\000\000"
/* offset=243715 */ "pm_inst_from_l21_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x34046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=244109 */ "pm_inst_from_l21_shr\000\000translation\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x34046\000\000\000\000\000\000\000"
/* offset=244314 */ "pm_inst_from_l2\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 due to an instruction fetch (not prefetch)\000event=0x14042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=244626 */ "pm_inst_from_l2\000\000marked\000The processor's Instruction cache was reloaded from local core's L2 due to an instruction fetch (not prefetch)\000event=0x14042\000\000\000\000\000\000\000"
/* offset=244781 */ "pm_inst_from_l2_disp_conflict_ldhitst\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to an instruction fetch (not prefetch)\000event=0x34040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=245173 */ "pm_inst_from_l2_disp_conflict_ldhitst\000\000marked\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to an instruction fetch (not prefetch)\000event=0x34040\000\000\000\000\000\000\000"
/* offset=245379 */ "pm_inst_from_l2_disp_conflict_other\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x44040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=245757 */ "pm_inst_from_l2_disp_conflict_other\000\000marked\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x44040\000\000\000\000\000\000\000"
/* offset=245955 */ "pm_inst_from_l2_mepf\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=246364 */ "pm_inst_from_l2_mepf\000\000other\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24040\000\000\000\000\000\000\000"
/* offset=246569 */ "pm_inst_from_l2_no_conflict\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to an instruction fetch (not prefetch)\000event=0x14040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=246927 */ "pm_inst_from_l2_no_conflict\000\000marked\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to an instruction fetch (not prefetch)\000event=0x14040\000\000\000\000\000\000\000"
/* offset=247111 */ "pm_inst_from_l2miss\000\000frontend\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to an instruction fetch (not prefetch)\000event=0x1404e\000\000\000\000\000\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=247479 */ "pm_inst_from_l2miss\000\000translation\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to an instruction fetch (not prefetch)\000event=0x1404e\000\000\000\000\000\000\000"
/* offset=247669 */ "pm_inst_from_l31_eco_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x44044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=248079 */ "pm_inst_from_l31_eco_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x44044\000\000\000\000\000\000\000"
/* offset=248288 */ "pm_inst_from_l31_eco_shr\000\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x34044\000\000\000\000\000\000\000"
/* offset=248496 */ "pm_inst_from_l31_eco_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x34044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=248902 */ "pm_inst_from_l31_mod\000\000marked\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x24044\000\000\000\000\000\000\000"
/* offset=249104 */ "pm_inst_from_l31_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x24044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=249502 */ "pm_inst_from_l31_shr\000\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14046\000\000\000\000\000\000\000"
/* offset=249702 */ "pm_inst_from_l31_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=250096 */ "pm_inst_from_l3\000\000frontend\000The processor's Instruction cache was reloaded from local core's L3 due to an instruction fetch (not prefetch)\000event=0x44042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=250408 */ "pm_inst_from_l3\000\000translation\000The processor's Instruction cache was reloaded from local core's L3 due to an instruction fetch (not prefetch)\000event=0x44042\000\000\000\000\000\000\000"
/* offset=250568 */ "pm_inst_from_l3_disp_conflict\000\000frontend\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x34042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=250940 */ "pm_inst_from_l3_disp_conflict\000\000translation\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x34042\000\000\000\000\000\000\000"
/* offset=251137 */ "pm_inst_from_l3_mepf\000\000frontend\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=251546 */ "pm_inst_from_l3_mepf\000\000translation\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24042\000\000\000\000\000\000\000"
/* offset=251757 */ "pm_inst_from_l3_no_conflict\000\000frontend\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to an instruction fetch (not prefetch)\000event=0x14044\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=252115 */ "pm_inst_from_l3_no_conflict\000\000translation\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to an instruction fetch (not prefetch)\000event=0x14044\000\000\000\000\000\000\000"
/* offset=252304 */ "pm_inst_from_l3miss\000\000frontend\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x300fa\000\000\000\000\000\000Inst from L3 miss\000"
/* offset=252444 */ "pm_inst_from_l3miss\000\000frontend\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x300fa\000\000\000\000\000\000\000"
/* offset=252567 */ "pm_inst_from_l3miss\000\000frontend\000The processor's instruction cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss\000event=0x300fa\000\000\000\000\000\000\000"
/* offset=252741 */ "pm_inst_from_l3miss_mod\000\000frontend\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x4404e\000\000\000\000\000\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=253097 */ "pm_inst_from_l3miss_mod\000\000marked\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x4404e\000\000\000\000\000\000\000"
/* offset=253270 */ "pm_inst_from_ll4\000\000frontend\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to an instruction fetch (not prefetch)\000event=0x1404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=253603 */ "pm_inst_from_ll4\000\000marked\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to an instruction fetch (not prefetch)\000event=0x1404c\000\000\000\000\000\000\000"
/* offset=253769 */ "pm_inst_from_lmem\000\000frontend\000The processor's Instruction cache was reloaded from the local chip's Memory due to an instruction fetch (not prefetch)\000event=0x24048\000\000\000\000\000\000The processor's Instruction cache was reloaded from the local chip's Memory due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=254099 */ "pm_inst_from_lmem\000\000other\000The processor's Instruction cache was reloaded from the local chip's Memory due to an instruction fetch (not prefetch)\000event=0x24048\000\000\000\000\000\000\000"
/* offset=254263 */ "pm_inst_from_memory\000\000frontend\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to an instruction fetch (not prefetch)\000event=0x2404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=254667 */ "pm_inst_from_memory\000\000pipeline\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to an instruction fetch (not prefetch)\000event=0x2404c\000\000\000\000\000\000\000"
/* offset=254872 */ "pm_inst_from_off_chip_cache\000\000frontend\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to an instruction fetch (not prefetch)\000event=0x4404a\000\000\000\000\000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=255348 */ "pm_inst_from_off_chip_cache\000\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to an instruction fetch (not prefetch)\000event=0x4404a\000\000\000\000\000\000\000"
/* offset=255590 */ "pm_inst_from_on_chip_cache\000\000cache\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14048\000\000\000\000\000\000\000"
/* offset=255808 */ "pm_inst_from_on_chip_cache\000\000frontend\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14048\000\000\000\000\000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=256237 */ "pm_inst_from_rl2l3_mod\000\000cache\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x24046\000\000\000\000\000\000\000"
/* offset=256478 */ "pm_inst_from_rl2l3_mod\000\000frontend\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x24046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=256957 */ "pm_inst_from_rl2l3_shr\000\000cache\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x1404a\000\000\000\000\000\000\000"
/* offset=257196 */ "pm_inst_from_rl2l3_shr\000\000frontend\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x1404a\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=257671 */ "pm_inst_from_rl4\000\000cache\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x2404a\000\000\000\000\000\000\000"
/* offset=257864 */ "pm_inst_from_rl4\000\000frontend\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x2404a\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=258253 */ "pm_inst_from_rmem\000\000frontend\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x3404a\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=258651 */ "pm_inst_from_rmem\000\000memory\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x3404a\000\000\000\000\000\000\000"
/* offset=258850 */ "pm_inst_grp_pump_cpred\000\000frontend\000Initial and Final Pump Scope was group pump (prediction=correct) for an instruction fetch\000event=0x24050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for an instruction fetch\000"
/* offset=259096 */ "pm_inst_grp_pump_cpred\000\000memory\000Initial and Final Pump Scope was group pump (prediction=correct) for an instruction fetch (demand only)\000event=0x2c05c\000\000\000\000\000\000\000"
/* offset=259251 */ "pm_inst_grp_pump_mpred\000\000frontend\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for an instruction fetch\000event=0x24052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=259662 */ "pm_inst_grp_pump_mpred\000\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for an instruction fetch (demand only)\000event=0x2c05e\000\000\000\000\000\000\000"
/* offset=259834 */ "pm_inst_grp_pump_mpred_rty\000\000frontend\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for an instruction fetch\000event=0x14052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor an instruction fetch\000"
/* offset=260160 */ "pm_inst_grp_pump_mpred_rty\000\000pipeline\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for an instruction fetch\000event=0x14052\000\000\000\000\000\000\000"
/* offset=260314 */ "pm_inst_imc_match_cmpl\000\000frontend\000IMC Match Count ( Not architected in P8)\000event=0x1003a\000\000\000\000\000\000\000"
/* offset=260408 */ "pm_inst_imc_match_cmpl\000\000other\000IMC Match Count\000event=0x4001c\000\000\000\000\000\000\000"
/* offset=260474 */ "pm_inst_imc_match_disp\000\000other\000Matched Instructions Dispatched\000event=0x30016\000\000\000\000\000\000IMC Matches dispatched\000"
/* offset=260578 */ "pm_inst_pump_cpred\000\000frontend\000Pump prediction correct. Counts across all types of pumps for an instruction fetch\000event=0x14054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumpsfor an instruction fetch\000"
/* offset=260791 */ "pm_inst_pump_cpred\000\000frontend\000Pump prediction correct. Counts across all types of pumps for an instruction fetch\000event=0x14054\000\000\000\000\000\000\000"
/* offset=260923 */ "pm_inst_pump_mpred\000\000frontend\000Pump misprediction. Counts across all types of pumps for an instruction fetch\000event=0x44052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor an instruction fetch\000"
/* offset=261126 */ "pm_inst_pump_mpred\000\000frontend\000Pump misprediction. Counts across all types of pumps for an instruction fetch\000event=0x44052\000\000\000\000\000\000\000"
/* offset=261253 */ "pm_inst_sys_pump_cpred\000\000frontend\000Initial and Final Pump Scope was system pump (prediction=correct) for an instruction fetch\000event=0x34050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for an instruction fetch\000"
/* offset=261501 */ "pm_inst_sys_pump_cpred\000\000frontend\000Initial and Final Pump Scope was system pump (prediction=correct) for an instruction fetch\000event=0x34050\000\000\000\000\000\000\000"
/* offset=261645 */ "pm_inst_sys_pump_mpred\000\000frontend\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for an instruction fetch\000event=0x34052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=262138 */ "pm_inst_sys_pump_mpred\000\000frontend\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for an instruction fetch\000event=0x34052\000\000\000\000\000\000\000"
/* offset=262382 */ "pm_inst_sys_pump_mpred_rty\000\000frontend\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for an instruction fetch\000event=0x44050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for an instruction fetch\000"
/* offset=262669 */ "pm_inst_sys_pump_mpred_rty\000\000frontend\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for an instruction fetch\000event=0x44050\000\000\000\000\000\000\000"
/* offset=262830 */ "pm_iops_cmpl\000\000frontend\000Internal Operations completed\000event=0x24050\000\000\000\000\000\000\000"
/* offset=262903 */ "pm_iops_cmpl\000\000pipeline\000Internal Operations completed\000event=0x10014\000\000\000\000\000\000IOPS Completed\000"
/* offset=262990 */ "pm_iops_disp\000\000frontend\000Internal Operations dispatched. PM_IOPS_DISP / PM_INST_DISP will show the average number of internal operations per PowerPC instruction\000event=0x24050\000\000\000\000\000\000\000"
/* offset=263169 */ "pm_iops_disp\000\000other\000Internal Operations dispatched\000event=0x30014\000\000\000\000\000\000IOPS dispatched\000"
/* offset=263255 */ "pm_ipteg_from_dl2l3_mod\000\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x45048\000\000\000\000\000\000\000"
/* offset=263491 */ "pm_ipteg_from_dl2l3_shr\000\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x35048\000\000\000\000\000\000\000"
/* offset=263725 */ "pm_ipteg_from_dl2l3_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x35048\000\000\000\000\000\000\000"
/* offset=263956 */ "pm_ipteg_from_dl4\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a instruction side request\000event=0x3504c\000\000\000\000\000\000\000"
/* offset=264143 */ "pm_ipteg_from_dl4\000\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a instruction side request\000event=0x3504c\000\000\000\000\000\000\000"
/* offset=264327 */ "pm_ipteg_from_dmem\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a instruction side request\000event=0x4504c\000\000\000\000\000\000\000"
/* offset=264516 */ "pm_ipteg_from_dmem\000\000other\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a instruction side request\000event=0x4504c\000\000\000\000\000\000\000"
/* offset=264702 */ "pm_ipteg_from_l21_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a instruction side request\000event=0x45046\000\000\000\000\000\000\000"
/* offset=264892 */ "pm_ipteg_from_l21_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a instruction side request\000event=0x45046\000\000\000\000\000\000\000"
/* offset=265081 */ "pm_ipteg_from_l21_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a instruction side request\000event=0x35046\000\000\000\000\000\000\000"
/* offset=265269 */ "pm_ipteg_from_l21_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a instruction side request\000event=0x35046\000\000\000\000\000\000\000"
/* offset=265456 */ "pm_ipteg_from_l2\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 due to a instruction side request\000event=0x15042\000\000\000\000\000\000\000"
/* offset=265601 */ "pm_ipteg_from_l2\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a instruction side request\000event=0x15042\000\000\000\000\000\000\000"
/* offset=265744 */ "pm_ipteg_from_l2_disp_conflict_ldhitst\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a instruction side request\000event=0x35040\000\000\000\000\000\000\000"
/* offset=265937 */ "pm_ipteg_from_l2_disp_conflict_other\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a instruction side request\000event=0x45040\000\000\000\000\000\000\000"
/* offset=266122 */ "pm_ipteg_from_l2_mepf\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a instruction side request\000event=0x25040\000\000\000\000\000\000\000"
/* offset=266318 */ "pm_ipteg_from_l2_mepf\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a instruction side request\000event=0x25040\000\000\000\000\000\000\000"
/* offset=266512 */ "pm_ipteg_from_l2_no_conflict\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a instruction side request\000event=0x15040\000\000\000\000\000\000\000"
/* offset=266686 */ "pm_ipteg_from_l2_no_conflict\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a instruction side request\000event=0x15040\000\000\000\000\000\000\000"
/* offset=266857 */ "pm_ipteg_from_l2miss\000\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a instruction side request\000event=0x1504e\000\000\000\000\000\000\000"
/* offset=267032 */ "pm_ipteg_from_l2miss\000\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a instruction side request\000event=0x1504e\000\000\000\000\000\000\000"
/* offset=267205 */ "pm_ipteg_from_l31_eco_mod\000\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x45044\000\000\000\000\000\000\000"
/* offset=267405 */ "pm_ipteg_from_l31_eco_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x45044\000\000\000\000\000\000\000"
/* offset=267602 */ "pm_ipteg_from_l31_eco_shr\000\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x35044\000\000\000\000\000\000\000"
/* offset=267800 */ "pm_ipteg_from_l31_eco_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x35044\000\000\000\000\000\000\000"
/* offset=267995 */ "pm_ipteg_from_l31_mod\000\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a instruction side request\000event=0x25044\000\000\000\000\000\000\000"
/* offset=268187 */ "pm_ipteg_from_l31_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a instruction side request\000event=0x25044\000\000\000\000\000\000\000"
/* offset=268376 */ "pm_ipteg_from_l31_shr\000\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a instruction side request\000event=0x15046\000\000\000\000\000\000\000"
/* offset=268566 */ "pm_ipteg_from_l31_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a instruction side request\000event=0x15046\000\000\000\000\000\000\000"
/* offset=268753 */ "pm_ipteg_from_l3\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 due to a instruction side request\000event=0x45042\000\000\000\000\000\000\000"
/* offset=268898 */ "pm_ipteg_from_l3\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 due to a instruction side request\000event=0x45042\000\000\000\000\000\000\000"
/* offset=269041 */ "pm_ipteg_from_l3_disp_conflict\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a instruction side request\000event=0x35042\000\000\000\000\000\000\000"
/* offset=269223 */ "pm_ipteg_from_l3_disp_conflict\000\000other\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a instruction side request\000event=0x35042\000\000\000\000\000\000\000"
/* offset=269402 */ "pm_ipteg_from_l3_mepf\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a instruction side request\000event=0x25042\000\000\000\000\000\000\000"
/* offset=269598 */ "pm_ipteg_from_l3_no_conflict\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a instruction side request\000event=0x15044\000\000\000\000\000\000\000"
/* offset=269772 */ "pm_ipteg_from_l3miss\000\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a instruction side request\000event=0x4504e\000\000\000\000\000\000\000"
/* offset=269947 */ "pm_ipteg_from_ll4\000\000frontend\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a instruction side request\000event=0x1504c\000\000\000\000\000\000\000"
/* offset=270103 */ "pm_ipteg_from_ll4\000\000other\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a instruction side request\000event=0x1504c\000\000\000\000\000\000\000"
/* offset=270256 */ "pm_ipteg_from_lmem\000\000frontend\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a instruction side request\000event=0x25048\000\000\000\000\000\000\000"
/* offset=270411 */ "pm_ipteg_from_lmem\000\000other\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a instruction side request\000event=0x25048\000\000\000\000\000\000\000"
/* offset=270563 */ "pm_ipteg_from_memory\000\000frontend\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a instruction side request\000event=0x2504c\000\000\000\000\000\000\000"
/* offset=270756 */ "pm_ipteg_from_memory\000\000translation\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a instruction side request\000event=0x2504c\000\000\000\000\000\000\000"
/* offset=270952 */ "pm_ipteg_from_off_chip_cache\000\000frontend\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a instruction side request\000event=0x4504a\000\000\000\000\000\000\000"
/* offset=271185 */ "pm_ipteg_from_off_chip_cache\000\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a instruction side request\000event=0x4504a\000\000\000\000\000\000\000"
/* offset=271421 */ "pm_ipteg_from_on_chip_cache\000\000frontend\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a instruction side request\000event=0x15048\000\000\000\000\000\000\000"
/* offset=271630 */ "pm_ipteg_from_on_chip_cache\000\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a instruction side request\000event=0x15048\000\000\000\000\000\000\000"
/* offset=271842 */ "pm_ipteg_from_rl2l3_mod\000\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x25046\000\000\000\000\000\000\000"
/* offset=272074 */ "pm_ipteg_from_rl2l3_mod\000\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x25046\000\000\000\000\000\000\000"
/* offset=272309 */ "pm_ipteg_from_rl2l3_shr\000\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x1504a\000\000\000\000\000\000\000"
/* offset=272539 */ "pm_ipteg_from_rl2l3_shr\000\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x1504a\000\000\000\000\000\000\000"
/* offset=272772 */ "pm_ipteg_from_rl4\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a instruction side request\000event=0x2504a\000\000\000\000\000\000\000"
/* offset=272956 */ "pm_ipteg_from_rl4\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a instruction side request\000event=0x2504a\000\000\000\000\000\000\000"
/* offset=273143 */ "pm_ipteg_from_rmem\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a instruction side request\000event=0x3504a\000\000\000\000\000\000\000"
/* offset=273332 */ "pm_ipteg_from_rmem\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a instruction side request\000event=0x3504a\000\000\000\000\000\000\000"
/* offset=273524 */ "pm_iside_disp\000\000other\000All I-side-instruction-fetch dispatch attempts for this thread\000event=0x1688a\000\000\000\000\000\000\000"
/* offset=273628 */ "pm_iside_disp_fail_addr\000\000other\000All I-side-instruction-fetch dispatch attempts for this thread that failed due to an address collision conflict with an L2 machine already working on this line (e.g. ld-hit-stq or RC/CO/SN machines)\000event=0x2608a\000\000\000\000\000\000\000"
/* offset=273878 */ "pm_iside_disp_fail_other\000\000other\000All I-side-instruction-fetch dispatch attempts for this thread that failed due to reasons other than an address collision conflict with an L2 machine (e.g. no available RC/CO machines)\000event=0x2688a\000\000\000\000\000\000\000"
/* offset=274115 */ "pm_iside_l2memacc\000\000other\000Valid when first beat of data comes in for an I-side fetch where data came from memory\000event=0x26890\000\000\000\000\000\000\000"
/* offset=274247 */ "pm_iside_l2memacc\000\000other\000valid when first beat of data comes in for an i-side fetch where data came from mem(or L4)\000event=0x4608e\000\000\000\000\000\000\000"
/* offset=274383 */ "pm_iside_mru_touch\000\000other\000I-side L2 MRU touch sent to L2 for this thread I-side L2 MRU touch commands sent to the L2 for this thread\000event=0x46880\000\000\000\000\000\000\000"
/* offset=274536 */ "pm_islb_miss\000\000frontend\000I SLB Miss\000event=0xd096\000\000\000\000\000\000\000"
/* offset=274589 */ "pm_islb_miss\000\000other\000Instruction SLB Miss - Total of all segment sizes\000event=0xd8a8\000\000\000\000\000\000\000"
/* offset=274678 */ "pm_isq_0_8_entries\000\000other\000Cycles in which 8 or less Issue Queue entries are in use. This is a shared event, not per thread\000event=0x3005a\000\000\000\000\000\000\000"
/* offset=274821 */ "pm_isq_36_44_entries\000\000marked\000Cycles in which 36 or more Issue Queue entries are in use. This is a shared event, not per thread. There are 44 issue queue entries across 4 slices in the whole core\000event=0x4000a\000\000\000\000\000\000\000"
/* offset=275036 */ "pm_issue_cancel\000\000frontend\000An instruction issued and the issue was later cancelled. Only one cancel per PowerPC instruction\000event=0x2405e\000\000\000\000\000\000\000"
/* offset=275179 */ "pm_issue_kill\000\000frontend\000Cycles in which an instruction or group of instructions were cancelled after being issued. This event increments once per occurrence, regardless of how many instructions are included in the issue group\000event=0x40006\000\000\000\000\000\000\000"
/* offset=275425 */ "pm_issue_stall\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was dispatched but not issued yet\000event=0x20004\000\000\000\000\000\000\000"
/* offset=275559 */ "pm_isu0_iss_hold_all\000\000other\000All ISU rejects\000event=0x3080\000\000\000\000\000\000\000"
/* offset=275622 */ "pm_isu1_iss_hold_all\000\000other\000All ISU rejects\000event=0x3084\000\000\000\000\000\000\000"
/* offset=275685 */ "pm_isu2_iss_hold_all\000\000other\000All ISU rejects\000event=0x3880\000\000\000\000\000\000\000"
/* offset=275748 */ "pm_isu3_iss_hold_all\000\000other\000All ISU rejects\000event=0x3884\000\000\000\000\000\000\000"
/* offset=275811 */ "pm_isu_ref_fx0\000\000other\000FX0 ISU reject\000event=0x30ac\000\000\000\000\000\000\000"
/* offset=275867 */ "pm_isu_ref_fx1\000\000other\000FX1 ISU reject\000event=0x30ae\000\000\000\000\000\000\000"
/* offset=275923 */ "pm_isu_ref_fxu\000\000other\000FXU ISU reject from either pipe\000event=0x38ac\000\000\000\000\000\000\000"
/* offset=275996 */ "pm_isu_ref_ls0\000\000other\000LS0 ISU reject\000event=0x30b0\000\000\000\000\000\000\000"
/* offset=276052 */ "pm_isu_ref_ls1\000\000other\000LS1 ISU reject\000event=0x30b2\000\000\000\000\000\000\000"
/* offset=276108 */ "pm_isu_ref_ls2\000\000other\000LS2 ISU reject\000event=0x30b4\000\000\000\000\000\000\000"
/* offset=276164 */ "pm_isu_ref_ls3\000\000other\000LS3 ISU reject\000event=0x30b6\000\000\000\000\000\000\000"
/* offset=276220 */ "pm_isu_rej_vs0\000\000other\000VS0 ISU reject\000event=0x30a8\000\000\000\000\000\000\000"
/* offset=276276 */ "pm_isu_rej_vs1\000\000other\000VS1 ISU reject\000event=0x30aa\000\000\000\000\000\000\000"
/* offset=276332 */ "pm_isu_rej_vsu\000\000other\000VSU ISU reject from either pipe\000event=0x38a8\000\000\000\000\000\000\000"
/* offset=276405 */ "pm_isu_reject_res_na\000\000other\000ISU reject due to resource not available\000event=0x30a2\000\000\000\000\000\000\000"
/* offset=276493 */ "pm_isu_reject_sar_bypass\000\000other\000Reject because of SAR bypass\000event=0x309e\000\000\000\000\000\000\000"
/* offset=276573 */ "pm_isu_reject_src_na\000\000other\000ISU reject due to source not available\000event=0x30a0\000\000\000\000\000\000\000"
/* offset=276659 */ "pm_isu_rejects_all\000\000other\000All isu rejects could be more than 1 per cycle\000event=0x309c\000\000\000\000\000\000\000"
/* offset=276751 */ "pm_isync\000\000other\000Isync completion count per thread\000event=0x2884\000\000\000\000\000\000\000"
/* offset=276820 */ "pm_isync\000\000other\000Isync count per thread\000event=0x30b8\000\000\000\000\000\000\000"
/* offset=276878 */ "pm_itlb_hit\000\000memory\000The PTE required to translate the instruction address was resident in the TLB (instruction TLB access/IERAT reload). Applies to both HPT and RPT. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x2001a\000\000\000\000\000\000\000"
/* offset=277189 */ "pm_itlb_hit_1g\000\000frontend\000Instruction TLB hit (IERAT reload) page size 1G, which implies Radix Page Table translation is in use. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x3f046\000\000\000\000\000\000\000"
/* offset=277462 */ "pm_itlb_miss\000\000frontend\000ITLB Reloaded (always zero on POWER6)\000event=0x400fc\000\000\000\000\000\000\000"
/* offset=277543 */ "pm_itlb_miss\000\000marked\000ITLB Reloaded. Counts 1 per ITLB miss for HPT but multiple for radix depending on number of levels traveresed\000event=0x400fc\000\000\000\000\000\000\000"
/* offset=277694 */ "pm_l1_dcache_reload_valid\000\000cache\000DL1 reloaded due to Demand Load\000event=0x300f6\000\000\000\000\000\000\000"
/* offset=277779 */ "pm_l1_dcache_reload_valid\000\000marked\000DL1 reloaded due to Demand Load\000event=0x300f6\000\000\000\000\000\000\000"
/* offset=277865 */ "pm_l1_dcache_reloaded_all\000\000cache\000L1 data cache reloaded for demand or prefetch\000event=0x1002c\000\000\000\000\000\000\000"
/* offset=277964 */ "pm_l1_dcache_reloaded_all\000\000marked\000L1 data cache reloaded for demand. If MMCR1[16] is 1, prefetches will be included as well\000event=0x1002c\000\000\000\000\000\000\000"
/* offset=278108 */ "pm_l1_demand_write\000\000other\000Instruction Demand sectors wriittent into IL1\000event=0x408c\000\000\000\000\000\000\000"
/* offset=278199 */ "pm_l1_demand_write\000\000other\000Instruction Demand sectors written into IL1\000event=0x408c\000\000\000\000\000\000\000"
/* offset=278288 */ "pm_l1_icache_miss\000\000frontend\000Demand iCache Miss\000event=0x200fd\000\000\000\000\000\000\000"
/* offset=278355 */ "pm_l1_icache_miss\000\000marked\000Demand iCache Miss\000event=0x200fd\000\000\000\000\000\000\000"
/* offset=278420 */ "pm_l1_icache_reloaded_all\000\000frontend\000Counts all Icache reloads includes demand, prefetchm prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\000\000\000\000\000\000"
/* offset=278589 */ "pm_l1_icache_reloaded_all\000\000marked\000Counts all Icache reloads includes demand, prefetch, prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\000\000\000\000\000\000"
/* offset=278756 */ "pm_l1_icache_reloaded_pref\000\000frontend\000Counts all Icache prefetch reloads ( includes demand turned into prefetch)\000event=0x30068\000\000\000\000\000\000\000"
/* offset=278888 */ "pm_l1_icache_reloaded_pref\000\000marked\000Counts all Icache prefetch reloads ( includes demand turned into prefetch)\000event=0x30068\000\000\000\000\000\000\000"
/* offset=279018 */ "pm_l1_pref\000\000other\000A data line was written to the L1 due to a hardware or software prefetch\000event=0x20054\000\000\000\000\000\000\000"
/* offset=279129 */ "pm_l1_sw_pref\000\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xe880\000\000\000\000\000\000\000"
/* offset=279227 */ "pm_l1miss_lat_exc_1024\000\000other\000L1 misses that took longer than 1024 cyles to resolve (miss to reload)\000event=0x200301ea\000\000\000\000\000\000Reload latency exceeded 1024 cyc\000"
/* offset=279383 */ "pm_l1miss_lat_exc_2048\000\000other\000L1 misses that took longer than 2048 cyles to resolve (miss to reload)\000event=0x200401ec\000\000\000\000\000\000Reload latency exceeded 2048 cyc\000"
/* offset=279539 */ "pm_l1miss_lat_exc_256\000\000other\000L1 misses that took longer than 256 cyles to resolve (miss to reload)\000event=0x200101e8\000\000\000\000\000\000Reload latency exceeded 256 cyc\000"
/* offset=279692 */ "pm_l1miss_lat_exc_32\000\000other\000L1 misses that took longer than 32 cyles to resolve (miss to reload)\000event=0x200201e6\000\000\000\000\000\000Reload latency exceeded 32 cyc\000"
/* offset=279842 */ "pm_l1pf_l2memacc\000\000other\000Valid when first beat of data comes in for an L1PF where data came from memory\000event=0x16890\000\000\000\000\000\000\000"
/* offset=279965 */ "pm_l1pf_l2memacc\000\000other\000valid when first beat of data comes in for an L1pref where data came from mem(or L4)\000event=0x26086\000\000\000\000\000\000\000"
/* offset=280094 */ "pm_l2_castout_mod\000\000other\000L2 Castouts - Modified (M,Mu,Me)\000event=0x16082\000\000\000\000\000\000\000"
/* offset=280172 */ "pm_l2_castout_shr\000\000other\000L2 Castouts - Shared (Tx,Sx)\000event=0x16882\000\000\000\000\000\000\000"
/* offset=280246 */ "pm_l2_chip_pump\000\000other\000RC requests that were local (aka chip) pump attempts\000event=0x46088\000\000\000\000\000\000\000"
/* offset=280342 */ "pm_l2_chip_pump\000\000other\000RC requests that were local on chip pump attempts\000event=0x27084\000\000\000\000\000\000\000"
/* offset=280435 */ "pm_l2_dc_inv\000\000other\000D-cache invalidates sent over the reload bus to the core\000event=0x26882\000\000\000\000\000\000\000"
/* offset=280532 */ "pm_l2_disp_all_l2miss\000\000other\000All successful D-side-Ld/St or I-side-instruction-fetch dispatches for this thread that were an L2 miss\000event=0x46080\000\000\000\000\000\000\000"
/* offset=280685 */ "pm_l2_group_pump\000\000other\000RC requests that were on Node Pump attempts\000event=0x27086\000\000\000\000\000\000\000"
/* offset=280773 */ "pm_l2_group_pump\000\000other\000RC requests that were on group (aka nodel) pump attempts\000event=0x46888\000\000\000\000\000\000\000"
/* offset=280874 */ "pm_l2_grp_guess_correct\000\000other\000L2 guess grp (GS or NNS) and guess was correct (data intra-group AND ^on-chip)\000event=0x26088\000\000\000\000\000\000\000"
/* offset=281004 */ "pm_l2_grp_guess_wrong\000\000other\000L2 guess grp (GS or NNS) and guess was not correct (ie data on-chip OR beyond-group)\000event=0x26888\000\000\000\000\000\000\000"
/* offset=281138 */ "pm_l2_ic_inv\000\000other\000I-cache Invalidates sent over the realod bus to the core\000event=0x26082\000\000\000\000\000\000\000"
/* offset=281235 */ "pm_l2_inst\000\000other\000All successful I-side-instruction-fetch (e.g. i-demand, i-prefetch) dispatches for this thread\000event=0x36080\000\000\000\000\000\000\000"
/* offset=281368 */ "pm_l2_inst_miss\000\000other\000All successful I-side-instruction-fetch (e.g. i-demand, i-prefetch) dispatches for this thread that were an L2 miss\000event=0x36880\000\000\000\000\000\000\000"
/* offset=281527 */ "pm_l2_ld\000\000other\000All successful D-side Load dispatches for this thread (L2 miss + L2 hits)\000event=0x16080\000\000\000\000\000\000\000"
/* offset=281637 */ "pm_l2_ld_disp\000\000other\000All successful D-side-Ld or I-side-instruction-fetch dispatches for this thread\000event=0x36082\000\000\000\000\000\000\000"
/* offset=281758 */ "pm_l2_ld_hit\000\000other\000All successful D-side-Ld or I-side-instruction-fetch dispatches for this thread that were L2 hits\000event=0x36882\000\000\000\000\000\000\000"
/* offset=281896 */ "pm_l2_ld_miss\000\000other\000All successful D-Side Load dispatches that were an L2 miss for this thread\000event=0x26080\000\000\000\000\000\000\000"
/* offset=282012 */ "pm_l2_ld_miss_128b\000\000other\000All successful D-side load dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 128B (i.e., M=0)\000event=0x16092\000\000\000\000\000\000\000"
/* offset=282213 */ "pm_l2_ld_miss_64b\000\000other\000All successful D-side load dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 64B(i.e., M=1)\000event=0x26092\000\000\000\000\000\000\000"
/* offset=282411 */ "pm_l2_loc_guess_correct\000\000other\000L2 guess local (LNS) and guess was correct (ie data local)\000event=0x16088\000\000\000\000\000\000\000"
/* offset=282521 */ "pm_l2_loc_guess_wrong\000\000other\000L2 guess local (LNS) and guess was not correct (ie data not on chip)\000event=0x16888\000\000\000\000\000\000\000"
/* offset=282639 */ "pm_l2_rc_st_done\000\000other\000Read-claim machine did store to line that was in Tx or Sx (Tagged or Shared state)\000event=0x36086\000\000\000\000\000\000\000"
/* offset=282766 */ "pm_l2_rcld_disp\000\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread\000event=0x16084\000\000\000\000\000\000\000"
/* offset=282885 */ "pm_l2_rcld_disp_fail_addr\000\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread that failed due to an address collision conflicts with an L2 machines already working on this line (e.g. ld-hit-stq or Read-claim/Castout/Snoop machines)\000event=0x16884\000\000\000\000\000\000\000"
/* offset=283168 */ "pm_l2_rcld_disp_fail_other\000\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread that failed due to reasons other than an address collision conflicts with an L2 machines (e.g. Read-Claim/Snoop machine not available)\000event=0x26084\000\000\000\000\000\000\000"
/* offset=283433 */ "pm_l2_rcst_disp\000\000other\000All D-side store dispatch attempts for this thread\000event=0x36084\000\000\000\000\000\000\000"
/* offset=283527 */ "pm_l2_rcst_disp_fail_addr\000\000other\000All D-side store dispatch attempts for this thread that failed due to address collision with RC/CO/SN/SQ\000event=0x36884\000\000\000\000\000\000\000"
/* offset=283685 */ "pm_l2_rcst_disp_fail_other\000\000other\000All D-side store dispatch attempts for this thread that failed due to reason other than address collision\000event=0x46084\000\000\000\000\000\000\000"
/* offset=283845 */ "pm_l2_rty_ld\000\000other\000RC retries on PB for any load from core (excludes DCBFs)\000event=0x3688a\000\000\000\000\000\000\000"
/* offset=283942 */ "pm_l2_rty_st\000\000other\000RC retries on PB for any store from core (excludes DCBFs)\000event=0x3608a\000\000\000\000\000\000\000"
/* offset=284040 */ "pm_l2_rty_st\000\000other\000RC retries on PB for any store from core\000event=0x3708a\000\000\000\000\000\000\000"
/* offset=284121 */ "pm_l2_sn_m_rd_done\000\000other\000Snoop dispatched for a read and was M (true M)\000event=0x46086\000\000\000\000\000\000\000"
/* offset=284214 */ "pm_l2_sn_m_wr_done\000\000other\000SNP dispatched for a write and was M (true M); for DMA cacheinj this will pulse if rty/push is required (won't pulse if cacheinj is accepted)\000event=0x16086\000\000\000\000\000\000\000"
/* offset=284402 */ "pm_l2_sn_sx_i_done\000\000other\000Snoop dispatched and went from Sx to Ix\000event=0x36886\000\000\000\000\000\000\000"
/* offset=284488 */ "pm_l2_st\000\000other\000All successful D-side store dispatches for this thread (L2 miss + L2 hits)\000event=0x16880\000\000\000\000\000\000\000"
/* offset=284599 */ "pm_l2_st\000\000other\000All successful D-side store dispatches for this thread\000event=0x17080\000\000\000\000\000\000\000"
/* offset=284690 */ "pm_l2_st_disp\000\000other\000All successful D-side store dispatches for this thread\000event=0x46082\000\000\000\000\000\000\000"
/* offset=284786 */ "pm_l2_st_hit\000\000other\000All successful D-side store dispatches for this thread that were L2 hits\000event=0x46882\000\000\000\000\000\000\000"
/* offset=284899 */ "pm_l2_st_miss\000\000other\000All successful D-Side Store dispatches that were an L2 miss for this thread\000event=0x26880\000\000\000\000\000\000\000"
/* offset=285016 */ "pm_l2_st_miss\000\000other\000All successful D-side store dispatches for this thread that were L2 Miss\000event=0x17082\000\000\000\000\000\000\000"
/* offset=285130 */ "pm_l2_st_miss_128b\000\000other\000All successful D-side store dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 128B (i.e., M=0)\000event=0x16892\000\000\000\000\000\000\000"
/* offset=285332 */ "pm_l2_st_miss_64b\000\000other\000All successful D-side store dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 64B (i.e., M=1)\000event=0x26892\000\000\000\000\000\000\000"
/* offset=285532 */ "pm_l2_sys_guess_correct\000\000other\000L2 guess system (VGS or RNS) and guess was correct (ie data beyond-group)\000event=0x36088\000\000\000\000\000\000\000"
/* offset=285657 */ "pm_l2_sys_guess_wrong\000\000other\000L2 guess system (VGS or RNS) and guess was not correct (ie data ^beyond-group)\000event=0x36888\000\000\000\000\000\000\000"
/* offset=285785 */ "pm_l2_sys_pump\000\000other\000RC requests that were system pump attempts\000event=0x4688a\000\000\000\000\000\000\000"
/* offset=285870 */ "pm_l2_tm_req_abort\000\000other\000TM abort\000event=0x1e05e\000\000\000\000\000\000\000"
/* offset=285925 */ "pm_l2_tm_st_abort_sister\000\000other\000TM marked store abort\000event=0x3e05c\000\000\000\000\000\000\000"
/* offset=285999 */ "pm_l3_ci_hit\000\000other\000L3 Castins Hit (total count)\000event=0x260a2\000\000\000\000\000\000\000"
/* offset=286068 */ "pm_l3_ci_miss\000\000other\000L3 castins miss (total count)\000event=0x268a2\000\000\000\000\000\000\000"
/* offset=286139 */ "pm_l3_ci_usage\000\000other\000Rotating sample of 16 CI or CO actives\000event=0x168ac\000\000\000\000\000\000\000"
/* offset=286220 */ "pm_l3_ci_usage\000\000other\000rotating sample of 16 CI or CO actives\000event=0x819082\000\000\000\000\000\000\000"
/* offset=286302 */ "pm_l3_cinj\000\000other\000L3 castin of cache inject\000event=0x368a4\000\000\000\000\000\000\000"
/* offset=286366 */ "pm_l3_co0_alloc\000\000other\000lifetime, sample of CO machine 0 valid\000event=0x83908b\000\000\000\000\000\0000.0\000"
/* offset=286452 */ "pm_l3_co0_busy\000\000other\000Lifetime, sample of CO machine 0 valid\000event=0x368ac\000\000\000\000\000\000\000"
/* offset=286533 */ "pm_l3_co0_busy\000\000other\000lifetime, sample of CO machine 0 valid\000event=0x83908a\000\000\000\000\000\000\000"
/* offset=286615 */ "pm_l3_co\000\000other\000L3 castout occurring (does not include casthrough or log writes (cinj/dmaw))\000event=0x360a8\000\000\000\000\000\000\000"
/* offset=286728 */ "pm_l3_co_l31\000\000other\000L3 CO to L3.1 OR of port 0 and 1 ( lossy)\000event=0x28086\000\000\000\000\000\000\000"
/* offset=286810 */ "pm_l3_co_l31\000\000other\000L3 CO to L3.1 OR of port 0 and 1 (lossy = may undercount if two cresps come in the same cyc)\000event=0x268a0\000\000\000\000\000\000\000"
/* offset=286943 */ "pm_l3_co_lco\000\000other\000Total L3 COs occurred on LCO L3.1 (good cresp, may end up in mem on a retry)\000event=0x360a4\000\000\000\000\000\000\000"
/* offset=287060 */ "pm_l3_co_mem\000\000other\000L3 CO to memory OR of port 0 and 1 ( lossy)\000event=0x28084\000\000\000\000\000\000\000"
/* offset=287144 */ "pm_l3_co_mem\000\000other\000L3 CO to memory OR of port 0 and 1 (lossy = may undercount if two cresp come in the same cyc)\000event=0x260a0\000\000\000\000\000\000\000"
/* offset=287278 */ "pm_l3_co_mepf\000\000memory\000L3 CO of line in Mep state ( includes casthrough\000event=0x18082\000\000\000\000\000\000\000"
/* offset=287369 */ "pm_l3_co_mepf\000\000other\000L3 CO of line in Mep state (includes casthrough to memory).  The Mepf state indicates that a line was brought in to satisfy an L3 prefetch request\000event=0x3e05e\000\000\000\000\000\000\000"
/* offset=287557 */ "pm_l3_grp_guess_correct\000\000other\000Prefetch scope predictor selected GS or NNS and was correct\000event=0x168b2\000\000\000\000\000\000\000"
/* offset=287668 */ "pm_l3_grp_guess_wrong_high\000\000other\000Prefetch scope predictor selected GS or NNS, but was wrong because scope was VGS or RNS\000event=0x368b2\000\000\000\000\000\000\000"
/* offset=287810 */ "pm_l3_grp_guess_wrong_low\000\000other\000Prefetch scope predictor selected GS or NNS, but was wrong because scope was LNS\000event=0x360b2\000\000\000\000\000\000\000"
/* offset=287944 */ "pm_l3_hit\000\000other\000L3 Hits (L2 miss hitting L3, including data/instrn/xlate)\000event=0x160a4\000\000\000\000\000\000\000"
/* offset=288039 */ "pm_l3_l2_co_hit\000\000other\000L2 CO hits\000event=0x360a2\000\000\000\000\000\000\000"
/* offset=288093 */ "pm_l3_l2_co_miss\000\000other\000L2 CO miss\000event=0x368a2\000\000\000\000\000\000\000"
/* offset=288148 */ "pm_l3_lat_ci_hit\000\000other\000L3 Lateral Castins Hit\000event=0x460a2\000\000\000\000\000\000\000"
/* offset=288215 */ "pm_l3_lat_ci_miss\000\000other\000L3 Lateral Castins Miss\000event=0x468a2\000\000\000\000\000\000\000"
/* offset=288284 */ "pm_l3_ld_hit\000\000other\000L3 Hits for demand LDs\000event=0x260a4\000\000\000\000\000\000\000"
/* offset=288347 */ "pm_l3_ld_miss\000\000other\000L3 Misses for demand LDs\000event=0x268a4\000\000\000\000\000\000\000"
/* offset=288413 */ "pm_l3_ld_pref\000\000other\000L3 Load Prefetches\000event=0x1e052\000\000\000\000\000\000\000"
/* offset=288473 */ "pm_l3_ld_pref\000\000other\000L3 load prefetch, sourced from a hardware or software stream, was sent to the nest\000event=0xf0b0\000\000\000\000\000\000\000"
/* offset=288596 */ "pm_l3_loc_guess_correct\000\000other\000Prefetch scope predictor selected LNS and was correct\000event=0x160b2\000\000\000\000\000\000\000"
/* offset=288701 */ "pm_l3_loc_guess_wrong\000\000other\000Prefetch scope predictor selected LNS, but was wrong\000event=0x268b2\000\000\000\000\000\000\000"
/* offset=288803 */ "pm_l3_miss\000\000other\000L3 Misses (L2 miss also missing L3, including data/instrn/xlate)\000event=0x168a4\000\000\000\000\000\000\000"
/* offset=288906 */ "pm_l3_p0_co_l31\000\000other\000L3 CO to L3.1 (LCO) port 0 with or without data\000event=0x460aa\000\000\000\000\000\000\000"
/* offset=288997 */ "pm_l3_p0_co_mem\000\000other\000L3 CO to memory port 0 with or without data\000event=0x360aa\000\000\000\000\000\000\000"
/* offset=289084 */ "pm_l3_p0_co_rty\000\000other\000L3 CO received retry port 0 (memory only), every retry counted\000event=0x360ae\000\000\000\000\000\000\000"
/* offset=289190 */ "pm_l3_p0_grp_pump\000\000other\000L3 PF sent with grp scope port 0, counts even retried requests\000event=0x260b0\000\000\000\000\000\000\000"
/* offset=289298 */ "pm_l3_p0_lco_data\000\000other\000LCO sent with data port 0\000event=0x260aa\000\000\000\000\000\000\000"
/* offset=289369 */ "pm_l3_p0_lco_no_data\000\000other\000Dataless L3 LCO sent port 0\000event=0x160aa\000\000\000\000\000\000\000"
/* offset=289445 */ "pm_l3_p0_lco_rty\000\000other\000L3 initiated LCO received retry on port 0 (can try 4 times)\000event=0x160b4\000\000\000\000\000\000\000"
/* offset=289549 */ "pm_l3_p0_node_pump\000\000other\000L3 PF sent with nodal scope port 0, counts even retried requests\000event=0x160b0\000\000\000\000\000\000\000"
/* offset=289660 */ "pm_l3_p0_pf_rty\000\000other\000L3 PF received retry port 0, every retry counted\000event=0x160ae\000\000\000\000\000\000\000"
/* offset=289752 */ "pm_l3_p0_sys_pump\000\000other\000L3 PF sent with sys scope port 0, counts even retried requests\000event=0x360b0\000\000\000\000\000\000\000"
/* offset=289860 */ "pm_l3_p1_co_l31\000\000other\000L3 CO to L3.1 (LCO) port 1 with or without data\000event=0x468aa\000\000\000\000\000\000\000"
/* offset=289951 */ "pm_l3_p1_co_mem\000\000other\000L3 CO to memory port 1 with or without data\000event=0x368aa\000\000\000\000\000\000\000"
/* offset=290038 */ "pm_l3_p1_co_rty\000\000other\000L3 CO received retry port 1 (memory only), every retry counted\000event=0x368ae\000\000\000\000\000\000\000"
/* offset=290144 */ "pm_l3_p1_grp_pump\000\000other\000L3 PF sent with grp scope port 1, counts even retried requests\000event=0x268b0\000\000\000\000\000\000\000"
/* offset=290252 */ "pm_l3_p1_lco_data\000\000other\000LCO sent with data port 1\000event=0x268aa\000\000\000\000\000\000\000"
/* offset=290323 */ "pm_l3_p1_lco_no_data\000\000other\000Dataless L3 LCO sent port 1\000event=0x168aa\000\000\000\000\000\000\000"
/* offset=290399 */ "pm_l3_p1_lco_rty\000\000other\000L3 initiated LCO received retry on port 1 (can try 4 times)\000event=0x168b4\000\000\000\000\000\000\000"
/* offset=290503 */ "pm_l3_p1_node_pump\000\000other\000L3 PF sent with nodal scope port 1, counts even retried requests\000event=0x168b0\000\000\000\000\000\000\000"
/* offset=290614 */ "pm_l3_p1_pf_rty\000\000other\000L3 PF received retry port 1, every retry counted\000event=0x168ae\000\000\000\000\000\000\000"
/* offset=290706 */ "pm_l3_p1_sys_pump\000\000other\000L3 PF sent with sys scope port 1, counts even retried requests\000event=0x368b0\000\000\000\000\000\000\000"
/* offset=290814 */ "pm_l3_p2_co_rty\000\000other\000L3 CO received retry port 2 (memory only), every retry counted\000event=0x460ae\000\000\000\000\000\000\000"
/* offset=290920 */ "pm_l3_p2_lco_rty\000\000other\000L3 initiated LCO received retry on port 2 (can try 4 times)\000event=0x260b4\000\000\000\000\000\000\000"
/* offset=291024 */ "pm_l3_p2_pf_rty\000\000other\000L3 PF received retry port 2, every retry counted\000event=0x260ae\000\000\000\000\000\000\000"
/* offset=291116 */ "pm_l3_p3_co_rty\000\000other\000L3 CO received retry port 3 (memory only), every retry counted\000event=0x468ae\000\000\000\000\000\000\000"
/* offset=291222 */ "pm_l3_p3_lco_rty\000\000other\000L3 initiated LCO received retry on port 3 (can try 4 times)\000event=0x268b4\000\000\000\000\000\000\000"
/* offset=291326 */ "pm_l3_p3_pf_rty\000\000other\000L3 PF received retry port 3, every retry counted\000event=0x268ae\000\000\000\000\000\000\000"
/* offset=291418 */ "pm_l3_pf0_alloc\000\000other\000lifetime, sample of PF machine 0 valid\000event=0x84908d\000\000\000\000\000\0000.0\000"
/* offset=291504 */ "pm_l3_pf0_busy\000\000other\000Lifetime, sample of PF machine 0 valid\000event=0x360b4\000\000\000\000\000\000\000"
/* offset=291585 */ "pm_l3_pf0_busy\000\000other\000lifetime, sample of PF machine 0 valid\000event=0x84908c\000\000\000\000\000\000\000"
/* offset=291667 */ "pm_l3_pf_hit_l3\000\000other\000L3 PF hit in L3 (abandoned)\000event=0x260a8\000\000\000\000\000\000\000"
/* offset=291738 */ "pm_l3_pf_miss_l3\000\000other\000L3 PF missed in L3\000event=0x160a0\000\000\000\000\000\000\000"
/* offset=291801 */ "pm_l3_pf_miss_l3\000\000other\000L3 Prefetch missed in L3\000event=0x18080\000\000\000\000\000\000\000"
/* offset=291870 */ "pm_l3_pf_off_chip_cache\000\000other\000L3 PF from Off chip cache\000event=0x368a0\000\000\000\000\000\000\000"
/* offset=291947 */ "pm_l3_pf_off_chip_cache\000\000other\000L3 Prefetch from Off chip cache\000event=0x3808a\000\000\000\000\000\000\000"
/* offset=292030 */ "pm_l3_pf_off_chip_mem\000\000other\000L3 PF from Off chip memory\000event=0x468a0\000\000\000\000\000\000\000"
/* offset=292106 */ "pm_l3_pf_off_chip_mem\000\000other\000L3 Prefetch from Off chip memory\000event=0x4808e\000\000\000\000\000\000\000"
/* offset=292188 */ "pm_l3_pf_on_chip_cache\000\000other\000L3 PF from On chip cache\000event=0x360a0\000\000\000\000\000\000\000"
/* offset=292263 */ "pm_l3_pf_on_chip_cache\000\000other\000L3 Prefetch from On chip cache\000event=0x38088\000\000\000\000\000\000\000"
/* offset=292344 */ "pm_l3_pf_on_chip_mem\000\000other\000L3 PF from On chip memory\000event=0x460a0\000\000\000\000\000\000\000"
/* offset=292418 */ "pm_l3_pf_on_chip_mem\000\000other\000L3 Prefetch from On chip memory\000event=0x4808c\000\000\000\000\000\000\000"
/* offset=292498 */ "pm_l3_pf_usage\000\000other\000Rotating sample of 32 PF actives\000event=0x260ac\000\000\000\000\000\000\000"
/* offset=292573 */ "pm_l3_pf_usage\000\000other\000rotating sample of 32 PF actives\000event=0x829084\000\000\000\000\000\000\000"
/* offset=292649 */ "pm_l3_pref_all\000\000other\000Total HW L3 prefetches(Load+store)\000event=0x4e052\000\000\000\000\000\000\000"
/* offset=292726 */ "pm_l3_rd0_alloc\000\000other\000lifetime, sample of RD machine 0 valid\000event=0x84908f\000\000\000\000\000\0000.0\000"
/* offset=292812 */ "pm_l3_rd0_busy\000\000other\000Lifetime, sample of RD machine 0 valid\000event=0x368b4\000\000\000\000\000\000\000"
/* offset=292893 */ "pm_l3_rd0_busy\000\000other\000lifetime, sample of RD machine 0 valid\000event=0x84908e\000\000\000\000\000\000\000"
/* offset=292975 */ "pm_l3_rd_usage\000\000other\000Rotating sample of 16 RD actives\000event=0x268ac\000\000\000\000\000\000\000"
/* offset=293050 */ "pm_l3_rd_usage\000\000other\000rotating sample of 16 RD actives\000event=0x829086\000\000\000\000\000\000\000"
/* offset=293126 */ "pm_l3_sn0_alloc\000\000other\000lifetime, sample of snooper machine 0 valid\000event=0x839089\000\000\000\000\000\0000.0\000"
/* offset=293217 */ "pm_l3_sn0_busy\000\000other\000Lifetime, sample of snooper machine 0 valid\000event=0x360ac\000\000\000\000\000\000\000"
/* offset=293303 */ "pm_l3_sn0_busy\000\000other\000lifetime, sample of snooper machine 0 valid\000event=0x839088\000\000\000\000\000\000\000"
/* offset=293390 */ "pm_l3_sn_usage\000\000other\000Rotating sample of 16 snoop valids\000event=0x160ac\000\000\000\000\000\000\000"
/* offset=293467 */ "pm_l3_sn_usage\000\000other\000rotating sample of 8 snoop valids\000event=0x819080\000\000\000\000\000\000\000"
/* offset=293544 */ "pm_l3_st_pref\000\000other\000L3 store Prefetches\000event=0x2e052\000\000\000\000\000\000\000"
/* offset=293605 */ "pm_l3_sw_pref\000\000other\000Data stream touchto L3\000event=0x3e052\000\000\000\000\000\000\000"
/* offset=293669 */ "pm_l3_sw_pref\000\000other\000L3 load prefetch, sourced from a software prefetch stream, was sent to the nest\000event=0xf8b0\000\000\000\000\000\000\000"
/* offset=293789 */ "pm_l3_sys_guess_correct\000\000other\000Prefetch scope predictor selected VGS or RNS and was correct\000event=0x260b2\000\000\000\000\000\000\000"
/* offset=293901 */ "pm_l3_sys_guess_wrong\000\000other\000Prefetch scope predictor selected VGS or RNS, but was wrong\000event=0x460b2\000\000\000\000\000\000\000"
/* offset=294010 */ "pm_l3_trans_pf\000\000other\000L3 Transient prefetch received from L2\000event=0x468a4\000\000\000\000\000\000\000"
/* offset=294091 */ "pm_l3_wi0_alloc\000\000other\000lifetime, sample of Write Inject machine 0 valid\000event=0x18081\000\000\000\000\000\0000.0\000"
/* offset=294186 */ "pm_l3_wi0_busy\000\000other\000Rotating sample of 8 WI valid (duplicate)\000event=0x160b6\000\000\000\000\000\000\000"
/* offset=294270 */ "pm_l3_wi_usage\000\000other\000Lifetime, sample of Write Inject machine 0 valid\000event=0x168a8\000\000\000\000\000\000\000"
/* offset=294361 */ "pm_larx_fin\000\000memory\000Larx finished\000event=0x3c058\000\000\000\000\000\000\000"
/* offset=294415 */ "pm_larx_fin\000\000memory\000Load and reserve instruction (LARX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x3c058\000\000\000\000\000\000\000"
/* offset=294555 */ "pm_larx_fin\000\000pipeline\000Larx finished\000event=0x3c058\000\000\000\000\000\000\000"
/* offset=294611 */ "pm_ld_cmpl\000\000memory\000Loads completed\000event=0x4003e\000\000\000\000\000\000\000"
/* offset=294666 */ "pm_ld_cmpl\000\000memory\000count of Loads completed\000event=0x4003e\000\000\000\000\000\000\000"
/* offset=294730 */ "pm_ld_cmpl\000\000pipeline\000count of Loads completed\000event=0x1002e\000\000\000\000\000\000\000"
/* offset=294796 */ "pm_ld_demand_miss_l1\000\000marked\000The L1 cache was reloaded with a line that fulfills a demand miss request. Counted at reload time, before finish\000event=0x300f6\000\000\000\000\000\000\000"
/* offset=294958 */ "pm_ld_demand_miss_l1_fin\000\000others\000Load Missed L1, counted at finish time\000event=0x400f0\000\000\000\000\000\000\000"
/* offset=295050 */ "pm_ld_hit_l1\000\000others\000Loads that finished without experiencing an L1 miss\000event=0x1505e\000\000\000\000\000\000\000"
/* offset=295143 */ "pm_ld_l3miss_pend_cyc\000\000memory\000Cycles L3 miss was pending for this thread\000event=0x10062\000\000\000\000\000\000\000"
/* offset=295236 */ "pm_ld_l3miss_pend_cyc\000\000pipeline\000Cycles L3 miss was pending for this thread\000event=0x10062\000\000\000\000\000\000\000"
/* offset=295331 */ "pm_ld_miss_l1\000\000cache\000Load Missed L1\000event=0x3e054\000\000\000\000\000\000\000"
/* offset=295387 */ "pm_ld_miss_l1\000\000frontend\000Load Missed L1, counted at execution time (can be greater than loads finished). LMQ merges are not included in this count. i.e. if a load instruction misses on an address that is already allocated on the LMQ, this event will not increment for that load). Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x3e054\000\000\000\000\000\000\000"
/* offset=295815 */ "pm_ld_miss_l1_fin\000\000other\000Number of load instructions that finished with an L1 miss. Note that even if a load spans multiple slices this event will increment only once per load op\000event=0x2c04e\000\000\000\000\000\000\000"
/* offset=296014 */ "pm_ld_prefetch_cache_line_miss\000\000marked\000The L1 cache was reloaded with a line that fulfills a prefetch request\000event=0x1002c\000\000\000\000\000\000\000"
/* offset=296144 */ "pm_ld_ref_l1\000\000cache\000All L1 D cache load references counted at finish, gated by reject\000event=0x100ee\000\000\000\000\000\000Load Ref count combined for all units\000"
/* offset=296287 */ "pm_ld_ref_l1\000\000other\000All L1 D cache load references counted at finish, gated by reject\000event=0x100fc\000\000\000\000\000\000\000"
/* offset=296393 */ "pm_ld_ref_l1\000\000others\000All L1 D cache load references counted at finish, gated by reject. In P9 and earlier this event counted only cacheable loads but in P10 both cacheable and non-cacheable loads are included\000event=0x100fc\000\000\000\000\000\000\000"
/* offset=296622 */ "pm_ld_ref_l1_lsu0\000\000other\000LS0 L1 D cache load references counted at finish, gated by reject\000event=0xc080\000\000\000\000\000\000LS0 L1 D cache load references counted at finish, gated by rejectLSU0 L1 D cache load references\000"
/* offset=296828 */ "pm_ld_ref_l1_lsu1\000\000other\000LS1 L1 D cache load references counted at finish, gated by reject\000event=0xc082\000\000\000\000\000\000LS1 L1 D cache load references counted at finish, gated by rejectLSU1 L1 D cache load references\000"
/* offset=297034 */ "pm_ld_ref_l1_lsu2\000\000other\000LS2 L1 D cache load references counted at finish, gated by reject\000event=0xc094\000\000\000\000\000\000LS2 L1 D cache load references counted at finish, gated by reject42\000"
/* offset=297211 */ "pm_ld_ref_l1_lsu3\000\000other\000LS3 L1 D cache load references counted at finish, gated by reject\000event=0xc096\000\000\000\000\000\000LS3 L1 D cache load references counted at finish, gated by reject42\000"
/* offset=297388 */ "pm_link_stack_correct\000\000other\000Link stack predicts right address\000event=0x58a0\000\000\000\000\000\000\000"
/* offset=297470 */ "pm_link_stack_invalid_ptr\000\000other\000A flush were LS ptr is invalid, results in a pop , A lot of interrupts between push and pops\000event=0x509a\000\000\000\000\000\000\000"
/* offset=297615 */ "pm_link_stack_invalid_ptr\000\000other\000It is most often caused by certain types of flush where the pointer is not available. Can result in the data in the link stack becoming unusable\000event=0x5898\000\000\000\000\000\000\000"
/* offset=297812 */ "pm_link_stack_wrong_add_pred\000\000other\000Link stack predicts wrong address, because of link stack design limitation or software violating the coding conventions\000event=0x5098\000\000\000\000\000\000\000"
/* offset=297987 */ "pm_link_stack_wrong_add_pred\000\000other\000Link stack predicts wrong address, because of link stack design limitation\000event=0x5098\000\000\000\000\000\000\000"
/* offset=298117 */ "pm_lmq_empty_cyc\000\000marked\000Cycles in which the LMQ has no pending load misses for this thread\000event=0x2e05e\000\000\000\000\000\000\000"
/* offset=298229 */ "pm_lmq_merge\000\000other\000A demand miss collides with a prefetch for the same line\000event=0x1002e\000\000\000\000\000\000\000"
/* offset=298326 */ "pm_lrq_reject\000\000memory\000Internal LSU reject from LRQ. Rejects cause the load to go back to LRQ, but it stays contained within the LSU once it gets issued. This event counts the number of times the LRQ attempts to relaunch an instruction after a reject. Any load can suffer multiple rejects\000event=0x2e05a\000\000\000\000\000\000\000"
/* offset=298634 */ "pm_ls0_dc_collisions\000\000other\000Read-write data cache collisions\000event=0xd090\000\000\000\000\000\000\000"
/* offset=298714 */ "pm_ls0_erat_miss_pref\000\000other\000LS0 Erat miss due to prefetch\000event=0xe080\000\000\000\000\000\000LS0 Erat miss due to prefetch42\000"
/* offset=298823 */ "pm_ls0_erat_miss_pref\000\000other\000LS0 Erat miss due to prefetch\000event=0xe084\000\000\000\000\000\000\000"
/* offset=298901 */ "pm_ls0_l1_pref\000\000other\000LS0 L1 cache data prefetches\000event=0xd0b8\000\000\000\000\000\000LS0 L1 cache data prefetches42\000"
/* offset=299001 */ "pm_ls0_l1_sw_pref\000\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xc098\000\000\000\000\000\000Software L1 Prefetches, including SW Transient Prefetches42\000"
/* offset=299162 */ "pm_ls0_launch_held_pref\000\000other\000Number of times a load or store instruction was unable to launch/relaunch because a high priority prefetch used that relaunch cycle\000event=0xc09c\000\000\000\000\000\000\000"
/* offset=299344 */ "pm_ls0_ld_vector_fin\000\000other\000LS0 finished load vector op\000event=0xc080\000\000\000\000\000\000\000"
/* offset=299419 */ "pm_ls0_pte_tablewalk_cyc\000\000other\000Cycles when a tablewalk is pending on this thread on table 0\000event=0xe0bc\000\000\000\000\000\000\000"
/* offset=299531 */ "pm_ls0_tm_disallow\000\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe0b4\000\000\000\000\000\000\000"
/* offset=299667 */ "pm_ls0_unaligned_ld\000\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc094\000\000\000\000\000\000\000"
/* offset=299971 */ "pm_ls0_unaligned_st\000\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf0b8\000\000\000\000\000\000\000"
/* offset=300278 */ "pm_ls1_dc_collisions\000\000other\000Read-write data cache collisions\000event=0xd890\000\000\000\000\000\000\000"
/* offset=300358 */ "pm_ls1_erat_miss_pref\000\000other\000LS1 Erat miss due to prefetch\000event=0xe082\000\000\000\000\000\000LS1 Erat miss due to prefetch42\000"
/* offset=300467 */ "pm_ls1_erat_miss_pref\000\000other\000LS1 Erat miss due to prefetch\000event=0xe884\000\000\000\000\000\000\000"
/* offset=300545 */ "pm_ls1_l1_pref\000\000other\000LS1 L1 cache data prefetches\000event=0xd0ba\000\000\000\000\000\000LS1 L1 cache data prefetches42\000"
/* offset=300645 */ "pm_ls1_l1_sw_pref\000\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xc09a\000\000\000\000\000\000Software L1 Prefetches, including SW Transient Prefetches42\000"
/* offset=300806 */ "pm_ls1_launch_held_pref\000\000other\000Number of times a load or store instruction was unable to launch/relaunch because a high priority prefetch used that relaunch cycle\000event=0xc89c\000\000\000\000\000\000\000"
/* offset=300988 */ "pm_ls1_ld_vector_fin\000\000other\000LS1 finished load vector op\000event=0xc880\000\000\000\000\000\000\000"
/* offset=301063 */ "pm_ls1_pte_tablewalk_cyc\000\000other\000Cycles when a tablewalk is pending on this thread on table 1\000event=0xe8bc\000\000\000\000\000\000\000"
/* offset=301175 */ "pm_ls1_tm_disallow\000\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe8b4\000\000\000\000\000\000\000"
/* offset=301311 */ "pm_ls1_unaligned_ld\000\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc894\000\000\000\000\000\000\000"
/* offset=301615 */ "pm_ls1_unaligned_st\000\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf8b8\000\000\000\000\000\000\000"
/* offset=301922 */ "pm_ls2_dc_collisions\000\000other\000Read-write data cache collisions\000event=0xd094\000\000\000\000\000\000\000"
/* offset=302002 */ "pm_ls2_erat_miss_pref\000\000other\000LS0 Erat miss due to prefetch\000event=0xe088\000\000\000\000\000\000\000"
/* offset=302080 */ "pm_ls2_ld_vector_fin\000\000other\000LS2 finished load vector op\000event=0xc084\000\000\000\000\000\000\000"
/* offset=302155 */ "pm_ls2_tm_disallow\000\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe0b8\000\000\000\000\000\000\000"
/* offset=302291 */ "pm_ls2_unaligned_ld\000\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc098\000\000\000\000\000\000\000"
/* offset=302595 */ "pm_ls2_unaligned_st\000\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf0bc\000\000\000\000\000\000\000"
/* offset=302902 */ "pm_ls3_dc_collisions\000\000other\000Read-write data cache collisions\000event=0xd894\000\000\000\000\000\000\000"
/* offset=302982 */ "pm_ls3_erat_miss_pref\000\000other\000LS1 Erat miss due to prefetch\000event=0xe888\000\000\000\000\000\000\000"
/* offset=303060 */ "pm_ls3_ld_vector_fin\000\000other\000LS3 finished load vector op\000event=0xc884\000\000\000\000\000\000\000"
/* offset=303135 */ "pm_ls3_tm_disallow\000\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe8b8\000\000\000\000\000\000\000"
/* offset=303271 */ "pm_ls3_unaligned_ld\000\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc898\000\000\000\000\000\000\000"
/* offset=303575 */ "pm_ls3_unaligned_st\000\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf8bc\000\000\000\000\000\000\000"
/* offset=303882 */ "pm_lsu0_1_lrqf_full_cyc\000\000other\000Counts the number of cycles the LRQF is full.  LRQF is the queue that holds loads between finish and completion.  If it fills up, instructions stay in LRQ until completion, potentially backing up the LRQ\000event=0xd0bc\000\000\000\000\000\000\000"
/* offset=304136 */ "pm_lsu0_erat_hit\000\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe08c\000\000\000\000\000\000\000"
/* offset=304225 */ "pm_lsu0_false_lhs\000\000other\000False LHS match detected\000event=0xc0a0\000\000\000\000\000\000\000"
/* offset=304294 */ "pm_lsu0_flush_lrq\000\000other\000LS0 Flush: LRQ\000event=0xc0b0\000\000\000\000\000\000LS0 Flush: LRQLSU0 LRQ flushes\000"
/* offset=304383 */ "pm_lsu0_flush_srq\000\000other\000LS0 Flush: SRQ\000event=0xc0b8\000\000\000\000\000\000LS0 Flush: SRQLSU0 SRQ lhs flushes\000"
/* offset=304476 */ "pm_lsu0_flush_uld\000\000other\000LS0 Flush: Unaligned Load\000event=0xc0a4\000\000\000\000\000\000LS0 Flush: Unaligned LoadLSU0 unaligned load flushes\000"
/* offset=304598 */ "pm_lsu0_flush_ust\000\000other\000LS0 Flush: Unaligned Store\000event=0xc0ac\000\000\000\000\000\000LS0 Flush: Unaligned StoreLSU0 unaligned store flushes\000"
/* offset=304723 */ "pm_lsu0_l1_cam_cancel\000\000other\000ls0 l1 tm cam cancel\000event=0xf088\000\000\000\000\000\000ls0 l1 tm cam cancel42\000"
/* offset=304814 */ "pm_lsu0_l1_cam_cancel\000\000other\000ls0 l1 tm cam cancel\000event=0xf090\000\000\000\000\000\000\000"
/* offset=304883 */ "pm_lsu0_larx_fin\000\000other\000Larx finished in LSU pipe0\000event=0x1e056\000\000\000\000\000\000\000"
/* offset=304954 */ "pm_lsu0_ldmx_fin\000\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd088\000\000\000\000\000\000\000"
/* offset=305396 */ "pm_lsu0_lmq_lhr_merge\000\000other\000LS0 Load Merged with another cacheline request\000event=0xd08c\000\000\000\000\000\000LS0 Load Merged with another cacheline request42\000"
/* offset=305539 */ "pm_lsu0_lmq_s0_valid\000\000other\000Slot 0 of LMQ valid\000event=0xd8b8\000\000\000\000\000\000\000"
/* offset=305606 */ "pm_lsu0_lrq_s0_valid_cyc\000\000other\000Slot 0 of LRQ valid\000event=0xd8b4\000\000\000\000\000\000\000"
/* offset=305677 */ "pm_lsu0_ncld\000\000other\000LS0 Non-cachable Loads counted at finish\000event=0xc08c\000\000\000\000\000\000LS0 Non-cachable Loads counted at finishLSU0 non-cacheable loads\000"
/* offset=305821 */ "pm_lsu0_primary_erat_hit\000\000other\000Primary ERAT hit\000event=0xe090\000\000\000\000\000\000Primary ERAT hit42\000"
/* offset=305907 */ "pm_lsu0_reject\000\000other\000LSU0 reject\000event=0x1e05a\000\000\000\000\000\000\000"
/* offset=305961 */ "pm_lsu0_srq_s0_valid_cyc\000\000other\000Slot 0 of SRQ valid\000event=0xd0b4\000\000\000\000\000\000\000"
/* offset=306032 */ "pm_lsu0_srq_stfwd\000\000other\000LS0 SRQ forwarded data to a load\000event=0xc09c\000\000\000\000\000\000LS0 SRQ forwarded data to a loadLSU0 SRQ store forwarded\000"
/* offset=306165 */ "pm_lsu0_store_reject\000\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf088\000\000\000\000\000\000\000"
/* offset=306360 */ "pm_lsu0_store_reject\000\000other\000ls0 store reject\000event=0xf084\000\000\000\000\000\000ls0 store reject42\000"
/* offset=306442 */ "pm_lsu0_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe094\000\000\000\000\000\000\000"
/* offset=306504 */ "pm_lsu0_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe098\000\000\000\000\000\000Load tm hit in L142\000"
/* offset=306585 */ "pm_lsu0_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe09c\000\000\000\000\000\000\000"
/* offset=306646 */ "pm_lsu0_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a0\000\000\000\000\000\000Load tm L1 miss42\000"
/* offset=306724 */ "pm_lsu0_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0a8\000\000\000\000\000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000"
/* offset=306952 */ "pm_lsu1_erat_hit\000\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe88c\000\000\000\000\000\000\000"
/* offset=307041 */ "pm_lsu1_false_lhs\000\000other\000False LHS match detected\000event=0xc8a0\000\000\000\000\000\000\000"
/* offset=307110 */ "pm_lsu1_flush_lrq\000\000other\000LS1 Flush: LRQ\000event=0xc0b2\000\000\000\000\000\000LS1 Flush: LRQLSU1 LRQ flushes\000"
/* offset=307199 */ "pm_lsu1_flush_srq\000\000other\000LS1 Flush: SRQ\000event=0xc0ba\000\000\000\000\000\000LS1 Flush: SRQLSU1 SRQ lhs flushes\000"
/* offset=307292 */ "pm_lsu1_flush_uld\000\000other\000LS 1 Flush: Unaligned Load\000event=0xc0a6\000\000\000\000\000\000LS 1 Flush: Unaligned LoadLSU1 unaligned load flushes\000"
/* offset=307416 */ "pm_lsu1_flush_ust\000\000other\000LS1 Flush: Unaligned Store\000event=0xc0ae\000\000\000\000\000\000LS1 Flush: Unaligned StoreLSU1 unaligned store flushes\000"
/* offset=307541 */ "pm_lsu1_l1_cam_cancel\000\000other\000ls1 l1 tm cam cancel\000event=0xf08a\000\000\000\000\000\000ls1 l1 tm cam cancel42\000"
/* offset=307632 */ "pm_lsu1_l1_cam_cancel\000\000other\000ls1 l1 tm cam cancel\000event=0xf890\000\000\000\000\000\000\000"
/* offset=307701 */ "pm_lsu1_larx_fin\000\000other\000Larx finished in LSU pipe1\000event=0x2e056\000\000\000\000\000\000\000"
/* offset=307772 */ "pm_lsu1_ldmx_fin\000\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd888\000\000\000\000\000\000\000"
/* offset=308214 */ "pm_lsu1_lmq_lhr_merge\000\000other\000LS1 Load Merge with another cacheline request\000event=0xd08e\000\000\000\000\000\000LS1 Load Merge with another cacheline request42\000"
/* offset=308355 */ "pm_lsu1_ncld\000\000other\000LS1 Non-cachable Loads counted at finish\000event=0xc08e\000\000\000\000\000\000LS1 Non-cachable Loads counted at finishLSU1 non-cacheable loads\000"
/* offset=308499 */ "pm_lsu1_primary_erat_hit\000\000other\000Primary ERAT hit\000event=0xe092\000\000\000\000\000\000Primary ERAT hit42\000"
/* offset=308585 */ "pm_lsu1_reject\000\000other\000LSU1 reject\000event=0x2e05a\000\000\000\000\000\000\000"
/* offset=308639 */ "pm_lsu1_srq_stfwd\000\000other\000LS1 SRQ forwarded data to a load\000event=0xc09e\000\000\000\000\000\000LS1 SRQ forwarded data to a loadLSU1 SRQ store forwarded\000"
/* offset=308772 */ "pm_lsu1_store_reject\000\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf888\000\000\000\000\000\000\000"
/* offset=308967 */ "pm_lsu1_store_reject\000\000other\000ls1 store reject\000event=0xf086\000\000\000\000\000\000ls1 store reject42\000"
/* offset=309049 */ "pm_lsu1_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe09a\000\000\000\000\000\000Load tm hit in L142\000"
/* offset=309130 */ "pm_lsu1_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe894\000\000\000\000\000\000\000"
/* offset=309192 */ "pm_lsu1_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a2\000\000\000\000\000\000Load tm L1 miss42\000"
/* offset=309270 */ "pm_lsu1_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe89c\000\000\000\000\000\000\000"
/* offset=309331 */ "pm_lsu1_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0aa\000\000\000\000\000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000"
/* offset=309559 */ "pm_lsu2_3_lrqf_full_cyc\000\000other\000Counts the number of cycles the LRQF is full.  LRQF is the queue that holds loads between finish and completion.  If it fills up, instructions stay in LRQ until completion, potentially backing up the LRQ\000event=0xd8bc\000\000\000\000\000\000\000"
/* offset=309813 */ "pm_lsu2_erat_hit\000\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe090\000\000\000\000\000\000\000"
/* offset=309902 */ "pm_lsu2_false_lhs\000\000other\000False LHS match detected\000event=0xc0a4\000\000\000\000\000\000\000"
/* offset=309971 */ "pm_lsu2_flush_lrq\000\000other\000LS02Flush: LRQ\000event=0xc0b4\000\000\000\000\000\000LS02Flush: LRQ42\000"
/* offset=310046 */ "pm_lsu2_flush_srq\000\000other\000LS2 Flush: SRQ\000event=0xc0bc\000\000\000\000\000\000LS2 Flush: SRQ42\000"
/* offset=310121 */ "pm_lsu2_flush_uld\000\000other\000LS3 Flush: Unaligned Load\000event=0xc0a8\000\000\000\000\000\000LS3 Flush: Unaligned Load42\000"
/* offset=310218 */ "pm_lsu2_l1_cam_cancel\000\000other\000ls2 l1 tm cam cancel\000event=0xf08c\000\000\000\000\000\000ls2 l1 tm cam cancel42\000"
/* offset=310309 */ "pm_lsu2_l1_cam_cancel\000\000other\000ls2 l1 tm cam cancel\000event=0xf094\000\000\000\000\000\000\000"
/* offset=310378 */ "pm_lsu2_larx_fin\000\000other\000Larx finished in LSU pipe2\000event=0x3e056\000\000\000\000\000\000\000"
/* offset=310449 */ "pm_lsu2_ldf\000\000other\000LS2 Scalar Loads\000event=0xc084\000\000\000\000\000\000LS2 Scalar Loads42\000"
/* offset=310522 */ "pm_lsu2_ldmx_fin\000\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd08c\000\000\000\000\000\000\000"
/* offset=310964 */ "pm_lsu2_ldx\000\000other\000LS0 Vector Loads\000event=0xc088\000\000\000\000\000\000LS0 Vector Loads42\000"
/* offset=311037 */ "pm_lsu2_lmq_lhr_merge\000\000other\000LS0 Load Merged with another cacheline request\000event=0xd090\000\000\000\000\000\000LS0 Load Merged with another cacheline request42\000"
/* offset=311180 */ "pm_lsu2_primary_erat_hit\000\000other\000Primary ERAT hit\000event=0xe094\000\000\000\000\000\000Primary ERAT hit42\000"
/* offset=311266 */ "pm_lsu2_reject\000\000other\000LSU2 reject\000event=0x3e05a\000\000\000\000\000\000\000"
/* offset=311320 */ "pm_lsu2_srq_stfwd\000\000other\000LS2 SRQ forwarded data to a load\000event=0xc0a0\000\000\000\000\000\000LS2 SRQ forwarded data to a load42\000"
/* offset=311431 */ "pm_lsu2_store_reject\000\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf08c\000\000\000\000\000\000\000"
/* offset=311626 */ "pm_lsu2_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe098\000\000\000\000\000\000\000"
/* offset=311688 */ "pm_lsu2_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe09c\000\000\000\000\000\000Load tm hit in L142\000"
/* offset=311769 */ "pm_lsu2_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a0\000\000\000\000\000\000\000"
/* offset=311830 */ "pm_lsu2_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a4\000\000\000\000\000\000Load tm L1 miss42\000"
/* offset=311908 */ "pm_lsu2_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0ac\000\000\000\000\000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000"
/* offset=312136 */ "pm_lsu3_erat_hit\000\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe890\000\000\000\000\000\000\000"
/* offset=312225 */ "pm_lsu3_false_lhs\000\000other\000False LHS match detected\000event=0xc8a4\000\000\000\000\000\000\000"
/* offset=312294 */ "pm_lsu3_flush_lrq\000\000other\000LS3 Flush: LRQ\000event=0xc0b6\000\000\000\000\000\000LS3 Flush: LRQ42\000"
/* offset=312369 */ "pm_lsu3_flush_srq\000\000other\000LS13 Flush: SRQ\000event=0xc0be\000\000\000\000\000\000LS13 Flush: SRQ42\000"
/* offset=312446 */ "pm_lsu3_flush_uld\000\000other\000LS 14Flush: Unaligned Load\000event=0xc0aa\000\000\000\000\000\000LS 14Flush: Unaligned Load42\000"
/* offset=312545 */ "pm_lsu3_l1_cam_cancel\000\000other\000ls3 l1 tm cam cancel\000event=0xf08e\000\000\000\000\000\000ls3 l1 tm cam cancel42\000"
/* offset=312636 */ "pm_lsu3_l1_cam_cancel\000\000other\000ls3 l1 tm cam cancel\000event=0xf894\000\000\000\000\000\000\000"
/* offset=312705 */ "pm_lsu3_larx_fin\000\000other\000Larx finished in LSU pipe3\000event=0x4e056\000\000\000\000\000\000\000"
/* offset=312776 */ "pm_lsu3_ldf\000\000other\000LS3 Scalar Loads\000event=0xc086\000\000\000\000\000\000LS3 Scalar Loads 42\000"
/* offset=312850 */ "pm_lsu3_ldmx_fin\000\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd88c\000\000\000\000\000\000\000"
/* offset=313292 */ "pm_lsu3_ldx\000\000other\000LS1 Vector Loads\000event=0xc08a\000\000\000\000\000\000LS1 Vector Loads42\000"
/* offset=313365 */ "pm_lsu3_lmq_lhr_merge\000\000other\000LS1 Load Merge with another cacheline request\000event=0xd092\000\000\000\000\000\000LS1 Load Merge with another cacheline request42\000"
/* offset=313506 */ "pm_lsu3_primary_erat_hit\000\000other\000Primary ERAT hit\000event=0xe096\000\000\000\000\000\000Primary ERAT hit42\000"
/* offset=313592 */ "pm_lsu3_reject\000\000other\000LSU3 reject\000event=0x4e05a\000\000\000\000\000\000\000"
/* offset=313646 */ "pm_lsu3_srq_stfwd\000\000other\000LS3 SRQ forwarded data to a load\000event=0xc0a2\000\000\000\000\000\000LS3 SRQ forwarded data to a load42\000"
/* offset=313757 */ "pm_lsu3_store_reject\000\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf88c\000\000\000\000\000\000\000"
/* offset=313952 */ "pm_lsu3_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe09e\000\000\000\000\000\000Load tm hit in L142\000"
/* offset=314033 */ "pm_lsu3_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe898\000\000\000\000\000\000\000"
/* offset=314095 */ "pm_lsu3_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a6\000\000\000\000\000\000Load tm L1 miss42\000"
/* offset=314173 */ "pm_lsu3_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe8a0\000\000\000\000\000\000\000"
/* offset=314234 */ "pm_lsu3_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0ae\000\000\000\000\000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000"
/* offset=314462 */ "pm_lsu_derat_miss\000\000memory\000DERAT Reloaded due to a DERAT miss\000event=0x200f6\000\000\000\000\000\000\000"
/* offset=314543 */ "pm_lsu_derat_miss\000\000translation\000DERAT Reloaded due to a DERAT miss\000event=0x200f6\000\000\000\000\000\000DERAT Reloaded (Miss)\000"
/* offset=314650 */ "pm_lsu_dtlb_miss_16g_1g\000\000other\000Data TLB Miss page size 16G (HPT) or 1G (Radix)\000event=0xc88c\000\000\000\000\000\000\000"
/* offset=314748 */ "pm_lsu_dtlb_miss_16m_2m\000\000other\000Data TLB Miss page size 16M (HPT) or 2M (Radix)\000event=0xc08c\000\000\000\000\000\000\000"
/* offset=314846 */ "pm_lsu_dtlb_miss_4k\000\000other\000Data TLB Miss page size 4K\000event=0xc088\000\000\000\000\000\000\000"
/* offset=314919 */ "pm_lsu_dtlb_miss_64k\000\000other\000Data TLB Miss page size 64K\000event=0xc888\000\000\000\000\000\000\000"
/* offset=314994 */ "pm_lsu_erat_miss_pref\000\000other\000Erat miss due to prefetch, on either pipe\000event=0xe880\000\000\000\000\000\000LSU\000"
/* offset=315087 */ "pm_lsu_fin\000\000pipeline\000LSU Finished an instruction (up to 2 per cycle)\000event=0x30066\000\000\000\000\000\000\000"
/* offset=315176 */ "pm_lsu_fin\000\000pipeline\000LSU Finished an internal operation (up to 4 per cycle)\000event=0x30066\000\000\000\000\000\000\000"
/* offset=315272 */ "pm_lsu_fin\000\000translation\000LSU Finished a PPC instruction (up to 4 per cycle)\000event=0x30066\000\000\000\000\000\000\000"
/* offset=315367 */ "pm_lsu_flush_atomic\000\000other\000Quad-word loads (lq) are considered atomic because they always span at least 2 slices.  If a snoop or store from another thread changes the data the load is accessing between the 2 or 3 pieces of the lq instruction, the lq will be flushed\000event=0xc8a8\000\000\000\000\000\000\000"
/* offset=315652 */ "pm_lsu_flush_ci\000\000other\000Load was not issued to LSU as a cache inhibited (non-cacheable) load but it was later determined to be cache inhibited\000event=0xc0a8\000\000\000\000\000\000\000"
/* offset=315813 */ "pm_lsu_flush_emsh\000\000other\000An ERAT miss was detected after a set-p hit. Erat tracker indicates fail due to tlbmiss and the instruction gets flushed because the instruction was working on the wrong address\000event=0xc0ac\000\000\000\000\000\000\000"
/* offset=316035 */ "pm_lsu_flush_larx_stcx\000\000other\000A larx is flushed because an older larx has an LMQ reservation for the same thread.  A stcx is flushed because an older stcx is in the LMQ.  The flush happens when the older larx/stcx relaunches\000event=0xc8b8\000\000\000\000\000\000\000"
/* offset=316279 */ "pm_lsu_flush_lhl_shl\000\000other\000The instruction was flushed because of a sequential load/store consistency.  If a load or store hits on an older load that has either been snooped (for loads) or has stale data (for stores)\000event=0xc8b4\000\000\000\000\000\000\000"
/* offset=316516 */ "pm_lsu_flush_lhs\000\000other\000Effective Address alias flush : no EA match but Real Address match.  If the data has not yet been returned for this load, the instruction will just be rejected, but if it has returned data, it will be flushed\000event=0xc8b0\000\000\000\000\000\000\000"
/* offset=316768 */ "pm_lsu_flush_next\000\000other\000LSU flush next reported at flush time.  Sometimes these also come with an exception\000event=0x20b0\000\000\000\000\000\000\000"
/* offset=316896 */ "pm_lsu_flush_other\000\000other\000Other LSU flushes including: Sync (sync ack from L2 caused search of LRQ for oldest snooped load, This will either signal a Precise Flush of the oldest snooped loa or a Flush Next PPC); Data Valid Flush Next (several cases of this, one example is store and reload are lined up such that a store-hit-reload scenario exists and the CDF has already launched and has gotten bad/stale data); Bad Data Valid Flush Next (might be a few cases of this, one example is a larxa (D$ hit) return data and dval but can't allocate to LMQ (LMQ full or other reason). Already gave dval but can't watch it for snoop_hit_larx. Need to take the “bad dval” back and flush all younger ops)\000event=0xc0bc\000\000\000\000\000\000\000"
/* offset=317613 */ "pm_lsu_flush_relaunch_miss\000\000other\000If a load that has already returned data and has to relaunch for any reason then gets a miss (erat, setp, data cache), it will often be flushed at relaunch time because the data might be inconsistent\000event=0xc8ac\000\000\000\000\000\000\000"
/* offset=317866 */ "pm_lsu_flush_sao\000\000other\000A load-hit-load condition with Strong Address Ordering will have address compare disabled and flush\000event=0xc0b8\000\000\000\000\000\000\000"
/* offset=318009 */ "pm_lsu_flush_ue\000\000other\000Correctable ECC error on reload data, reported at critical data forward time\000event=0xc0b0\000\000\000\000\000\000\000"
/* offset=318128 */ "pm_lsu_flush_ust\000\000other\000Unaligned Store Flush on either pipe\000event=0xc8ac\000\000\000\000\000\000LSU\000"
/* offset=318211 */ "pm_lsu_flush_wrk_arnd\000\000other\000LSU workaround flush.  These flushes are setup with programmable scan only latches to perform various actions when the flush macro receives a trigger from the dbg macros. These actions include things like flushing the next op encountered for a particular thread or flushing the next op that is NTC op that is encountered on a particular slice. The kind of flush that the workaround is setup to perform is highly variable\000event=0xc0b4\000\000\000\000\000\000\000"
/* offset=318680 */ "pm_lsu_four_tablewalk_cyc\000\000other\000Cycles when four tablewalks pending on this thread\000event=0xd0a4\000\000\000\000\000\000Cycles when four tablewalks pending on this thread42\000"
/* offset=318835 */ "pm_lsu_fx_fin\000\000other\000LSU Finished a FX operation (up to 2 per cycle\000event=0x10066\000\000\000\000\000\000\000"
/* offset=318923 */ "pm_lsu_l1_pref\000\000other\000hw initiated , include sw streaming forms as well , include sw streams as a separate event\000event=0xd8b8\000\000\000\000\000\000LSU\000"
/* offset=319058 */ "pm_lsu_l1_sw_pref\000\000other\000Software L1 Prefetches, including SW Transient Prefetches, on both pipes\000event=0xc898\000\000\000\000\000\000LSU\000"
/* offset=319178 */ "pm_lsu_ld0_fin\000\000pipeline\000LSU Finished an internal operation in LD0 port\000event=0x1000c\000\000\000\000\000\000\000"
/* offset=319270 */ "pm_lsu_ld1_fin\000\000pipeline\000LSU Finished an internal operation in LD1 port\000event=0x2000e\000\000\000\000\000\000\000"
/* offset=319362 */ "pm_lsu_ldf\000\000other\000FPU loads only on LS2/LS3 ie LU0/LU1\000event=0xc884\000\000\000\000\000\000LSU\000"
/* offset=319439 */ "pm_lsu_ldx\000\000other\000Vector loads can issue only on LS2/LS3\000event=0xc888\000\000\000\000\000\000LSU\000"
/* offset=319518 */ "pm_lsu_lmq_full_cyc\000\000other\000Counts the number of cycles the LMQ is full\000event=0xd0b8\000\000\000\000\000\000\000"
/* offset=319608 */ "pm_lsu_lmq_full_cyc\000\000other\000LMQ full\000event=0xd0a2\000\000\000\000\000\000LMQ fullCycles LMQ full\000"
/* offset=319686 */ "pm_lsu_lmq_s0_alloc\000\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd0a1\000\000\000\000\000\0000.0\000"
/* offset=320141 */ "pm_lsu_lmq_s0_valid\000\000other\000Slot 0 of LMQ valid\000event=0xd0a0\000\000\000\000\000\000Slot 0 of LMQ validLMQ slot 0 valid\000"
/* offset=320242 */ "pm_lsu_lmq_srq_empty_all_cyc\000\000other\000ALL threads lsu empty (lmq and srq empty)\000event=0x3001c\000\000\000\000\000\000ALL threads lsu empty (lmq and srq empty). Issue HW016541\000"
/* offset=320397 */ "pm_lsu_lmq_srq_empty_cyc\000\000pipeline\000LSU empty (lmq and srq empty)\000event=0x2003e\000\000\000\000\000\000\000"
/* offset=320482 */ "pm_lsu_lmq_srq_empty_cyc\000\000translation\000Cycles in which the LSU is empty for all threads (lmq and srq are completely empty)\000event=0x2003e\000\000\000\000\000\000\000"
/* offset=320624 */ "pm_lsu_lrq_s0_alloc\000\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd09f\000\000\000\000\000\0000.0\000"
/* offset=321079 */ "pm_lsu_lrq_s0_valid\000\000other\000Slot 0 of LRQ valid\000event=0xd09e\000\000\000\000\000\000Slot 0 of LRQ validLRQ slot 0 valid\000"
/* offset=321180 */ "pm_lsu_lrq_s43_alloc\000\000other\000LRQ slot 43 was released\000event=0xf091\000\000\000\000\000\0000.0\000"
/* offset=321255 */ "pm_lsu_lrq_s43_valid\000\000other\000LRQ slot 43 was busy\000event=0xf090\000\000\000\000\000\000LRQ slot 43 was busy42\000"
/* offset=321345 */ "pm_lsu_mrk_derat_miss\000\000other\000DERAT Reloaded (Miss)\000event=0x30162\000\000\000\000\000\000\000"
/* offset=321416 */ "pm_lsu_ncld\000\000other\000count at finish so can return only on ls0 or ls1\000event=0xc88c\000\000\000\000\000\000LSU\000"
/* offset=321506 */ "pm_lsu_ncst\000\000other\000Asserts when a i=1 store op is sent to the nest. No record of issue pipe (LS0/LS1) is maintained so this is for both pipes. Probably don't need separate LS0 and LS1\000event=0xc890\000\000\000\000\000\000\000"
/* offset=321709 */ "pm_lsu_ncst\000\000other\000Non-cachable Stores sent to nest\000event=0xc092\000\000\000\000\000\000Non-cachable Stores sent to nest42\000"
/* offset=321814 */ "pm_lsu_reject\000\000other\000LSU Reject (up to 4 per cycle)\000event=0x10064\000\000\000\000\000\000\000"
/* offset=321886 */ "pm_lsu_reject_erat_miss\000\000memory\000LSU Reject due to ERAT (up to 4 per cycles)\000event=0x2e05c\000\000\000\000\000\000\000"
/* offset=321982 */ "pm_lsu_reject_erat_miss\000\000pipeline\000LSU Reject due to ERAT (up to 4 per cycles)\000event=0x2e05c\000\000\000\000\000\000\000"
/* offset=322080 */ "pm_lsu_reject_lhs\000\000pipeline\000LSU Reject due to LHS (up to 4 per cycle)\000event=0x4e05c\000\000\000\000\000\000\000"
/* offset=322170 */ "pm_lsu_reject_lhs\000\000translation\000LSU Reject due to LHS (up to 4 per cycle)\000event=0x4e05c\000\000\000\000\000\000\000"
/* offset=322263 */ "pm_lsu_reject_lmq_full\000\000frontend\000LSU Reject due to LMQ full (up to 4 per cycles)\000event=0x3001c\000\000\000\000\000\000\000"
/* offset=322364 */ "pm_lsu_reject_lmq_full\000\000pipeline\000LSU reject due to LMQ full ( 4 per cycle)\000event=0x1e05c\000\000\000\000\000\000\000"
/* offset=322459 */ "pm_lsu_set_mpred\000\000other\000Line already in cache at reload time\000event=0xd082\000\000\000\000\000\000Line already in cache at reload time42\000"
/* offset=322577 */ "pm_lsu_srq_empty_cyc\000\000other\000ALL threads srq empty\000event=0x40008\000\000\000\000\000\000All threads srq empty\000"
/* offset=322668 */ "pm_lsu_srq_full_cyc\000\000frontend\000Cycles in which the Store Queue is full on all 4 slices. This is event is not per thread. All the threads will see the same count for this core resource\000event=0x1001a\000\000\000\000\000\000\000"
/* offset=322871 */ "pm_lsu_srq_full_cyc\000\000pipeline\000Storage Queue is full and is blocking dispatch\000event=0x1001a\000\000\000\000\000\000SRQ is Full\000"
/* offset=322979 */ "pm_lsu_srq_s0_alloc\000\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd09d\000\000\000\000\000\0000.0\000"
/* offset=323434 */ "pm_lsu_srq_s0_valid\000\000other\000Slot 0 of SRQ valid\000event=0xd09c\000\000\000\000\000\000Slot 0 of SRQ validSRQ slot 0 valid\000"
/* offset=323535 */ "pm_lsu_srq_s39_alloc\000\000other\000SRQ slot 39 was released\000event=0xf093\000\000\000\000\000\0000.0\000"
/* offset=323610 */ "pm_lsu_srq_s39_valid\000\000other\000SRQ slot 39 was busy\000event=0xf092\000\000\000\000\000\000SRQ slot 39 was busy42\000"
/* offset=323700 */ "pm_lsu_srq_sync\000\000other\000A sync in the SRQ ended\000event=0xd09b\000\000\000\000\000\0000.0\000"
/* offset=323769 */ "pm_lsu_srq_sync_cyc\000\000other\000A sync is in the SRQ (edge detect to count)\000event=0xd09a\000\000\000\000\000\000A sync is in the SRQ (edge detect to count)SRQ sync duration\000"
/* offset=323919 */ "pm_lsu_st0_fin\000\000pipeline\000LSU Finished an internal operation in ST0 port\000event=0x10012\000\000\000\000\000\000\000"
/* offset=324011 */ "pm_lsu_st1_fin\000\000pipeline\000LSU Finished an internal operation in ST1 port\000event=0x2d010\000\000\000\000\000\000\000"
/* offset=324103 */ "pm_lsu_st2_fin\000\000pipeline\000LSU Finished an internal operation in ST2 port\000event=0x3001a\000\000\000\000\000\000\000"
/* offset=324195 */ "pm_lsu_st3_fin\000\000pipeline\000LSU Finished an internal operation in ST3 port\000event=0x4c01e\000\000\000\000\000\000\000"
/* offset=324287 */ "pm_lsu_st4_fin\000\000pipeline\000LSU Finished an internal operation in ST4 port\000event=0x10014\000\000\000\000\000\000\000"
/* offset=324379 */ "pm_lsu_st5_fin\000\000others\000LSU Finished an internal operation in ST2 port\000event=0x3f04a\000\000\000\000\000\000\000"
/* offset=324469 */ "pm_lsu_stcx\000\000other\000STCX sent to nest, i.e. total\000event=0xc090\000\000\000\000\000\000\000"
/* offset=324537 */ "pm_lsu_stcx_fail\000\000other\000The LSU detects the condition that a stcx instruction failed. No requirement to wait for a response from the nest\000event=0xf080\000\000\000\000\000\000\000"
/* offset=324694 */ "pm_lsu_store_reject\000\000other\000Store reject on either pipe\000event=0xf084\000\000\000\000\000\000LSU\000"
/* offset=324771 */ "pm_lsu_two_tablewalk_cyc\000\000other\000Cycles when two tablewalks pending on this thread\000event=0xd0a6\000\000\000\000\000\000Cycles when two tablewalks pending on this thread42\000"
/* offset=324923 */ "pm_lwsync\000\000other\000An lwsync instruction was decoded and transferred\000event=0xd8ac\000\000\000\000\000\000\000"
/* offset=325009 */ "pm_lwsync\000\000other\000threaded version, IC Misses where we got EA dir hit but no sector valids were on. ICBI took line out\000event=0x5094\000\000\000\000\000\000\000"
/* offset=325146 */ "pm_lwsync_held\000\000other\000LWSYNC held at dispatch\000event=0x209a\000\000\000\000\000\000\000"
/* offset=325211 */ "pm_math_flop_cmpl\000\000other\000Math flop instruction completed\000event=0x4505c\000\000\000\000\000\000\000"
/* offset=325288 */ "pm_math_flop_cmpl\000\000others\000Math floating point instructions completed\000event=0x4505c\000\000\000\000\000\000\000"
/* offset=325377 */ "pm_mem_co\000\000memory\000Memory castouts from this lpar\000event=0x4c058\000\000\000\000\000\000\000"
/* offset=325446 */ "pm_mem_co\000\000pipeline\000Memory castouts from this thread\000event=0x4c058\000\000\000\000\000\000\000"
/* offset=325519 */ "pm_mem_loc_thresh_ifu\000\000floating point\000Local Memory above threshold for IFU speculation control\000event=0x10058\000\000\000\000\000\000\000"
/* offset=325634 */ "pm_mem_loc_thresh_ifu\000\000memory\000Local Memory above threshold for IFU speculation control\000event=0x10058\000\000\000\000\000\000\000"
/* offset=325741 */ "pm_mem_loc_thresh_lsu_high\000\000memory\000Local memory above threshold for LSU medium\000event=0x40056\000\000\000\000\000\000\000"
/* offset=325840 */ "pm_mem_loc_thresh_lsu_high\000\000pmc\000Local memory above threshold for LSU medium\000event=0x40056\000\000\000\000\000\000\000"
/* offset=325936 */ "pm_mem_loc_thresh_lsu_med\000\000marked\000Local memory above threshold for data prefetch\000event=0x1c05e\000\000\000\000\000\000\000"
/* offset=326037 */ "pm_mem_loc_thresh_lsu_med\000\000memory\000Local memory above theshold for data prefetch\000event=0x1c05e\000\000\000\000\000\000\000"
/* offset=326137 */ "pm_mem_pref\000\000marked\000Memory prefetch for this thread. Includes L4\000event=0x2c058\000\000\000\000\000\000\000"
/* offset=326222 */ "pm_mem_pref\000\000memory\000Memory prefetch for this lpar. Includes L4\000event=0x2c058\000\000\000\000\000\000\000"
/* offset=326305 */ "pm_mem_read\000\000memory\000Reads from Memory from this lpar (includes data/inst/xlate/l1prefetch/inst prefetch). Includes L4\000event=0x10056\000\000\000\000\000\000\000"
/* offset=326443 */ "pm_mem_read\000\000pipeline\000Reads from Memory from this thread (includes data/inst/xlate/l1prefetch/inst prefetch). Includes L4\000event=0x10056\000\000\000\000\000\000\000"
/* offset=326585 */ "pm_mem_rwitm\000\000memory\000Memory rwitm for this lpar\000event=0x3c05e\000\000\000\000\000\000\000"
/* offset=326653 */ "pm_mem_rwitm\000\000other\000Memory Read With Intent to Modify for this thread\000event=0x3c05e\000\000\000\000\000\000\000"
/* offset=326743 */ "pm_mma_issued\000\000pipeline\000MMA instructions issued\000event=0x1000e\000\000\000\000\000\000\000"
/* offset=326811 */ "pm_mrk_back_br_cmpl\000\000marked\000Marked branch instruction completed with a target address less than current instruction address\000event=0x3515e\000\000\000\000\000\000\000"
/* offset=326955 */ "pm_mrk_back_br_cmpl\000\000other\000Marked branch instruction completed with a target address less than current instruction address\000event=0x3515e\000\000\000\000\000\000\000"
/* offset=327098 */ "pm_mrk_br_2path\000\000other\000marked branches which are not strongly biased\000event=0x10138\000\000\000\000\000\000\000"
/* offset=327187 */ "pm_mrk_br_cmpl\000\000marked\000A marked branch completed. All branches are included\000event=0x2415c\000\000\000\000\000\000\000"
/* offset=327283 */ "pm_mrk_br_cmpl\000\000marked\000Branch Instruction completed\000event=0x1016e\000\000\000\000\000\000\000"
/* offset=327355 */ "pm_mrk_br_mpred_cmpl\000\000marked\000Marked Branch Mispredicted. Includes direction and target\000event=0x301e4\000\000\000\000\000\000\000"
/* offset=327462 */ "pm_mrk_br_mpred_cmpl\000\000marked\000Marked Branch Mispredicted\000event=0x301e4\000\000\000\000\000\000\000"
/* offset=327538 */ "pm_mrk_br_taken_cmpl\000\000marked\000Marked Branch Taken completed\000event=0x101e2\000\000\000\000\000\000\000"
/* offset=327617 */ "pm_mrk_br_taken_cmpl\000\000marked\000Marked Branch Taken instruction completed\000event=0x101e2\000\000\000\000\000\000\000"
/* offset=327708 */ "pm_mrk_bru_fin\000\000marked\000Marked Branch instruction finished\000event=0x2013a\000\000\000\000\000\000\000"
/* offset=327786 */ "pm_mrk_bru_fin\000\000marked\000bru marked instr finish\000event=0x2013a\000\000\000\000\000\000\000"
/* offset=327853 */ "pm_mrk_cru_fin\000\000other\000IFU non-branch finished\000event=0x3013a\000\000\000\000\000\000IFU non-branch marked instruction finished\000"
/* offset=327961 */ "pm_mrk_data_from_dl2l3_mod\000\000marked\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x4d148\000\000\000\000\000\000\000"
/* offset=328182 */ "pm_mrk_data_from_dl2l3_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x3d14e\000\000\000\000\000\000\000"
/* offset=328402 */ "pm_mrk_data_from_dl2l3_mod_cyc\000\000marked\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2d128\000\000\000\000\000\000\000"
/* offset=328616 */ "pm_mrk_data_from_dl2l3_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x4d12e\000\000\000\000\000\000\000"
/* offset=328829 */ "pm_mrk_data_from_dl2l3_shr\000\000marked\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x3d148\000\000\000\000\000\000\000"
/* offset=329048 */ "pm_mrk_data_from_dl2l3_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x1d150\000\000\000\000\000\000\000"
/* offset=329266 */ "pm_mrk_data_from_dl2l3_shr_cyc\000\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2c128\000\000\000\000\000\000\000"
/* offset=329478 */ "pm_mrk_data_from_dl4\000\000marked\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x3d14c\000\000\000\000\000\000\000"
/* offset=329650 */ "pm_mrk_data_from_dl4\000\000other\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x1d152\000\000\000\000\000\000\000"
/* offset=329821 */ "pm_mrk_data_from_dl4_cyc\000\000marked\000Duration in cycles to reload from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x2c12c\000\000\000\000\000\000\000"
/* offset=329986 */ "pm_mrk_data_from_dl4_cyc\000\000other\000Duration in cycles to reload from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x2c12c\000\000\000\000\000\000\000"
/* offset=330150 */ "pm_mrk_data_from_dmem\000\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x4d14c\000\000\000\000\000\000\000"
/* offset=330324 */ "pm_mrk_data_from_dmem\000\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x3d14c\000\000\000\000\000\000\000"
/* offset=330497 */ "pm_mrk_data_from_dmem_cyc\000\000marked\000Duration in cycles to reload from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x2d12c\000\000\000\000\000\000\000"
/* offset=330664 */ "pm_mrk_data_from_dmem_cyc\000\000other\000Duration in cycles to reload from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x4e11e\000\000\000\000\000\000\000"
/* offset=330830 */ "pm_mrk_data_from_l21_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x4d146\000\000\000\000\000\000\000"
/* offset=331006 */ "pm_mrk_data_from_l21_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x2d126\000\000\000\000\000\000\000"
/* offset=331175 */ "pm_mrk_data_from_l21_mod_cyc\000\000pipeline\000Duration in cycles to reload with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x3d148\000\000\000\000\000\000\000"
/* offset=331347 */ "pm_mrk_data_from_l21_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x3d146\000\000\000\000\000\000\000"
/* offset=331521 */ "pm_mrk_data_from_l21_shr\000\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x2d14e\000\000\000\000\000\000\000"
/* offset=331698 */ "pm_mrk_data_from_l21_shr_cyc\000\000other\000Duration in cycles to reload with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x2c126\000\000\000\000\000\000\000"
/* offset=331865 */ "pm_mrk_data_from_l21_shr_cyc\000\000pipeline\000Duration in cycles to reload with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x1d154\000\000\000\000\000\000\000"
/* offset=332035 */ "pm_mrk_data_from_l2\000\000marked\000The processor's data cache was reloaded from local core's L2 due to a marked load\000event=0x1d142\000\000\000\000\000\000\000"
/* offset=332165 */ "pm_mrk_data_from_l2\000\000other\000The processor's data cache was reloaded from local core's L2 due to a marked load\000event=0x2c126\000\000\000\000\000\000\000"
/* offset=332294 */ "pm_mrk_data_from_l2_cyc\000\000marked\000Duration in cycles to reload from local core's L2 due to a marked load\000event=0x4c122\000\000\000\000\000\000\000"
/* offset=332417 */ "pm_mrk_data_from_l2_cyc\000\000other\000Duration in cycles to reload from local core's L2 due to a marked load\000event=0x14156\000\000\000\000\000\000\000"
/* offset=332539 */ "pm_mrk_data_from_l2_disp_conflict_ldhitst\000\000marked\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a marked load\000event=0x3d140\000\000\000\000\000\000\000"
/* offset=332720 */ "pm_mrk_data_from_l2_disp_conflict_ldhitst\000\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a marked load\000event=0x2d148\000\000\000\000\000\000\000"
/* offset=332900 */ "pm_mrk_data_from_l2_disp_conflict_ldhitst_cyc\000\000floating point\000Duration in cycles to reload from local core's L2 with load hit store conflict due to a marked load\000event=0x1415a\000\000\000\000\000\000\000"
/* offset=333082 */ "pm_mrk_data_from_l2_disp_conflict_ldhitst_cyc\000\000marked\000Duration in cycles to reload from local core's L2 with load hit store conflict due to a marked load\000event=0x2c120\000\000\000\000\000\000\000"
/* offset=333256 */ "pm_mrk_data_from_l2_disp_conflict_other\000\000frontend\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a marked load\000event=0x2c124\000\000\000\000\000\000\000"
/* offset=333431 */ "pm_mrk_data_from_l2_disp_conflict_other\000\000marked\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a marked load\000event=0x4d140\000\000\000\000\000\000\000"
/* offset=333604 */ "pm_mrk_data_from_l2_disp_conflict_other_cyc\000\000marked\000Duration in cycles to reload from local core's L2 with dispatch conflict due to a marked load\000event=0x2d120\000\000\000\000\000\000\000"
/* offset=333770 */ "pm_mrk_data_from_l2_disp_conflict_other_cyc\000\000other\000Duration in cycles to reload from local core's L2 with dispatch conflict due to a marked load\000event=0x3d140\000\000\000\000\000\000\000"
/* offset=333935 */ "pm_mrk_data_from_l2_mepf\000\000marked\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x2d140\000\000\000\000\000\000\000"
/* offset=334116 */ "pm_mrk_data_from_l2_mepf\000\000pipeline\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x4c120\000\000\000\000\000\000\000"
/* offset=334299 */ "pm_mrk_data_from_l2_mepf_cyc\000\000marked\000Duration in cycles to reload from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x4d120\000\000\000\000\000\000\000"
/* offset=334473 */ "pm_mrk_data_from_l2_mepf_cyc\000\000other\000Duration in cycles to reload from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x3d144\000\000\000\000\000\000\000"
/* offset=334646 */ "pm_mrk_data_from_l2_no_conflict\000\000marked\000The processor's data cache was reloaded from local core's L2 without conflict due to a marked load\000event=0x1d140\000\000\000\000\000\000\000"
/* offset=334805 */ "pm_mrk_data_from_l2_no_conflict\000\000other\000The processor's data cache was reloaded from local core's L2 without conflict due to a marked load\000event=0x2c120\000\000\000\000\000\000\000"
/* offset=334963 */ "pm_mrk_data_from_l2_no_conflict_cyc\000\000marked\000Duration in cycles to reload from local core's L2 without conflict due to a marked load\000event=0x4c120\000\000\000\000\000\000\000"
/* offset=335115 */ "pm_mrk_data_from_l2_no_conflict_cyc\000\000other\000Duration in cycles to reload from local core's L2 without conflict due to a marked load\000event=0x14158\000\000\000\000\000\000\000"
/* offset=335266 */ "pm_mrk_data_from_l2miss\000\000marked\000Data cache reload L2 miss\000event=0x1d14e\000\000\000\000\000\000\000"
/* offset=335344 */ "pm_mrk_data_from_l2miss\000\000other\000The processor's data cache was reloaded from a location other than the local core's L2 due to a marked load\000event=0x401e8\000\000\000\000\000\000\000"
/* offset=335503 */ "pm_mrk_data_from_l2miss\000\000others\000The processor's data cache was reloaded from a source other than the local core's L1 or L2 due to a demand miss for a marked load\000event=0x401e8\000\000\000\000\000\000\000"
/* offset=335685 */ "pm_mrk_data_from_l2miss_cyc\000\000marked\000Duration in cycles to reload from a location other than the local core's L2 due to a marked load\000event=0x4c12e\000\000\000\000\000\000\000"
/* offset=335838 */ "pm_mrk_data_from_l2miss_cyc\000\000other\000Duration in cycles to reload from a location other than the local core's L2 due to a marked load\000event=0x35152\000\000\000\000\000\000\000"
/* offset=335990 */ "pm_mrk_data_from_l31_eco_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x4d144\000\000\000\000\000\000\000"
/* offset=336174 */ "pm_mrk_data_from_l31_eco_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2d124\000\000\000\000\000\000\000"
/* offset=336351 */ "pm_mrk_data_from_l31_eco_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x35158\000\000\000\000\000\000\000"
/* offset=336528 */ "pm_mrk_data_from_l31_eco_shr\000\000frontend\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2d14c\000\000\000\000\000\000\000"
/* offset=336713 */ "pm_mrk_data_from_l31_eco_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x3d144\000\000\000\000\000\000\000"
/* offset=336895 */ "pm_mrk_data_from_l31_eco_shr_cyc\000\000other\000Duration in cycles to reload with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2c124\000\000\000\000\000\000\000"
/* offset=337070 */ "pm_mrk_data_from_l31_eco_shr_cyc\000\000translation\000Duration in cycles to reload with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x1d142\000\000\000\000\000\000\000"
/* offset=337251 */ "pm_mrk_data_from_l31_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x2d144\000\000\000\000\000\000\000"
/* offset=337427 */ "pm_mrk_data_from_l31_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x1d140\000\000\000\000\000\000\000"
/* offset=337596 */ "pm_mrk_data_from_l31_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x4d124\000\000\000\000\000\000\000"
/* offset=337765 */ "pm_mrk_data_from_l31_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x1d146\000\000\000\000\000\000\000"
/* offset=337939 */ "pm_mrk_data_from_l31_shr\000\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x4d124\000\000\000\000\000\000\000"
/* offset=338116 */ "pm_mrk_data_from_l31_shr_cyc\000\000other\000Duration in cycles to reload with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x35156\000\000\000\000\000\000\000"
/* offset=338283 */ "pm_mrk_data_from_l31_shr_cyc\000\000other\000Duration in cycles to reload with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x4c126\000\000\000\000\000\000\000"
/* offset=338450 */ "pm_mrk_data_from_l3\000\000marked\000The processor's data cache was reloaded from local core's L3 due to a marked load\000event=0x4d142\000\000\000\000\000\000\000"
/* offset=338580 */ "pm_mrk_data_from_l3_cyc\000\000marked\000Duration in cycles to reload from local core's L3 due to a marked load\000event=0x2d122\000\000\000\000\000\000\000"
/* offset=338703 */ "pm_mrk_data_from_l3_cyc\000\000other\000Duration in cycles to reload from local core's L3 due to a marked load\000event=0x35154\000\000\000\000\000\000\000"
/* offset=338825 */ "pm_mrk_data_from_l3_disp_conflict\000\000marked\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a marked load\000event=0x3d142\000\000\000\000\000\000\000"
/* offset=338992 */ "pm_mrk_data_from_l3_disp_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a marked load\000event=0x1d144\000\000\000\000\000\000\000"
/* offset=339158 */ "pm_mrk_data_from_l3_disp_conflict_cyc\000\000marked\000Duration in cycles to reload from local core's L3 with dispatch conflict due to a marked load\000event=0x2c122\000\000\000\000\000\000\000"
/* offset=339318 */ "pm_mrk_data_from_l3_disp_conflict_cyc\000\000other\000Duration in cycles to reload from local core's L3 with dispatch conflict due to a marked load\000event=0x2c122\000\000\000\000\000\000\000"
/* offset=339477 */ "pm_mrk_data_from_l3_mepf\000\000marked\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x2d142\000\000\000\000\000\000\000"
/* offset=339658 */ "pm_mrk_data_from_l3_mepf\000\000other\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x2d142\000\000\000\000\000\000\000"
/* offset=339838 */ "pm_mrk_data_from_l3_mepf_cyc\000\000marked\000Duration in cycles to reload from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x4d122\000\000\000\000\000\000\000"
/* offset=340012 */ "pm_mrk_data_from_l3_mepf_cyc\000\000other\000Duration in cycles to reload from local core's L3 without dispatch conflicts hit on Mepf state due to a marked load\000event=0x1415c\000\000\000\000\000\000\000"
/* offset=340184 */ "pm_mrk_data_from_l3_no_conflict\000\000marked\000The processor's data cache was reloaded from local core's L3 without conflict due to a marked load\000event=0x1d144\000\000\000\000\000\000\000"
/* offset=340343 */ "pm_mrk_data_from_l3_no_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 without conflict due to a marked load\000event=0x3d146\000\000\000\000\000\000\000"
/* offset=340501 */ "pm_mrk_data_from_l3_no_conflict_cyc\000\000marked\000Duration in cycles to reload from local core's L3 without conflict due to a marked load\000event=0x4c124\000\000\000\000\000\000\000"
/* offset=340653 */ "pm_mrk_data_from_l3_no_conflict_cyc\000\000other\000Duration in cycles to reload from local core's L3 without conflict due to a marked load\000event=0x4c124\000\000\000\000\000\000\000"
/* offset=340804 */ "pm_mrk_data_from_l3miss\000\000marked\000The processor's data cache was reloaded from a location other than the local core's L3 due to a marked load\000event=0x201e4\000\000\000\000\000\000\000"
/* offset=340964 */ "pm_mrk_data_from_l3miss\000\000other\000The processor's data cache was reloaded from a location other than the local core's L3 due to a marked load\000event=0x201e4\000\000\000\000\000\000\000"
/* offset=341123 */ "pm_mrk_data_from_l3miss\000\000others\000The processor's data cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss for a marked load\000event=0x201e4\000\000\000\000\000\000\000"
/* offset=341310 */ "pm_mrk_data_from_l3miss_cyc\000\000marked\000Duration in cycles to reload from a location other than the local core's L3 due to a marked load\000event=0x1415e\000\000\000\000\000\000\000"
/* offset=341463 */ "pm_mrk_data_from_l3miss_cyc\000\000marked\000Duration in cycles to reload from a location other than the local core's L3 due to a marked load\000event=0x2d12e\000\000\000\000\000\000\000"
/* offset=341616 */ "pm_mrk_data_from_ll4\000\000marked\000The processor's data cache was reloaded from the local chip's L4 cache due to a marked load\000event=0x1d14c\000\000\000\000\000\000\000"
/* offset=341757 */ "pm_mrk_data_from_ll4_cyc\000\000marked\000Duration in cycles to reload from the local chip's L4 cache due to a marked load\000event=0x2c12e\000\000\000\000\000\000\000"
/* offset=341891 */ "pm_mrk_data_from_ll4_cyc\000\000marked\000Duration in cycles to reload from the local chip's L4 cache due to a marked load\000event=0x4c12c\000\000\000\000\000\000\000"
/* offset=342025 */ "pm_mrk_data_from_lmem\000\000marked\000The processor's data cache was reloaded from the local chip's Memory due to a marked load\000event=0x2d148\000\000\000\000\000\000\000"
/* offset=342165 */ "pm_mrk_data_from_lmem\000\000pmc\000The processor's data cache was reloaded from the local chip's Memory due to a marked load\000event=0x3d142\000\000\000\000\000\000\000"
/* offset=342302 */ "pm_mrk_data_from_lmem_cyc\000\000marked\000Duration in cycles to reload from the local chip's Memory due to a marked load\000event=0x4d128\000\000\000\000\000\000\000"
/* offset=342435 */ "pm_mrk_data_from_lmem_cyc\000\000pmc\000Duration in cycles to reload from the local chip's Memory due to a marked load\000event=0x4d128\000\000\000\000\000\000\000"
/* offset=342565 */ "pm_mrk_data_from_mem\000\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x201e0\000\000\000\000\000\000\000"
/* offset=342739 */ "pm_mrk_data_from_memory\000\000marked\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x2d14c\000\000\000\000\000\000\000"
/* offset=342917 */ "pm_mrk_data_from_memory\000\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x201e0\000\000\000\000\000\000\000"
/* offset=343094 */ "pm_mrk_data_from_memory\000\000others\000The processor's data cache was reloaded from local, remote, or distant memory due to a demand miss for a marked load\000event=0x201e0\000\000\000\000\000\000\000"
/* offset=343263 */ "pm_mrk_data_from_memory_cyc\000\000marked\000Duration in cycles to reload from a memory location including L4 from local remote or distant due to a marked load\000event=0x4d12c\000\000\000\000\000\000\000"
/* offset=343434 */ "pm_mrk_data_from_memory_cyc\000\000other\000Duration in cycles to reload from a memory location including L4 from local remote or distant due to a marked load\000event=0x1d146\000\000\000\000\000\000\000"
/* offset=343604 */ "pm_mrk_data_from_off_chip_cache\000\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x4d14a\000\000\000\000\000\000\000"
/* offset=343822 */ "pm_mrk_data_from_off_chip_cache\000\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x2d120\000\000\000\000\000\000\000"
/* offset=344039 */ "pm_mrk_data_from_off_chip_cache_cyc\000\000marked\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x2d12a\000\000\000\000\000\000\000"
/* offset=344250 */ "pm_mrk_data_from_off_chip_cache_cyc\000\000other\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x1d14e\000\000\000\000\000\000\000"
/* offset=344460 */ "pm_mrk_data_from_on_chip_cache\000\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x1d148\000\000\000\000\000\000\000"
/* offset=344654 */ "pm_mrk_data_from_on_chip_cache\000\000pipeline\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x4d140\000\000\000\000\000\000\000"
/* offset=344850 */ "pm_mrk_data_from_on_chip_cache_cyc\000\000frontend\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x3515a\000\000\000\000\000\000\000"
/* offset=345039 */ "pm_mrk_data_from_on_chip_cache_cyc\000\000marked\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x4c128\000\000\000\000\000\000\000"
/* offset=345226 */ "pm_mrk_data_from_rl2l3_mod\000\000marked\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x2d146\000\000\000\000\000\000\000"
/* offset=345443 */ "pm_mrk_data_from_rl2l3_mod\000\000pipeline\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x1d14a\000\000\000\000\000\000\000"
/* offset=345662 */ "pm_mrk_data_from_rl2l3_mod_cyc\000\000marked\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4d126\000\000\000\000\000\000\000"
/* offset=345872 */ "pm_mrk_data_from_rl2l3_mod_cyc\000\000translation\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x2d14a\000\000\000\000\000\000\000"
/* offset=346087 */ "pm_mrk_data_from_rl2l3_shr\000\000marked\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x1d14a\000\000\000\000\000\000\000"
/* offset=346302 */ "pm_mrk_data_from_rl2l3_shr\000\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x35150\000\000\000\000\000\000\000"
/* offset=346519 */ "pm_mrk_data_from_rl2l3_shr_cyc\000\000frontend\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4c12a\000\000\000\000\000\000\000"
/* offset=346729 */ "pm_mrk_data_from_rl2l3_shr_cyc\000\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4c12a\000\000\000\000\000\000\000"
/* offset=346937 */ "pm_mrk_data_from_rl4\000\000frontend\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x3515c\000\000\000\000\000\000\000"
/* offset=347108 */ "pm_mrk_data_from_rl4\000\000marked\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x2d14a\000\000\000\000\000\000\000"
/* offset=347277 */ "pm_mrk_data_from_rl4_cyc\000\000cache\000Duration in cycles to reload from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x4d12a\000\000\000\000\000\000\000"
/* offset=347438 */ "pm_mrk_data_from_rl4_cyc\000\000marked\000Duration in cycles to reload from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x4d12a\000\000\000\000\000\000\000"
/* offset=347600 */ "pm_mrk_data_from_rmem\000\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x3d14a\000\000\000\000\000\000\000"
/* offset=347774 */ "pm_mrk_data_from_rmem\000\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x1d148\000\000\000\000\000\000\000"
/* offset=347947 */ "pm_mrk_data_from_rmem_cyc\000\000marked\000Duration in cycles to reload from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x2c12a\000\000\000\000\000\000\000"
/* offset=348114 */ "pm_mrk_data_from_rmem_cyc\000\000other\000Duration in cycles to reload from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x2c12a\000\000\000\000\000\000\000"
/* offset=348280 */ "pm_mrk_dcache_reload_intv\000\000marked\000Combined Intervention event\000event=0x40118\000\000\000\000\000\000\000"
/* offset=348362 */ "pm_mrk_dcache_reload_intv\000\000pmc\000Combined Intervention event\000event=0x40118\000\000\000\000\000\000\000"
/* offset=348441 */ "pm_mrk_derat_miss\000\000frontend\000Erat Miss (TLB Access) All page sizes\000event=0x301e6\000\000\000\000\000\000\000"
/* offset=348527 */ "pm_mrk_derat_miss\000\000marked\000Erat Miss (TLB Access) All page sizes\000event=0x301e6\000\000\000\000\000\000\000"
/* offset=348611 */ "pm_mrk_derat_miss_16g\000\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 16G\000event=0x4d154\000\000\000\000\000\000\000"
/* offset=348715 */ "pm_mrk_derat_miss_16g_1g\000\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 16G (hpt mode) and 1G (radix mode)\000event=0x4c15c\000\000\000\000\000\000\000"
/* offset=348855 */ "pm_mrk_derat_miss_16m\000\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 16M\000event=0x3d154\000\000\000\000\000\000\000"
/* offset=348959 */ "pm_mrk_derat_miss_16m_2m\000\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 16M (hpt mode) or 2M (radix mode)\000event=0x3d154\000\000\000\000\000\000\000"
/* offset=349098 */ "pm_mrk_derat_miss_2m\000\000memory\000Data ERAT Miss (Data TLB Access) page size 2M for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x40164\000\000\000\000\000\000\000"
/* offset=349358 */ "pm_mrk_derat_miss_4k\000\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1d156\000\000\000\000\000\000\000"
/* offset=349460 */ "pm_mrk_derat_miss_4k\000\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 4K\000event=0x2d150\000\000\000\000\000\000\000"
/* offset=349564 */ "pm_mrk_derat_miss_64k\000\000floating point\000Marked Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2d154\000\000\000\000\000\000\000"
/* offset=349676 */ "pm_mrk_derat_miss_64k\000\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2d154\000\000\000\000\000\000\000"
/* offset=349780 */ "pm_mrk_derat_miss_64k\000\000memory\000Data ERAT Miss (Data TLB Access) page size 64K for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2d154\000\000\000\000\000\000\000"
/* offset=350042 */ "pm_mrk_dfu_fin\000\000marked\000Decimal Unit marked Instruction Finish\000event=0x20132\000\000\000\000\000\000\000"
/* offset=350124 */ "pm_mrk_dfu_fin\000\000other\000Decimal Unit marked Instruction Finish\000event=0x20132\000\000\000\000\000\000\000"
/* offset=350205 */ "pm_mrk_dfu_issue\000\000others\000The marked instruction was a decimal floating point operation issued to the VSU. Measured at issue time\000event=0x20132\000\000\000\000\000\000\000"
/* offset=350354 */ "pm_mrk_dpteg_from_dl2l3_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request\000event=0x4f148\000\000\000\000\000\000\000"
/* offset=350592 */ "pm_mrk_dpteg_from_dl2l3_mod\000\000pmc\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f148\000\000\000\000\000\000\000"
/* offset=350926 */ "pm_mrk_dpteg_from_dl2l3_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request\000event=0x3f148\000\000\000\000\000\000\000"
/* offset=351162 */ "pm_mrk_dpteg_from_dl2l3_shr\000\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f148\000\000\000\000\000\000\000"
/* offset=351499 */ "pm_mrk_dpteg_from_dl4\000\000marked\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a marked data side request\000event=0x3f14c\000\000\000\000\000\000\000"
/* offset=351688 */ "pm_mrk_dpteg_from_dl4\000\000pipeline\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f14c\000\000\000\000\000\000\000"
/* offset=351978 */ "pm_mrk_dpteg_from_dmem\000\000marked\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a marked data side request\000event=0x4f14c\000\000\000\000\000\000\000"
/* offset=352169 */ "pm_mrk_dpteg_from_dmem\000\000pipeline\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14c\000\000\000\000\000\000\000"
/* offset=352461 */ "pm_mrk_dpteg_from_l21_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a marked data side request\000event=0x4f146\000\000\000\000\000\000\000"
/* offset=352654 */ "pm_mrk_dpteg_from_l21_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f146\000\000\000\000\000\000\000"
/* offset=352949 */ "pm_mrk_dpteg_from_l21_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f146\000\000\000\000\000\000\000"
/* offset=353239 */ "pm_mrk_dpteg_from_l21_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a marked data side request\000event=0x3f146\000\000\000\000\000\000\000"
/* offset=353430 */ "pm_mrk_dpteg_from_l2\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a marked data side request\000event=0x1f142\000\000\000\000\000\000\000"
/* offset=353577 */ "pm_mrk_dpteg_from_l2\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f142\000\000\000\000\000\000\000"
/* offset=353825 */ "pm_mrk_dpteg_from_l2_disp_conflict_ldhitst\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a marked data side request\000event=0x3f140\000\000\000\000\000\000\000"
/* offset=354022 */ "pm_mrk_dpteg_from_l2_disp_conflict_other\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a marked data side request\000event=0x4f140\000\000\000\000\000\000\000"
/* offset=354211 */ "pm_mrk_dpteg_from_l2_mepf\000\000cache\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f140\000\000\000\000\000\000\000"
/* offset=354507 */ "pm_mrk_dpteg_from_l2_mepf\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked data side request\000event=0x2f140\000\000\000\000\000\000\000"
/* offset=354705 */ "pm_mrk_dpteg_from_l2_no_conflict\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a marked data side request\000event=0x1f140\000\000\000\000\000\000\000"
/* offset=354881 */ "pm_mrk_dpteg_from_l2_no_conflict\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f140\000\000\000\000\000\000\000"
/* offset=355158 */ "pm_mrk_dpteg_from_l2miss\000\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a marked data side request\000event=0x1f14e\000\000\000\000\000\000\000"
/* offset=355335 */ "pm_mrk_dpteg_from_l2miss\000\000pmc\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14e\000\000\000\000\000\000\000"
/* offset=355609 */ "pm_mrk_dpteg_from_l31_eco_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f144\000\000\000\000\000\000\000"
/* offset=355910 */ "pm_mrk_dpteg_from_l31_eco_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a marked data side request\000event=0x4f144\000\000\000\000\000\000\000"
/* offset=356111 */ "pm_mrk_dpteg_from_l31_eco_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f144\000\000\000\000\000\000\000"
/* offset=356410 */ "pm_mrk_dpteg_from_l31_eco_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a marked data side request\000event=0x3f144\000\000\000\000\000\000\000"
/* offset=356609 */ "pm_mrk_dpteg_from_l31_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a marked data side request\000event=0x2f144\000\000\000\000\000\000\000"
/* offset=356802 */ "pm_mrk_dpteg_from_l31_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f144\000\000\000\000\000\000\000"
/* offset=357097 */ "pm_mrk_dpteg_from_l31_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f146\000\000\000\000\000\000\000"
/* offset=357388 */ "pm_mrk_dpteg_from_l31_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a marked data side request\000event=0x1f146\000\000\000\000\000\000\000"
/* offset=357579 */ "pm_mrk_dpteg_from_l3\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 due to a marked data side request\000event=0x4f142\000\000\000\000\000\000\000"
/* offset=357726 */ "pm_mrk_dpteg_from_l3\000\000pmc\000A Page Table Entry was loaded into the TLB from local core's L3 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f142\000\000\000\000\000\000\000"
/* offset=357969 */ "pm_mrk_dpteg_from_l3_disp_conflict\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a marked data side request\000event=0x3f142\000\000\000\000\000\000\000"
/* offset=358153 */ "pm_mrk_dpteg_from_l3_disp_conflict\000\000pmc\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f142\000\000\000\000\000\000\000"
/* offset=358433 */ "pm_mrk_dpteg_from_l3_mepf\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked data side request\000event=0x2f142\000\000\000\000\000\000\000"
/* offset=358631 */ "pm_mrk_dpteg_from_l3_mepf\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f142\000\000\000\000\000\000\000"
/* offset=358930 */ "pm_mrk_dpteg_from_l3_no_conflict\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a marked data side request\000event=0x1f144\000\000\000\000\000\000\000"
/* offset=359106 */ "pm_mrk_dpteg_from_l3_no_conflict\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f144\000\000\000\000\000\000\000"
/* offset=359383 */ "pm_mrk_dpteg_from_l3miss\000\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14e\000\000\000\000\000\000\000"
/* offset=359659 */ "pm_mrk_dpteg_from_l3miss\000\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a marked data side request\000event=0x4f14e\000\000\000\000\000\000\000"
/* offset=359836 */ "pm_mrk_dpteg_from_ll4\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14c\000\000\000\000\000\000\000"
/* offset=360094 */ "pm_mrk_dpteg_from_ll4\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a marked data side request\000event=0x1f14c\000\000\000\000\000\000\000"
/* offset=360252 */ "pm_mrk_dpteg_from_lmem\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f148\000\000\000\000\000\000\000"
/* offset=360508 */ "pm_mrk_dpteg_from_lmem\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a marked data side request\000event=0x2f148\000\000\000\000\000\000\000"
/* offset=360665 */ "pm_mrk_dpteg_from_memory\000\000marked\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a marked data side request\000event=0x2f14c\000\000\000\000\000\000\000"
/* offset=360860 */ "pm_mrk_dpteg_from_memory\000\000pipeline\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f14c\000\000\000\000\000\000\000"
/* offset=361156 */ "pm_mrk_dpteg_from_off_chip_cache\000\000marked\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked data side request\000event=0x4f14a\000\000\000\000\000\000\000"
/* offset=361391 */ "pm_mrk_dpteg_from_off_chip_cache\000\000pipeline\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14a\000\000\000\000\000\000\000"
/* offset=361727 */ "pm_mrk_dpteg_from_on_chip_cache\000\000marked\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a marked data side request\000event=0x1f148\000\000\000\000\000\000\000"
/* offset=361938 */ "pm_mrk_dpteg_from_on_chip_cache\000\000pipeline\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f148\000\000\000\000\000\000\000"
/* offset=362251 */ "pm_mrk_dpteg_from_rl2l3_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request\000event=0x2f146\000\000\000\000\000\000\000"
/* offset=362485 */ "pm_mrk_dpteg_from_rl2l3_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f146\000\000\000\000\000\000\000"
/* offset=362820 */ "pm_mrk_dpteg_from_rl2l3_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14a\000\000\000\000\000\000\000"
/* offset=363152 */ "pm_mrk_dpteg_from_rl2l3_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request\000event=0x1f14a\000\000\000\000\000\000\000"
/* offset=363384 */ "pm_mrk_dpteg_from_rl4\000\000marked\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a marked data side request\000event=0x2f14a\000\000\000\000\000\000\000"
/* offset=363570 */ "pm_mrk_dpteg_from_rl4\000\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f14a\000\000\000\000\000\000\000"
/* offset=363854 */ "pm_mrk_dpteg_from_rmem\000\000cache\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f14a\000\000\000\000\000\000\000"
/* offset=364143 */ "pm_mrk_dpteg_from_rmem\000\000marked\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a marked data side request\000event=0x3f14a\000\000\000\000\000\000\000"
/* offset=364334 */ "pm_mrk_dtlb_miss\000\000cache\000Marked dtlb miss\000event=0x401e4\000\000\000\000\000\000\000"
/* offset=364395 */ "pm_mrk_dtlb_miss\000\000marked\000Marked dtlb miss\000event=0x401e4\000\000\000\000\000\000\000"
/* offset=364457 */ "pm_mrk_dtlb_miss_16g\000\000marked\000Marked Data TLB Miss page size 16G\000event=0x1d158\000\000\000\000\000\000\000"
/* offset=364541 */ "pm_mrk_dtlb_miss_16m\000\000marked\000Marked Data TLB Miss page size 16M\000event=0x4d156\000\000\000\000\000\000\000"
/* offset=364625 */ "pm_mrk_dtlb_miss_4k\000\000marked\000Marked Data TLB Miss page size 4k\000event=0x2d156\000\000\000\000\000\000\000"
/* offset=364707 */ "pm_mrk_dtlb_miss_64k\000\000marked\000Marked Data TLB Miss page size 64K\000event=0x3d156\000\000\000\000\000\000\000"
/* offset=364791 */ "pm_mrk_dtlb_miss_64k\000\000memory\000Marked Data TLB reload (after a miss) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c15e\000\000\000\000\000\000\000"
/* offset=365018 */ "pm_mrk_fab_rsp_bkill\000\000marked\000Marked store had to do a bkill\000event=0x40154\000\000\000\000\000\000\000"
/* offset=365098 */ "pm_mrk_fab_rsp_bkill\000\000other\000Marked store had to do a bkill\000event=0x40154\000\000\000\000\000\000\000"
/* offset=365177 */ "pm_mrk_fab_rsp_bkill_cyc\000\000marked\000cycles L2 RC took for a bkill\000event=0x2f150\000\000\000\000\000\000\000"
/* offset=365260 */ "pm_mrk_fab_rsp_bkill_cyc\000\000other\000cycles L2 RC took for a bkill\000event=0x1f152\000\000\000\000\000\000\000"
/* offset=365342 */ "pm_mrk_fab_rsp_claim_rty\000\000frontend\000Sampled store did a rwitm and got a rty\000event=0x3015e\000\000\000\000\000\000\000"
/* offset=365437 */ "pm_mrk_fab_rsp_claim_rty\000\000marked\000Sampled store did a rwitm and got a rty\000event=0x3015e\000\000\000\000\000\000\000"
/* offset=365530 */ "pm_mrk_fab_rsp_dclaim\000\000frontend\000Marked store had to do a dclaim\000event=0x30154\000\000\000\000\000\000\000"
/* offset=365614 */ "pm_mrk_fab_rsp_dclaim\000\000marked\000Marked store had to do a dclaim\000event=0x30154\000\000\000\000\000\000\000"
/* offset=365696 */ "pm_mrk_fab_rsp_dclaim_cyc\000\000frontend\000cycles L2 RC took for a dclaim\000event=0x2f152\000\000\000\000\000\000\000"
/* offset=365783 */ "pm_mrk_fab_rsp_dclaim_cyc\000\000marked\000cycles L2 RC took for a dclaim\000event=0x2f152\000\000\000\000\000\000\000"
/* offset=365868 */ "pm_mrk_fab_rsp_match\000\000other\000ttype and cresp matched as specified in MMCR1\000event=0x30156\000\000\000\000\000\000\000"
/* offset=365962 */ "pm_mrk_fab_rsp_match_cyc\000\000other\000cresp/ttype match cycles\000event=0x4f152\000\000\000\000\000\000\000"
/* offset=366039 */ "pm_mrk_fab_rsp_rd_rty\000\000frontend\000Sampled L2 reads retry count\000event=0x4015e\000\000\000\000\000\000\000"
/* offset=366120 */ "pm_mrk_fab_rsp_rd_rty\000\000marked\000Sampled L2 reads retry count\000event=0x4015e\000\000\000\000\000\000\000"
/* offset=366199 */ "pm_mrk_fab_rsp_rd_t_intv\000\000frontend\000Sampled Read got a T intervention\000event=0x1015e\000\000\000\000\000\000\000"
/* offset=366288 */ "pm_mrk_fab_rsp_rd_t_intv\000\000marked\000Sampled Read got a T intervention\000event=0x1015e\000\000\000\000\000\000\000"
/* offset=366375 */ "pm_mrk_fab_rsp_rwitm_cyc\000\000frontend\000cycles L2 RC took for a rwitm\000event=0x4f150\000\000\000\000\000\000\000"
/* offset=366460 */ "pm_mrk_fab_rsp_rwitm_cyc\000\000marked\000cycles L2 RC took for a rwitm\000event=0x4f150\000\000\000\000\000\000\000"
/* offset=366543 */ "pm_mrk_fab_rsp_rwitm_rty\000\000frontend\000Sampled store did a rwitm and got a rty\000event=0x2015e\000\000\000\000\000\000\000"
/* offset=366638 */ "pm_mrk_fab_rsp_rwitm_rty\000\000marked\000Sampled store did a rwitm and got a rty\000event=0x2015e\000\000\000\000\000\000\000"
/* offset=366731 */ "pm_mrk_filt_match\000\000other\000Marked filter Match\000event=0x2013c\000\000\000\000\000\000\000"
/* offset=366796 */ "pm_mrk_fin_stall_cyc\000\000other\000Marked instruction Finish Stall cycles (marked finish after NTC) (use edge detect to count )\000event=0x1013c\000\000\000\000\000\000Marked instruction Finish Stall cycles (marked finish after NTC) (use edge detect to count #)\000"
/* offset=367030 */ "pm_mrk_fx_lsu_fin\000\000pipeline\000The marked instruction was simple fixed point that was issued to the store unit. Measured at finish time\000event=0x2013c\000\000\000\000\000\000\000"
/* offset=367183 */ "pm_mrk_fxu_fin\000\000marked\000fxu marked instr finish\000event=0x20134\000\000\000\000\000\000\000"
/* offset=367250 */ "pm_mrk_fxu_fin\000\000other\000fxu marked instr finish\000event=0x20134\000\000\000\000\000\000\000"
/* offset=367316 */ "pm_mrk_fxu_issue\000\000others\000The marked instruction was a fixed point operation issued to the VSU. Measured at issue time\000event=0x20134\000\000\000\000\000\000\000"
/* offset=367454 */ "pm_mrk_grp_cmpl\000\000other\000marked instruction finished (completed)\000event=0x40130\000\000\000\000\000\000\000"
/* offset=367537 */ "pm_mrk_grp_ic_miss\000\000other\000Marked Group experienced I cache miss\000event=0x4013a\000\000\000\000\000\000\000"
/* offset=367621 */ "pm_mrk_grp_ntc\000\000other\000Marked group ntc cycles\000event=0x3013c\000\000\000\000\000\000\000"
/* offset=367687 */ "pm_mrk_ic_miss\000\000other\000Marked instruction experienced I cache miss\000event=0x4013a\000\000\000\000\000\000\000"
/* offset=367773 */ "pm_mrk_inst\000\000marked\000An instruction was marked. Includes both Random Instruction Sampling (RIS) at decode time and Random Event Sampling (RES) at the time the configured event happens\000event=0x24158\000\000\000\000\000\000\000"
/* offset=367976 */ "pm_mrk_inst_cmpl\000\000marked\000marked instruction completed\000event=0x401e0\000\000\000\000\000\000\000"
/* offset=368050 */ "pm_mrk_inst_decoded\000\000marked\000An instruction was marked at decode time. Random Instruction Sampling (RIS) only\000event=0x20130\000\000\000\000\000\000\000"
/* offset=368179 */ "pm_mrk_inst_decoded\000\000marked\000marked instruction decoded\000event=0x20130\000\000\000\000\000\000marked instruction decoded. Name from ISU?\000"
/* offset=368296 */ "pm_mrk_inst_decoded\000\000others\000An instruction was marked at decode time. Random Instruction Sampling (RIS) only\000event=0x20130\000\000\000\000\000\000\000"
/* offset=368425 */ "pm_mrk_inst_disp\000\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\000\000\000\000\000Marked Instruction dispatched\000"
/* offset=368563 */ "pm_mrk_inst_disp\000\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\000\000\000\000\000\000"
/* offset=368672 */ "pm_mrk_inst_fin\000\000marked\000marked instruction finished. Excludes instructions that finish at dispatch. Note that stores always finish twice since the address gets issued to the LSU and the data gets issued to the VSU\000event=0x30130\000\000\000\000\000\000\000"
/* offset=368906 */ "pm_mrk_inst_fin\000\000marked\000marked instruction finished\000event=0x30130\000\000\000\000\000\000\000"
/* offset=368978 */ "pm_mrk_inst_fin\000\000marked\000marked instruction finished\000event=0x30130\000\000\000\000\000\000marked instr finish any unit\000"
/* offset=369078 */ "pm_mrk_inst_flushed\000\000others\000The marked instruction was flushed\000event=0x4e15e\000\000\000\000\000\000\000"
/* offset=369161 */ "pm_mrk_inst_from_l3miss\000\000marked\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x401e6\000\000\000\000\000\000n/a\000"
/* offset=369289 */ "pm_mrk_inst_from_l3miss\000\000other\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x401e6\000\000\000\000\000\000\000"
/* offset=369413 */ "pm_mrk_inst_from_l3miss\000\000others\000The processor's instruction cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss for a marked instruction\000event=0x401e6\000\000\000\000\000\000\000"
/* offset=369614 */ "pm_mrk_inst_issued\000\000marked\000Marked instruction issued. Note that stores always get issued twice, the address gets issued to the LSU and the data gets issued to the VSU. Also, issues can sometimes get killed/cancelled and cause multiple sequential issues for the same instruction\000event=0x10132\000\000\000\000\000\000\000"
/* offset=369912 */ "pm_mrk_inst_issued\000\000marked\000Marked instruction issued\000event=0x10132\000\000\000\000\000\000\000"
/* offset=369985 */ "pm_mrk_inst_timeo\000\000marked\000Marked instruction finish timeout (instruction was lost)\000event=0x40134\000\000\000\000\000\000\000"
/* offset=370088 */ "pm_mrk_inst_timeo\000\000marked\000marked Instruction finish timeout (instruction lost)\000event=0x40134\000\000\000\000\000\000\000"
/* offset=370187 */ "pm_mrk_issue_dependent_load\000\000others\000The marked instruction was dependent on a load. It is eligible for issue kill\000event=0x30162\000\000\000\000\000\000\000"
/* offset=370321 */ "pm_mrk_l1_icache_miss\000\000marked\000sampled Instruction suffered an icache Miss\000event=0x101e4\000\000\000\000\000\000Marked L1 Icache Miss\000"
/* offset=370436 */ "pm_mrk_l1_icache_miss\000\000other\000sampled Instruction suffered an icache Miss\000event=0x101e4\000\000\000\000\000\000\000"
/* offset=370529 */ "pm_mrk_l1_icache_miss\000\000others\000Marked Instruction suffered an icache Miss\000event=0x101e4\000\000\000\000\000\000\000"
/* offset=370622 */ "pm_mrk_l1_reload_valid\000\000marked\000Marked demand reload\000event=0x101ea\000\000\000\000\000\000\000"
/* offset=370694 */ "pm_mrk_l1_reload_valid\000\000other\000Marked demand reload\000event=0x101ea\000\000\000\000\000\000\000"
/* offset=370765 */ "pm_mrk_l1_reload_valid\000\000others\000Marked demand reload\000event=0x101ea\000\000\000\000\000\000\000"
/* offset=370837 */ "pm_mrk_l2_rc_disp\000\000frontend\000Marked Instruction RC dispatched in L2\000event=0x20114\000\000\000\000\000\000\000"
/* offset=370924 */ "pm_mrk_l2_rc_disp\000\000frontend\000Marked instruction RC dispatched in L2\000event=0x20114\000\000\000\000\000\000\000"
/* offset=371011 */ "pm_mrk_l2_rc_disp\000\000marked\000Marked Instruction RC dispatched in L2\000event=0x20114\000\000\000\000\000\000\000"
/* offset=371096 */ "pm_mrk_l2_rc_done\000\000frontend\000L2 RC machine completed the transaction for the marked instruction\000event=0x3012a\000\000\000\000\000\000\000"
/* offset=371211 */ "pm_mrk_l2_rc_done\000\000frontend\000Marked RC done\000event=0x3012a\000\000\000\000\000\000\000"
/* offset=371274 */ "pm_mrk_l2_rc_done\000\000marked\000Marked RC done\000event=0x3012a\000\000\000\000\000\000\000"
/* offset=371335 */ "pm_mrk_l2_tm_req_abort\000\000frontend\000TM abort\000event=0x1e15e\000\000\000\000\000\000\000"
/* offset=371397 */ "pm_mrk_larx_fin\000\000frontend\000Larx finished\000event=0x40116\000\000\000\000\000\000\000"
/* offset=371457 */ "pm_mrk_larx_fin\000\000frontend\000Marked load and reserve instruction (LARX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x40116\000\000\000\000\000\000\000"
/* offset=371610 */ "pm_mrk_larx_fin\000\000marked\000Larx finished\000event=0x40116\000\000\000\000\000\000\000"
/* offset=371668 */ "pm_mrk_ld_cmpl\000\000marked\000Marked loads completed\000event=0x34146\000\000\000\000\000\000\000"
/* offset=371734 */ "pm_mrk_ld_miss_exposed\000\000other\000Marked Load exposed Miss (exposed period ended)\000event=0x1013f\000\000\000\000\000\000Marked Load exposed Miss (use edge detect to count #)\000"
/* offset=371885 */ "pm_mrk_ld_miss_exposed_cyc\000\000frontend\000Marked Load exposed Miss (use edge detect to count #)\000event=0x1013e\000\000\000\000\000\000\000"
/* offset=371996 */ "pm_mrk_ld_miss_exposed_cyc\000\000marked\000Marked Load exposed Miss cycles\000event=0x1013e\000\000\000\000\000\000Marked Load exposed Miss (use edge detect to count #)\000"
/* offset=372136 */ "pm_mrk_ld_miss_l1\000\000marked\000Marked DL1 Demand Miss counted at exec time\000event=0x201e2\000\000\000\000\000\000\000"
/* offset=372226 */ "pm_mrk_ld_miss_l1\000\000pipeline\000Marked DL1 Demand Miss counted at exec time. Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x201e2\000\000\000\000\000\000\000"
/* offset=372448 */ "pm_mrk_ld_miss_l1\000\000pipeline\000Marked DL1 Demand Miss counted at finish time\000event=0x201e2\000\000\000\000\000\000\000"
/* offset=372542 */ "pm_mrk_ld_miss_l1_cyc\000\000marked\000Marked ld latency\000event=0x4013e\000\000\000\000\000\000\000"
/* offset=372610 */ "pm_mrk_ld_miss_l1_cyc\000\000other\000Marked ld latency\000event=0x1d156\000\000\000\000\000\000\000"
/* offset=372677 */ "pm_mrk_lsu_derat_miss\000\000other\000Marked derat reload (miss) for any page size\000event=0x30162\000\000\000\000\000\000\000"
/* offset=372771 */ "pm_mrk_lsu_fin\000\000marked\000lsu marked instr finish\000event=0x40132\000\000\000\000\000\000\000"
/* offset=372838 */ "pm_mrk_lsu_fin\000\000pipeline\000LSU marked instruction finish\000event=0x40132\000\000\000\000\000\000\000"
/* offset=372913 */ "pm_mrk_lsu_fin\000\000translation\000lsu marked instr PPC finish\000event=0x40132\000\000\000\000\000\000\000"
/* offset=372989 */ "pm_mrk_lsu_flush\000\000other\000Flush: (marked) : All Cases\000event=0xd180\000\000\000\000\000\000Flush: (marked) : All Cases42\000"
/* offset=373089 */ "pm_mrk_lsu_flush_lrq\000\000other\000Flush: (marked) LRQ\000event=0xd188\000\000\000\000\000\000Flush: (marked) LRQMarked LRQ flushes\000"
/* offset=373193 */ "pm_mrk_lsu_flush_srq\000\000other\000Flush: (marked) SRQ\000event=0xd18a\000\000\000\000\000\000Flush: (marked) SRQMarked SRQ lhs flushes\000"
/* offset=373301 */ "pm_mrk_lsu_flush_uld\000\000other\000Flush: (marked) Unaligned Load\000event=0xd184\000\000\000\000\000\000Flush: (marked) Unaligned LoadMarked unaligned load flushes\000"
/* offset=373438 */ "pm_mrk_lsu_flush_ust\000\000other\000Flush: (marked) Unaligned Store\000event=0xd186\000\000\000\000\000\000Flush: (marked) Unaligned StoreMarked unaligned store flushes\000"
/* offset=373578 */ "pm_mrk_lsu_reject\000\000other\000LSU marked reject (up to 2 per cycle)\000event=0x40164\000\000\000\000\000\000\000"
/* offset=373661 */ "pm_mrk_lsu_reject_erat_miss\000\000other\000LSU marked reject due to ERAT (up to 2 per cycle)\000event=0x30164\000\000\000\000\000\000\000"
/* offset=373766 */ "pm_mrk_ntc_cyc\000\000translation\000Cycles during which the marked instruction is next to complete (completion is held up because the marked instruction hasn't completed yet)\000event=0x2011c\000\000\000\000\000\000\000"
/* offset=373953 */ "pm_mrk_ntf_cyc\000\000translation\000Cycles during which the marked instruction is the oldest in the pipeline (NTF or NTC)\000event=0x2011c\000\000\000\000\000\000\000"
/* offset=374087 */ "pm_mrk_ntf_fin\000\000marked\000Marked next to finish instruction finished\000event=0x20112\000\000\000\000\000\000\000"
/* offset=374173 */ "pm_mrk_ntf_fin\000\000marked\000The marked instruction became the oldest in the pipeline before it finished. It excludes instructions that finish at dispatch\000event=0x20112\000\000\000\000\000\000\000"
/* offset=374342 */ "pm_mrk_probe_nop_cmpl\000\000translation\000Marked probeNops completed\000event=0x1f15e\000\000\000\000\000\000\000"
/* offset=374424 */ "pm_mrk_run_cyc\000\000marked\000Marked run cycles\000event=0x1d15e\000\000\000\000\000\000\000"
/* offset=374485 */ "pm_mrk_run_cyc\000\000memory\000Run cycles in which a marked instruction is in the pipeline\000event=0x1d15e\000\000\000\000\000\000\000"
/* offset=374588 */ "pm_mrk_src_pref_track_eff\000\000other\000Marked src pref track was effective\000event=0x1d15a\000\000\000\000\000\000\000"
/* offset=374677 */ "pm_mrk_src_pref_track_ineff\000\000other\000Prefetch tracked was ineffective for marked src\000event=0x3d15a\000\000\000\000\000\000\000"
/* offset=374780 */ "pm_mrk_src_pref_track_mod\000\000other\000Prefetch tracked was moderate for marked src\000event=0x4d15c\000\000\000\000\000\000\000"
/* offset=374878 */ "pm_mrk_src_pref_track_mod_l2\000\000other\000Marked src Prefetch Tracked was moderate (source L2)\000event=0x1d15c\000\000\000\000\000\000\000"
/* offset=374987 */ "pm_mrk_src_pref_track_mod_l3\000\000other\000Prefetch tracked was moderate (L3 hit) for marked src\000event=0x3d15c\000\000\000\000\000\000\000"
/* offset=375097 */ "pm_mrk_st_cmpl\000\000marked\000marked store completed and sent to nest\000event=0x10134\000\000\000\000\000\000Marked store completed\000"
/* offset=375202 */ "pm_mrk_st_cmpl\000\000memory\000Marked store completed and sent to nest. Note that this count excludes cache-inhibited stores\000event=0x301e2\000\000\000\000\000\000\000"
/* offset=375339 */ "pm_mrk_st_cmpl\000\000memory\000Marked store completed and sent to nest\000event=0x301e2\000\000\000\000\000\000\000"
/* offset=375422 */ "pm_mrk_st_cmpl_int\000\000marked\000marked store finished with intervention\000event=0x30134\000\000\000\000\000\000marked store complete (data home) with intervention\000"
/* offset=375560 */ "pm_mrk_st_cmpl_int\000\000other\000marked store finished with intervention\000event=0x30134\000\000\000\000\000\000\000"
/* offset=375646 */ "pm_mrk_st_done_l2\000\000others\000Marked stores completed in L2 (RC machine done)\000event=0x10134\000\000\000\000\000\000\000"
/* offset=375740 */ "pm_mrk_st_drain_cyc\000\000others\000cycles to drain st from core to L2\000event=0x3f150\000\000\000\000\000\000\000"
/* offset=375823 */ "pm_mrk_st_drain_to_l2disp_cyc\000\000marked\000cycles to drain st from core to L2\000event=0x3f150\000\000\000\000\000\000\000"
/* offset=375916 */ "pm_mrk_st_drain_to_l2disp_cyc\000\000other\000cycles to drain st from core to L2\000event=0x3f150\000\000\000\000\000\000\000"
/* offset=376008 */ "pm_mrk_st_fin\000\000marked\000The marked instruction was a store of any kind\000event=0x3e15a\000\000\000\000\000\000\000"
/* offset=376097 */ "pm_mrk_st_fwd\000\000marked\000Marked st forwards\000event=0x3012c\000\000\000\000\000\000\000"
/* offset=376158 */ "pm_mrk_st_l2_cyc\000\000memory\000Cycles from L2 RC dispatch to L2 RC completion\000event=0x1f150\000\000\000\000\000\000\000"
/* offset=376250 */ "pm_mrk_st_l2disp_to_cmpl_cyc\000\000marked\000cycles from L2 rc disp to l2 rc completion\000event=0x1f150\000\000\000\000\000\000\000"
/* offset=376350 */ "pm_mrk_st_nest\000\000marked\000A store has been sampled/marked and is at the point of execution where it has completed in the core and can no longer be flushed. At this point the store is sent to the L2\000event=0x20138\000\000\000\000\000\000\000"
/* offset=376565 */ "pm_mrk_st_nest\000\000marked\000Marked store sent to nest\000event=0x20138\000\000\000\000\000\000\000"
/* offset=376634 */ "pm_mrk_stall_cmplu_cyc\000\000marked\000Marked Group completion Stall\000event=0x3013e\000\000\000\000\000\000Marked Group Completion Stall cycles (use edge detect to count #)\000"
/* offset=376780 */ "pm_mrk_stall_cmplu_cyc\000\000marked\000Number of cycles the marked instruction is experiencing a stall while it is next to complete (NTC)\000event=0x3013e\000\000\000\000\000\000\000"
/* offset=376930 */ "pm_mrk_start_probe_nop_cmpl\000\000translation\000Marked Start probe nop (AND R0,R0,R0) completed\000event=0x1f15e\000\000\000\000\000\000\000"
/* offset=377039 */ "pm_mrk_start_probe_nop_disp\000\000others\000Marked Start probe nop dispatched. Instruction AND R0,R0,R0\000event=0x40114\000\000\000\000\000\000\000"
/* offset=377155 */ "pm_mrk_stcx_core_cyc\000\000others\000Cycles spent in the core portion of a marked Stcx instruction. It starts counting when the instruction is decoded and stops counting when it drains into the L2\000event=0x44146\000\000\000\000\000\000\000"
/* offset=377364 */ "pm_mrk_stcx_fail\000\000marked\000Marked conditional store instruction (STCX) failed. LARX and STCX are instructions used to acquire a lock\000event=0x3e158\000\000\000\000\000\000\000"
/* offset=377515 */ "pm_mrk_stcx_fail\000\000marked\000marked stcx failed\000event=0x3e158\000\000\000\000\000\000\000"
/* offset=377579 */ "pm_mrk_stcx_fin\000\000marked\000Marked conditional store instruction (STCX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x24156\000\000\000\000\000\000\000"
/* offset=377731 */ "pm_mrk_stcx_fin\000\000marked\000Number of marked stcx instructions finished. This includes instructions in the speculative path of a branch that may be flushed\000event=0x24156\000\000\000\000\000\000\000"
/* offset=377903 */ "pm_mrk_stcx_l2_cyc\000\000others\000Cycles spent in the nest portion of a marked Stcx instruction. It starts counting when the operation starts to drain to the L2 and it stops counting when the instruction retires from the Instruction Completion Table (ICT) in the Instruction Sequencing Unit (ISU)\000event=0x1f15c\000\000\000\000\000\000\000"
/* offset=378213 */ "pm_mrk_tend_fail\000\000other\000Nested or not nested tend failed for a marked tend instruction\000event=0x28a4\000\000\000\000\000\000\000"
/* offset=378319 */ "pm_mrk_tgt_pref_track_eff\000\000other\000Marked target pref track was effective\000event=0x1c15a\000\000\000\000\000\000\000"
/* offset=378411 */ "pm_mrk_tgt_pref_track_ineff\000\000other\000Prefetch tracked was ineffective for marked target\000event=0x3c15a\000\000\000\000\000\000\000"
/* offset=378517 */ "pm_mrk_tgt_pref_track_mod\000\000other\000Prefetch tracked was moderate for marked target\000event=0x4c15c\000\000\000\000\000\000\000"
/* offset=378618 */ "pm_mrk_tgt_pref_track_mod_l2\000\000other\000Marked target Prefetch Tracked was moderate (source L2)\000event=0x1c15c\000\000\000\000\000\000\000"
/* offset=378730 */ "pm_mrk_tgt_pref_track_mod_l3\000\000other\000Prefetch tracked was moderate (L3 hit) for marked target\000event=0x3c15c\000\000\000\000\000\000\000"
/* offset=378843 */ "pm_mrk_vsu_fin\000\000marked\000VSU marked instr finish\000event=0x30132\000\000\000\000\000\000vsu (fpu) marked instr finish\000"
/* offset=378939 */ "pm_mrk_vsu_fin\000\000other\000VSU marked instr finish\000event=0x30132\000\000\000\000\000\000\000"
/* offset=379005 */ "pm_mrk_vsu_fin\000\000others\000VSU marked instructions finished. Excludes simple FX instructions issued to the Store Unit\000event=0x30132\000\000\000\000\000\000\000"
/* offset=379139 */ "pm_mrk_xfer_from_src_cyc_pmc1\000\000memory\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[0:12]\000event=0x1c144\000\000\000\000\000\000\000"
/* offset=379293 */ "pm_mrk_xfer_from_src_cyc_pmc2\000\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[15:27]\000event=0x2c144\000\000\000\000\000\000\000"
/* offset=379448 */ "pm_mrk_xfer_from_src_cyc_pmc3\000\000memory\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[30:42]\000event=0x3c144\000\000\000\000\000\000\000"
/* offset=379603 */ "pm_mrk_xfer_from_src_cyc_pmc4\000\000memory\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[45:57]\000event=0x4c144\000\000\000\000\000\000\000"
/* offset=379758 */ "pm_mrk_xfer_from_src_pmc1\000\000memory\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[0:12]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x1c142\000\000\000\000\000\000\000"
/* offset=380127 */ "pm_mrk_xfer_from_src_pmc2\000\000frontend\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[15:27]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x2c142\000\000\000\000\000\000\000"
/* offset=380499 */ "pm_mrk_xfer_from_src_pmc3\000\000memory\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[30:42]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x3c142\000\000\000\000\000\000\000"
/* offset=380869 */ "pm_mrk_xfer_from_src_pmc4\000\000memory\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[45:57]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x4c142\000\000\000\000\000\000\000"
/* offset=381239 */ "pm_mult_mrk\000\000marked\000mult marked instr\000event=0x3d15e\000\000\000\000\000\000\000"
/* offset=381297 */ "pm_mult_mrk\000\000other\000mult marked instr\000event=0x3d15e\000\000\000\000\000\000\000"
/* offset=381354 */ "pm_nest_ref_clk\000\000memory\000Multiply by 4 to obtain the number of PB cycles\000event=0x3006e\000\000\000\000\000\000Nest reference clocks\000"
/* offset=381467 */ "pm_nest_ref_clk\000\000memory\000Multiply by 4 to obtain the number of PB cycles\000event=0x3006e\000\000\000\000\000\000\000"
/* offset=381559 */ "pm_nested_tend\000\000other\000Completion time nested tend\000event=0x20b0\000\000\000\000\000\000\000"
/* offset=381628 */ "pm_non_data_store\000\000other\000All ops that drain from s2q to L2 and contain no data\000event=0xf8a0\000\000\000\000\000\000\000"
/* offset=381726 */ "pm_non_fav_tbegin\000\000other\000Dispatch time non favored tbegin\000event=0x20b6\000\000\000\000\000\000\000"
/* offset=381803 */ "pm_non_fma_flop_cmpl\000\000memory\000Non FMA instruction completed\000event=0x4d056\000\000\000\000\000\000\000"
/* offset=381882 */ "pm_non_math_flop_cmpl\000\000marked\000Non FLOP operation completed\000event=0x4d05a\000\000\000\000\000\000\000"
/* offset=381961 */ "pm_non_math_flop_cmpl\000\000marked\000Non Math instructions completed\000event=0x4d05a\000\000\000\000\000\000\000"
/* offset=382043 */ "pm_non_tm_rst_sc\000\000other\000Non-TM snoop hits line in L3 that is TM_SC state and causes it to be invalidated\000event=0x260a6\000\000\000\000\000\000\000"
/* offset=382168 */ "pm_ntc_all_fin\000\000other\000Cycles after instruction finished to instruction completed\000event=0x2001a\000\000\000\000\000\000\000"
/* offset=382269 */ "pm_ntc_all_fin\000\000pipeline\000Cycles in which both instructions in the ICT entry pair show as finished. These are the cycles between finish and completion for the oldest pair of instructions in the pipeline\000event=0x40008\000\000\000\000\000\000\000"
/* offset=382491 */ "pm_ntc_fin\000\000pipeline\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. Note that instructions can finish out of order, therefore not all the instructions that finish have a Next-to-complete status\000event=0x2405a\000\000\000\000\000\000\000"
/* offset=382729 */ "pm_ntc_fin\000\000pipeline\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. This event is used to account for cycles in which work is being completed in the CPI stack\000event=0x2405a\000\000\000\000\000\000\000"
/* offset=382932 */ "pm_ntc_issue_held_arb\000\000pipeline\000The NTC instruction is being held at dispatch because it lost arbitration onto the issue pipe to another instruction (from the same thread or a different thread)\000event=0x2e016\000\000\000\000\000\000\000"
/* offset=383146 */ "pm_ntc_issue_held_darq_full\000\000frontend\000The NTC instruction is being held at dispatch because there are no slots in the DARQ for it\000event=0x1006a\000\000\000\000\000\000\000"
/* offset=383296 */ "pm_ntc_issue_held_other\000\000marked\000The NTC instruction is being held at dispatch during regular pipeline cycles, or because the VSU is busy with multi-cycle instructions, or because of a write-back collision with VSU\000event=0x3d05a\000\000\000\000\000\000\000"
/* offset=383530 */ "pm_ntcg_all_fin\000\000other\000Cycles after all instructions have finished to group completed\000event=0x2001a\000\000\000\000\000\000Ccycles after all instructions have finished to group completed\000"
/* offset=383699 */ "pm_outer_tbegin\000\000other\000Completion time outer tbegin\000event=0x20ac\000\000\000\000\000\000\000"
/* offset=383770 */ "pm_outer_tend\000\000other\000Completion time outer tend\000event=0x20ae\000\000\000\000\000\000\000"
/* offset=383837 */ "pm_partial_st_fin\000\000other\000Any store finished by an LSU slice\000event=0x34054\000\000\000\000\000\000\000"
/* offset=383917 */ "pm_pmc1_overflow\000\000memory\000Overflow from counter 1\000event=0x20010\000\000\000\000\000\000\000"
/* offset=383986 */ "pm_pmc1_overflow\000\000memory\000The event selected for PMC1 caused the event counter to overflow\000event=0x20010\000\000\000\000\000\000\000"
/* offset=384096 */ "pm_pmc1_overflow\000\000pmc\000Overflow from counter 1\000event=0x20010\000\000\000\000\000\000\000"
/* offset=384162 */ "pm_pmc1_rewind\000\000memory\000PMC1 rewind event\000event=0x4d02c\000\000\000\000\000\000\000"
/* offset=384223 */ "pm_pmc1_rewind\000\000memory\000The speculative event selected for PMC1 rewinds and the counter for PMC1 is not charged\000event=0x4d02c\000\000\000\000\000\000\000"
/* offset=384354 */ "pm_pmc1_saved\000\000translation\000PMC1 Rewind Value saved\000event=0x4d010\000\000\000\000\000\000\000"
/* offset=384425 */ "pm_pmc1_saved\000\000translation\000The conditions for the speculative event selected for PMC1 are met and PMC1 is charged\000event=0x4d010\000\000\000\000\000\000\000"
/* offset=384559 */ "pm_pmc2_overflow\000\000pmc\000Overflow from counter 2\000event=0x30010\000\000\000\000\000\000\000"
/* offset=384625 */ "pm_pmc2_overflow\000\000translation\000Overflow from counter 2\000event=0x30010\000\000\000\000\000\000\000"
/* offset=384699 */ "pm_pmc2_overflow\000\000translation\000The event selected for PMC2 caused the event counter to overflow\000event=0x30010\000\000\000\000\000\000\000"
/* offset=384814 */ "pm_pmc2_rewind\000\000pipeline\000PMC2 Rewind Event (did not match condition)\000event=0x30020\000\000\000\000\000\000\000"
/* offset=384903 */ "pm_pmc2_rewind\000\000pipeline\000The speculative event selected for PMC2 rewinds and the counter for PMC2 is not charged\000event=0x30020\000\000\000\000\000\000\000"
/* offset=385036 */ "pm_pmc2_rewind\000\000pmc\000PMC2 Rewind Event (did not match condition)\000event=0x30020\000\000\000\000\000\000\000"
/* offset=385120 */ "pm_pmc2_saved\000\000pipeline\000PMC2 Rewind Value saved\000event=0x10022\000\000\000\000\000\000\000"
/* offset=385188 */ "pm_pmc2_saved\000\000pipeline\000The conditions for the speculative event selected for PMC2 are met and PMC2 is charged\000event=0x10022\000\000\000\000\000\000\000"
/* offset=385319 */ "pm_pmc2_saved\000\000pmc\000PMC2 Rewind Value saved\000event=0x10022\000\000\000\000\000\000PMC2 Rewind Value saved (matched condition)\000"
/* offset=385425 */ "pm_pmc3_overflow\000\000pipeline\000Overflow from counter 3\000event=0x40010\000\000\000\000\000\000\000"
/* offset=385496 */ "pm_pmc3_overflow\000\000pipeline\000The event selected for PMC3 caused the event counter to overflow\000event=0x40010\000\000\000\000\000\000\000"
/* offset=385608 */ "pm_pmc3_overflow\000\000pmc\000Overflow from counter 3\000event=0x40010\000\000\000\000\000\000\000"
/* offset=385674 */ "pm_pmc3_rewind\000\000memory\000PMC3 rewind event. A rewind happens when a speculative event (such as latency or CPI stack) is selected on PMC3 and the stall reason or reload source did not match the one programmed in PMC3. When this occurs, the count in PMC3 will not change\000event=0x1000a\000\000\000\000\000\000\000"
/* offset=385961 */ "pm_pmc3_rewind\000\000memory\000The speculative event selected for PMC3 rewinds and the counter for PMC3 is not charged\000event=0x1000a\000\000\000\000\000\000\000"
/* offset=386092 */ "pm_pmc3_saved\000\000other\000PMC3 Rewind Value saved\000event=0x4d012\000\000\000\000\000\000\000"
/* offset=386157 */ "pm_pmc3_saved\000\000others\000The conditions for the speculative event selected for PMC3 are met and PMC3 is charged\000event=0x4d012\000\000\000\000\000\000\000"
/* offset=386286 */ "pm_pmc4_overflow\000\000frontend\000Overflow from counter 4\000event=0x10010\000\000\000\000\000\000\000"
/* offset=386357 */ "pm_pmc4_overflow\000\000frontend\000The event selected for PMC4 caused the event counter to overflow\000event=0x10010\000\000\000\000\000\000\000"
/* offset=386469 */ "pm_pmc4_overflow\000\000pmc\000Overflow from counter 4\000event=0x10010\000\000\000\000\000\000\000"
/* offset=386535 */ "pm_pmc4_rewind\000\000frontend\000PMC4 Rewind Event\000event=0x10020\000\000\000\000\000\000\000"
/* offset=386598 */ "pm_pmc4_rewind\000\000frontend\000The speculative event selected for PMC4 rewinds and the counter for PMC4 is not charged\000event=0x10020\000\000\000\000\000\000\000"
/* offset=386731 */ "pm_pmc4_rewind\000\000pmc\000PMC4 Rewind Event\000event=0x10020\000\000\000\000\000\000PMC4 Rewind Event (did not match condition)\000"
/* offset=386832 */ "pm_pmc4_saved\000\000pipeline\000PMC4 Rewind Value saved (matched condition)\000event=0x30022\000\000\000\000\000\000\000"
/* offset=386920 */ "pm_pmc4_saved\000\000pipeline\000The conditions for the speculative event selected for PMC4 are met and PMC4 is charged\000event=0x30022\000\000\000\000\000\000\000"
/* offset=387051 */ "pm_pmc4_saved\000\000pmc\000PMC4 Rewind Value saved (matched condition)\000event=0x30022\000\000\000\000\000\000\000"
/* offset=387134 */ "pm_pmc5_overflow\000\000pipeline\000Overflow from counter 5\000event=0x10024\000\000\000\000\000\000\000"
/* offset=387205 */ "pm_pmc5_overflow\000\000pipeline\000The event selected for PMC5 caused the event counter to overflow\000event=0x10024\000\000\000\000\000\000\000"
/* offset=387317 */ "pm_pmc5_overflow\000\000pmc\000Overflow from counter 5\000event=0x10024\000\000\000\000\000\000\000"
/* offset=387383 */ "pm_pmc6_overflow\000\000pipeline\000Overflow from counter 6\000event=0x30024\000\000\000\000\000\000\000"
/* offset=387454 */ "pm_pmc6_overflow\000\000pipeline\000The event selected for PMC6 caused the event counter to overflow\000event=0x30024\000\000\000\000\000\000\000"
/* offset=387566 */ "pm_pmc6_overflow\000\000pmc\000Overflow from counter 6\000event=0x30024\000\000\000\000\000\000\000"
/* offset=387632 */ "pm_pref_track_eff\000\000other\000Prefetch Tracked was effective\000event=0x1005a\000\000\000\000\000\000\000"
/* offset=387708 */ "pm_pref_track_ineff\000\000other\000Prefetch tracked was ineffective\000event=0x3005a\000\000\000\000\000\000\000"
/* offset=387788 */ "pm_pref_track_mod\000\000other\000Prefetch tracked was moderate\000event=0x4005a\000\000\000\000\000\000\000"
/* offset=387863 */ "pm_pref_track_mod_l2\000\000other\000Prefetch Tracked was moderate (source L2)\000event=0x1005c\000\000\000\000\000\000\000"
/* offset=387953 */ "pm_pref_track_mod_l3\000\000other\000Prefetch tracked was moderate (L3)\000event=0x3005c\000\000\000\000\000\000\000"
/* offset=388036 */ "pm_pref_tracked\000\000other\000Total number of Prefetch Operations that were tracked\000event=0x2005a\000\000\000\000\000\000\000"
/* offset=388133 */ "pm_privileged_cyc\000\000others\000Cycles when the thread is in Privileged state. MSR[S HV PR]=x00\000event=0x4d028\000\000\000\000\000\000\000"
/* offset=388243 */ "pm_privileged_inst_cmpl\000\000others\000PowerPC Instructions that completed while the thread is in Privileged state\000event=0x3405a\000\000\000\000\000\000\000"
/* offset=388371 */ "pm_probe_nop_disp\000\000other\000ProbeNops dispatched\000event=0x40014\000\000\000\000\000\000\000"
/* offset=388437 */ "pm_probe_nop_disp\000\000pipeline\000ProbeNops dispatched\000event=0x40014\000\000\000\000\000\000\000"
/* offset=388506 */ "pm_pte_prefetch\000\000other\000PTE prefetches\000event=0xe084\000\000\000\000\000\000PTE prefetches42\000"
/* offset=388579 */ "pm_pte_prefetch\000\000other\000PTE prefetches\000event=0xf084\000\000\000\000\000\000\000"
/* offset=388636 */ "pm_ptesync\000\000other\000A ptesync instruction was counted when the instruction is decoded and transmitted\000event=0xd8b0\000\000\000\000\000\000\000"
/* offset=388755 */ "pm_ptesync_fin\000\000memory\000Ptesync instruction finished in the store unit. Only one ptesync can finish at a time\000event=0x2003e\000\000\000\000\000\000\000"
/* offset=388884 */ "pm_pump_cpred\000\000memory\000Pump prediction correct. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=389216 */ "pm_pump_cpred\000\000pipeline\000Pump prediction correct. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10054\000\000\000\000\000\000\000"
/* offset=389406 */ "pm_pump_mpred\000\000memory\000Pump misprediction. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=389728 */ "pm_pump_mpred\000\000pipeline\000Pump misprediction. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40052\000\000\000\000\000\000\000"
/* offset=389913 */ "pm_radix_pwc_l1_pde_from_l2\000\000other\000A Page Directory Entry was reloaded to a level 1 page walk cache from the core's L2 data cache\000event=0x2d026\000\000\000\000\000\000\000"
/* offset=390063 */ "pm_radix_pwc_l1_pde_from_l3\000\000marked\000A Page Directory Entry was reloaded to a level 1 page walk cache from the core's L3 data cache\000event=0x3f058\000\000\000\000\000\000\000"
/* offset=390214 */ "pm_radix_pwc_l1_pde_from_l3miss\000\000marked\000A Page Directory Entry was reloaded to a level 1 page walk cache from beyond the core's L3 data cache. The source could be local/remote/distant memory or another core's cache\000event=0x4f056\000\000\000\000\000\000\000"
/* offset=390449 */ "pm_radix_pwc_l2_pde_from_l2\000\000floating point\000A Page Directory Entry was reloaded to a level 2 page walk cache from the core's L2 data cache\000event=0x2d028\000\000\000\000\000\000\000"
/* offset=390608 */ "pm_radix_pwc_l2_pde_from_l3\000\000pipeline\000A Page Directory Entry was reloaded to a level 2 page walk cache from the core's L3 data cache\000event=0x3f05a\000\000\000\000\000\000\000"
/* offset=390761 */ "pm_radix_pwc_l2_pte_from_l2\000\000pipeline\000A Page Table Entry was reloaded to a level 2 page walk cache from the core's L2 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation\000event=0x1f058\000\000\000\000\000\000\000"
/* offset=391002 */ "pm_radix_pwc_l2_pte_from_l3\000\000marked\000A Page Table Entry was reloaded to a level 2 page walk cache from the core's L3 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation\000event=0x4f058\000\000\000\000\000\000\000"
/* offset=391241 */ "pm_radix_pwc_l2_pte_from_l3miss\000\000other\000A Page Table Entry was reloaded to a level 2 page walk cache from beyond the core's L3 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation. The source could be local/remote/distant memory or another core's cache\000event=0x4f05c\000\000\000\000\000\000\000"
/* offset=391563 */ "pm_radix_pwc_l3_pde_from_l2\000\000marked\000A Page Directory Entry was reloaded to a level 3 page walk cache from the core's L2 data cache\000event=0x2d02a\000\000\000\000\000\000\000"
/* offset=391714 */ "pm_radix_pwc_l3_pde_from_l3\000\000marked\000A Page Directory Entry was reloaded to a level 3 page walk cache from the core's L3 data cache\000event=0x1f05c\000\000\000\000\000\000\000"
/* offset=391865 */ "pm_radix_pwc_l3_pte_from_l2\000\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from the core's L2 data cache. This implies that a level 4 PWC access was not necessary for this translation\000event=0x2d02e\000\000\000\000\000\000\000"
/* offset=392091 */ "pm_radix_pwc_l3_pte_from_l3\000\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from the core's L3 data cache. This implies that a level 4 PWC access was not necessary for this translation\000event=0x3f05e\000\000\000\000\000\000\000"
/* offset=392317 */ "pm_radix_pwc_l3_pte_from_l3miss\000\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from beyond the core's L3 data cache. This implies that a level 4 PWC access was not necessary for this translation. The source could be local/remote/distant memory or another core's cache\000event=0x4f05e\000\000\000\000\000\000\000"
/* offset=392627 */ "pm_radix_pwc_l4_pte_from_l2\000\000marked\000A Page Table Entry was reloaded to a level 4 page walk cache from the core's L2 data cache. This is the deepest level of PWC possible for a translation\000event=0x1f05a\000\000\000\000\000\000\000"
/* offset=392835 */ "pm_radix_pwc_l4_pte_from_l3\000\000marked\000A Page Table Entry was reloaded to a level 4 page walk cache from the core's L3 data cache. This is the deepest level of PWC possible for a translation\000event=0x4f05a\000\000\000\000\000\000\000"
/* offset=393043 */ "pm_radix_pwc_l4_pte_from_l3miss\000\000other\000A Page Table Entry was reloaded to a level 4 page walk cache from beyond the core's L3 data cache. This is the deepest level of PWC possible for a translation. The source could be local/remote/distant memory or another core's cache\000event=0x3f054\000\000\000\000\000\000\000"
/* offset=393334 */ "pm_radix_pwc_miss\000\000other\000A radix translation attempt missed in the TLB and all levels of page walk cache\000event=0x4f054\000\000\000\000\000\000\000"
/* offset=393459 */ "pm_rc0_alloc\000\000other\000RC mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16081\000\000\000\000\000\0000.0\000"
/* offset=393584 */ "pm_rc0_busy\000\000other\000RC mach 0 Busy. Used by PMU to sample ave RC lifetime (mach0 used as sample point)\000event=0x1608c\000\000\000\000\000\000\000"
/* offset=393706 */ "pm_rc0_busy\000\000other\000RC mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16080\000\000\000\000\000\000\000"
/* offset=393827 */ "pm_rc_lifetime_exc_1024\000\000other\000Number of times the RC machine for a sampled instruction was active for more than 1024 cycles\000event=0x200301ea\000\000\000\000\000\000Reload latency exceeded 1024 cyc\000"
/* offset=394007 */ "pm_rc_lifetime_exc_2048\000\000other\000Number of times the RC machine for a sampled instruction was active for more than 2048 cycles\000event=0x200401ec\000\000\000\000\000\000Threshold counter exceeded a value of 2048\000"
/* offset=394197 */ "pm_rc_lifetime_exc_256\000\000other\000Number of times the RC machine for a sampled instruction was active for more than 256 cycles\000event=0x200101e8\000\000\000\000\000\000Threshold counter exceed a count of 256\000"
/* offset=394382 */ "pm_rc_lifetime_exc_32\000\000other\000Number of times the RC machine for a sampled instruction was active for more than 32 cycles\000event=0x200201e6\000\000\000\000\000\000Reload latency exceeded 32 cyc\000"
/* offset=394556 */ "pm_rc_usage\000\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each RC machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x1688c\000\000\000\000\000\000\000"
/* offset=394775 */ "pm_rc_usage\000\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 RC machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x36088\000\000\000\000\000\000\000"
/* offset=394996 */ "pm_rd_clearing_sc\000\000other\000Core TM load hits line in L3 in TM_SC state and causes it to be invalidated\000event=0x468a6\000\000\000\000\000\000\000"
/* offset=395117 */ "pm_rd_forming_sc\000\000other\000Doesn't occur\000event=0x460a6\000\000\000\000\000\000\000"
/* offset=395175 */ "pm_rd_hit_pf\000\000other\000RD machine hit L3 PF machine\000event=0x268a8\000\000\000\000\000\000\000"
/* offset=395244 */ "pm_real_srq_full\000\000other\000Out of real srq entries\000event=0x20004\000\000\000\000\000\000\000"
/* offset=395312 */ "pm_run_cyc\000\000pipeline\000Processor cycles gated by the run latch\000event=0x200f4\000\000\000\000\000\000\000"
/* offset=395393 */ "pm_run_cyc\000\000pipeline\000Run_cycles\000event=0x200f4\000\000\000\000\000\000\000"
/* offset=395445 */ "pm_run_cyc\000\000pipeline\000Run_cycles\000event=0x600f4\000\000\000\000\000\000\000"
/* offset=395497 */ "pm_run_cyc_smt2_mode\000\000cache\000Cycles when this thread's run latch is set and the core is in SMT2 mode\000event=0x3006c\000\000\000\000\000\000\000"
/* offset=395617 */ "pm_run_cyc_smt2_mode\000\000pipeline\000Cycles run latch is set and core is in SMT2 mode\000event=0x3006c\000\000\000\000\000\000\000"
/* offset=395717 */ "pm_run_cyc_smt2_shrd_mode\000\000other\000cycles this threads run latch is set and the core is in SMT2 shared mode\000event=0x2006a\000\000\000\000\000\000Cycles run latch is set and core is in SMT2-shared mode\000"
/* offset=395898 */ "pm_run_cyc_smt2_split_mode\000\000other\000Cycles run latch is set and core is in SMT2-split mode\000event=0x1006a\000\000\000\000\000\000\000"
/* offset=396007 */ "pm_run_cyc_smt4_mode\000\000other\000Cycles in which this thread's run latch is set and the core is in SMT4 mode\000event=0x2006c\000\000\000\000\000\000\000"
/* offset=396131 */ "pm_run_cyc_smt4_mode\000\000others\000Cycles when this thread's run latch is set and the core is in SMT4 mode\000event=0x2006c\000\000\000\000\000\000\000"
/* offset=396252 */ "pm_run_cyc_smt4_mode\000\000pipeline\000cycles this threads run latch is set and the core is in SMT4 mode\000event=0x2006c\000\000\000\000\000\000Cycles run latch is set and core is in SMT4 mode\000"
/* offset=396417 */ "pm_run_cyc_smt8_mode\000\000other\000Cycles run latch is set and core is in SMT8 mode\000event=0x4006c\000\000\000\000\000\000\000"
/* offset=396514 */ "pm_run_cyc_st_mode\000\000marked\000Cycles run latch is set and core is in ST mode\000event=0x1006c\000\000\000\000\000\000\000"
/* offset=396608 */ "pm_run_cyc_st_mode\000\000pipeline\000Cycles run latch is set and core is in ST mode\000event=0x1006c\000\000\000\000\000\000\000"
/* offset=396704 */ "pm_run_cyc_st_mode\000\000pipeline\000Cycles when the run latch is set and the core is in ST mode\000event=0x1006c\000\000\000\000\000\000\000"
/* offset=396813 */ "pm_run_inst_cmpl\000\000other\000Run_Instructions\000event=0x400fa\000\000\000\000\000\000\000"
/* offset=396874 */ "pm_run_inst_cmpl\000\000others\000Completed PowerPC instructions gated by the run latch\000event=0x500fa\000\000\000\000\000\000\000"
/* offset=396973 */ "pm_run_inst_cmpl\000\000pipeline\000Run_Instructions\000event=0x500fa\000\000\000\000\000\000\000"
/* offset=397037 */ "pm_run_inst_cmpl_conc\000\000cache\000PowerPC instructions completed by this thread when all threads in the core had the run-latch set\000event=0x300f4\000\000\000\000\000\000\000"
/* offset=397183 */ "pm_run_latch_all_threads_cyc\000\000others\000Cycles when the run latch is set for all threads\000event=0x2000c\000\000\000\000\000\000\000"
/* offset=397289 */ "pm_run_latch_any_thread_cyc\000\000others\000Cycles when at least one thread has the run latch set\000event=0x100fa\000\000\000\000\000\000\000"
/* offset=397399 */ "pm_run_purr\000\000marked\000Run_PURR\000event=0x400f4\000\000\000\000\000\000\000"
/* offset=397448 */ "pm_run_purr\000\000pmc\000Run_PURR\000event=0x400f4\000\000\000\000\000\000\000"
/* offset=397494 */ "pm_run_spurr\000\000memory\000Run SPURR\000event=0x10008\000\000\000\000\000\000\000"
/* offset=397545 */ "pm_run_spurr\000\000pmc\000Run SPURR\000event=0x10008\000\000\000\000\000\000\000"
/* offset=397593 */ "pm_s2q_full\000\000other\000Cycles during which the S2Q is full\000event=0xe080\000\000\000\000\000\000\000"
/* offset=397667 */ "pm_scalar_flop_cmpl\000\000other\000Scalar flop operation completed\000event=0x45056\000\000\000\000\000\000\000"
/* offset=397746 */ "pm_scalar_flop_cmpl\000\000others\000Scalar floating point instructions completed\000event=0x45056\000\000\000\000\000\000\000"
/* offset=397839 */ "pm_scalar_fsqrt_fdiv_issue\000\000pipeline\000Scalar versions of four floating point operations: fdiv,fsqrt (xvdivdp, xvdivsp, xvsqrtdp, xvsqrtsp)\000event=0x3d058\000\000\000\000\000\000\000"
/* offset=397997 */ "pm_sec_erat_hit\000\000other\000secondary ERAT Hit\000event=0xf082\000\000\000\000\000\000secondary ERAT Hit42\000"
/* offset=398078 */ "pm_shl_created\000\000other\000Store-Hit-Load Table Entry Created\000event=0x508c\000\000\000\000\000\000\000"
/* offset=398154 */ "pm_shl_st_convert\000\000other\000Store-Hit-Load Table Read Hit with entry Enabled\000event=0x508e\000\000\000\000\000\000\000"
/* offset=398247 */ "pm_shl_st_dep_created\000\000other\000Store-Hit-Load Table Read Hit with entry Enabled\000event=0x588c\000\000\000\000\000\000\000"
/* offset=398344 */ "pm_shl_st_disable\000\000other\000Store-Hit-Load Table Read Hit with entry Disabled (entry was disabled due to the entry shown to not prevent the flush)\000event=0x5090\000\000\000\000\000\000\000"
/* offset=398507 */ "pm_sn0_alloc\000\000other\000SN mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x26085\000\000\000\000\000\0000.0\000"
/* offset=398632 */ "pm_sn0_busy\000\000other\000SN mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x26084\000\000\000\000\000\000\000"
/* offset=398753 */ "pm_sn0_busy\000\000other\000SN mach 0 Busy. Used by PMU to sample ave SN lifetime (mach0 used as sample point)\000event=0x16090\000\000\000\000\000\000\000"
/* offset=398875 */ "pm_sn_hit\000\000other\000Any port snooper hit L3.  Up to 4 can happen in a cycle but we only count 1\000event=0x460a8\000\000\000\000\000\000\000"
/* offset=398988 */ "pm_sn_invl\000\000other\000Any port snooper detects a store to a line in the Sx state and invalidates the line.  Up to 4 can happen in a cycle but we only count 1\000event=0x368a8\000\000\000\000\000\000\000"
/* offset=399162 */ "pm_sn_miss\000\000other\000Any port snooper L3 miss or collision.  Up to 4 can happen in a cycle but we only count 1\000event=0x468a8\000\000\000\000\000\000\000"
/* offset=399290 */ "pm_sn_usage\000\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each SN machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x3688c\000\000\000\000\000\000\000"
/* offset=399509 */ "pm_sn_usage\000\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 SN machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x4608c\000\000\000\000\000\000\000"
/* offset=399730 */ "pm_snoop_tlbie\000\000other\000TLBIE snoop\000event=0xd0b2\000\000\000\000\000\000TLBIE snoopSnoop TLBIE\000"
/* offset=399805 */ "pm_snoop_tlbie\000\000other\000TLBIE snoop\000event=0xf880\000\000\000\000\000\000\000"
/* offset=399858 */ "pm_snp_tm_hit_m\000\000other\000TM snoop that is a store hits line in L3 in M or Mu state (exclusive modified)\000event=0x360a6\000\000\000\000\000\000\000"
/* offset=399980 */ "pm_snp_tm_hit_t\000\000other\000TM snoop that is a store hits line in L3 in T, Tn or Te state (shared modified)\000event=0x368a6\000\000\000\000\000\000\000"
/* offset=400103 */ "pm_sp_flop_cmpl\000\000marked\000SP instruction completed\000event=0x4505a\000\000\000\000\000\000\000"
/* offset=400172 */ "pm_sp_flop_cmpl\000\000marked\000Single Precision floating point instructions completed\000event=0x4505a\000\000\000\000\000\000\000"
/* offset=400271 */ "pm_srq_empty_cyc\000\000other\000Cycles in which the SRQ has at least one (out of four) empty slice\000event=0x40008\000\000\000\000\000\000\000"
/* offset=400382 */ "pm_srq_sync_cyc\000\000other\000A sync is in the S2Q (edge detect to count)\000event=0xd0ac\000\000\000\000\000\000\000"
/* offset=400468 */ "pm_st_caused_fail\000\000other\000Non-TM Store caused any thread to fail\000event=0x1608e\000\000\000\000\000\000\000"
/* offset=400552 */ "pm_st_cmpl\000\000pipeline\000Store completion count\000event=0x20016\000\000\000\000\000\000\000"
/* offset=400616 */ "pm_st_cmpl\000\000translation\000Stores completed from S2Q (2nd-level store queue). This event includes regular stores, stcx and cache inhibited stores. The following operations are excluded (pteupdate, snoop tlbie complete, store atomics, miso, load atomic payloads, tlbie, tlbsync, slbieg, isync, msgsnd, slbiag, cpabort, copy, tcheck, tend, stsync, dcbst, icbi, dcbf, hwsync, lwsync, ptesync, eieio, msgsync)\000event=0x200f0\000\000\000\000\000\000\000"
/* offset=401039 */ "pm_st_cmpl\000\000translation\000Stores completed from S2Q (2nd-level store queue)\000event=0x200f0\000\000\000\000\000\000\000"
/* offset=401133 */ "pm_st_fin\000\000pipeline\000Store Instructions Finished\000event=0x200f0\000\000\000\000\000\000Store Instructions Finished (store sent to nest)\000"
/* offset=401249 */ "pm_st_fin\000\000translation\000Store finish count. Includes speculative activity\000event=0x20016\000\000\000\000\000\000\000"
/* offset=401342 */ "pm_st_fwd\000\000pipeline\000Store forwards that finished\000event=0x20018\000\000\000\000\000\000\000"
/* offset=401411 */ "pm_st_fwd\000\000translation\000Store forwards that finished\000event=0x20018\000\000\000\000\000\000\000"
/* offset=401483 */ "pm_st_miss_l1\000\000cache\000Store Missed L1\000event=0x300f0\000\000\000\000\000\000\000"
/* offset=401540 */ "pm_st_miss_l1\000\000translation\000Store Missed L1\000event=0x300f0\000\000\000\000\000\000\000"
/* offset=401603 */ "pm_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_PM / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was issued to the Permute execution pipe and waiting to finish\000\000\000\000\000"
/* offset=401776 */ "pm_stall_end_gct_empty\000\000other\000Count ended because GCT went empty\000event=0x10028\000\000\000\000\000\000\000"
/* offset=401861 */ "pm_stall_end_ict_empty\000\000translation\000The number a times the core transitioned from a stall to ICT-empty for this thread\000event=0x10028\000\000\000\000\000\000\000"
/* offset=402000 */ "pm_stcx_fail\000\000pipeline\000stcx failed\000event=0x1e058\000\000\000\000\000\000\000"
/* offset=402055 */ "pm_stcx_fail\000\000translation\000stcx failed\000event=0x1e058\000\000\000\000\000\000\000"
/* offset=402113 */ "pm_stcx_fail_fin\000\000locks\000Conditional store instruction (STCX) failed. LARX and STCX are instructions used to acquire a lock\000event=0x1e058\000\000\000\000\000\000\000"
/* offset=402256 */ "pm_stcx_fin\000\000other\000Number of stcx instructions finished. This includes instructions in the speculative path of a branch that may be flushed\000event=0x2e014\000\000\000\000\000\000\000"
/* offset=402416 */ "pm_stcx_fin\000\000others\000Conditional store instruction (STCX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x2e014\000\000\000\000\000\000\000"
/* offset=402557 */ "pm_stcx_lsu\000\000other\000STCX executed reported at sent to nest\000event=0xc090\000\000\000\000\000\000STCX executed reported at sent to nest42\000"
/* offset=402674 */ "pm_stcx_pass_fin\000\000locks\000Conditional store instruction (STCX) passed. LARX and STCX are instructions used to acquire a lock\000event=0x4e050\000\000\000\000\000\000\000"
/* offset=402817 */ "pm_stcx_success_cmpl\000\000other\000Number of stcx instructions that completed successfully\000event=0xc8bc\000\000\000\000\000\000\000"
/* offset=402920 */ "pm_stop_fetch_pending_cyc\000\000other\000Fetching is stopped due to an incoming instruction that will result in a flush\000event=0x48a4\000\000\000\000\000\000\000"
/* offset=403051 */ "pm_suspended\000\000frontend\000Counter OFF\000event=0\000\000\000\000\000\000\000"
/* offset=403100 */ "pm_suspended\000\000pmc\000Counter OFF\000event=0\000\000\000\000\000\000\000"
/* offset=403144 */ "pm_swap_cancel\000\000other\000SWAP cancel , rtag not available\000event=0x3090\000\000\000\000\000\000\000"
/* offset=403218 */ "pm_swap_cancel_gpr\000\000other\000SWAP cancel , rtag not available for gpr\000event=0x3092\000\000\000\000\000\000\000"
/* offset=403304 */ "pm_swap_complete\000\000other\000swap cast in completed\000event=0x308c\000\000\000\000\000\000\000"
/* offset=403370 */ "pm_swap_complete_gpr\000\000other\000swap cast in completed fpr gpr\000event=0x308e\000\000\000\000\000\000\000"
/* offset=403448 */ "pm_sync_mrk_br_link\000\000frontend\000Marked Branch and link branch that can cause a synchronous interrupt\000event=0x15152\000\000\000\000\000\000\000"
/* offset=403567 */ "pm_sync_mrk_br_link\000\000marked\000Marked Branch and link branch that can cause a synchronous interrupt\000event=0x15152\000\000\000\000\000\000\000"
/* offset=403684 */ "pm_sync_mrk_br_mpred\000\000frontend\000Marked Branch mispredict that can cause a synchronous interrupt\000event=0x1515c\000\000\000\000\000\000\000"
/* offset=403799 */ "pm_sync_mrk_br_mpred\000\000marked\000Marked Branch mispredict that can cause a synchronous interrupt\000event=0x1515c\000\000\000\000\000\000\000"
/* offset=403912 */ "pm_sync_mrk_fx_divide\000\000marked\000Marked fixed point divide that can cause a synchronous interrupt\000event=0x15156\000\000\000\000\000\000\000"
/* offset=404027 */ "pm_sync_mrk_fx_divide\000\000pipeline\000Marked fixed point divide that can cause a synchronous interrupt\000event=0x15156\000\000\000\000\000\000\000"
/* offset=404144 */ "pm_sync_mrk_l2hit\000\000marked\000Marked L2 Hits that can throw a synchronous interrupt\000event=0x15158\000\000\000\000\000\000\000"
/* offset=404244 */ "pm_sync_mrk_l2hit\000\000memory\000Marked L2 Hits that can throw a synchronous interrupt\000event=0x15158\000\000\000\000\000\000\000"
/* offset=404344 */ "pm_sync_mrk_l2miss\000\000marked\000Marked L2 Miss that can throw a synchronous interrupt\000event=0x1515a\000\000\000\000\000\000\000"
/* offset=404445 */ "pm_sync_mrk_l2miss\000\000other\000Marked L2 Miss that can throw a synchronous interrupt\000event=0x1515a\000\000\000\000\000\000\000"
/* offset=404545 */ "pm_sync_mrk_l3miss\000\000marked\000Marked L3 misses that can throw a synchronous interrupt\000event=0x15154\000\000\000\000\000\000\000"
/* offset=404648 */ "pm_sync_mrk_l3miss\000\000other\000Marked L3 misses that can throw a synchronous interrupt\000event=0x15154\000\000\000\000\000\000\000"
/* offset=404750 */ "pm_sync_mrk_probe_nop\000\000marked\000Marked probeNops which can cause synchronous interrupts\000event=0x15150\000\000\000\000\000\000\000"
/* offset=404856 */ "pm_sys_pump_cpred\000\000marked\000Initial and Final Pump Scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30050\000\000\000\000\000\000\000"
/* offset=405035 */ "pm_sys_pump_cpred\000\000memory\000Initial and Final Pump Scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=405381 */ "pm_sys_pump_mpred\000\000marked\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30052\000\000\000\000\000\000\000"
/* offset=405681 */ "pm_sys_pump_mpred\000\000memory\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=406230 */ "pm_sys_pump_mpred_rty\000\000memory\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=406636 */ "pm_sys_pump_mpred_rty\000\000pmc\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40050\000\000\000\000\000\000\000"
/* offset=406850 */ "pm_tablewalk_cyc\000\000pipeline\000Cycles when a tablewalk (I or D) is active\000event=0x10026\000\000\000\000\000\000Tablewalk Active\000"
/* offset=406956 */ "pm_tablewalk_cyc\000\000pmc\000Cycles when an instruction tablewalk is active\000event=0x10026\000\000\000\000\000\000\000"
/* offset=407045 */ "pm_tablewalk_cyc_pref\000\000other\000tablewalk qualified for pte  prefetches\000event=0xf884\000\000\000\000\000\000\000"
/* offset=407133 */ "pm_tablewalk_cyc_pref\000\000other\000tablewalk qualified for pte prefetches\000event=0xe086\000\000\000\000\000\000tablewalk qualified for pte prefetches42\000"
/* offset=407260 */ "pm_tabort_treclaim\000\000other\000Completion time tabortnoncd, tabortcd, treclaim\000event=0x20b2\000\000\000\000\000\000\000"
/* offset=407353 */ "pm_tage_correct\000\000other\000The TAGE overrode BHT direction prediction and it was correct.   Includes taken and not taken and is counted at execution time\000event=0x58b4\000\000\000\000\000\000\000"
/* offset=407522 */ "pm_tage_correct_taken_cmpl\000\000other\000The TAGE overrode BHT direction prediction and it was correct.  Counted at completion for taken branches only\000event=0x50b4\000\000\000\000\000\000\000"
/* offset=407685 */ "pm_tage_override_wrong\000\000other\000The TAGE overrode BHT direction prediction but it was incorrect.  Counted at completion for taken branches only\000event=0x50b8\000\000\000\000\000\000\000"
/* offset=407846 */ "pm_tage_override_wrong_spec\000\000other\000The TAGE overrode BHT direction prediction and it was correct.   Includes taken and not taken and is counted at execution time\000event=0x58b8\000\000\000\000\000\000\000"
/* offset=408027 */ "pm_taken_br_mpred_cmpl\000\000other\000Total number of taken branches that were incorrectly predicted as not-taken. This event counts branches completed and does not include speculative instructions\000event=0x20056\000\000\000\000\000\000\000"
/* offset=408237 */ "pm_tb_bit_trans\000\000other\000timebase event\000event=0x300f8\000\000\000\000\000\000\000"
/* offset=408295 */ "pm_tb_bit_trans\000\000pipeline\000timebase event\000event=0x300f8\000\000\000\000\000\000\000"
/* offset=408356 */ "pm_tend_pend_cyc\000\000other\000TEND latency per thread\000event=0xe0ba\000\000\000\000\000\000TEND latency per thread42\000"
/* offset=408448 */ "pm_tend_pend_cyc\000\000other\000TEND latency per thread\000event=0xe8b0\000\000\000\000\000\000\000"
/* offset=408515 */ "pm_thrd_all_run_cyc\000\000other\000Cycles in which all the threads have the run latch set\000event=0x2000c\000\000\000\000\000\000\000"
/* offset=408617 */ "pm_thrd_all_run_cyc\000\000pipeline\000All Threads in Run_cycles (was both threads in run_cycles)\000event=0x2000c\000\000\000\000\000\000\000"
/* offset=408726 */ "pm_thrd_conc_run_inst\000\000cache\000PPC Instructions Finished by this thread when all threads in the core had the run-latch set\000event=0x300f4\000\000\000\000\000\000\000"
/* offset=408867 */ "pm_thrd_conc_run_inst\000\000frontend\000PPC Instructions Finished when both threads in run_cycles\000event=0x300f4\000\000\000\000\000\000Concurrent Run Instructions\000"
/* offset=409004 */ "pm_thrd_grp_cmpl_both_cyc\000\000other\000Cycles group completed on both completion slots by any thread\000event=0x10012\000\000\000\000\000\000Two threads finished same cycle (gated by run latch)\000"
/* offset=409171 */ "pm_thrd_prio_0_1_cyc\000\000other\000Cycles thread running at priority level 0 or 1\000event=0x40bc\000\000\000\000\000\000\000"
/* offset=409265 */ "pm_thrd_prio_2_3_cyc\000\000other\000Cycles thread running at priority level 2 or 3\000event=0x40be\000\000\000\000\000\000\000"
/* offset=409359 */ "pm_thrd_prio_2_3_cyc\000\000other\000Cycles thread running at priority level 2 or 3\000event=0x48bc\000\000\000\000\000\000\000"
/* offset=409453 */ "pm_thrd_prio_4_5_cyc\000\000other\000Cycles thread running at priority level 4 or 5\000event=0x5080\000\000\000\000\000\000\000"
/* offset=409547 */ "pm_thrd_prio_6_7_cyc\000\000other\000Cycles thread running at priority level 6 or 7\000event=0x5082\000\000\000\000\000\000\000"
/* offset=409641 */ "pm_thrd_prio_6_7_cyc\000\000other\000Cycles thread running at priority level 6 or 7\000event=0x5880\000\000\000\000\000\000\000"
/* offset=409735 */ "pm_thrd_rebal_cyc\000\000other\000cycles rebalance was active\000event=0x3098\000\000\000\000\000\000\000"
/* offset=409807 */ "pm_thresh_acc\000\000frontend\000This event increments every time the threshold event counter ticks. Thresholding must be enabled (via MMCRA) and the thresholding start event must occur for this counter to increment. It will stop incrementing when the thresholding stop event occurs or when thresholding is disabled, until the next time a configured thresholding start event occurs\000event=0x24154\000\000\000\000\000\000\000"
/* offset=410200 */ "pm_thresh_exc_1024\000\000frontend\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\000\000\000\000\000\000"
/* offset=410292 */ "pm_thresh_exc_1024\000\000pmc\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\000\000\000\000\000\000"
/* offset=410379 */ "pm_thresh_exc_128\000\000cache\000Threshold counter exceeded a value of 128\000event=0x401ea\000\000\000\000\000\000\000"
/* offset=410466 */ "pm_thresh_exc_128\000\000pmc\000Threshold counter exceeded a value of 128\000event=0x401ea\000\000\000\000\000\000\000"
/* offset=410551 */ "pm_thresh_exc_2048\000\000pipeline\000Threshold counter exceeded a value of 2048\000event=0x401ec\000\000\000\000\000\000\000"
/* offset=410643 */ "pm_thresh_exc_2048\000\000pmc\000Threshold counter exceeded a value of 2048\000event=0x401ec\000\000\000\000\000\000\000"
/* offset=410730 */ "pm_thresh_exc_256\000\000frontend\000Threshold counter exceed a count of 256\000event=0x101e8\000\000\000\000\000\000\000"
/* offset=410818 */ "pm_thresh_exc_256\000\000frontend\000Threshold counter exceeded a count of 256\000event=0x101e8\000\000\000\000\000\000\000"
/* offset=410908 */ "pm_thresh_exc_256\000\000pmc\000Threshold counter exceed a count of 256\000event=0x101e8\000\000\000\000\000\000\000"
/* offset=410991 */ "pm_thresh_exc_32\000\000pmc\000Threshold counter exceeded a value of 32\000event=0x201e6\000\000\000\000\000\000\000"
/* offset=411074 */ "pm_thresh_exc_32\000\000translation\000Threshold counter exceeded a value of 32\000event=0x201e6\000\000\000\000\000\000\000"
/* offset=411165 */ "pm_thresh_exc_4096\000\000cache\000Threshold counter exceed a count of 4096\000event=0x101e6\000\000\000\000\000\000\000"
/* offset=411252 */ "pm_thresh_exc_4096\000\000pmc\000Threshold counter exceed a count of 4096\000event=0x101e6\000\000\000\000\000\000\000"
/* offset=411337 */ "pm_thresh_exc_512\000\000other\000Threshold counter exceeded a value of 512\000event=0x201e8\000\000\000\000\000\000\000"
/* offset=411424 */ "pm_thresh_exc_512\000\000others\000Threshold counter exceeded a value of 512\000event=0x201e8\000\000\000\000\000\000\000"
/* offset=411512 */ "pm_thresh_exc_512\000\000pmc\000Threshold counter exceeded a value of 512\000event=0x201e8\000\000\000\000\000\000\000"
/* offset=411597 */ "pm_thresh_exc_64\000\000pmc\000IFU non-branch finished\000event=0x301e8\000\000\000\000\000\000Threshold counter exceeded a value of 64\000"
/* offset=411703 */ "pm_thresh_exc_64\000\000pmc\000Threshold counter exceeded a value of 64\000event=0x301e8\000\000\000\000\000\000\000"
/* offset=411786 */ "pm_thresh_met\000\000frontend\000Threshold exceeded\000event=0x101ec\000\000\000\000\000\000\000"
/* offset=411849 */ "pm_thresh_met\000\000frontend\000threshold exceeded\000event=0x101ec\000\000\000\000\000\000\000"
/* offset=411912 */ "pm_thresh_met\000\000pmc\000threshold exceeded\000event=0x101ec\000\000\000\000\000\000\000"
/* offset=411970 */ "pm_thresh_not_met\000\000floating point\000Threshold counter did not meet threshold\000event=0x4016e\000\000\000\000\000\000\000"
/* offset=412065 */ "pm_thresh_not_met\000\000floating_point\000Threshold counter did not meet threshold\000event=0x4016e\000\000\000\000\000\000\000"
/* offset=412160 */ "pm_thresh_not_met\000\000pmc\000Threshold counter did not meet threshold\000event=0x4016e\000\000\000\000\000\000\000"
/* offset=412244 */ "pm_tlb_hit\000\000frontend\000Number of times the TLB had the data required by the instruction. Applies to both HPT and RPT\000event=0x1f054\000\000\000\000\000\000\000"
/* offset=412379 */ "pm_tlb_miss\000\000pipeline\000TLB Miss (I + D)\000event=0x20066\000\000\000\000\000\000\000"
/* offset=412438 */ "pm_tlb_miss\000\000translation\000TLB Miss (I + D)\000event=0x20066\000\000\000\000\000\000\000"
/* offset=412500 */ "pm_tlbie_fin\000\000pipeline\000TLBIE instructions finished in the LSU. Two TLBIEs can finish each cycle. All will be counted\000event=0x30058\000\000\000\000\000\000\000"
/* offset=412637 */ "pm_tlbie_fin\000\000pipeline\000tlbie finished\000event=0x30058\000\000\000\000\000\000\000"
/* offset=412695 */ "pm_tm_aborts\000\000pipeline\000Number of TM transactions aborted\000event=0x30056\000\000\000\000\000\000\000"
/* offset=412772 */ "pm_tm_begin_all\000\000other\000Tm any tbegin\000event=0x20b8\000\000\000\000\000\000\000"
/* offset=412828 */ "pm_tm_cam_overflow\000\000other\000L3 TM CAM is full when a L2 castout of TM_SC line occurs.  Line is pushed to memory\000event=0x168a6\000\000\000\000\000\000\000"
/* offset=412958 */ "pm_tm_cap_overflow\000\000other\000TM Footprint Capacity Overflow\000event=0x4608e\000\000\000\000\000\000\000"
/* offset=413035 */ "pm_tm_end_all\000\000other\000Tm any tend\000event=0x20ba\000\000\000\000\000\000\000"
/* offset=413087 */ "pm_tm_fail_con_tm\000\000other\000TEXAS fail reason @ completion\000event=0x3088\000\000\000\000\000\000\000"
/* offset=413162 */ "pm_tm_fail_conf_non_tm\000\000other\000TEXAS fail reason @ completion\000event=0x3086\000\000\000\000\000\000\000"
/* offset=413242 */ "pm_tm_fail_conf_non_tm\000\000other\000TM aborted because a conflict occurred with a non-transactional access by another processor\000event=0x28a8\000\000\000\000\000\000\000"
/* offset=413383 */ "pm_tm_fail_conf_tm\000\000other\000TM aborted because a conflict occurred with another transaction\000event=0x20ac\000\000\000\000\000\000\000"
/* offset=413492 */ "pm_tm_fail_disallow\000\000other\000TM fail disallow\000event=0xe0b2\000\000\000\000\000\000TM fail disallow42\000"
/* offset=413573 */ "pm_tm_fail_footprint_overflow\000\000other\000TEXAS fail reason @ completion\000event=0x3084\000\000\000\000\000\000\000"
/* offset=413660 */ "pm_tm_fail_footprint_overflow\000\000other\000TM aborted because the tracking limit for transactional storage accesses was exceeded.. Asynchronous\000event=0x20a8\000\000\000\000\000\000\000"
/* offset=413817 */ "pm_tm_fail_non_tx_conflict\000\000other\000Non transactional conflict from LSU whtver gets repoted to texas\000event=0xe0b8\000\000\000\000\000\000Non transactional conflict from LSU whtver gets repoted to texas42\000"
/* offset=414001 */ "pm_tm_fail_non_tx_conflict\000\000other\000Non transactional conflict from LSU, gets reported to TEXASR\000event=0xe0b0\000\000\000\000\000\000\000"
/* offset=414115 */ "pm_tm_fail_self\000\000other\000TEXAS fail reason @ completion\000event=0x308a\000\000\000\000\000\000\000"
/* offset=414188 */ "pm_tm_fail_self\000\000other\000TM aborted because a self-induced conflict occurred in Suspended state, due to one of the following: a store to a storage location that was previously accessed transactionally; a dcbf, dcbi, or icbi specify- ing a block that was previously accessed transactionally; a dcbst specifying a block that was previously written transactionally; or a tlbie that specifies a translation that was pre- viously used transactionally\000event=0x28ac\000\000\000\000\000\000\000"
/* offset=414651 */ "pm_tm_fail_tlbie\000\000other\000TLBIE hit bloom filter\000event=0xe0b4\000\000\000\000\000\000TLBIE hit bloom filter42\000"
/* offset=414741 */ "pm_tm_fail_tlbie\000\000other\000Transaction failed because there was a TLBIE hit in the bloom filter\000event=0xe0ac\000\000\000\000\000\000\000"
/* offset=414853 */ "pm_tm_fail_tx_conflict\000\000other\000Transactional conflict from LSU, gets reported to TEXASR\000event=0xe8ac\000\000\000\000\000\000\000"
/* offset=414959 */ "pm_tm_fail_tx_conflict\000\000other\000Transactional conflict from LSU, whatever gets reported to texas\000event=0xe0b6\000\000\000\000\000\000Transactional conflict from LSU, whatever gets reported to texas 42\000"
/* offset=415140 */ "pm_tm_fav_caused_fail\000\000other\000TM Load (fav) caused another thread to fail\000event=0x2688e\000\000\000\000\000\000\000"
/* offset=415233 */ "pm_tm_fav_tbegin\000\000other\000Dispatch time Favored tbegin\000event=0x209c\000\000\000\000\000\000\000"
/* offset=415305 */ "pm_tm_ld_caused_fail\000\000other\000Non-TM Load caused any thread to fail\000event=0x1688e\000\000\000\000\000\000\000"
/* offset=415391 */ "pm_tm_ld_conf\000\000other\000TM Load (fav or non-fav) ran into conflict (failed)\000event=0x2608e\000\000\000\000\000\000\000"
/* offset=415484 */ "pm_tm_nested_tbegin\000\000other\000Completion Tm nested tbegin\000event=0x20a0\000\000\000\000\000\000\000"
/* offset=415558 */ "pm_tm_nested_tend\000\000other\000Completion time nested tend\000event=0x2098\000\000\000\000\000\000\000"
/* offset=415630 */ "pm_tm_non_fav_tbegin\000\000other\000Dispatch time non favored tbegin\000event=0x289c\000\000\000\000\000\000\000"
/* offset=415710 */ "pm_tm_outer_tbegin\000\000other\000Completion time outer tbegin\000event=0x2094\000\000\000\000\000\000\000"
/* offset=415784 */ "pm_tm_outer_tbegin_disp\000\000other\000Number of outer tbegin instructions dispatched. The dispatch unit determines whether the tbegin instruction is outer or nested. This is a speculative count, which includes flushed instructions\000event=0x4e05e\000\000\000\000\000\000\000"
/* offset=416028 */ "pm_tm_outer_tend\000\000other\000Completion time outer tend\000event=0x2894\000\000\000\000\000\000\000"
/* offset=416098 */ "pm_tm_passed\000\000other\000Number of TM transactions that passed\000event=0x2e052\000\000\000\000\000\000\000"
/* offset=416176 */ "pm_tm_rst_sc\000\000other\000TM snoop hits line in L3 that is TM_SC state and causes it to be invalidated\000event=0x268a6\000\000\000\000\000\000\000"
/* offset=416293 */ "pm_tm_sc_co\000\000other\000L3 castout of line that was StoreCopy (original value of speculatively written line) in a Transaction\000event=0x160a6\000\000\000\000\000\000\000"
/* offset=416434 */ "pm_tm_st_caused_fail\000\000other\000TM Store (fav or non-fav) caused another thread to fail\000event=0x3688e\000\000\000\000\000\000\000"
/* offset=416538 */ "pm_tm_st_conf\000\000other\000TM Store (fav or non-fav) ran into conflict (failed)\000event=0x3608e\000\000\000\000\000\000\000"
/* offset=416632 */ "pm_tm_tabort_treclaim\000\000other\000Completion time tabortnoncd, tabortcd, treclaim\000event=0x2898\000\000\000\000\000\000\000"
/* offset=416728 */ "pm_tm_tbegin\000\000other\000Tm nested tbegin\000event=0x20bc\000\000\000\000\000\000\000"
/* offset=416784 */ "pm_tm_trans_run_cyc\000\000pipeline\000run cycles in transactional state\000event=0x10060\000\000\000\000\000\000\000"
/* offset=416868 */ "pm_tm_trans_run_cyc\000\000pmc\000run cycles in transactional state\000event=0x10060\000\000\000\000\000\000\000"
/* offset=416947 */ "pm_tm_trans_run_inst\000\000frontend\000Instructions completed in transactional state\000event=0x30060\000\000\000\000\000\000\000"
/* offset=417044 */ "pm_tm_trans_run_inst\000\000frontend\000Run instructions completed in transactional state (gated by the run latch)\000event=0x30060\000\000\000\000\000\000\000"
/* offset=417170 */ "pm_tm_tresume\000\000other\000TM resume instruction completed\000event=0x20a4\000\000\000\000\000\000\000"
/* offset=417242 */ "pm_tm_tresume\000\000other\000Tm resume\000event=0x3080\000\000\000\000\000\000\000"
/* offset=417292 */ "pm_tm_tsuspend\000\000other\000TM suspend instruction completed\000event=0x28a0\000\000\000\000\000\000\000"
/* offset=417366 */ "pm_tm_tsuspend\000\000other\000Tm suspend\000event=0x20be\000\000\000\000\000\000\000"
/* offset=417418 */ "pm_tm_tx_pass_run_cyc\000\000pipeline\000cycles spent in successful transactions\000event=0x2e012\000\000\000\000\000\000\000"
/* offset=417510 */ "pm_tm_tx_pass_run_cyc\000\000pipeline\000cycles spent in successful transactions\000event=0x2e012\000\000\000\000\000\000run cycles spent in successful transactions\000"
/* offset=417645 */ "pm_tm_tx_pass_run_inst\000\000frontend\000run instructions spent in successful transactions\000event=0x4e014\000\000\000\000\000\000\000"
/* offset=417748 */ "pm_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0a4\000\000\000\000\000\000\000"
/* offset=417879 */ "pm_ultravisor_cyc\000\000others\000Cycles when the thread is in Ultravisor state. MSR[S HV PR]=110\000event=0x4d026\000\000\000\000\000\000\000"
/* offset=417989 */ "pm_ultravisor_inst_cmpl\000\000others\000PowerPC instructions that completed while the thread was in ultravisor state\000event=0x1001c\000\000\000\000\000\000\000"
/* offset=418118 */ "pm_up_pref_l3\000\000other\000Micropartition prefetch\000event=0xe08c\000\000\000\000\000\000Micropartition prefetch42\000"
/* offset=418207 */ "pm_up_pref_pointer\000\000other\000Micrpartition pointer prefetches\000event=0xe08e\000\000\000\000\000\000Micrpartition pointer prefetches42\000"
/* offset=418319 */ "pm_vector_flop_cmpl\000\000marked\000Vector FP instruction completed\000event=0x4d058\000\000\000\000\000\000\000"
/* offset=418399 */ "pm_vector_flop_cmpl\000\000marked\000Vector floating point instructions completed\000event=0x4d058\000\000\000\000\000\000\000"
/* offset=418492 */ "pm_vector_ld_cmpl\000\000other\000Number of vector load instructions completed\000event=0x44054\000\000\000\000\000\000\000"
/* offset=418582 */ "pm_vector_ld_cmpl\000\000others\000Vector load instructions completed\000event=0x44054\000\000\000\000\000\000\000"
/* offset=418663 */ "pm_vector_st_cmpl\000\000frontend\000Number of vector store instructions completed\000event=0x44056\000\000\000\000\000\000\000"
/* offset=418757 */ "pm_vector_st_cmpl\000\000frontend\000Vector store instructions completed\000event=0x44056\000\000\000\000\000\000\000"
/* offset=418841 */ "pm_vsu0_16flop\000\000other\000Sixteen flops operation (SP vector versions of fdiv,fsqrt)\000event=0xa0a4\000\000\000\000\000\000\000"
/* offset=418941 */ "pm_vsu0_1flop\000\000other\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finished\000event=0xa080\000\000\000\000\000\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finishedDecode into 1,2,4 FLOP according to instr IOP, multiplied by #vector elements according to route( eg x1, x2, x4) Only if instr sends finish to ISU\000"
/* offset=419310 */ "pm_vsu0_2flop\000\000other\000two flops operation (scalar fmadd, fnmadd, fmsub, fnmsub and DP vector versions of single flop instructions)\000event=0xa098\000\000\000\000\000\000\000"
/* offset=419459 */ "pm_vsu0_4flop\000\000other\000four flops operation (scalar fdiv, fsqrt, DP vector version of fmadd, fnmadd, fmsub, fnmsub, SP vector versions of single flop instructions)\000event=0xa09c\000\000\000\000\000\000\000"
/* offset=419640 */ "pm_vsu0_8flop\000\000other\000eight flops operation (DP vector versions of fdiv,fsqrt and SP vector versions of fmadd,fnmadd,fmsub,fnmsub)\000event=0xa0a0\000\000\000\000\000\000\000"
/* offset=419789 */ "pm_vsu0_complex_issued\000\000other\000Complex VMX instruction issued\000event=0xb0a4\000\000\000\000\000\000\000"
/* offset=419869 */ "pm_vsu0_cy_issued\000\000other\000Cryptographic instruction RFC02196 Issued\000event=0xb0b4\000\000\000\000\000\000\000"
/* offset=419955 */ "pm_vsu0_dd_issued\000\000other\00064BIT Decimal Issued\000event=0xb0a8\000\000\000\000\000\000\000"
/* offset=420020 */ "pm_vsu0_dp_2flop\000\000other\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0xa08c\000\000\000\000\000\000\000"
/* offset=420140 */ "pm_vsu0_dp_fma\000\000other\000DP vector version of fmadd,fnmadd,fmsub,fnmsub\000event=0xa090\000\000\000\000\000\000\000"
/* offset=420228 */ "pm_vsu0_dp_fsqrt_fdiv\000\000other\000DP vector versions of fdiv,fsqrt\000event=0xa094\000\000\000\000\000\000\000"
/* offset=420309 */ "pm_vsu0_dq_issued\000\000other\000128BIT Decimal Issued\000event=0xb0ac\000\000\000\000\000\000\000"
/* offset=420375 */ "pm_vsu0_ex_issued\000\000other\000Direct move 32/64b VRFtoGPR RFC02206 Issued\000event=0xb0b0\000\000\000\000\000\000\000"
/* offset=420463 */ "pm_vsu0_fin\000\000other\000VSU0 Finished an instruction\000event=0xa0bc\000\000\000\000\000\000\000"
/* offset=420530 */ "pm_vsu0_fma\000\000other\000two flops operation (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only!\000event=0xa084\000\000\000\000\000\000\000"
/* offset=420645 */ "pm_vsu0_fpscr\000\000other\000Move to/from FPSCR type instruction issued on Pipe 0\000event=0xb098\000\000\000\000\000\000\000"
/* offset=420738 */ "pm_vsu0_fsqrt_fdiv\000\000other\000four flops operation (fdiv,fsqrt) Scalar Instructions only!\000event=0xa088\000\000\000\000\000\000\000"
/* offset=420843 */ "pm_vsu0_issue\000\000others\000VSU instructions issued to VSU pipe 0\000event=0x10016\000\000\000\000\000\000\000"
/* offset=420923 */ "pm_vsu0_permute_issued\000\000other\000Permute VMX Instruction Issued\000event=0xb090\000\000\000\000\000\000\000"
/* offset=421003 */ "pm_vsu0_scalar_dp_issued\000\000other\000Double Precision scalar instruction issued on Pipe0\000event=0xb088\000\000\000\000\000\000\000"
/* offset=421106 */ "pm_vsu0_simple_issued\000\000other\000Simple VMX instruction issued\000event=0xb094\000\000\000\000\000\000\000"
/* offset=421184 */ "pm_vsu0_single\000\000other\000FPU single precision\000event=0xa0a8\000\000\000\000\000\000\000"
/* offset=421246 */ "pm_vsu0_sq\000\000other\000Store Vector Issued\000event=0xb09c\000\000\000\000\000\000\000"
/* offset=421303 */ "pm_vsu0_stf\000\000other\000FPU store (SP or DP) issued on Pipe0\000event=0xb08c\000\000\000\000\000\000\000"
/* offset=421378 */ "pm_vsu0_vector_dp_issued\000\000other\000Double Precision vector instruction issued on Pipe0\000event=0xb080\000\000\000\000\000\000\000"
/* offset=421481 */ "pm_vsu0_vector_sp_issued\000\000other\000Single Precision vector instruction issued (executed)\000event=0xb084\000\000\000\000\000\000\000"
/* offset=421586 */ "pm_vsu1_16flop\000\000other\000Sixteen flops operation (SP vector versions of fdiv,fsqrt)\000event=0xa0a6\000\000\000\000\000\000\000"
/* offset=421686 */ "pm_vsu1_1flop\000\000other\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finished\000event=0xa082\000\000\000\000\000\000\000"
/* offset=421818 */ "pm_vsu1_2flop\000\000other\000two flops operation (scalar fmadd, fnmadd, fmsub, fnmsub and DP vector versions of single flop instructions)\000event=0xa09a\000\000\000\000\000\000\000"
/* offset=421967 */ "pm_vsu1_4flop\000\000other\000four flops operation (scalar fdiv, fsqrt, DP vector version of fmadd, fnmadd, fmsub, fnmsub, SP vector versions of single flop instructions)\000event=0xa09e\000\000\000\000\000\000\000"
/* offset=422148 */ "pm_vsu1_8flop\000\000other\000eight flops operation (DP vector versions of fdiv,fsqrt and SP vector versions of fmadd,fnmadd,fmsub,fnmsub)\000event=0xa0a2\000\000\000\000\000\000\000"
/* offset=422297 */ "pm_vsu1_complex_issued\000\000other\000Complex VMX instruction issued\000event=0xb0a6\000\000\000\000\000\000\000"
/* offset=422377 */ "pm_vsu1_cy_issued\000\000other\000Cryptographic instruction RFC02196 Issued\000event=0xb0b6\000\000\000\000\000\000\000"
/* offset=422463 */ "pm_vsu1_dd_issued\000\000other\00064BIT Decimal Issued\000event=0xb0aa\000\000\000\000\000\000\000"
/* offset=422528 */ "pm_vsu1_dp_2flop\000\000other\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0xa08e\000\000\000\000\000\000\000"
/* offset=422648 */ "pm_vsu1_dp_fma\000\000other\000DP vector version of fmadd,fnmadd,fmsub,fnmsub\000event=0xa092\000\000\000\000\000\000\000"
/* offset=422736 */ "pm_vsu1_dp_fsqrt_fdiv\000\000other\000DP vector versions of fdiv,fsqrt\000event=0xa096\000\000\000\000\000\000\000"
/* offset=422817 */ "pm_vsu1_dq_issued\000\000other\000128BIT Decimal Issued\000event=0xb0ae\000\000\000\000\000\000\000"
/* offset=422883 */ "pm_vsu1_ex_issued\000\000other\000Direct move 32/64b VRFtoGPR RFC02206 Issued\000event=0xb0b2\000\000\000\000\000\000\000"
/* offset=422971 */ "pm_vsu1_fin\000\000other\000VSU1 Finished an instruction\000event=0xa0be\000\000\000\000\000\000\000"
/* offset=423038 */ "pm_vsu1_fma\000\000other\000two flops operation (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only!\000event=0xa086\000\000\000\000\000\000\000"
/* offset=423153 */ "pm_vsu1_fpscr\000\000other\000Move to/from FPSCR type instruction issued on Pipe 0\000event=0xb09a\000\000\000\000\000\000\000"
/* offset=423246 */ "pm_vsu1_fsqrt_fdiv\000\000other\000four flops operation (fdiv,fsqrt) Scalar Instructions only!\000event=0xa08a\000\000\000\000\000\000\000"
/* offset=423351 */ "pm_vsu1_issue\000\000pipeline\000VSU instructions issued to VSU pipe 1\000event=0x2d012\000\000\000\000\000\000\000"
/* offset=423433 */ "pm_vsu1_permute_issued\000\000other\000Permute VMX Instruction Issued\000event=0xb092\000\000\000\000\000\000\000"
/* offset=423513 */ "pm_vsu1_scalar_dp_issued\000\000other\000Double Precision scalar instruction issued on Pipe1\000event=0xb08a\000\000\000\000\000\000\000"
/* offset=423616 */ "pm_vsu1_simple_issued\000\000other\000Simple VMX instruction issued\000event=0xb096\000\000\000\000\000\000\000"
/* offset=423694 */ "pm_vsu1_single\000\000other\000FPU single precision\000event=0xa0aa\000\000\000\000\000\000\000"
/* offset=423756 */ "pm_vsu1_sq\000\000other\000Store Vector Issued\000event=0xb09e\000\000\000\000\000\000\000"
/* offset=423813 */ "pm_vsu1_stf\000\000other\000FPU store (SP or DP) issued on Pipe1\000event=0xb08e\000\000\000\000\000\000\000"
/* offset=423888 */ "pm_vsu1_vector_dp_issued\000\000other\000Double Precision vector instruction issued on Pipe1\000event=0xb082\000\000\000\000\000\000\000"
/* offset=423991 */ "pm_vsu1_vector_sp_issued\000\000other\000Single Precision vector instruction issued (executed)\000event=0xb086\000\000\000\000\000\000\000"
/* offset=424096 */ "pm_vsu2_issue\000\000pipeline\000VSU instructions issued to VSU pipe 2\000event=0x3f044\000\000\000\000\000\000\000"
/* offset=424178 */ "pm_vsu3_issue\000\000pipeline\000VSU instruction was issued to VSU pipe 3\000event=0x4d020\000\000\000\000\000\000\000"
/* offset=424263 */ "pm_vsu_dp_fsqrt_fdiv\000\000pipeline\000vector versions of fdiv,fsqrt\000event=0x3d058\000\000\000\000\000\000\000"
/* offset=424344 */ "pm_vsu_fin\000\000other\000VSU instruction finished. Up to 4 per cycle\000event=0x2505c\000\000\000\000\000\000\000"
/* offset=424426 */ "pm_vsu_fin\000\000others\000VSU instructions finished\000event=0x4001c\000\000\000\000\000\000\000"
/* offset=424491 */ "pm_vsu_fsqrt_fdiv\000\000pipeline\000four flops operation (fdiv,fsqrt) Scalar Instructions only\000event=0x4d04e\000\000\000\000\000\000\000"
/* offset=424598 */ "pm_vsu_issue\000\000others\000At least one VSU instruction was issued to one of the VSU pipes. Up to 4 per cycle. Includes fixed point operations\000event=0x2505c\000\000\000\000\000\000\000"
/* offset=424755 */ "pm_vsu_non_flop_cmpl\000\000pipeline\000Non FLOP operation completed\000event=0x4d050\000\000\000\000\000\000\000"
/* offset=424835 */ "pm_vsu_non_flop_cmpl\000\000pipeline\000Non-floating point VSU instructions completed\000event=0x4d050\000\000\000\000\000\000\000"
/* offset=424932 */ "pm_xfer_from_src_pmc1\000\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[0:12]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x1c040\000\000\000\000\000\000\000"
/* offset=425257 */ "pm_xfer_from_src_pmc2\000\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[15:27]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x2c040\000\000\000\000\000\000\000"
/* offset=425583 */ "pm_xfer_from_src_pmc3\000\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[30:42]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x3c040\000\000\000\000\000\000\000"
/* offset=425909 */ "pm_xfer_from_src_pmc4\000\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[45:57]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x4c040\000\000\000\000\000\000\000"
/* offset=426235 */ "pm_xlate_hpt_mode\000\000other\000LSU reports every cycle the thread is in HPT translation mode (as opposed to radix mode)\000event=0xf098\000\000\000\000\000\000\000"
/* offset=426368 */ "pm_xlate_miss\000\000other\000The LSU requested a line from L2 for translation.  It may be satisfied from any source beyond L2.  Includes speculative instructions. Includes instruction, prefetch and demand\000event=0xf89c\000\000\000\000\000\000\000"
/* offset=426584 */ "pm_xlate_radix_mode\000\000other\000LSU reports every cycle the thread is in radix translation mode (as opposed to HPT mode)\000event=0xf898\000\000\000\000\000\000\000"
/* offset=426719 */ "powerbus_freq\000\000\000nest_powerbus0_imc@PM_PB_CYC@\000\000\0001e-9GHz\000\000\000"
/* offset=426777 */ "pteg_from_dl2l3_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant L2 or L3 (Modified)\000\000\000\000\000"
/* offset=426936 */ "pteg_from_dl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant L2 or L3 (Modified) per inst\000\000\000\000\000"
/* offset=427114 */ "pteg_from_dl2l3_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant L2 or L3 (Shared)\000\000\000\000\000"
/* offset=427271 */ "pteg_from_dl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant L2 or L3 (Shared) per inst\000\000\000\000\000"
/* offset=427447 */ "pteg_from_dl4_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DL4 * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant L4\000\000\000\000\000"
/* offset=427577 */ "pteg_from_dl4_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant L4 per inst\000\000\000\000\000"
/* offset=427726 */ "pteg_from_dmem_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DMEM * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant Memory\000\000\000\000\000"
/* offset=427862 */ "pteg_from_dmem_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant Memory per inst\000\000\000\000\000"
/* offset=428017 */ "pteg_from_l21_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L21_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L2, other core\000\000\000\000\000"
/* offset=428167 */ "pteg_from_l21_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000"
/* offset=428336 */ "pteg_from_l21_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L21_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L2, other core\000\000\000\000\000"
/* offset=428486 */ "pteg_from_l21_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000"
/* offset=428655 */ "pteg_from_l2_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L2 * 100 / PM_DTLB_MISS\000% of DERAT reloads from L2\000\000\000\000\000"
/* offset=428775 */ "pteg_from_l2_rate_percent\000pteg_reloads_percent_per_inst\000\000dpteg_from_l2_rate_percent\000% of DERAT reloads from L2 per inst\000\000\000\000\000"
/* offset=428899 */ "pteg_from_l31_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L31_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L3, other core\000\000\000\000\000"
/* offset=429049 */ "pteg_from_l31_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000"
/* offset=429218 */ "pteg_from_l31_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L31_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L3, other core\000\000\000\000\000"
/* offset=429368 */ "pteg_from_l31_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000"
/* offset=429537 */ "pteg_from_l3_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L3 * 100 / PM_DTLB_MISS\000% of DERAT reloads from L3\000\000\000\000\000"
/* offset=429657 */ "pteg_from_l3_rate_percent\000pteg_reloads_percent_per_inst\000\000dpteg_from_l3_rate_percent\000% of DERAT reloads from L3 per inst\000\000\000\000\000"
/* offset=429781 */ "pteg_from_ll4_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_LL4 * 100 / PM_DTLB_MISS\000% of DERAT reloads from Local L4\000\000\000\000\000"
/* offset=429909 */ "pteg_from_ll4_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Local L4 per inst\000\000\000\000\000"
/* offset=430056 */ "pteg_from_lmem_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_LMEM * 100 / PM_DTLB_MISS\000% of DERAT reloads from Local Memory\000\000\000\000\000"
/* offset=430190 */ "pteg_from_lmem_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Local Memory per inst\000\000\000\000\000"
/* offset=430343 */ "pteg_from_rl2l3_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote L2 or L3 (Modified)\000\000\000\000\000"
/* offset=430501 */ "pteg_from_rl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote L2 or L3 (Modified) per inst\000\000\000\000\000"
/* offset=430678 */ "pteg_from_rl2l3_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote L2 or L3 (Shared)\000\000\000\000\000"
/* offset=430834 */ "pteg_from_rl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote L2 or L3 (Shared) per inst\000\000\000\000\000"
/* offset=431009 */ "pteg_from_rl4_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RL4 * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote L4\000\000\000\000\000"
/* offset=431138 */ "pteg_from_rl4_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote L4 per inst\000\000\000\000\000"
/* offset=431286 */ "pteg_from_rmem_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RMEM * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote Memory\000\000\000\000\000"
/* offset=431421 */ "pteg_from_rmem_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote Memory per inst\000\000\000\000\000"
/* offset=431575 */ "remote_centaur_ld_hit_ratio\000\000\000(PM_DATA_FROM_RMEM + PM_DATA_FROM_RL4) / PM_LD_REF_L1\000Fraction of hits on a remote chip's Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000"
/* offset=431736 */ "resource_na_reject_rate_percent\000\000\000PM_ISU_REJECT_RES_NA * 100 / PM_RUN_INST_CMPL\000Percent of all FXU/VSU instructions that got rejected because of unavailable resources or facilities\000\000\000\000\000"
/* offset=431921 */ "rl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL2L3_MOD * PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2l3 remote MOD miss rates with measured RL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=432191 */ "rl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL2L3_MOD / PM_RUN_INST_CMPL * rl2l3_mod_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2l3 remote MOD miss rates with measured RL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=432437 */ "rl2l3_mod_latency\000latency\000\000PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD\000Marked L2L3 remote Load latency\000\000\000\000\000"
/* offset=432560 */ "rl2l3_mod_ld_hit_ratio\000\000\000PM_DATA_FROM_RL2L3_MOD / PM_LD_REF_L1\000Fraction of hits of a line in the M (exclusive) state on the L2 or L3 of a core on a remote chip per L1 load ref\000\000\000\000\000"
/* offset=432740 */ "rl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL2L3_SHR * PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2l3 shared miss rates with measured RL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=433006 */ "rl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL2L3_SHR / PM_RUN_INST_CMPL * rl2l3_shr_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2l3 shared miss rates with measured RL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=433248 */ "rl2l3_shr_latency\000latency\000\000PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR\000Marked L2L3 remote Load latency\000\000\000\000\000"
/* offset=433371 */ "rl2l3_shr_ld_hit_ratio\000\000\000PM_DATA_FROM_RL2L3_SHR / PM_LD_REF_L1\000Fraction of hits of a line in the S state on the L2 or L3 of a core on a remote chip per L1 load ref\000\000\000\000\000"
/* offset=433539 */ "rl4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL4 * PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4 / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of remote L4 miss rates with measured RL4 latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=433772 */ "rl4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL4 / PM_RUN_INST_CMPL * rl4_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of remote L4 miss rates with measured RL4 latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=433987 */ "rl4_latency\000latency\000\000PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4\000Remote L4 average load latency\000\000\000\000\000"
/* offset=434091 */ "rl4_ld_hit_ratio\000\000\000PM_DATA_FROM_RL4 / PM_LD_REF_L1\000Fraction of hits on a remote Centaur's cache per L1 load ref\000\000\000\000\000"
/* offset=434207 */ "rmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RMEM * PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of remote memory miss rates with measured RMEM latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=434449 */ "rmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RMEM / PM_RUN_INST_CMPL * rmem_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of remote memory miss rates with measured RMEM latency as a %of dcache miss cpi\000\000\000\000\000"
/* offset=434672 */ "rmem_latency\000latency\000\000PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM\000Marked Rmem Load latency\000\000\000\000\000"
/* offset=434773 */ "rmem_ld_hit_ratio\000\000\000PM_DATA_FROM_RMEM / PM_LD_REF_L1\000Fraction of hits on a remote Centaur's DRAM per L1 load ref\000\000\000\000\000"
/* offset=434890 */ "run_cpi\000cpi_breakdown\000\000PM_RUN_CYC / PM_RUN_INST_CMPL\000Run cycles per run instruction\000\000\000\000\000"
/* offset=434978 */ "run_cpi\000cpi_breakdown\000\000run_cyc_cpi\000Run cycles per run instruction\000\000\000\000\000"
/* offset=435048 */ "run_cyc_cpi\000cpi_breakdown\000\000PM_RUN_CYC / PM_RUN_INST_CMPL\000Run_cycles\000\000\000\000\000"
/* offset=435120 */ "run_cycles_percent\000general\000\000PM_RUN_CYC / PM_CYC * 100\000Run cycles per cycle\000\000\000\000\000"
/* offset=435199 */ "sar_bypass_reject_rate_percent\000\000\000PM_ISU_REJECT_SAR_BYPASS * 100 / PM_RUN_INST_CMPL\000Percent of all FXU/VSU instructions that got rejected due to SAR Bypass\000\000\000\000\000"
/* offset=435358 */ "scalar_stall_cpi\000cpi_breakdown\000\000fxu_stall_cpi + dp_stall_cpi + dfu_stall_cpi + pm_stall_cpi + crypto_stall_cpi\000\000\000\000\000\000"
/* offset=435474 */ "segment_reg_loads.any\000\000other\000Number of segment register loads\000event=0x6,period=200000,umask=0x80\000\000\000\000\000\000\000"
/* offset=435577 */ "slb_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SLB / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was awaiting L2 response for an SLB\000\000\000\000\000"
/* offset=435725 */ "smt2_cycles_percent\000general\000\000PM_RUN_CYC_SMT2_MODE / PM_RUN_CYC * 100\000Percentage of cycles spent in SMT2 Mode\000\000\000\000\000"
/* offset=435838 */ "smt4_cycles_percent\000general\000\000PM_RUN_CYC_SMT4_MODE / PM_RUN_CYC * 100\000Percentage of cycles spent in SMT4 Mode\000\000\000\000\000"
/* offset=435951 */ "smt8_cycles_percent\000general\000\000PM_RUN_CYC_SMT8_MODE / PM_RUN_CYC * 100\000Percentage of cycles spent in SMT8 Mode\000\000\000\000\000"
/* offset=436064 */ "smt_benefit\000general\000\000PM_CMPLU_STALL_OTHER_CMPL / PM_RUN_CYC\000IPC of all instructions completed by the core while this thread was stalled\000\000\000\000\000"
/* offset=436204 */ "source_na_reject_rate_percent\000\000\000PM_ISU_REJECT_SRC_NA * 100 / PM_RUN_INST_CMPL\000Percent of all FXU/VSU instructions that got rejected because of unavailable sources\000\000\000\000\000"
/* offset=436371 */ "spec_finish_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SPEC_FINISH / PM_RUN_INST_CMPL\000Finish stall while waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000\000\000\000\000"
/* offset=436615 */ "speculation\000general\000\000PM_INST_DISP / PM_INST_CMPL\000Instruction dispatch-to-completion ratio\000\000\000\000\000"
/* offset=436709 */ "srq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SRQ_FULL / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a store that was held in LSAQ because the SRQ was full\000\000\000\000\000"
/* offset=436890 */ "srq_stall_cpi\000cpi_breakdown\000\000store_data_stall_cpi + eieio_stall_cpi + stcx_stall_cpi + slb_stall_cpi + tend_stall_cpi + paste_stall_cpi + tlbie_stall_cpi + store_pipe_arb_stall_cpi + store_fin_arb_stall_cpi\000\000\000\000\000\000"
/* offset=437102 */ "st_cycles_percent\000general\000\000PM_RUN_CYC_ST_MODE / PM_RUN_CYC * 100\000Percentage of cycles spent in Single Thread Mode\000\000\000\000\000"
/* offset=437220 */ "st_fwd_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000Completion stall due to store forward\000\000\000\000\000"
/* offset=437335 */ "stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL / PM_RUN_INST_CMPL\000Completion Stall Cycles\000\000\000\000\000"
/* offset=437422 */ "stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL / PM_RUN_INST_CMPL\000Nothing completed and Instruction Completion Table not empty\000\000\000\000\000"
/* offset=437546 */ "stcx_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STCX / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a stcx waiting for response from L2\000\000\000\000\000"
/* offset=437700 */ "store_data_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE_DATA / PM_RUN_INST_CMPL\000Finish stall because the next to finish instruction was a store waiting on data\000\000\000\000\000"
/* offset=437865 */ "store_fin_arb_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE_FIN_ARB / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a store waiting for a slot in the store finish pipe. This means the instruction is ready to finish but there are instructions ahead of it, using the finish pipe\000\000\000\000\000"
/* offset=438162 */ "store_finish_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE_FINISH / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a store with all its dependencies met, just waiting to go through the LSU pipe to finish\000\000\000\000\000"
/* offset=438385 */ "store_forward_rate_percent\000\000\000100 * (PM_LSU0_SRQ_STFWD + PM_LSU1_SRQ_STFWD) / PM_RUN_INST_CMPL\000Store forward rate\000\000\000\000\000"
/* offset=438502 */ "store_forward_ratio_percent\000\000\000100 * (PM_LSU0_SRQ_STFWD + PM_LSU1_SRQ_STFWD) / (PM_LD_REF_L1 - PM_LD_MISS_L1)\000Store forward rate\000\000\000\000\000"
/* offset=438634 */ "store_latency\000\000\000(PM_MRK_ST_L2DISP_TO_CMPL_CYC + PM_MRK_ST_DRAIN_TO_L2DISP_CYC) / PM_MRK_ST_NEST\000Marked store latency, from core completion to L2 RC machine completion\000\000\000\000\000"
/* offset=438805 */ "store_pipe_arb_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE_PIPE_ARB / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a store waiting for the next relaunch opportunity after an internal reject. This means the instruction is ready to relaunch and tried once but lost arbitration\000\000\000\000\000"
/* offset=439103 */ "stores_per_inst\000\000\000PM_ST_FIN / PM_RUN_INST_CMPL\000PCT instruction stores\000\000\000\000\000"
/* offset=439177 */ "stores_per_inst\000instruction_mix\000\000PM_ST_FIN / PM_RUN_INST_CMPL\000PCT instruction stores\000\000\000\000\000"
/* offset=439266 */ "sync_pmu_int_stall_cpi\000\000\000PM_CMPLU_STALL_SYNC_PMU_INT / PM_RUN_INST_CMPL\000ANY_SYNC_STALL_CPI\000\000\000\000\000"
/* offset=439361 */ "sync_stall_cpi\000\000\000(PM_CMPLU_STALL_LWSYNC + PM_CMPLU_STALL_HWSYNC) / PM_RUN_INST_CMPL\000Cycles stalled by any sync\000\000\000\000\000"
/* offset=439476 */ "sys_ccn_pmu.read_cycles\000uncore_sys_ccn_pmu\000uncore\000ccn read-cycles event. Unit: uncore_sys_ccn_pmu \000config=0x2c\000\0000x01\000\000\000\000\000"
/* offset=439597 */ "sys_ddr_pmu.write_cycles\000uncore_sys_ddr_pmu\000uncore\000ddr write-cycles event. Unit: uncore_sys_ddr_pmu \000event=0x2b\000\000v8\000\000\000\000\000"
/* offset=439717 */ "sys_pump_cpred_percent\000bus_stats\000\000PM_SYS_PUMP_CPRED * 100 / PM_L2_GROUP_PUMP\000Percent of system pumps that were correctly predicted as group pumps the first time\000\000\000\000\000"
/* offset=439882 */ "ta_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_TA / PM_RUN_INST_CMPL * 100\000TA MisPredictions per Instruction\000\000\000\000\000"
/* offset=440006 */ "ta_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_TA / (PM_BR_PRED_CCACHE_BR0 + PM_BR_PRED_CCACHE_BR1 + PM_BR_PRED_LSTACK_BR0 + PM_BR_PRED_LSTACK_BR1) * 100\000Percent of target address mispredictions out of all completed branches that required address prediction\000\000\000\000\000"
/* offset=440277 */ "taken_branches_percent\000branch_prediction\000\000PM_BR_TAKEN_CMPL * 100 / PM_BRU_FIN\000% Branches Taken\000\000\000\000\000"
/* offset=440376 */ "taken_branches_percent\000branch_prediction\000\000PM_BR_TAKEN_CMPL * 100 / PM_BR_CMPL\000Percent of branches completed that were taken\000\000\000\000\000"
/* offset=440504 */ "tend_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_TEND / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a tend instruction awaiting response from L2\000\000\000\000\000"
/* offset=440667 */ "thread_block_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL\000Completion Stalled because the thread was blocked\000\000\000\000\000"
/* offset=440798 */ "thread_block_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL\000Cycles a thread was blocked\000\000\000\000\000"
/* offset=440907 */ "tlbie_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_TLBIE / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a tlbie waiting for response from L2\000\000\000\000\000"
/* offset=441064 */ "unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\000\000\000\000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000"
/* offset=441328 */ "uncore_hisi_ddrc.flux_wcmd\000hisi_sccl,ddrc\000uncore\000DDRC write commands. Unit: hisi_sccl,ddrc \000event=0x2\000\000\000\000\000\000DDRC write commands\000"
/* offset=441455 */ "uncore_hisi_l3c.rd_hit_cpipe\000hisi_sccl,l3c\000uncore\000Total read hits. Unit: hisi_sccl,l3c \000event=0x7\000\000\000\000\000\000Total read hits\000"
/* offset=441574 */ "uncore_imc.cache_hits\000uncore_imc\000uncore\000Total cache hits. Unit: uncore_imc \000event=0x34\000\000\000\000\000\000Total cache hits\000"
/* offset=441683 */ "uncore_imc_free_running.cache_miss\000uncore_imc_free_running\000uncore\000Total cache misses. Unit: uncore_imc_free_running \000event=0x12\000\000\000\000\000\000Total cache misses\000"
/* offset=441835 */ "vdp_other_stall_cpi\000cpi_breakdown\000\000vdp_stall_cpi - vdplong_stall_cpi\000Vector stalls due to small latency double precision ops\000\000\000\000\000"
/* offset=441964 */ "vdp_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VDP / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a vector instruction issued to the Double Precision execution pipe and waiting to finish\000\000\000\000\000"
/* offset=442169 */ "vdplong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VDPLONG / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000"
/* offset=442485 */ "vector_stall_cpi\000cpi_breakdown\000\000vfxu_stall_cpi + vdp_stall_cpi\000\000\000\000\000\000"
/* offset=442553 */ "vfxlong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VFXLONG / PM_RUN_INST_CMPL\000Completion stall due to a long latency vector fixed point instruction (division, square root)\000\000\000\000\000"
/* offset=442726 */ "vfxu_other_stall_cpi\000cpi_breakdown\000\000vfxu_stall_cpi - vfxlong_stall_cpi\000Vector stalls due to small latency integer ops\000\000\000\000\000"
/* offset=442848 */ "vfxu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VFXU / PM_RUN_INST_CMPL\000Finish stall due to a vector fixed point instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000\000\000\000\000"
/* offset=443063 */ "vsu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VSU / PM_RUN_INST_CMPL\000Cycles stalled by VSU\000\000\000\000\000"
/* offset=443156 */ "vsu_stall_other_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_VSU - PM_CMPLU_STALL_VECTOR - PM_CMPLU_STALL_SCALAR) / PM_RUN_INST_CMPL\000Cycles stalled by other VSU Operations\000\000\000\000\000"
/* offset=443322 */ "vsu_stall_scalar_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SCALAR / PM_RUN_INST_CMPL\000Cycles stalled by VSU Scalar Operations\000\000\000\000\000"
/* offset=443443 */ "vsu_stall_scalar_long_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SCALAR_LONG / PM_RUN_INST_CMPL\000Cycles stalled by VSU Scalar Long Operations\000\000\000\000\000"
/* offset=443579 */ "vsu_stall_scalar_other_cpi\000cpi_breakdown\000\000vsu_stall_scalar_cpi - vsu_stall_scalar_long_cpi\000Cycles stalled by Other VSU Scalar Operations\000\000\000\000\000"
/* offset=443720 */ "vsu_stall_vector_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VECTOR / PM_RUN_INST_CMPL\000Cycles stalled by VSU Vector Operations\000\000\000\000\000"
/* offset=443841 */ "vsu_stall_vector_long_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VECTOR_LONG / PM_RUN_INST_CMPL\000Cycles stalled by VSU Vector Long Operations\000\000\000\000\000"
/* offset=443977 */ "vsu_stall_vector_other_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_VECTOR - PM_CMPLU_STALL_VECTOR_LONG) / PM_RUN_INST_CMPL\000Cycles stalled by other VSU Vector Operations\000\000\000\000\000"
/* offset=444141 */ "wasted_l3_prefetch_percent\000\000\000PM_L3_CO_MEPF / 2 / PM_L3_PREF_ALL * 100\000Percentage of lines that were prefetched into the L3 and evicted before they were consumed\000\000\000\000\000"
;

static const struct compact_pmu_event pmu_events__power8[] = {
{ 151772 }, /* pm_data_from_dl2l3_mod\000\000cache\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x4c048\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 152431 }, /* pm_data_from_dl2l3_shr\000\000cache\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x3c048\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 153084 }, /* pm_data_from_dl4\000\000cache\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a demand load\000event=0x3c04c\000\000\000\000\000\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 155192 }, /* pm_data_from_l2\000\000cache\000The processor's data cache was reloaded from local core's L2 due to a demand load\000event=0x1c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 155585 }, /* pm_data_from_l2_disp_conflict_ldhitst\000\000cache\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a demand load\000event=0x3c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 156108 }, /* pm_data_from_l2_disp_conflict_other\000\000cache\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a demand load\000event=0x4c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 156610 }, /* pm_data_from_l2_mepf\000\000cache\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to a demand load\000event=0x2c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 157148 }, /* pm_data_from_l2_no_conflict\000\000cache\000The processor's data cache was reloaded from local core's L2 without conflict due to a demand load\000event=0x1c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 157616 }, /* pm_data_from_l2miss\000\000cache\000Demand LD - L2 Miss (not L2 hit)\000event=0x200fe\000\000\000\000\000\000\000 */
{ 157947 }, /* pm_data_from_l2miss_mod\000\000cache\000The processor's data cache was reloaded from a location other than the local core's L2 due to a demand load\000event=0x1c04e\000\000\000\000\000\000The processor's data cache was reloaded from a location other than the local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 160585 }, /* pm_data_from_l3\000\000cache\000The processor's data cache was reloaded from local core's L3 due to a demand load\000event=0x4c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 160978 }, /* pm_data_from_l3_disp_conflict\000\000cache\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a demand load\000event=0x3c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 161467 }, /* pm_data_from_l3_mepf\000\000cache\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to a demand load\000event=0x2c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 162007 }, /* pm_data_from_l3_no_conflict\000\000cache\000The processor's data cache was reloaded from local core's L3 without conflict due to a demand load\000event=0x1c044\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 162477 }, /* pm_data_from_l3miss\000\000cache\000Demand LD - L3 Miss (not L2 hit and not L3 hit)\000event=0x300fe\000\000\000\000\000\000\000 */
{ 162833 }, /* pm_data_from_l3miss_mod\000\000cache\000The processor's data cache was reloaded from a location other than the local core's L3 due to a demand load\000event=0x4c04e\000\000\000\000\000\000The processor's data cache was reloaded from a location other than the local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 163320 }, /* pm_data_from_ll4\000\000cache\000The processor's data cache was reloaded from the local chip's L4 cache due to a demand load\000event=0x1c04c\000\000\000\000\000\000The processor's data cache was reloaded from the local chip's L4 cache due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 165061 }, /* pm_data_from_off_chip_cache\000\000cache\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a demand load\000event=0x4c04a\000\000\000\000\000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 165706 }, /* pm_data_from_on_chip_cache\000\000cache\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a demand load\000event=0x1c048\000\000\000\000\000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 166280 }, /* pm_data_from_rl2l3_mod\000\000cache\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x2c046\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 166929 }, /* pm_data_from_rl2l3_shr\000\000cache\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x1c04a\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 172125 }, /* pm_data_tablewalk_cyc\000\000cache\000Tablwalk Cycles (could be 1 or 2 active)\000event=0x3001a\000\000\000\000\000\000Data Tablewalk Active\000 */
{ 193104 }, /* pm_dpteg_from_l3miss\000\000cache\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a data side request\000event=0x4e04e\000\000\000\000\000\000\000 */
{ 198451 }, /* pm_dslb_miss\000\000cache\000Data SLB Miss - Total of all segment sizes\000event=0xd094\000\000\000\000\000\000Data SLB Miss - Total of all segment sizesData SLB misses\000 */
{ 277694 }, /* pm_l1_dcache_reload_valid\000\000cache\000DL1 reloaded due to Demand Load\000event=0x300f6\000\000\000\000\000\000\000 */
{ 277865 }, /* pm_l1_dcache_reloaded_all\000\000cache\000L1 data cache reloaded for demand or prefetch\000event=0x1002c\000\000\000\000\000\000\000 */
{ 295331 }, /* pm_ld_miss_l1\000\000cache\000Load Missed L1\000event=0x3e054\000\000\000\000\000\000\000 */
{ 296144 }, /* pm_ld_ref_l1\000\000cache\000All L1 D cache load references counted at finish, gated by reject\000event=0x100ee\000\000\000\000\000\000Load Ref count combined for all units\000 */
{ 401483 }, /* pm_st_miss_l1\000\000cache\000Store Missed L1\000event=0x300f0\000\000\000\000\000\000\000 */
{ 212738 }, /* pm_fxu_busy\000\000floating point\000fxu0 busy and fxu1 busy\000event=0x2000e\000\000\000\000\000\000\000 */
{ 213064 }, /* pm_fxu_idle\000\000floating point\000fxu0 idle and fxu1 idle\000event=0x1000e\000\000\000\000\000\000\000 */
{ 109598 }, /* pm_back_br_cmpl\000\000frontend\000Branch instruction completed with a target address less than current instruction address\000event=0x2505e\000\000\000\000\000\000\000 */
{ 110350 }, /* pm_br_2path\000\000frontend\000two path branch\000event=0x20036\000\000\000\000\000\000\000 */
{ 110735 }, /* pm_br_cmpl\000\000frontend\000Branch Instruction completed\000event=0x40060\000\000\000\000\000\000\000 */
{ 111567 }, /* pm_br_mpred_cmpl\000\000frontend\000Number of Branch Mispredicts\000event=0x400f6\000\000\000\000\000\000\000 */
{ 116700 }, /* pm_br_taken_cmpl\000\000frontend\000New event for Branch Taken\000event=0x200fa\000\000\000\000\000\000\000 */
{ 117743 }, /* pm_bru_fin\000\000frontend\000Branch Instruction Finished\000event=0x10068\000\000\000\000\000\000\000 */
{ 219267 }, /* pm_ic_demand_cyc\000\000frontend\000Cycles when a demand ifetch was pending\000event=0x10018\000\000\000\000\000\000Demand ifetch pending\000 */
{ 223631 }, /* pm_ierat_reload\000\000frontend\000Number of I-ERAT reloads\000event=0x100f6\000\000\000\000\000\000IERAT Reloaded (Miss)\000 */
{ 223794 }, /* pm_ierat_reload_16m\000\000frontend\000IERAT Reloaded (Miss) for a 16M page\000event=0x4006a\000\000\000\000\000\000\000 */
{ 223968 }, /* pm_ierat_reload_4k\000\000frontend\000IERAT Miss (Not implemented as DI on POWER6)\000event=0x20064\000\000\000\000\000\000IERAT Reloaded (Miss) for a 4k page\000 */
{ 224186 }, /* pm_ierat_reload_64k\000\000frontend\000IERAT Reloaded (Miss) for a 64k page\000event=0x3006a\000\000\000\000\000\000\000 */
{ 239366 }, /* pm_inst_chip_pump_cpred\000\000frontend\000Initial and Final Pump Scope was chip pump (prediction=correct) for an instruction fetch\000event=0x14050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for an instruction fetch\000 */
{ 239775 }, /* pm_inst_cmpl\000\000frontend\000Number of PowerPC Instructions that completed\000event=0x2\000\000\000\000\000\000PPC Instructions Finished (completed)\000 */
{ 240056 }, /* pm_inst_disp\000\000frontend\000PPC Dispatched\000event=0x200f2\000\000\000\000\000\000\000 */
{ 240306 }, /* pm_inst_from_dl2l3_mod\000\000frontend\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x44048\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 241039 }, /* pm_inst_from_dl2l3_shr\000\000frontend\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x34048\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 241766 }, /* pm_inst_from_dl4\000\000frontend\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x3404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 242358 }, /* pm_inst_from_dmem\000\000frontend\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x4404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 244314 }, /* pm_inst_from_l2\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 due to an instruction fetch (not prefetch)\000event=0x14042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 244781 }, /* pm_inst_from_l2_disp_conflict_ldhitst\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to an instruction fetch (not prefetch)\000event=0x34040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 245379 }, /* pm_inst_from_l2_disp_conflict_other\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x44040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 245955 }, /* pm_inst_from_l2_mepf\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 246569 }, /* pm_inst_from_l2_no_conflict\000\000frontend\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to an instruction fetch (not prefetch)\000event=0x14040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 247111 }, /* pm_inst_from_l2miss\000\000frontend\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to an instruction fetch (not prefetch)\000event=0x1404e\000\000\000\000\000\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 250096 }, /* pm_inst_from_l3\000\000frontend\000The processor's Instruction cache was reloaded from local core's L3 due to an instruction fetch (not prefetch)\000event=0x44042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 250568 }, /* pm_inst_from_l3_disp_conflict\000\000frontend\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x34042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 251137 }, /* pm_inst_from_l3_mepf\000\000frontend\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 251757 }, /* pm_inst_from_l3_no_conflict\000\000frontend\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to an instruction fetch (not prefetch)\000event=0x14044\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 252304 }, /* pm_inst_from_l3miss\000\000frontend\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x300fa\000\000\000\000\000\000Inst from L3 miss\000 */
{ 252741 }, /* pm_inst_from_l3miss_mod\000\000frontend\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x4404e\000\000\000\000\000\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 253270 }, /* pm_inst_from_ll4\000\000frontend\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to an instruction fetch (not prefetch)\000event=0x1404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 253769 }, /* pm_inst_from_lmem\000\000frontend\000The processor's Instruction cache was reloaded from the local chip's Memory due to an instruction fetch (not prefetch)\000event=0x24048\000\000\000\000\000\000The processor's Instruction cache was reloaded from the local chip's Memory due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 254263 }, /* pm_inst_from_memory\000\000frontend\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to an instruction fetch (not prefetch)\000event=0x2404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 254872 }, /* pm_inst_from_off_chip_cache\000\000frontend\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to an instruction fetch (not prefetch)\000event=0x4404a\000\000\000\000\000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 255808 }, /* pm_inst_from_on_chip_cache\000\000frontend\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14048\000\000\000\000\000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 256478 }, /* pm_inst_from_rl2l3_mod\000\000frontend\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x24046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 257196 }, /* pm_inst_from_rl2l3_shr\000\000frontend\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x1404a\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 257864 }, /* pm_inst_from_rl4\000\000frontend\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x2404a\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 258253 }, /* pm_inst_from_rmem\000\000frontend\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x3404a\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 258850 }, /* pm_inst_grp_pump_cpred\000\000frontend\000Initial and Final Pump Scope was group pump (prediction=correct) for an instruction fetch\000event=0x24050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for an instruction fetch\000 */
{ 259251 }, /* pm_inst_grp_pump_mpred\000\000frontend\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for an instruction fetch\000event=0x24052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 259834 }, /* pm_inst_grp_pump_mpred_rty\000\000frontend\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for an instruction fetch\000event=0x14052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor an instruction fetch\000 */
{ 260314 }, /* pm_inst_imc_match_cmpl\000\000frontend\000IMC Match Count ( Not architected in P8)\000event=0x1003a\000\000\000\000\000\000\000 */
{ 260578 }, /* pm_inst_pump_cpred\000\000frontend\000Pump prediction correct. Counts across all types of pumps for an instruction fetch\000event=0x14054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumpsfor an instruction fetch\000 */
{ 260923 }, /* pm_inst_pump_mpred\000\000frontend\000Pump misprediction. Counts across all types of pumps for an instruction fetch\000event=0x44052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor an instruction fetch\000 */
{ 261253 }, /* pm_inst_sys_pump_cpred\000\000frontend\000Initial and Final Pump Scope was system pump (prediction=correct) for an instruction fetch\000event=0x34050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for an instruction fetch\000 */
{ 261645 }, /* pm_inst_sys_pump_mpred\000\000frontend\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for an instruction fetch\000event=0x34052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 262382 }, /* pm_inst_sys_pump_mpred_rty\000\000frontend\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for an instruction fetch\000event=0x44050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for an instruction fetch\000 */
{ 263255 }, /* pm_ipteg_from_dl2l3_mod\000\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x45048\000\000\000\000\000\000\000 */
{ 263491 }, /* pm_ipteg_from_dl2l3_shr\000\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x35048\000\000\000\000\000\000\000 */
{ 263956 }, /* pm_ipteg_from_dl4\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a instruction side request\000event=0x3504c\000\000\000\000\000\000\000 */
{ 264327 }, /* pm_ipteg_from_dmem\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a instruction side request\000event=0x4504c\000\000\000\000\000\000\000 */
{ 265456 }, /* pm_ipteg_from_l2\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 due to a instruction side request\000event=0x15042\000\000\000\000\000\000\000 */
{ 266122 }, /* pm_ipteg_from_l2_mepf\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a instruction side request\000event=0x25040\000\000\000\000\000\000\000 */
{ 266512 }, /* pm_ipteg_from_l2_no_conflict\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a instruction side request\000event=0x15040\000\000\000\000\000\000\000 */
{ 266857 }, /* pm_ipteg_from_l2miss\000\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a instruction side request\000event=0x1504e\000\000\000\000\000\000\000 */
{ 268753 }, /* pm_ipteg_from_l3\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 due to a instruction side request\000event=0x45042\000\000\000\000\000\000\000 */
{ 269041 }, /* pm_ipteg_from_l3_disp_conflict\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a instruction side request\000event=0x35042\000\000\000\000\000\000\000 */
{ 269402 }, /* pm_ipteg_from_l3_mepf\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a instruction side request\000event=0x25042\000\000\000\000\000\000\000 */
{ 269598 }, /* pm_ipteg_from_l3_no_conflict\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a instruction side request\000event=0x15044\000\000\000\000\000\000\000 */
{ 269772 }, /* pm_ipteg_from_l3miss\000\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a instruction side request\000event=0x4504e\000\000\000\000\000\000\000 */
{ 269947 }, /* pm_ipteg_from_ll4\000\000frontend\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a instruction side request\000event=0x1504c\000\000\000\000\000\000\000 */
{ 270256 }, /* pm_ipteg_from_lmem\000\000frontend\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a instruction side request\000event=0x25048\000\000\000\000\000\000\000 */
{ 270563 }, /* pm_ipteg_from_memory\000\000frontend\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a instruction side request\000event=0x2504c\000\000\000\000\000\000\000 */
{ 270952 }, /* pm_ipteg_from_off_chip_cache\000\000frontend\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a instruction side request\000event=0x4504a\000\000\000\000\000\000\000 */
{ 271421 }, /* pm_ipteg_from_on_chip_cache\000\000frontend\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a instruction side request\000event=0x15048\000\000\000\000\000\000\000 */
{ 271842 }, /* pm_ipteg_from_rl2l3_mod\000\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x25046\000\000\000\000\000\000\000 */
{ 272309 }, /* pm_ipteg_from_rl2l3_shr\000\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x1504a\000\000\000\000\000\000\000 */
{ 272772 }, /* pm_ipteg_from_rl4\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a instruction side request\000event=0x2504a\000\000\000\000\000\000\000 */
{ 273143 }, /* pm_ipteg_from_rmem\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a instruction side request\000event=0x3504a\000\000\000\000\000\000\000 */
{ 274536 }, /* pm_islb_miss\000\000frontend\000I SLB Miss\000event=0xd096\000\000\000\000\000\000\000 */
{ 277462 }, /* pm_itlb_miss\000\000frontend\000ITLB Reloaded (always zero on POWER6)\000event=0x400fc\000\000\000\000\000\000\000 */
{ 278288 }, /* pm_l1_icache_miss\000\000frontend\000Demand iCache Miss\000event=0x200fd\000\000\000\000\000\000\000 */
{ 278420 }, /* pm_l1_icache_reloaded_all\000\000frontend\000Counts all Icache reloads includes demand, prefetchm prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\000\000\000\000\000\000 */
{ 278756 }, /* pm_l1_icache_reloaded_pref\000\000frontend\000Counts all Icache prefetch reloads ( includes demand turned into prefetch)\000event=0x30068\000\000\000\000\000\000\000 */
{ 408867 }, /* pm_thrd_conc_run_inst\000\000frontend\000PPC Instructions Finished when both threads in run_cycles\000event=0x300f4\000\000\000\000\000\000Concurrent Run Instructions\000 */
{ 416947 }, /* pm_tm_trans_run_inst\000\000frontend\000Instructions completed in transactional state\000event=0x30060\000\000\000\000\000\000\000 */
{ 417645 }, /* pm_tm_tx_pass_run_inst\000\000frontend\000run instructions spent in successful transactions\000event=0x4e014\000\000\000\000\000\000\000 */
{ 326811 }, /* pm_mrk_back_br_cmpl\000\000marked\000Marked branch instruction completed with a target address less than current instruction address\000event=0x3515e\000\000\000\000\000\000\000 */
{ 327283 }, /* pm_mrk_br_cmpl\000\000marked\000Branch Instruction completed\000event=0x1016e\000\000\000\000\000\000\000 */
{ 327462 }, /* pm_mrk_br_mpred_cmpl\000\000marked\000Marked Branch Mispredicted\000event=0x301e4\000\000\000\000\000\000\000 */
{ 327538 }, /* pm_mrk_br_taken_cmpl\000\000marked\000Marked Branch Taken completed\000event=0x101e2\000\000\000\000\000\000\000 */
{ 327786 }, /* pm_mrk_bru_fin\000\000marked\000bru marked instr finish\000event=0x2013a\000\000\000\000\000\000\000 */
{ 327961 }, /* pm_mrk_data_from_dl2l3_mod\000\000marked\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x4d148\000\000\000\000\000\000\000 */
{ 328402 }, /* pm_mrk_data_from_dl2l3_mod_cyc\000\000marked\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2d128\000\000\000\000\000\000\000 */
{ 328829 }, /* pm_mrk_data_from_dl2l3_shr\000\000marked\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x3d148\000\000\000\000\000\000\000 */
{ 329266 }, /* pm_mrk_data_from_dl2l3_shr_cyc\000\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2c128\000\000\000\000\000\000\000 */
{ 329478 }, /* pm_mrk_data_from_dl4\000\000marked\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x3d14c\000\000\000\000\000\000\000 */
{ 329821 }, /* pm_mrk_data_from_dl4_cyc\000\000marked\000Duration in cycles to reload from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x2c12c\000\000\000\000\000\000\000 */
{ 330150 }, /* pm_mrk_data_from_dmem\000\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x4d14c\000\000\000\000\000\000\000 */
{ 330497 }, /* pm_mrk_data_from_dmem_cyc\000\000marked\000Duration in cycles to reload from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x2d12c\000\000\000\000\000\000\000 */
{ 332035 }, /* pm_mrk_data_from_l2\000\000marked\000The processor's data cache was reloaded from local core's L2 due to a marked load\000event=0x1d142\000\000\000\000\000\000\000 */
{ 332294 }, /* pm_mrk_data_from_l2_cyc\000\000marked\000Duration in cycles to reload from local core's L2 due to a marked load\000event=0x4c122\000\000\000\000\000\000\000 */
{ 332539 }, /* pm_mrk_data_from_l2_disp_conflict_ldhitst\000\000marked\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a marked load\000event=0x3d140\000\000\000\000\000\000\000 */
{ 333082 }, /* pm_mrk_data_from_l2_disp_conflict_ldhitst_cyc\000\000marked\000Duration in cycles to reload from local core's L2 with load hit store conflict due to a marked load\000event=0x2c120\000\000\000\000\000\000\000 */
{ 333431 }, /* pm_mrk_data_from_l2_disp_conflict_other\000\000marked\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a marked load\000event=0x4d140\000\000\000\000\000\000\000 */
{ 333604 }, /* pm_mrk_data_from_l2_disp_conflict_other_cyc\000\000marked\000Duration in cycles to reload from local core's L2 with dispatch conflict due to a marked load\000event=0x2d120\000\000\000\000\000\000\000 */
{ 333935 }, /* pm_mrk_data_from_l2_mepf\000\000marked\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x2d140\000\000\000\000\000\000\000 */
{ 334299 }, /* pm_mrk_data_from_l2_mepf_cyc\000\000marked\000Duration in cycles to reload from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x4d120\000\000\000\000\000\000\000 */
{ 334646 }, /* pm_mrk_data_from_l2_no_conflict\000\000marked\000The processor's data cache was reloaded from local core's L2 without conflict due to a marked load\000event=0x1d140\000\000\000\000\000\000\000 */
{ 334963 }, /* pm_mrk_data_from_l2_no_conflict_cyc\000\000marked\000Duration in cycles to reload from local core's L2 without conflict due to a marked load\000event=0x4c120\000\000\000\000\000\000\000 */
{ 335266 }, /* pm_mrk_data_from_l2miss\000\000marked\000Data cache reload L2 miss\000event=0x1d14e\000\000\000\000\000\000\000 */
{ 335685 }, /* pm_mrk_data_from_l2miss_cyc\000\000marked\000Duration in cycles to reload from a location other than the local core's L2 due to a marked load\000event=0x4c12e\000\000\000\000\000\000\000 */
{ 338450 }, /* pm_mrk_data_from_l3\000\000marked\000The processor's data cache was reloaded from local core's L3 due to a marked load\000event=0x4d142\000\000\000\000\000\000\000 */
{ 338580 }, /* pm_mrk_data_from_l3_cyc\000\000marked\000Duration in cycles to reload from local core's L3 due to a marked load\000event=0x2d122\000\000\000\000\000\000\000 */
{ 338825 }, /* pm_mrk_data_from_l3_disp_conflict\000\000marked\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a marked load\000event=0x3d142\000\000\000\000\000\000\000 */
{ 339158 }, /* pm_mrk_data_from_l3_disp_conflict_cyc\000\000marked\000Duration in cycles to reload from local core's L3 with dispatch conflict due to a marked load\000event=0x2c122\000\000\000\000\000\000\000 */
{ 339477 }, /* pm_mrk_data_from_l3_mepf\000\000marked\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x2d142\000\000\000\000\000\000\000 */
{ 339838 }, /* pm_mrk_data_from_l3_mepf_cyc\000\000marked\000Duration in cycles to reload from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x4d122\000\000\000\000\000\000\000 */
{ 340184 }, /* pm_mrk_data_from_l3_no_conflict\000\000marked\000The processor's data cache was reloaded from local core's L3 without conflict due to a marked load\000event=0x1d144\000\000\000\000\000\000\000 */
{ 340501 }, /* pm_mrk_data_from_l3_no_conflict_cyc\000\000marked\000Duration in cycles to reload from local core's L3 without conflict due to a marked load\000event=0x4c124\000\000\000\000\000\000\000 */
{ 340804 }, /* pm_mrk_data_from_l3miss\000\000marked\000The processor's data cache was reloaded from a location other than the local core's L3 due to a marked load\000event=0x201e4\000\000\000\000\000\000\000 */
{ 341463 }, /* pm_mrk_data_from_l3miss_cyc\000\000marked\000Duration in cycles to reload from a location other than the local core's L3 due to a marked load\000event=0x2d12e\000\000\000\000\000\000\000 */
{ 341616 }, /* pm_mrk_data_from_ll4\000\000marked\000The processor's data cache was reloaded from the local chip's L4 cache due to a marked load\000event=0x1d14c\000\000\000\000\000\000\000 */
{ 341891 }, /* pm_mrk_data_from_ll4_cyc\000\000marked\000Duration in cycles to reload from the local chip's L4 cache due to a marked load\000event=0x4c12c\000\000\000\000\000\000\000 */
{ 342025 }, /* pm_mrk_data_from_lmem\000\000marked\000The processor's data cache was reloaded from the local chip's Memory due to a marked load\000event=0x2d148\000\000\000\000\000\000\000 */
{ 342302 }, /* pm_mrk_data_from_lmem_cyc\000\000marked\000Duration in cycles to reload from the local chip's Memory due to a marked load\000event=0x4d128\000\000\000\000\000\000\000 */
{ 342739 }, /* pm_mrk_data_from_memory\000\000marked\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x2d14c\000\000\000\000\000\000\000 */
{ 343263 }, /* pm_mrk_data_from_memory_cyc\000\000marked\000Duration in cycles to reload from a memory location including L4 from local remote or distant due to a marked load\000event=0x4d12c\000\000\000\000\000\000\000 */
{ 343604 }, /* pm_mrk_data_from_off_chip_cache\000\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x4d14a\000\000\000\000\000\000\000 */
{ 344039 }, /* pm_mrk_data_from_off_chip_cache_cyc\000\000marked\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x2d12a\000\000\000\000\000\000\000 */
{ 344460 }, /* pm_mrk_data_from_on_chip_cache\000\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x1d148\000\000\000\000\000\000\000 */
{ 345039 }, /* pm_mrk_data_from_on_chip_cache_cyc\000\000marked\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x4c128\000\000\000\000\000\000\000 */
{ 345226 }, /* pm_mrk_data_from_rl2l3_mod\000\000marked\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x2d146\000\000\000\000\000\000\000 */
{ 345662 }, /* pm_mrk_data_from_rl2l3_mod_cyc\000\000marked\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4d126\000\000\000\000\000\000\000 */
{ 346087 }, /* pm_mrk_data_from_rl2l3_shr\000\000marked\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x1d14a\000\000\000\000\000\000\000 */
{ 346729 }, /* pm_mrk_data_from_rl2l3_shr_cyc\000\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4c12a\000\000\000\000\000\000\000 */
{ 347108 }, /* pm_mrk_data_from_rl4\000\000marked\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x2d14a\000\000\000\000\000\000\000 */
{ 347438 }, /* pm_mrk_data_from_rl4_cyc\000\000marked\000Duration in cycles to reload from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x4d12a\000\000\000\000\000\000\000 */
{ 347600 }, /* pm_mrk_data_from_rmem\000\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x3d14a\000\000\000\000\000\000\000 */
{ 347947 }, /* pm_mrk_data_from_rmem_cyc\000\000marked\000Duration in cycles to reload from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x2c12a\000\000\000\000\000\000\000 */
{ 348280 }, /* pm_mrk_dcache_reload_intv\000\000marked\000Combined Intervention event\000event=0x40118\000\000\000\000\000\000\000 */
{ 348527 }, /* pm_mrk_derat_miss\000\000marked\000Erat Miss (TLB Access) All page sizes\000event=0x301e6\000\000\000\000\000\000\000 */
{ 348611 }, /* pm_mrk_derat_miss_16g\000\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 16G\000event=0x4d154\000\000\000\000\000\000\000 */
{ 348855 }, /* pm_mrk_derat_miss_16m\000\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 16M\000event=0x3d154\000\000\000\000\000\000\000 */
{ 349358 }, /* pm_mrk_derat_miss_4k\000\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1d156\000\000\000\000\000\000\000 */
{ 349676 }, /* pm_mrk_derat_miss_64k\000\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2d154\000\000\000\000\000\000\000 */
{ 350042 }, /* pm_mrk_dfu_fin\000\000marked\000Decimal Unit marked Instruction Finish\000event=0x20132\000\000\000\000\000\000\000 */
{ 350354 }, /* pm_mrk_dpteg_from_dl2l3_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request\000event=0x4f148\000\000\000\000\000\000\000 */
{ 350926 }, /* pm_mrk_dpteg_from_dl2l3_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request\000event=0x3f148\000\000\000\000\000\000\000 */
{ 351499 }, /* pm_mrk_dpteg_from_dl4\000\000marked\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a marked data side request\000event=0x3f14c\000\000\000\000\000\000\000 */
{ 351978 }, /* pm_mrk_dpteg_from_dmem\000\000marked\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a marked data side request\000event=0x4f14c\000\000\000\000\000\000\000 */
{ 353430 }, /* pm_mrk_dpteg_from_l2\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a marked data side request\000event=0x1f142\000\000\000\000\000\000\000 */
{ 354507 }, /* pm_mrk_dpteg_from_l2_mepf\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked data side request\000event=0x2f140\000\000\000\000\000\000\000 */
{ 354705 }, /* pm_mrk_dpteg_from_l2_no_conflict\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a marked data side request\000event=0x1f140\000\000\000\000\000\000\000 */
{ 355158 }, /* pm_mrk_dpteg_from_l2miss\000\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a marked data side request\000event=0x1f14e\000\000\000\000\000\000\000 */
{ 357579 }, /* pm_mrk_dpteg_from_l3\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 due to a marked data side request\000event=0x4f142\000\000\000\000\000\000\000 */
{ 357969 }, /* pm_mrk_dpteg_from_l3_disp_conflict\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a marked data side request\000event=0x3f142\000\000\000\000\000\000\000 */
{ 358433 }, /* pm_mrk_dpteg_from_l3_mepf\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked data side request\000event=0x2f142\000\000\000\000\000\000\000 */
{ 358930 }, /* pm_mrk_dpteg_from_l3_no_conflict\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a marked data side request\000event=0x1f144\000\000\000\000\000\000\000 */
{ 359659 }, /* pm_mrk_dpteg_from_l3miss\000\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a marked data side request\000event=0x4f14e\000\000\000\000\000\000\000 */
{ 360094 }, /* pm_mrk_dpteg_from_ll4\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a marked data side request\000event=0x1f14c\000\000\000\000\000\000\000 */
{ 360508 }, /* pm_mrk_dpteg_from_lmem\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a marked data side request\000event=0x2f148\000\000\000\000\000\000\000 */
{ 360665 }, /* pm_mrk_dpteg_from_memory\000\000marked\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a marked data side request\000event=0x2f14c\000\000\000\000\000\000\000 */
{ 361156 }, /* pm_mrk_dpteg_from_off_chip_cache\000\000marked\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked data side request\000event=0x4f14a\000\000\000\000\000\000\000 */
{ 361727 }, /* pm_mrk_dpteg_from_on_chip_cache\000\000marked\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a marked data side request\000event=0x1f148\000\000\000\000\000\000\000 */
{ 362251 }, /* pm_mrk_dpteg_from_rl2l3_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request\000event=0x2f146\000\000\000\000\000\000\000 */
{ 363152 }, /* pm_mrk_dpteg_from_rl2l3_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request\000event=0x1f14a\000\000\000\000\000\000\000 */
{ 363384 }, /* pm_mrk_dpteg_from_rl4\000\000marked\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a marked data side request\000event=0x2f14a\000\000\000\000\000\000\000 */
{ 364143 }, /* pm_mrk_dpteg_from_rmem\000\000marked\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a marked data side request\000event=0x3f14a\000\000\000\000\000\000\000 */
{ 364395 }, /* pm_mrk_dtlb_miss\000\000marked\000Marked dtlb miss\000event=0x401e4\000\000\000\000\000\000\000 */
{ 364457 }, /* pm_mrk_dtlb_miss_16g\000\000marked\000Marked Data TLB Miss page size 16G\000event=0x1d158\000\000\000\000\000\000\000 */
{ 364541 }, /* pm_mrk_dtlb_miss_16m\000\000marked\000Marked Data TLB Miss page size 16M\000event=0x4d156\000\000\000\000\000\000\000 */
{ 364625 }, /* pm_mrk_dtlb_miss_4k\000\000marked\000Marked Data TLB Miss page size 4k\000event=0x2d156\000\000\000\000\000\000\000 */
{ 364707 }, /* pm_mrk_dtlb_miss_64k\000\000marked\000Marked Data TLB Miss page size 64K\000event=0x3d156\000\000\000\000\000\000\000 */
{ 365018 }, /* pm_mrk_fab_rsp_bkill\000\000marked\000Marked store had to do a bkill\000event=0x40154\000\000\000\000\000\000\000 */
{ 365177 }, /* pm_mrk_fab_rsp_bkill_cyc\000\000marked\000cycles L2 RC took for a bkill\000event=0x2f150\000\000\000\000\000\000\000 */
{ 365437 }, /* pm_mrk_fab_rsp_claim_rty\000\000marked\000Sampled store did a rwitm and got a rty\000event=0x3015e\000\000\000\000\000\000\000 */
{ 365614 }, /* pm_mrk_fab_rsp_dclaim\000\000marked\000Marked store had to do a dclaim\000event=0x30154\000\000\000\000\000\000\000 */
{ 365783 }, /* pm_mrk_fab_rsp_dclaim_cyc\000\000marked\000cycles L2 RC took for a dclaim\000event=0x2f152\000\000\000\000\000\000\000 */
{ 366120 }, /* pm_mrk_fab_rsp_rd_rty\000\000marked\000Sampled L2 reads retry count\000event=0x4015e\000\000\000\000\000\000\000 */
{ 366288 }, /* pm_mrk_fab_rsp_rd_t_intv\000\000marked\000Sampled Read got a T intervention\000event=0x1015e\000\000\000\000\000\000\000 */
{ 366460 }, /* pm_mrk_fab_rsp_rwitm_cyc\000\000marked\000cycles L2 RC took for a rwitm\000event=0x4f150\000\000\000\000\000\000\000 */
{ 366638 }, /* pm_mrk_fab_rsp_rwitm_rty\000\000marked\000Sampled store did a rwitm and got a rty\000event=0x2015e\000\000\000\000\000\000\000 */
{ 367183 }, /* pm_mrk_fxu_fin\000\000marked\000fxu marked instr finish\000event=0x20134\000\000\000\000\000\000\000 */
{ 367976 }, /* pm_mrk_inst_cmpl\000\000marked\000marked instruction completed\000event=0x401e0\000\000\000\000\000\000\000 */
{ 368179 }, /* pm_mrk_inst_decoded\000\000marked\000marked instruction decoded\000event=0x20130\000\000\000\000\000\000marked instruction decoded. Name from ISU?\000 */
{ 368425 }, /* pm_mrk_inst_disp\000\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\000\000\000\000\000Marked Instruction dispatched\000 */
{ 368978 }, /* pm_mrk_inst_fin\000\000marked\000marked instruction finished\000event=0x30130\000\000\000\000\000\000marked instr finish any unit\000 */
{ 369161 }, /* pm_mrk_inst_from_l3miss\000\000marked\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x401e6\000\000\000\000\000\000n/a\000 */
{ 369912 }, /* pm_mrk_inst_issued\000\000marked\000Marked instruction issued\000event=0x10132\000\000\000\000\000\000\000 */
{ 370088 }, /* pm_mrk_inst_timeo\000\000marked\000marked Instruction finish timeout (instruction lost)\000event=0x40134\000\000\000\000\000\000\000 */
{ 370321 }, /* pm_mrk_l1_icache_miss\000\000marked\000sampled Instruction suffered an icache Miss\000event=0x101e4\000\000\000\000\000\000Marked L1 Icache Miss\000 */
{ 370622 }, /* pm_mrk_l1_reload_valid\000\000marked\000Marked demand reload\000event=0x101ea\000\000\000\000\000\000\000 */
{ 371011 }, /* pm_mrk_l2_rc_disp\000\000marked\000Marked Instruction RC dispatched in L2\000event=0x20114\000\000\000\000\000\000\000 */
{ 371274 }, /* pm_mrk_l2_rc_done\000\000marked\000Marked RC done\000event=0x3012a\000\000\000\000\000\000\000 */
{ 371610 }, /* pm_mrk_larx_fin\000\000marked\000Larx finished\000event=0x40116\000\000\000\000\000\000\000 */
{ 371996 }, /* pm_mrk_ld_miss_exposed_cyc\000\000marked\000Marked Load exposed Miss cycles\000event=0x1013e\000\000\000\000\000\000Marked Load exposed Miss (use edge detect to count #)\000 */
{ 372136 }, /* pm_mrk_ld_miss_l1\000\000marked\000Marked DL1 Demand Miss counted at exec time\000event=0x201e2\000\000\000\000\000\000\000 */
{ 372542 }, /* pm_mrk_ld_miss_l1_cyc\000\000marked\000Marked ld latency\000event=0x4013e\000\000\000\000\000\000\000 */
{ 372771 }, /* pm_mrk_lsu_fin\000\000marked\000lsu marked instr finish\000event=0x40132\000\000\000\000\000\000\000 */
{ 374087 }, /* pm_mrk_ntf_fin\000\000marked\000Marked next to finish instruction finished\000event=0x20112\000\000\000\000\000\000\000 */
{ 374424 }, /* pm_mrk_run_cyc\000\000marked\000Marked run cycles\000event=0x1d15e\000\000\000\000\000\000\000 */
{ 375097 }, /* pm_mrk_st_cmpl\000\000marked\000marked store completed and sent to nest\000event=0x10134\000\000\000\000\000\000Marked store completed\000 */
{ 375422 }, /* pm_mrk_st_cmpl_int\000\000marked\000marked store finished with intervention\000event=0x30134\000\000\000\000\000\000marked store complete (data home) with intervention\000 */
{ 375823 }, /* pm_mrk_st_drain_to_l2disp_cyc\000\000marked\000cycles to drain st from core to L2\000event=0x3f150\000\000\000\000\000\000\000 */
{ 376097 }, /* pm_mrk_st_fwd\000\000marked\000Marked st forwards\000event=0x3012c\000\000\000\000\000\000\000 */
{ 376250 }, /* pm_mrk_st_l2disp_to_cmpl_cyc\000\000marked\000cycles from L2 rc disp to l2 rc completion\000event=0x1f150\000\000\000\000\000\000\000 */
{ 376565 }, /* pm_mrk_st_nest\000\000marked\000Marked store sent to nest\000event=0x20138\000\000\000\000\000\000\000 */
{ 376634 }, /* pm_mrk_stall_cmplu_cyc\000\000marked\000Marked Group completion Stall\000event=0x3013e\000\000\000\000\000\000Marked Group Completion Stall cycles (use edge detect to count #)\000 */
{ 377515 }, /* pm_mrk_stcx_fail\000\000marked\000marked stcx failed\000event=0x3e158\000\000\000\000\000\000\000 */
{ 378843 }, /* pm_mrk_vsu_fin\000\000marked\000VSU marked instr finish\000event=0x30132\000\000\000\000\000\000vsu (fpu) marked instr finish\000 */
{ 381239 }, /* pm_mult_mrk\000\000marked\000mult marked instr\000event=0x3d15e\000\000\000\000\000\000\000 */
{ 403567 }, /* pm_sync_mrk_br_link\000\000marked\000Marked Branch and link branch that can cause a synchronous interrupt\000event=0x15152\000\000\000\000\000\000\000 */
{ 403799 }, /* pm_sync_mrk_br_mpred\000\000marked\000Marked Branch mispredict that can cause a synchronous interrupt\000event=0x1515c\000\000\000\000\000\000\000 */
{ 403912 }, /* pm_sync_mrk_fx_divide\000\000marked\000Marked fixed point divide that can cause a synchronous interrupt\000event=0x15156\000\000\000\000\000\000\000 */
{ 404144 }, /* pm_sync_mrk_l2hit\000\000marked\000Marked L2 Hits that can throw a synchronous interrupt\000event=0x15158\000\000\000\000\000\000\000 */
{ 404344 }, /* pm_sync_mrk_l2miss\000\000marked\000Marked L2 Miss that can throw a synchronous interrupt\000event=0x1515a\000\000\000\000\000\000\000 */
{ 404545 }, /* pm_sync_mrk_l3miss\000\000marked\000Marked L3 misses that can throw a synchronous interrupt\000event=0x15154\000\000\000\000\000\000\000 */
{ 404750 }, /* pm_sync_mrk_probe_nop\000\000marked\000Marked probeNops which can cause synchronous interrupts\000event=0x15150\000\000\000\000\000\000\000 */
{ 118350 }, /* pm_chip_pump_cpred\000\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for all data types ( demand load,data,inst prefetch,inst fetch,xlate (I or d)\000 */
{ 151388 }, /* pm_data_chip_pump_cpred\000\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for a demand load\000event=0x1c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for a demand load\000 */
{ 153604 }, /* pm_data_from_dmem\000\000memory\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a demand load\000event=0x4c04c\000\000\000\000\000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 163880 }, /* pm_data_from_lmem\000\000memory\000The processor's data cache was reloaded from the local chip's Memory due to a demand load\000event=0x2c048\000\000\000\000\000\000The processor's data cache was reloaded from the local chip's Memory due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 164701 }, /* pm_data_from_memory\000\000memory\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x2c04c\000\000\000\000\000\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 167734 }, /* pm_data_from_rl4\000\000memory\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a demand load\000event=0x2c04a\000\000\000\000\000\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 168249 }, /* pm_data_from_rmem\000\000memory\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a demand load\000event=0x3c04a\000\000\000\000\000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 168603 }, /* pm_data_grp_pump_cpred\000\000memory\000Initial and Final Pump Scope was group pump (prediction=correct) for a demand load\000event=0x2c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for a demand load\000 */
{ 169118 }, /* pm_data_grp_pump_mpred\000\000memory\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for a demand load\000event=0x2c052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 169665 }, /* pm_data_grp_pump_mpred_rty\000\000memory\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for a demand load\000event=0x1c052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor a demand load\000 */
{ 170098 }, /* pm_data_pump_cpred\000\000memory\000Pump prediction correct. Counts across all types of pumps for a demand load\000event=0x1c054\000\000\000\000\000\000\000 */
{ 170339 }, /* pm_data_pump_mpred\000\000memory\000Pump misprediction. Counts across all types of pumps for a demand load\000event=0x4c052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor a demand load\000 */
{ 170751 }, /* pm_data_sys_pump_cpred\000\000memory\000Initial and Final Pump Scope was system pump (prediction=correct) for a demand load\000event=0x3c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for a demand load\000 */
{ 171218 }, /* pm_data_sys_pump_mpred\000\000memory\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for a demand load\000event=0x3c052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 171854 }, /* pm_data_sys_pump_mpred_rty\000\000memory\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for a demand load\000event=0x4c050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for a demand load\000 */
{ 185541 }, /* pm_dpteg_from_dl4\000\000memory\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a data side request\000event=0x3e04c\000\000\000\000\000\000\000 */
{ 186001 }, /* pm_dpteg_from_dmem\000\000memory\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a data side request\000event=0x4e04c\000\000\000\000\000\000\000 */
{ 197679 }, /* pm_dpteg_from_rmem\000\000memory\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a data side request\000event=0x3e04a\000\000\000\000\000\000\000 */
{ 215976 }, /* pm_grp_pump_cpred\000\000memory\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20050\000\000\000\000\000\000\000 */
{ 216189 }, /* pm_grp_pump_mpred\000\000memory\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 216875 }, /* pm_grp_pump_mpred_rty\000\000memory\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 287278 }, /* pm_l3_co_mepf\000\000memory\000L3 CO of line in Mep state ( includes casthrough\000event=0x18082\000\000\000\000\000\000\000 */
{ 325377 }, /* pm_mem_co\000\000memory\000Memory castouts from this lpar\000event=0x4c058\000\000\000\000\000\000\000 */
{ 325634 }, /* pm_mem_loc_thresh_ifu\000\000memory\000Local Memory above threshold for IFU speculation control\000event=0x10058\000\000\000\000\000\000\000 */
{ 325741 }, /* pm_mem_loc_thresh_lsu_high\000\000memory\000Local memory above threshold for LSU medium\000event=0x40056\000\000\000\000\000\000\000 */
{ 326037 }, /* pm_mem_loc_thresh_lsu_med\000\000memory\000Local memory above theshold for data prefetch\000event=0x1c05e\000\000\000\000\000\000\000 */
{ 326222 }, /* pm_mem_pref\000\000memory\000Memory prefetch for this lpar. Includes L4\000event=0x2c058\000\000\000\000\000\000\000 */
{ 326305 }, /* pm_mem_read\000\000memory\000Reads from Memory from this lpar (includes data/inst/xlate/l1prefetch/inst prefetch). Includes L4\000event=0x10056\000\000\000\000\000\000\000 */
{ 326585 }, /* pm_mem_rwitm\000\000memory\000Memory rwitm for this lpar\000event=0x3c05e\000\000\000\000\000\000\000 */
{ 381354 }, /* pm_nest_ref_clk\000\000memory\000Multiply by 4 to obtain the number of PB cycles\000event=0x3006e\000\000\000\000\000\000Nest reference clocks\000 */
{ 388884 }, /* pm_pump_cpred\000\000memory\000Pump prediction correct. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 389406 }, /* pm_pump_mpred\000\000memory\000Pump misprediction. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 405035 }, /* pm_sys_pump_cpred\000\000memory\000Initial and Final Pump Scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 405681 }, /* pm_sys_pump_mpred\000\000memory\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 406230 }, /* pm_sys_pump_mpred_rty\000\000memory\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 103865 }, /* pm_1lpar_cyc\000\000other\000Number of cycles in single lpar mode. All threads in the core are assigned to the same lpar\000event=0x1f05e\000\000\000\000\000\000\000 */
{ 104836 }, /* pm_2lpar_cyc\000\000other\000Cycles in 2-lpar mode. Threads 0-3 belong to Lpar0 and threads 4-7 belong to Lpar1\000event=0x2006e\000\000\000\000\000\000Number of cycles in 2 lpar mode\000 */
{ 105204 }, /* pm_4lpar_cyc\000\000other\000Number of cycles in 4 LPAR mode. Threads 0-1 belong to lpar0, threads 2-3 belong to lpar1, threads 4-5 belong to lpar2, and threads 6-7 belong to lpar3\000event=0x4e05e\000\000\000\000\000\000\000 */
{ 105792 }, /* pm_all_chip_pump_cpred\000\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for all data types ( demand load,data,inst prefetch,inst fetch,xlate (I or d)\000 */
{ 106161 }, /* pm_all_grp_pump_cpred\000\000other\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x520050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 106534 }, /* pm_all_grp_pump_mpred\000\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x620052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 106995 }, /* pm_all_grp_pump_mpred_rty\000\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 107434 }, /* pm_all_pump_cpred\000\000other\000Pump prediction correct. Counts across all types of pumps for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 107760 }, /* pm_all_pump_mpred\000\000other\000Pump misprediction. Counts across all types of pumps for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x640052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 108076 }, /* pm_all_sys_pump_cpred\000\000other\000Initial and Final Pump Scope was system pump for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x630050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 108416 }, /* pm_all_sys_pump_mpred\000\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x630052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 108959 }, /* pm_all_sys_pump_mpred_rty\000\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x640050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 110043 }, /* pm_bank_conflict\000\000other\000Read blocked due to interleave conflict. The ifar logic will detect an interleave conflict and kill the data that was read that cycle\000event=0x4082\000\000\000\000\000\000\000 */
{ 110483 }, /* pm_br_bc_8\000\000other\000Pairable BC+8 branch that has not been converted to a Resolve Finished in the BRU pipeline\000event=0x5086\000\000\000\000\000\000\000 */
{ 110611 }, /* pm_br_bc_8_conv\000\000other\000Pairable BC+8 branch that was converted to a Resolve Finished in the BRU pipeline\000event=0x5084\000\000\000\000\000\000\000 */
{ 111250 }, /* pm_br_mpred_ccache\000\000other\000Conditional Branch Completed that was Mispredicted due to the Count Cache Target Prediction\000event=0x40ac\000\000\000\000\000\000\000 */
{ 111643 }, /* pm_br_mpred_cr\000\000other\000Conditional Branch Completed that was Mispredicted due to the BHT Direction Prediction (taken/not taken)\000event=0x40b8\000\000\000\000\000\000\000 */
{ 111789 }, /* pm_br_mpred_lstack\000\000other\000Conditional Branch Completed that was Mispredicted due to the Link Stack Target Prediction\000event=0x40ae\000\000\000\000\000\000\000 */
{ 112189 }, /* pm_br_mpred_ta\000\000other\000Conditional Branch Completed that was Mispredicted due to the Target Address Prediction from the Count Cache or Link Stack. Only XL-form branches that resolved Taken set this event\000event=0x40ba\000\000\000\000\000\000\000 */
{ 112799 }, /* pm_br_mrk_2path\000\000other\000marked two path branch\000event=0x10138\000\000\000\000\000\000\000 */
{ 113044 }, /* pm_br_pred_br0\000\000other\000Conditional Branch Completed on BR0 (1st branch in group) in which the HW predicted the Direction or Target\000event=0x409c\000\000\000\000\000\000\000 */
{ 113193 }, /* pm_br_pred_br1\000\000other\000Conditional Branch Completed on BR1 (2nd branch in group) in which the HW predicted the Direction or Target. Note: BR1 can only be used in Single Thread Mode. In all of the SMT modes, only one branch can complete, thus BR1 is unused\000event=0x409e\000\000\000\000\000\000\000 */
{ 113467 }, /* pm_br_pred_br_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) OR if_pc_br0_br_pred(1)\000event=0x489c\000\000\000\000\000\000IFU\000 */
{ 113770 }, /* pm_br_pred_ccache_br0\000\000other\000Conditional Branch Completed on BR0 that used the Count Cache for Target Prediction\000event=0x40a4\000\000\000\000\000\000\000 */
{ 113902 }, /* pm_br_pred_ccache_br1\000\000other\000Conditional Branch Completed on BR1 that used the Count Cache for Target Prediction\000event=0x40a6\000\000\000\000\000\000\000 */
{ 114034 }, /* pm_br_pred_ccache_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) AND if_pc_br0_pred_type\000event=0x48a4\000\000\000\000\000\000IFU\000 */
{ 114220 }, /* pm_br_pred_cr_br0\000\000other\000Conditional Branch Completed on BR0 that had its direction predicted. I-form branches do not set this event. In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b0\000\000\000\000\000\000\000 */
{ 114519 }, /* pm_br_pred_cr_br1\000\000other\000Conditional Branch Completed on BR1 that had its direction predicted. I-form branches do not set this event. In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b2\000\000\000\000\000\000\000 */
{ 114818 }, /* pm_br_pred_cr_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(1)='1'\000event=0x48b0\000\000\000\000\000\000IFU\000 */
{ 115101 }, /* pm_br_pred_lstack_br0\000\000other\000Conditional Branch Completed on BR0 that used the Link Stack for Target Prediction\000event=0x40a8\000\000\000\000\000\000\000 */
{ 115232 }, /* pm_br_pred_lstack_br1\000\000other\000Conditional Branch Completed on BR1 that used the Link Stack for Target Prediction\000event=0x40aa\000\000\000\000\000\000\000 */
{ 115363 }, /* pm_br_pred_lstack_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) AND (not if_pc_br0_pred_type)\000event=0x48a8\000\000\000\000\000\000IFU\000 */
{ 115859 }, /* pm_br_pred_ta_br0\000\000other\000Conditional Branch Completed on BR0 that had its target address predicted. Only XL-form branches set this event\000event=0x40b4\000\000\000\000\000\000\000 */
{ 116015 }, /* pm_br_pred_ta_br1\000\000other\000Conditional Branch Completed on BR1 that had its target address predicted. Only XL-form branches set this event\000event=0x40b6\000\000\000\000\000\000\000 */
{ 116171 }, /* pm_br_pred_ta_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0)='1'\000event=0x48b4\000\000\000\000\000\000IFU\000 */
{ 117030 }, /* pm_br_uncond_br0\000\000other\000Unconditional Branch Completed on BR0. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was coverted to a Resolve\000event=0x40a0\000\000\000\000\000\000\000 */
{ 117296 }, /* pm_br_uncond_br1\000\000other\000Unconditional Branch Completed on BR1. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was coverted to a Resolve\000event=0x40a2\000\000\000\000\000\000\000 */
{ 117562 }, /* pm_br_uncond_cmpl\000\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred=00 AND if_pc_br0_completed\000event=0x48a0\000\000\000\000\000\000IFU\000 */
{ 118222 }, /* pm_castout_issued\000\000other\000Castouts issued\000event=0x3094\000\000\000\000\000\000\000 */
{ 118282 }, /* pm_castout_issued_gpr\000\000other\000Castouts issued GPR\000event=0x3096\000\000\000\000\000\000\000 */
{ 119040 }, /* pm_clb_held\000\000other\000CLB Hold: Any Reason\000event=0x2090\000\000\000\000\000\000\000 */
{ 120835 }, /* pm_cmplu_stall_bru_cru\000\000other\000Completion stall due to IFU\000event=0x2d018\000\000\000\000\000\000\000 */
{ 120913 }, /* pm_cmplu_stall_coq_full\000\000other\000Completion stall due to CO q full\000event=0x30026\000\000\000\000\000\000\000 */
{ 125145 }, /* pm_cmplu_stall_flush\000\000other\000completion stall due to flush by own thread\000event=0x30038\000\000\000\000\000\000\000 */
{ 128420 }, /* pm_cmplu_stall_mem_ecc_delay\000\000other\000Completion stall due to mem ECC delay\000event=0x30028\000\000\000\000\000\000\000 */
{ 129069 }, /* pm_cmplu_stall_no_ntf\000\000other\000Completion stall due to nop\000event=0x2e01c\000\000\000\000\000\000\000 */
{ 129367 }, /* pm_cmplu_stall_ntcg_flush\000\000other\000Completion stall due to ntcg flush\000event=0x2e01e\000\000\000\000\000\000Completion stall due to reject (load hit store)\000 */
{ 130249 }, /* pm_cmplu_stall_rej_lmq_full\000\000other\000Completion stall due to LSU reject LMQ full\000event=0x4c014\000\000\000\000\000\000\000 */
{ 130348 }, /* pm_cmplu_stall_reject\000\000other\000Completion stall due to LSU reject\000event=0x4c010\000\000\000\000\000\000\000 */
{ 130432 }, /* pm_cmplu_stall_reject_lhs\000\000other\000Completion stall due to reject (load hit store)\000event=0x2c01a\000\000\000\000\000\000\000 */
{ 130533 }, /* pm_cmplu_stall_scalar\000\000other\000Completion stall due to VSU scalar instruction\000event=0x4d010\000\000\000\000\000\000\000 */
{ 130629 }, /* pm_cmplu_stall_scalar_long\000\000other\000Completion stall due to VSU scalar long latency instruction\000event=0x2d010\000\000\000\000\000\000\000 */
{ 131541 }, /* pm_cmplu_stall_store\000\000other\000Completion stall by stores this includes store agen finishes in pipe LS0/LS1 and store data finishes in LS2/LS3\000event=0x2c014\000\000\000\000\000\000\000 */
{ 133915 }, /* pm_cmplu_stall_vector\000\000other\000Completion stall due to VSU vector instruction\000event=0x2d014\000\000\000\000\000\000\000 */
{ 134011 }, /* pm_cmplu_stall_vector_long\000\000other\000Completion stall due to VSU vector long instruction\000event=0x4d012\000\000\000\000\000\000\000 */
{ 134462 }, /* pm_cmplu_stall_vsu\000\000other\000Completion stall due to VSU instruction\000event=0x2d012\000\000\000\000\000\000\000 */
{ 134548 }, /* pm_co0_alloc\000\000other\000CO mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16083\000\000\000\000\000\0000.0\000 */
{ 134795 }, /* pm_co0_busy\000\000other\000CO mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16082\000\000\000\000\000\000\000 */
{ 135432 }, /* pm_co_usage\000\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 CO machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x3608a\000\000\000\000\000\000\000 */
{ 135653 }, /* pm_cru_fin\000\000other\000IFU Finished a (non-branch) instruction\000event=0x40066\000\000\000\000\000\000\000 */
{ 137157 }, /* pm_data_all_chip_pump_cpred\000\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for either demand loads or data prefetch\000event=0x61c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for a demand load\000 */
{ 137434 }, /* pm_data_all_from_dl2l3_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either demand loads or data prefetch\000event=0x64c048\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 137904 }, /* pm_data_all_from_dl2l3_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either demand loads or data prefetch\000event=0x63c048\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 138370 }, /* pm_data_all_from_dl4\000\000other\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either demand loads or data prefetch\000event=0x63c04c\000\000\000\000\000\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 138748 }, /* pm_data_all_from_dmem\000\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either demand loads or data prefetch\000event=0x64c04c\000\000\000\000\000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 139893 }, /* pm_data_all_from_l2\000\000other\000The processor's data cache was reloaded from local core's L2 due to either demand loads or data prefetch\000event=0x61c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 139129 }, /* pm_data_all_from_l21_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either demand loads or data prefetch\000event=0x64c046\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 139513 }, /* pm_data_all_from_l21_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either demand loads or data prefetch\000event=0x63c046\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 140188 }, /* pm_data_all_from_l2_disp_conflict_ldhitst\000\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either demand loads or data prefetch\000event=0x63c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 140563 }, /* pm_data_all_from_l2_disp_conflict_other\000\000other\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either demand loads or data prefetch\000event=0x64c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 140924 }, /* pm_data_all_from_l2_mepf\000\000other\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either demand loads or data prefetch\000event=0x62c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 141314 }, /* pm_data_all_from_l2_no_conflict\000\000other\000The processor's data cache was reloaded from local core's L2 without conflict due to either demand loads or data prefetch\000event=0x61c040\000\000\000\000\000\000The processor's data cache was reloaded from local core's L2 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 141655 }, /* pm_data_all_from_l2miss_mod\000\000other\000The processor's data cache was reloaded from a location other than the local core's L2 due to either demand loads or data prefetch\000event=0x61c04e\000\000\000\000\000\000The processor's data cache was reloaded from a location other than the local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 143562 }, /* pm_data_all_from_l3\000\000other\000The processor's data cache was reloaded from local core's L3 due to either demand loads or data prefetch\000event=0x64c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 142010 }, /* pm_data_all_from_l31_eco_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either demand loads or data prefetch\000event=0x64c044\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 142406 }, /* pm_data_all_from_l31_eco_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either demand loads or data prefetch\000event=0x63c044\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 142798 }, /* pm_data_all_from_l31_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either demand loads or data prefetch\000event=0x62c044\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 143182 }, /* pm_data_all_from_l31_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either demand loads or data prefetch\000event=0x61c046\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 143857 }, /* pm_data_all_from_l3_disp_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either demand loads or data prefetch\000event=0x63c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 144212 }, /* pm_data_all_from_l3_mepf\000\000other\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either demand loads or data prefetch\000event=0x62c042\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 144602 }, /* pm_data_all_from_l3_no_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 without conflict due to either demand loads or data prefetch\000event=0x61c044\000\000\000\000\000\000The processor's data cache was reloaded from local core's L3 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 144943 }, /* pm_data_all_from_l3miss_mod\000\000other\000The processor's data cache was reloaded from a location other than the local core's L3 due to either demand loads or data prefetch\000event=0x64c04e\000\000\000\000\000\000The processor's data cache was reloaded from a location other than the local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 145298 }, /* pm_data_all_from_ll4\000\000other\000The processor's data cache was reloaded from the local chip's L4 cache due to either demand loads or data prefetch\000event=0x61c04c\000\000\000\000\000\000The processor's data cache was reloaded from the local chip's L4 cache due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 145614 }, /* pm_data_all_from_lmem\000\000other\000The processor's data cache was reloaded from the local chip's Memory due to either demand loads or data prefetch\000event=0x62c048\000\000\000\000\000\000The processor's data cache was reloaded from the local chip's Memory due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 145927 }, /* pm_data_all_from_memory\000\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either demand loads or data prefetch\000event=0x62c04c\000\000\000\000\000\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 146314 }, /* pm_data_all_from_off_chip_cache\000\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either demand loads or data prefetch\000event=0x64c04a\000\000\000\000\000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 146773 }, /* pm_data_all_from_on_chip_cache\000\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either demand loads or data prefetch\000event=0x61c048\000\000\000\000\000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 147185 }, /* pm_data_all_from_rl2l3_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either demand loads or data prefetch\000event=0x62c046\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 147647 }, /* pm_data_all_from_rl2l3_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either demand loads or data prefetch\000event=0x61c04a\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 148105 }, /* pm_data_all_from_rl4\000\000other\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either demand loads or data prefetch\000event=0x62c04a\000\000\000\000\000\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 148477 }, /* pm_data_all_from_rmem\000\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either demand loads or data prefetch\000event=0x63c04a\000\000\000\000\000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 148858 }, /* pm_data_all_grp_pump_cpred\000\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for either demand loads or data prefetch\000event=0x62c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for a demand load\000 */
{ 149115 }, /* pm_data_all_grp_pump_mpred\000\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for either demand loads or data prefetch\000event=0x62c052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 149544 }, /* pm_data_all_grp_pump_mpred_rty\000\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for either demand loads or data prefetch\000event=0x61c052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor a demand load\000 */
{ 149881 }, /* pm_data_all_pump_cpred\000\000other\000Pump prediction correct. Counts across all types of pumps for either demand loads or data prefetch\000event=0x61c054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumps for a demand load\000 */
{ 150106 }, /* pm_data_all_pump_mpred\000\000other\000Pump misprediction. Counts across all types of pumps for either demand loads or data prefetch\000event=0x64c052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor a demand load\000 */
{ 150320 }, /* pm_data_all_sys_pump_cpred\000\000other\000Initial and Final Pump Scope was system pump (prediction=correct) for either demand loads or data prefetch\000event=0x63c050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for a demand load\000 */
{ 150579 }, /* pm_data_all_sys_pump_mpred\000\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for either demand loads or data prefetch\000event=0x63c052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 151090 }, /* pm_data_all_sys_pump_mpred_rty\000\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for either demand loads or data prefetch\000event=0x64c050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for a demand load\000 */
{ 154130 }, /* pm_data_from_l21_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a demand load\000event=0x4c046\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 154664 }, /* pm_data_from_l21_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a demand load\000event=0x3c046\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 158622 }, /* pm_data_from_l31_eco_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a demand load\000event=0x4c044\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 159169 }, /* pm_data_from_l31_eco_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a demand load\000event=0x3c044\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 159706 }, /* pm_data_from_l31_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a demand load\000event=0x2c044\000\000\000\000\000\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 160233 }, /* pm_data_from_l31_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a demand load\000event=0x1c046\000\000\000\000\000\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 164166 }, /* pm_data_from_mem\000\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x400fe\000\000\000\000\000\000Data cache reload from memory (including L4)\000 */
{ 172369 }, /* pm_dc_collisions\000\000other\000DATA Cache collisions\000event=0xe0bc\000\000\000\000\000\000DATA Cache collisions42\000 */
{ 173631 }, /* pm_dc_pref_stream_alloc\000\000other\000Stream marked valid. The stream could have been allocated through the hardware prefetch mechanism or through software. This is combined ls0 and ls1\000event=0x1e050\000\000\000\000\000\000\000 */
{ 173830 }, /* pm_dc_pref_stream_conf\000\000other\000A demand load referenced a line in an active prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software. Combine up + down\000event=0x2e050\000\000\000\000\000\000\000 */
{ 174058 }, /* pm_dc_pref_stream_fuzzy_conf\000\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0x4e050\000\000\000\000\000\000\000 */
{ 174343 }, /* pm_dc_pref_stream_strided_conf\000\000other\000A demand load referenced a line in an active strided prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software\000event=0x3e050\000\000\000\000\000\000\000 */
{ 177525 }, /* pm_dfu\000\000other\000Finish DFU (all finish)\000event=0xb0ba\000\000\000\000\000\000\000 */
{ 177716 }, /* pm_dfu_dcffix\000\000other\000Convert from fixed opcode finish (dcffix,dcffixq)\000event=0xb0be\000\000\000\000\000\000\000 */
{ 177806 }, /* pm_dfu_denbcd\000\000other\000BCD->DPD opcode finish (denbcd, denbcdq)\000event=0xb0bc\000\000\000\000\000\000\000 */
{ 177887 }, /* pm_dfu_mc\000\000other\000Finish DFU multicycle\000event=0xb0b8\000\000\000\000\000\000\000 */
{ 178025 }, /* pm_disp_clb_held_bal\000\000other\000Dispatch/CLB Hold: Balance\000event=0x2092\000\000\000\000\000\000\000 */
{ 178099 }, /* pm_disp_clb_held_res\000\000other\000Dispatch/CLB Hold: Resource\000event=0x2094\000\000\000\000\000\000\000 */
{ 178250 }, /* pm_disp_clb_held_sb\000\000other\000Dispatch/CLB Hold: Scoreboard\000event=0x20a8\000\000\000\000\000\000\000 */
{ 178326 }, /* pm_disp_clb_held_sync\000\000other\000Dispatch/CLB Hold: Sync type instruction\000event=0x2098\000\000\000\000\000\000\000 */
{ 178415 }, /* pm_disp_clb_held_tlbie\000\000other\000Dispatch Hold: Due to TLBIE\000event=0x2096\000\000\000\000\000\000\000 */
{ 178775 }, /* pm_disp_held_iq_full\000\000other\000Dispatch held due to Issue q full\000event=0x20006\000\000\000\000\000\000\000 */
{ 178980 }, /* pm_disp_held_map_full\000\000other\000Dispatch for this thread was held because the Mappers were full\000event=0x1002a\000\000\000\000\000\000Dispatch held due to Mapper full\000 */
{ 179125 }, /* pm_disp_held_srq_full\000\000other\000Dispatch held due SRQ no room\000event=0x30018\000\000\000\000\000\000\000 */
{ 179431 }, /* pm_disp_hold_gct_full\000\000other\000Dispatch Hold Due to no space in the GCT\000event=0x30a6\000\000\000\000\000\000\000 */
{ 184097 }, /* pm_disp_wt\000\000other\000Dispatched Starved\000event=0x30008\000\000\000\000\000\000Dispatched Starved (not held, nothing to dispatch)\000 */
{ 186465 }, /* pm_dpteg_from_l21_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a data side request\000event=0x4e046\000\000\000\000\000\000\000 */
{ 186931 }, /* pm_dpteg_from_l21_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a data side request\000event=0x3e046\000\000\000\000\000\000\000 */
{ 187769 }, /* pm_dpteg_from_l2_disp_conflict_ldhitst\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a data side request\000event=0x3e040\000\000\000\000\000\000\000 */
{ 187955 }, /* pm_dpteg_from_l2_disp_conflict_other\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a data side request\000event=0x4e040\000\000\000\000\000\000\000 */
{ 189770 }, /* pm_dpteg_from_l31_eco_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a data side request\000event=0x4e044\000\000\000\000\000\000\000 */
{ 190248 }, /* pm_dpteg_from_l31_eco_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a data side request\000event=0x3e044\000\000\000\000\000\000\000 */
{ 190718 }, /* pm_dpteg_from_l31_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a data side request\000event=0x2e044\000\000\000\000\000\000\000 */
{ 191180 }, /* pm_dpteg_from_l31_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a data side request\000event=0x1e046\000\000\000\000\000\000\000 */
{ 201588 }, /* pm_eat_force_mispred\000\000other\000XL-form branch was mispredicted due to the predicted target address missing from EAT. The EAT forces a mispredict in this case since there is no predicated target to validate. This is a rare case that may occur when the EAT is full and a branch is issue\000event=0x50a8\000\000\000\000\000\000\000 */
{ 201889 }, /* pm_eat_full_cyc\000\000other\000Cycles No room in EAT\000event=0x4084\000\000\000\000\000\000Cycles No room in EATSet on bank conflict and case where no ibuffers available\000 */
{ 202195 }, /* pm_ee_off_ext_int\000\000other\000Ee off and external interrupt\000event=0x2080\000\000\000\000\000\000\000 */
{ 208088 }, /* pm_fav_tbegin\000\000other\000Dispatch time Favored tbegin\000event=0x20b4\000\000\000\000\000\000\000 */
{ 208157 }, /* pm_flop\000\000other\000Floating Point Operation Finished\000event=0x100f4\000\000\000\000\000\000Floating Point Operations Finished\000 */
{ 208536 }, /* pm_flop_sum_scalar\000\000other\000flops summary scalar instructions\000event=0xa0ae\000\000\000\000\000\000\000 */
{ 208615 }, /* pm_flop_sum_vec\000\000other\000flops summary vector instructions\000event=0xa0ac\000\000\000\000\000\000\000 */
{ 208747 }, /* pm_flush_br_mpred\000\000other\000Flush caused by branch mispredict\000event=0x2084\000\000\000\000\000\000\000 */
{ 209197 }, /* pm_flush_disp\000\000other\000Dispatch flush\000event=0x2082\000\000\000\000\000\000\000 */
{ 209377 }, /* pm_flush_disp_sb\000\000other\000Dispatch Flush: Scoreboard\000event=0x208c\000\000\000\000\000\000\000 */
{ 209447 }, /* pm_flush_disp_sync\000\000other\000Dispatch Flush: Sync\000event=0x2088\000\000\000\000\000\000\000 */
{ 209513 }, /* pm_flush_disp_tlbie\000\000other\000Dispatch Flush: TLBIE\000event=0x208a\000\000\000\000\000\000\000 */
{ 209804 }, /* pm_flush_lsu\000\000other\000Flush initiated by LSU\000event=0x208e\000\000\000\000\000\000\000 */
{ 210176 }, /* pm_flush_partial\000\000other\000Partial flush\000event=0x2086\000\000\000\000\000\000\000 */
{ 210527 }, /* pm_fpu0_fconv\000\000other\000Convert instruction executed\000event=0xa0b0\000\000\000\000\000\000\000 */
{ 210596 }, /* pm_fpu0_fest\000\000other\000Estimate instruction executed\000event=0xa0b8\000\000\000\000\000\000\000 */
{ 210665 }, /* pm_fpu0_frsp\000\000other\000Round to single precision instruction executed\000event=0xa0b4\000\000\000\000\000\000\000 */
{ 210751 }, /* pm_fpu1_fconv\000\000other\000Convert instruction executed\000event=0xa0b2\000\000\000\000\000\000\000 */
{ 210820 }, /* pm_fpu1_fest\000\000other\000Estimate instruction executed\000event=0xa0ba\000\000\000\000\000\000\000 */
{ 210889 }, /* pm_fpu1_frsp\000\000other\000Round to single precision instruction executed\000event=0xa0b6\000\000\000\000\000\000\000 */
{ 211386 }, /* pm_fusion_toc_grp0_1\000\000other\000One pair of instructions fused with TOC in Group0\000event=0x50b0\000\000\000\000\000\000\000 */
{ 211483 }, /* pm_fusion_toc_grp0_2\000\000other\000Two pairs of instructions fused with TOCin Group0\000event=0x50ae\000\000\000\000\000\000\000 */
{ 211580 }, /* pm_fusion_toc_grp0_3\000\000other\000Three pairs of instructions fused with TOC in Group0\000event=0x50ac\000\000\000\000\000\000\000 */
{ 211680 }, /* pm_fusion_toc_grp1_1\000\000other\000One pair of instructions fused with TOX in Group1\000event=0x50b2\000\000\000\000\000\000\000 */
{ 211777 }, /* pm_fusion_vsx_grp0_1\000\000other\000One pair of instructions fused with VSX in Group0\000event=0x50b8\000\000\000\000\000\000\000 */
{ 211874 }, /* pm_fusion_vsx_grp0_2\000\000other\000Two pairs of instructions fused with VSX in Group0\000event=0x50b6\000\000\000\000\000\000\000 */
{ 211972 }, /* pm_fusion_vsx_grp0_3\000\000other\000Three pairs of instructions fused with VSX in Group0\000event=0x50b4\000\000\000\000\000\000\000 */
{ 212072 }, /* pm_fusion_vsx_grp1_1\000\000other\000One pair of instructions fused with VSX in Group1\000event=0x50ba\000\000\000\000\000\000\000 */
{ 212294 }, /* pm_fxu0_busy_fxu1_idle\000\000other\000fxu0 busy and fxu1 idle\000event=0x3000e\000\000\000\000\000\000\000 */
{ 212368 }, /* pm_fxu0_fin\000\000other\000The fixed point unit Unit 0 finished an instruction. Instructions that finish may not necessary complete\000event=0x10004\000\000\000\000\000\000FXU0 Finished\000 */
{ 212525 }, /* pm_fxu1_busy_fxu0_idle\000\000other\000fxu0 idle and fxu1 busy\000event=0x4000e\000\000\000\000\000\000\000 */
{ 212599 }, /* pm_fxu1_fin\000\000other\000FXU1 Finished\000event=0x40004\000\000\000\000\000\000\000 */
{ 213325 }, /* pm_gct_empty_cyc\000\000other\000No itags assigned either thread (GCT Empty)\000event=0x20008\000\000\000\000\000\000\000 */
{ 213413 }, /* pm_gct_merge\000\000other\000Group dispatched on a merged GCT empty. GCT entries can be merged only within the same thread\000event=0x30a4\000\000\000\000\000\000\000 */
{ 213546 }, /* pm_gct_noslot_br_mpred\000\000other\000Gct empty for this thread due to branch mispred\000event=0x4d01e\000\000\000\000\000\000\000 */
{ 213644 }, /* pm_gct_noslot_br_mpred_icmiss\000\000other\000Gct empty for this thread due to Icache Miss and branch mispred\000event=0x4d01a\000\000\000\000\000\000\000 */
{ 213765 }, /* pm_gct_noslot_cyc\000\000other\000No itags assigned\000event=0x100f8\000\000\000\000\000\000Pipeline empty (No itags assigned , no GCT slots used)\000 */
{ 213882 }, /* pm_gct_noslot_disp_held_issq\000\000other\000Gct empty for this thread due to dispatch hold on this thread due to Issue q full\000event=0x2d01e\000\000\000\000\000\000\000 */
{ 214020 }, /* pm_gct_noslot_disp_held_map\000\000other\000Gct empty for this thread due to dispatch hold on this thread due to Mapper full\000event=0x4d01c\000\000\000\000\000\000\000 */
{ 214156 }, /* pm_gct_noslot_disp_held_other\000\000other\000Gct empty for this thread due to dispatch hold on this thread due to sync\000event=0x2e010\000\000\000\000\000\000\000 */
{ 214287 }, /* pm_gct_noslot_disp_held_srq\000\000other\000Gct empty for this thread due to dispatch hold on this thread due to SRQ full\000event=0x2d01c\000\000\000\000\000\000\000 */
{ 214420 }, /* pm_gct_noslot_ic_l3miss\000\000other\000Gct empty for this thread due to icache l3 miss\000event=0x4e010\000\000\000\000\000\000\000 */
{ 214519 }, /* pm_gct_noslot_ic_miss\000\000other\000Gct empty for this thread due to Icache Miss\000event=0x2d01a\000\000\000\000\000\000\000 */
{ 214613 }, /* pm_gct_util_11_14_entries\000\000other\000GCT Utilization 11-14 entries\000event=0x20a2\000\000\000\000\000\000\000 */
{ 214695 }, /* pm_gct_util_15_17_entries\000\000other\000GCT Utilization 15-17 entries\000event=0x20a4\000\000\000\000\000\000\000 */
{ 214777 }, /* pm_gct_util_18_entries\000\000other\000GCT Utilization 18+ entries\000event=0x20a6\000\000\000\000\000\000\000 */
{ 214854 }, /* pm_gct_util_1_2_entries\000\000other\000GCT Utilization 1-2 entries\000event=0x209c\000\000\000\000\000\000\000 */
{ 214932 }, /* pm_gct_util_3_6_entries\000\000other\000GCT Utilization 3-6 entries\000event=0x209e\000\000\000\000\000\000\000 */
{ 215010 }, /* pm_gct_util_7_10_entries\000\000other\000GCT Utilization 7-10 entries\000event=0x20a0\000\000\000\000\000\000\000 */
{ 215090 }, /* pm_grp_br_mpred_nonspec\000\000other\000Group experienced non-speculative branch redirect\000event=0x1000a\000\000\000\000\000\000Group experienced Non-speculative br mispredicct\000 */
{ 215239 }, /* pm_grp_cmpl\000\000other\000group completed\000event=0x30004\000\000\000\000\000\000\000 */
{ 215294 }, /* pm_grp_disp\000\000other\000group dispatch\000event=0x3000a\000\000\000\000\000\000dispatch_success (Group Dispatched)\000 */
{ 215383 }, /* pm_grp_ic_miss_nonspec\000\000other\000Group experienced non-speculative I cache miss\000event=0x1000c\000\000\000\000\000\000Group experi enced Non-specu lative I cache miss\000 */
{ 215528 }, /* pm_grp_mrk\000\000other\000Instruction Marked\000event=0x10130\000\000\000\000\000\000Instruction marked in idu\000 */
{ 215610 }, /* pm_grp_non_full_group\000\000other\000GROUPs where we did not have 6 non branch instructions in the group(ST mode), in SMT mode 3 non branches\000event=0x509c\000\000\000\000\000\000\000 */
{ 217529 }, /* pm_grp_term_2nd_branch\000\000other\000There were enough instructions in the Ibuffer, but 2nd branch ends group\000event=0x50a4\000\000\000\000\000\000\000 */
{ 217651 }, /* pm_grp_term_fpu_after_br\000\000other\000There were enough instructions in the Ibuffer, but FPU OP IN same group after a branch terminates a group, cant do partial flushes\000event=0x50a6\000\000\000\000\000\000\000 */
{ 217833 }, /* pm_grp_term_noinst\000\000other\000Do not fill every slot in the group, Not enough instructions in the Ibuffer. This includes cases where the group started with enough instructions, but some got knocked out by a cache miss or branch redirect (which would also empty the Ibuffer)\000event=0x509e\000\000\000\000\000\000\000 */
{ 218122 }, /* pm_grp_term_other\000\000other\000There were enough instructions in the Ibuffer, but the group terminated early for some other reason, most likely due to a First or Last\000event=0x50a0\000\000\000\000\000\000\000 */
{ 218302 }, /* pm_grp_term_slot_limit\000\000other\000There were enough instructions in the Ibuffer, but 3 src RA/RB/RC , 2 way crack caused a group termination\000event=0x50a2\000\000\000\000\000\000\000 */
{ 219074 }, /* pm_ibuf_full_cyc\000\000other\000Cycles No room in ibuff\000event=0x4086\000\000\000\000\000\000Cycles No room in ibufffully qualified transfer (if5 valid)\000 */
{ 219569 }, /* pm_ic_demand_l2_bht_redirect\000\000other\000L2 I cache demand request due to BHT redirect, branch redirect ( 2 bubbles 3 cycles)\000event=0x4098\000\000\000\000\000\000\000 */
{ 219709 }, /* pm_ic_demand_l2_br_redirect\000\000other\000L2 I cache demand request due to branch Mispredict ( 15 cycle path)\000event=0x409a\000\000\000\000\000\000\000 */
{ 219953 }, /* pm_ic_demand_req\000\000other\000Demand Instruction fetch request\000event=0x4088\000\000\000\000\000\000\000 */
{ 220029 }, /* pm_ic_invalidate\000\000other\000Ic line invalidated\000event=0x508a\000\000\000\000\000\000\000 */
{ 220395 }, /* pm_ic_pref_cancel_hit\000\000other\000Prefetch Canceled due to icache hit\000event=0x4092\000\000\000\000\000\000\000 */
{ 220651 }, /* pm_ic_pref_cancel_l2\000\000other\000L2 Squashed request\000event=0x4094\000\000\000\000\000\000\000 */
{ 220718 }, /* pm_ic_pref_cancel_page\000\000other\000Prefetch Canceled due to page boundary\000event=0x4090\000\000\000\000\000\000\000 */
{ 220806 }, /* pm_ic_pref_req\000\000other\000Instruction prefetch requests\000event=0x408a\000\000\000\000\000\000\000 */
{ 220948 }, /* pm_ic_pref_write\000\000other\000Instruction prefetch written into IL1\000event=0x408e\000\000\000\000\000\000\000 */
{ 221413 }, /* pm_ic_reload_private\000\000other\000Reloading line was brought in private for a specific thread. Most lines are brought in shared for all eight thrreads. If RA does not match then invalidates and then brings it shared to other thread. In P7 line brought in private , then line was invalidat\000event=0x4096\000\000\000\000\000\000\000 */
{ 224505 }, /* pm_ifu_l2_touch\000\000other\000L2 touch to update MRU on a line\000event=0x5088\000\000\000\000\000\000\000 */
{ 224580 }, /* pm_inst_all_chip_pump_cpred\000\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for instruction fetches and prefetches\000event=0x514050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for an instruction fetch\000 */
{ 224862 }, /* pm_inst_all_from_dl2l3_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to instruction fetches and prefetches\000event=0x544048\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 225350 }, /* pm_inst_all_from_dl2l3_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to instruction fetches and prefetches\000event=0x534048\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 225834 }, /* pm_inst_all_from_dl4\000\000other\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to instruction fetches and prefetches\000event=0x53404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 226230 }, /* pm_inst_all_from_dmem\000\000other\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to instruction fetches and prefetches\000event=0x54404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 227429 }, /* pm_inst_all_from_l2\000\000other\000The processor's Instruction cache was reloaded from local core's L2 due to instruction fetches and prefetches\000event=0x514042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 226629 }, /* pm_inst_all_from_l21_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to instruction fetches and prefetches\000event=0x544046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 227031 }, /* pm_inst_all_from_l21_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to instruction fetches and prefetches\000event=0x534046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 227742 }, /* pm_inst_all_from_l2_disp_conflict_ldhitst\000\000other\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to instruction fetches and prefetches\000event=0x534040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 228135 }, /* pm_inst_all_from_l2_disp_conflict_other\000\000other\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to instruction fetches and prefetches\000event=0x544040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 228514 }, /* pm_inst_all_from_l2_mepf\000\000other\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to instruction fetches and prefetches\000event=0x524040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 228924 }, /* pm_inst_all_from_l2_no_conflict\000\000other\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to instruction fetches and prefetches\000event=0x514040\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 229283 }, /* pm_inst_all_from_l2miss\000\000other\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to instruction fetches and prefetches\000event=0x51404e\000\000\000\000\000\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 231276 }, /* pm_inst_all_from_l3\000\000other\000The processor's Instruction cache was reloaded from local core's L3 due to instruction fetches and prefetches\000event=0x544042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 229652 }, /* pm_inst_all_from_l31_eco_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to instruction fetches and prefetches\000event=0x544044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 230066 }, /* pm_inst_all_from_l31_eco_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to instruction fetches and prefetches\000event=0x534044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 230476 }, /* pm_inst_all_from_l31_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to instruction fetches and prefetches\000event=0x524044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 230878 }, /* pm_inst_all_from_l31_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to instruction fetches and prefetches\000event=0x514046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 231589 }, /* pm_inst_all_from_l3_disp_conflict\000\000other\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to instruction fetches and prefetches\000event=0x534042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 231962 }, /* pm_inst_all_from_l3_mepf\000\000other\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to instruction fetches and prefetches\000event=0x524042\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 232372 }, /* pm_inst_all_from_l3_no_conflict\000\000other\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to instruction fetches and prefetches\000event=0x514044\000\000\000\000\000\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 232731 }, /* pm_inst_all_from_l3miss_mod\000\000other\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x54404e\000\000\000\000\000\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 233089 }, /* pm_inst_all_from_ll4\000\000other\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to instruction fetches and prefetches\000event=0x51404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 233423 }, /* pm_inst_all_from_lmem\000\000other\000The processor's Instruction cache was reloaded from the local chip's Memory due to instruction fetches and prefetches\000event=0x524048\000\000\000\000\000\000The processor's Instruction cache was reloaded from the local chip's Memory due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 233754 }, /* pm_inst_all_from_memory\000\000other\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to instruction fetches and prefetches\000event=0x52404c\000\000\000\000\000\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 234159 }, /* pm_inst_all_from_off_chip_cache\000\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to instruction fetches and prefetches\000event=0x54404a\000\000\000\000\000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 234636 }, /* pm_inst_all_from_on_chip_cache\000\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to instruction fetches and prefetches\000event=0x514048\000\000\000\000\000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 235066 }, /* pm_inst_all_from_rl2l3_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to instruction fetches and prefetches\000event=0x524046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 235546 }, /* pm_inst_all_from_rl2l3_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to instruction fetches and prefetches\000event=0x51404a\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 236022 }, /* pm_inst_all_from_rl4\000\000other\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to instruction fetches and prefetches\000event=0x52404a\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 236412 }, /* pm_inst_all_from_rmem\000\000other\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to instruction fetches and prefetches\000event=0x53404a\000\000\000\000\000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 236811 }, /* pm_inst_all_grp_pump_cpred\000\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for instruction fetches and prefetches\000event=0x524050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was group pump for an instruction fetch\000 */
{ 237073 }, /* pm_inst_all_grp_pump_mpred\000\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for instruction fetches and prefetches\000event=0x524052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 237500 }, /* pm_inst_all_grp_pump_mpred_rty\000\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for instruction fetches and prefetches\000event=0x514052\000\000\000\000\000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor an instruction fetch\000 */
{ 237842 }, /* pm_inst_all_pump_cpred\000\000other\000Pump prediction correct. Counts across all types of pumps for instruction fetches and prefetches\000event=0x514054\000\000\000\000\000\000Pump prediction correct. Counts across all types of pumpsfor an instruction fetch\000 */
{ 238071 }, /* pm_inst_all_pump_mpred\000\000other\000Pump misprediction. Counts across all types of pumps for instruction fetches and prefetches\000event=0x544052\000\000\000\000\000\000Pump Mis prediction Counts across all types of pumpsfor an instruction fetch\000 */
{ 238290 }, /* pm_inst_all_sys_pump_cpred\000\000other\000Initial and Final Pump Scope was system pump (prediction=correct) for instruction fetches and prefetches\000event=0x534050\000\000\000\000\000\000Initial and Final Pump Scope and data sourced across this scope was system pump for an instruction fetch\000 */
{ 238554 }, /* pm_inst_all_sys_pump_mpred\000\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for instruction fetches and prefetches\000event=0x534052\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 239063 }, /* pm_inst_all_sys_pump_mpred_rty\000\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for instruction fetches and prefetches\000event=0x544050\000\000\000\000\000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for an instruction fetch\000 */
{ 243046 }, /* pm_inst_from_l1\000\000other\000Instruction fetches from L1\000event=0x4080\000\000\000\000\000\000\000 */
{ 243116 }, /* pm_inst_from_l21_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x44046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 243715 }, /* pm_inst_from_l21_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x34046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 247669 }, /* pm_inst_from_l31_eco_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x44044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 248496 }, /* pm_inst_from_l31_eco_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x34044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 249104 }, /* pm_inst_from_l31_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x24044\000\000\000\000\000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 249702 }, /* pm_inst_from_l31_shr\000\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14046\000\000\000\000\000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 260474 }, /* pm_inst_imc_match_disp\000\000other\000Matched Instructions Dispatched\000event=0x30016\000\000\000\000\000\000IMC Matches dispatched\000 */
{ 263169 }, /* pm_iops_disp\000\000other\000Internal Operations dispatched\000event=0x30014\000\000\000\000\000\000IOPS dispatched\000 */
{ 264892 }, /* pm_ipteg_from_l21_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a instruction side request\000event=0x45046\000\000\000\000\000\000\000 */
{ 265269 }, /* pm_ipteg_from_l21_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a instruction side request\000event=0x35046\000\000\000\000\000\000\000 */
{ 265744 }, /* pm_ipteg_from_l2_disp_conflict_ldhitst\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a instruction side request\000event=0x35040\000\000\000\000\000\000\000 */
{ 265937 }, /* pm_ipteg_from_l2_disp_conflict_other\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a instruction side request\000event=0x45040\000\000\000\000\000\000\000 */
{ 267405 }, /* pm_ipteg_from_l31_eco_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x45044\000\000\000\000\000\000\000 */
{ 267800 }, /* pm_ipteg_from_l31_eco_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x35044\000\000\000\000\000\000\000 */
{ 268187 }, /* pm_ipteg_from_l31_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a instruction side request\000event=0x25044\000\000\000\000\000\000\000 */
{ 268566 }, /* pm_ipteg_from_l31_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a instruction side request\000event=0x15046\000\000\000\000\000\000\000 */
{ 274247 }, /* pm_iside_l2memacc\000\000other\000valid when first beat of data comes in for an i-side fetch where data came from mem(or L4)\000event=0x4608e\000\000\000\000\000\000\000 */
{ 275811 }, /* pm_isu_ref_fx0\000\000other\000FX0 ISU reject\000event=0x30ac\000\000\000\000\000\000\000 */
{ 275867 }, /* pm_isu_ref_fx1\000\000other\000FX1 ISU reject\000event=0x30ae\000\000\000\000\000\000\000 */
{ 275923 }, /* pm_isu_ref_fxu\000\000other\000FXU ISU reject from either pipe\000event=0x38ac\000\000\000\000\000\000\000 */
{ 275996 }, /* pm_isu_ref_ls0\000\000other\000LS0 ISU reject\000event=0x30b0\000\000\000\000\000\000\000 */
{ 276052 }, /* pm_isu_ref_ls1\000\000other\000LS1 ISU reject\000event=0x30b2\000\000\000\000\000\000\000 */
{ 276108 }, /* pm_isu_ref_ls2\000\000other\000LS2 ISU reject\000event=0x30b4\000\000\000\000\000\000\000 */
{ 276164 }, /* pm_isu_ref_ls3\000\000other\000LS3 ISU reject\000event=0x30b6\000\000\000\000\000\000\000 */
{ 276220 }, /* pm_isu_rej_vs0\000\000other\000VS0 ISU reject\000event=0x30a8\000\000\000\000\000\000\000 */
{ 276276 }, /* pm_isu_rej_vs1\000\000other\000VS1 ISU reject\000event=0x30aa\000\000\000\000\000\000\000 */
{ 276332 }, /* pm_isu_rej_vsu\000\000other\000VSU ISU reject from either pipe\000event=0x38a8\000\000\000\000\000\000\000 */
{ 276405 }, /* pm_isu_reject_res_na\000\000other\000ISU reject due to resource not available\000event=0x30a2\000\000\000\000\000\000\000 */
{ 276493 }, /* pm_isu_reject_sar_bypass\000\000other\000Reject because of SAR bypass\000event=0x309e\000\000\000\000\000\000\000 */
{ 276573 }, /* pm_isu_reject_src_na\000\000other\000ISU reject due to source not available\000event=0x30a0\000\000\000\000\000\000\000 */
{ 276659 }, /* pm_isu_rejects_all\000\000other\000All isu rejects could be more than 1 per cycle\000event=0x309c\000\000\000\000\000\000\000 */
{ 276820 }, /* pm_isync\000\000other\000Isync count per thread\000event=0x30b8\000\000\000\000\000\000\000 */
{ 278108 }, /* pm_l1_demand_write\000\000other\000Instruction Demand sectors wriittent into IL1\000event=0x408c\000\000\000\000\000\000\000 */
{ 279227 }, /* pm_l1miss_lat_exc_1024\000\000other\000L1 misses that took longer than 1024 cyles to resolve (miss to reload)\000event=0x200301ea\000\000\000\000\000\000Reload latency exceeded 1024 cyc\000 */
{ 279383 }, /* pm_l1miss_lat_exc_2048\000\000other\000L1 misses that took longer than 2048 cyles to resolve (miss to reload)\000event=0x200401ec\000\000\000\000\000\000Reload latency exceeded 2048 cyc\000 */
{ 279539 }, /* pm_l1miss_lat_exc_256\000\000other\000L1 misses that took longer than 256 cyles to resolve (miss to reload)\000event=0x200101e8\000\000\000\000\000\000Reload latency exceeded 256 cyc\000 */
{ 279692 }, /* pm_l1miss_lat_exc_32\000\000other\000L1 misses that took longer than 32 cyles to resolve (miss to reload)\000event=0x200201e6\000\000\000\000\000\000Reload latency exceeded 32 cyc\000 */
{ 279965 }, /* pm_l1pf_l2memacc\000\000other\000valid when first beat of data comes in for an L1pref where data came from mem(or L4)\000event=0x26086\000\000\000\000\000\000\000 */
{ 280342 }, /* pm_l2_chip_pump\000\000other\000RC requests that were local on chip pump attempts\000event=0x27084\000\000\000\000\000\000\000 */
{ 280685 }, /* pm_l2_group_pump\000\000other\000RC requests that were on Node Pump attempts\000event=0x27086\000\000\000\000\000\000\000 */
{ 284040 }, /* pm_l2_rty_st\000\000other\000RC retries on PB for any store from core\000event=0x3708a\000\000\000\000\000\000\000 */
{ 284599 }, /* pm_l2_st\000\000other\000All successful D-side store dispatches for this thread\000event=0x17080\000\000\000\000\000\000\000 */
{ 285016 }, /* pm_l2_st_miss\000\000other\000All successful D-side store dispatches for this thread that were L2 Miss\000event=0x17082\000\000\000\000\000\000\000 */
{ 285870 }, /* pm_l2_tm_req_abort\000\000other\000TM abort\000event=0x1e05e\000\000\000\000\000\000\000 */
{ 285925 }, /* pm_l2_tm_st_abort_sister\000\000other\000TM marked store abort\000event=0x3e05c\000\000\000\000\000\000\000 */
{ 286220 }, /* pm_l3_ci_usage\000\000other\000rotating sample of 16 CI or CO actives\000event=0x819082\000\000\000\000\000\000\000 */
{ 286366 }, /* pm_l3_co0_alloc\000\000other\000lifetime, sample of CO machine 0 valid\000event=0x83908b\000\000\000\000\000\0000.0\000 */
{ 286533 }, /* pm_l3_co0_busy\000\000other\000lifetime, sample of CO machine 0 valid\000event=0x83908a\000\000\000\000\000\000\000 */
{ 286728 }, /* pm_l3_co_l31\000\000other\000L3 CO to L3.1 OR of port 0 and 1 ( lossy)\000event=0x28086\000\000\000\000\000\000\000 */
{ 287060 }, /* pm_l3_co_mem\000\000other\000L3 CO to memory OR of port 0 and 1 ( lossy)\000event=0x28084\000\000\000\000\000\000\000 */
{ 288413 }, /* pm_l3_ld_pref\000\000other\000L3 Load Prefetches\000event=0x1e052\000\000\000\000\000\000\000 */
{ 291418 }, /* pm_l3_pf0_alloc\000\000other\000lifetime, sample of PF machine 0 valid\000event=0x84908d\000\000\000\000\000\0000.0\000 */
{ 291585 }, /* pm_l3_pf0_busy\000\000other\000lifetime, sample of PF machine 0 valid\000event=0x84908c\000\000\000\000\000\000\000 */
{ 291801 }, /* pm_l3_pf_miss_l3\000\000other\000L3 Prefetch missed in L3\000event=0x18080\000\000\000\000\000\000\000 */
{ 291947 }, /* pm_l3_pf_off_chip_cache\000\000other\000L3 Prefetch from Off chip cache\000event=0x3808a\000\000\000\000\000\000\000 */
{ 292106 }, /* pm_l3_pf_off_chip_mem\000\000other\000L3 Prefetch from Off chip memory\000event=0x4808e\000\000\000\000\000\000\000 */
{ 292263 }, /* pm_l3_pf_on_chip_cache\000\000other\000L3 Prefetch from On chip cache\000event=0x38088\000\000\000\000\000\000\000 */
{ 292418 }, /* pm_l3_pf_on_chip_mem\000\000other\000L3 Prefetch from On chip memory\000event=0x4808c\000\000\000\000\000\000\000 */
{ 292573 }, /* pm_l3_pf_usage\000\000other\000rotating sample of 32 PF actives\000event=0x829084\000\000\000\000\000\000\000 */
{ 292649 }, /* pm_l3_pref_all\000\000other\000Total HW L3 prefetches(Load+store)\000event=0x4e052\000\000\000\000\000\000\000 */
{ 292726 }, /* pm_l3_rd0_alloc\000\000other\000lifetime, sample of RD machine 0 valid\000event=0x84908f\000\000\000\000\000\0000.0\000 */
{ 292893 }, /* pm_l3_rd0_busy\000\000other\000lifetime, sample of RD machine 0 valid\000event=0x84908e\000\000\000\000\000\000\000 */
{ 293050 }, /* pm_l3_rd_usage\000\000other\000rotating sample of 16 RD actives\000event=0x829086\000\000\000\000\000\000\000 */
{ 293126 }, /* pm_l3_sn0_alloc\000\000other\000lifetime, sample of snooper machine 0 valid\000event=0x839089\000\000\000\000\000\0000.0\000 */
{ 293303 }, /* pm_l3_sn0_busy\000\000other\000lifetime, sample of snooper machine 0 valid\000event=0x839088\000\000\000\000\000\000\000 */
{ 293467 }, /* pm_l3_sn_usage\000\000other\000rotating sample of 8 snoop valids\000event=0x819080\000\000\000\000\000\000\000 */
{ 293544 }, /* pm_l3_st_pref\000\000other\000L3 store Prefetches\000event=0x2e052\000\000\000\000\000\000\000 */
{ 293605 }, /* pm_l3_sw_pref\000\000other\000Data stream touchto L3\000event=0x3e052\000\000\000\000\000\000\000 */
{ 294091 }, /* pm_l3_wi0_alloc\000\000other\000lifetime, sample of Write Inject machine 0 valid\000event=0x18081\000\000\000\000\000\0000.0\000 */
{ 296622 }, /* pm_ld_ref_l1_lsu0\000\000other\000LS0 L1 D cache load references counted at finish, gated by reject\000event=0xc080\000\000\000\000\000\000LS0 L1 D cache load references counted at finish, gated by rejectLSU0 L1 D cache load references\000 */
{ 296828 }, /* pm_ld_ref_l1_lsu1\000\000other\000LS1 L1 D cache load references counted at finish, gated by reject\000event=0xc082\000\000\000\000\000\000LS1 L1 D cache load references counted at finish, gated by rejectLSU1 L1 D cache load references\000 */
{ 297034 }, /* pm_ld_ref_l1_lsu2\000\000other\000LS2 L1 D cache load references counted at finish, gated by reject\000event=0xc094\000\000\000\000\000\000LS2 L1 D cache load references counted at finish, gated by reject42\000 */
{ 297211 }, /* pm_ld_ref_l1_lsu3\000\000other\000LS3 L1 D cache load references counted at finish, gated by reject\000event=0xc096\000\000\000\000\000\000LS3 L1 D cache load references counted at finish, gated by reject42\000 */
{ 297470 }, /* pm_link_stack_invalid_ptr\000\000other\000A flush were LS ptr is invalid, results in a pop , A lot of interrupts between push and pops\000event=0x509a\000\000\000\000\000\000\000 */
{ 297987 }, /* pm_link_stack_wrong_add_pred\000\000other\000Link stack predicts wrong address, because of link stack design limitation\000event=0x5098\000\000\000\000\000\000\000 */
{ 298714 }, /* pm_ls0_erat_miss_pref\000\000other\000LS0 Erat miss due to prefetch\000event=0xe080\000\000\000\000\000\000LS0 Erat miss due to prefetch42\000 */
{ 298901 }, /* pm_ls0_l1_pref\000\000other\000LS0 L1 cache data prefetches\000event=0xd0b8\000\000\000\000\000\000LS0 L1 cache data prefetches42\000 */
{ 299001 }, /* pm_ls0_l1_sw_pref\000\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xc098\000\000\000\000\000\000Software L1 Prefetches, including SW Transient Prefetches42\000 */
{ 300358 }, /* pm_ls1_erat_miss_pref\000\000other\000LS1 Erat miss due to prefetch\000event=0xe082\000\000\000\000\000\000LS1 Erat miss due to prefetch42\000 */
{ 300545 }, /* pm_ls1_l1_pref\000\000other\000LS1 L1 cache data prefetches\000event=0xd0ba\000\000\000\000\000\000LS1 L1 cache data prefetches42\000 */
{ 300645 }, /* pm_ls1_l1_sw_pref\000\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xc09a\000\000\000\000\000\000Software L1 Prefetches, including SW Transient Prefetches42\000 */
{ 304294 }, /* pm_lsu0_flush_lrq\000\000other\000LS0 Flush: LRQ\000event=0xc0b0\000\000\000\000\000\000LS0 Flush: LRQLSU0 LRQ flushes\000 */
{ 304383 }, /* pm_lsu0_flush_srq\000\000other\000LS0 Flush: SRQ\000event=0xc0b8\000\000\000\000\000\000LS0 Flush: SRQLSU0 SRQ lhs flushes\000 */
{ 304476 }, /* pm_lsu0_flush_uld\000\000other\000LS0 Flush: Unaligned Load\000event=0xc0a4\000\000\000\000\000\000LS0 Flush: Unaligned LoadLSU0 unaligned load flushes\000 */
{ 304598 }, /* pm_lsu0_flush_ust\000\000other\000LS0 Flush: Unaligned Store\000event=0xc0ac\000\000\000\000\000\000LS0 Flush: Unaligned StoreLSU0 unaligned store flushes\000 */
{ 304723 }, /* pm_lsu0_l1_cam_cancel\000\000other\000ls0 l1 tm cam cancel\000event=0xf088\000\000\000\000\000\000ls0 l1 tm cam cancel42\000 */
{ 304883 }, /* pm_lsu0_larx_fin\000\000other\000Larx finished in LSU pipe0\000event=0x1e056\000\000\000\000\000\000\000 */
{ 305396 }, /* pm_lsu0_lmq_lhr_merge\000\000other\000LS0 Load Merged with another cacheline request\000event=0xd08c\000\000\000\000\000\000LS0 Load Merged with another cacheline request42\000 */
{ 305677 }, /* pm_lsu0_ncld\000\000other\000LS0 Non-cachable Loads counted at finish\000event=0xc08c\000\000\000\000\000\000LS0 Non-cachable Loads counted at finishLSU0 non-cacheable loads\000 */
{ 305821 }, /* pm_lsu0_primary_erat_hit\000\000other\000Primary ERAT hit\000event=0xe090\000\000\000\000\000\000Primary ERAT hit42\000 */
{ 305907 }, /* pm_lsu0_reject\000\000other\000LSU0 reject\000event=0x1e05a\000\000\000\000\000\000\000 */
{ 306032 }, /* pm_lsu0_srq_stfwd\000\000other\000LS0 SRQ forwarded data to a load\000event=0xc09c\000\000\000\000\000\000LS0 SRQ forwarded data to a loadLSU0 SRQ store forwarded\000 */
{ 306360 }, /* pm_lsu0_store_reject\000\000other\000ls0 store reject\000event=0xf084\000\000\000\000\000\000ls0 store reject42\000 */
{ 306504 }, /* pm_lsu0_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe098\000\000\000\000\000\000Load tm hit in L142\000 */
{ 306646 }, /* pm_lsu0_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a0\000\000\000\000\000\000Load tm L1 miss42\000 */
{ 306724 }, /* pm_lsu0_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0a8\000\000\000\000\000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000 */
{ 307110 }, /* pm_lsu1_flush_lrq\000\000other\000LS1 Flush: LRQ\000event=0xc0b2\000\000\000\000\000\000LS1 Flush: LRQLSU1 LRQ flushes\000 */
{ 307199 }, /* pm_lsu1_flush_srq\000\000other\000LS1 Flush: SRQ\000event=0xc0ba\000\000\000\000\000\000LS1 Flush: SRQLSU1 SRQ lhs flushes\000 */
{ 307292 }, /* pm_lsu1_flush_uld\000\000other\000LS 1 Flush: Unaligned Load\000event=0xc0a6\000\000\000\000\000\000LS 1 Flush: Unaligned LoadLSU1 unaligned load flushes\000 */
{ 307416 }, /* pm_lsu1_flush_ust\000\000other\000LS1 Flush: Unaligned Store\000event=0xc0ae\000\000\000\000\000\000LS1 Flush: Unaligned StoreLSU1 unaligned store flushes\000 */
{ 307541 }, /* pm_lsu1_l1_cam_cancel\000\000other\000ls1 l1 tm cam cancel\000event=0xf08a\000\000\000\000\000\000ls1 l1 tm cam cancel42\000 */
{ 307701 }, /* pm_lsu1_larx_fin\000\000other\000Larx finished in LSU pipe1\000event=0x2e056\000\000\000\000\000\000\000 */
{ 308214 }, /* pm_lsu1_lmq_lhr_merge\000\000other\000LS1 Load Merge with another cacheline request\000event=0xd08e\000\000\000\000\000\000LS1 Load Merge with another cacheline request42\000 */
{ 308355 }, /* pm_lsu1_ncld\000\000other\000LS1 Non-cachable Loads counted at finish\000event=0xc08e\000\000\000\000\000\000LS1 Non-cachable Loads counted at finishLSU1 non-cacheable loads\000 */
{ 308499 }, /* pm_lsu1_primary_erat_hit\000\000other\000Primary ERAT hit\000event=0xe092\000\000\000\000\000\000Primary ERAT hit42\000 */
{ 308585 }, /* pm_lsu1_reject\000\000other\000LSU1 reject\000event=0x2e05a\000\000\000\000\000\000\000 */
{ 308639 }, /* pm_lsu1_srq_stfwd\000\000other\000LS1 SRQ forwarded data to a load\000event=0xc09e\000\000\000\000\000\000LS1 SRQ forwarded data to a loadLSU1 SRQ store forwarded\000 */
{ 308967 }, /* pm_lsu1_store_reject\000\000other\000ls1 store reject\000event=0xf086\000\000\000\000\000\000ls1 store reject42\000 */
{ 309049 }, /* pm_lsu1_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe09a\000\000\000\000\000\000Load tm hit in L142\000 */
{ 309192 }, /* pm_lsu1_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a2\000\000\000\000\000\000Load tm L1 miss42\000 */
{ 309331 }, /* pm_lsu1_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0aa\000\000\000\000\000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000 */
{ 309971 }, /* pm_lsu2_flush_lrq\000\000other\000LS02Flush: LRQ\000event=0xc0b4\000\000\000\000\000\000LS02Flush: LRQ42\000 */
{ 310046 }, /* pm_lsu2_flush_srq\000\000other\000LS2 Flush: SRQ\000event=0xc0bc\000\000\000\000\000\000LS2 Flush: SRQ42\000 */
{ 310121 }, /* pm_lsu2_flush_uld\000\000other\000LS3 Flush: Unaligned Load\000event=0xc0a8\000\000\000\000\000\000LS3 Flush: Unaligned Load42\000 */
{ 310218 }, /* pm_lsu2_l1_cam_cancel\000\000other\000ls2 l1 tm cam cancel\000event=0xf08c\000\000\000\000\000\000ls2 l1 tm cam cancel42\000 */
{ 310378 }, /* pm_lsu2_larx_fin\000\000other\000Larx finished in LSU pipe2\000event=0x3e056\000\000\000\000\000\000\000 */
{ 310449 }, /* pm_lsu2_ldf\000\000other\000LS2 Scalar Loads\000event=0xc084\000\000\000\000\000\000LS2 Scalar Loads42\000 */
{ 310964 }, /* pm_lsu2_ldx\000\000other\000LS0 Vector Loads\000event=0xc088\000\000\000\000\000\000LS0 Vector Loads42\000 */
{ 311037 }, /* pm_lsu2_lmq_lhr_merge\000\000other\000LS0 Load Merged with another cacheline request\000event=0xd090\000\000\000\000\000\000LS0 Load Merged with another cacheline request42\000 */
{ 311180 }, /* pm_lsu2_primary_erat_hit\000\000other\000Primary ERAT hit\000event=0xe094\000\000\000\000\000\000Primary ERAT hit42\000 */
{ 311266 }, /* pm_lsu2_reject\000\000other\000LSU2 reject\000event=0x3e05a\000\000\000\000\000\000\000 */
{ 311320 }, /* pm_lsu2_srq_stfwd\000\000other\000LS2 SRQ forwarded data to a load\000event=0xc0a0\000\000\000\000\000\000LS2 SRQ forwarded data to a load42\000 */
{ 311688 }, /* pm_lsu2_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe09c\000\000\000\000\000\000Load tm hit in L142\000 */
{ 311830 }, /* pm_lsu2_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a4\000\000\000\000\000\000Load tm L1 miss42\000 */
{ 311908 }, /* pm_lsu2_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0ac\000\000\000\000\000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000 */
{ 312294 }, /* pm_lsu3_flush_lrq\000\000other\000LS3 Flush: LRQ\000event=0xc0b6\000\000\000\000\000\000LS3 Flush: LRQ42\000 */
{ 312369 }, /* pm_lsu3_flush_srq\000\000other\000LS13 Flush: SRQ\000event=0xc0be\000\000\000\000\000\000LS13 Flush: SRQ42\000 */
{ 312446 }, /* pm_lsu3_flush_uld\000\000other\000LS 14Flush: Unaligned Load\000event=0xc0aa\000\000\000\000\000\000LS 14Flush: Unaligned Load42\000 */
{ 312545 }, /* pm_lsu3_l1_cam_cancel\000\000other\000ls3 l1 tm cam cancel\000event=0xf08e\000\000\000\000\000\000ls3 l1 tm cam cancel42\000 */
{ 312705 }, /* pm_lsu3_larx_fin\000\000other\000Larx finished in LSU pipe3\000event=0x4e056\000\000\000\000\000\000\000 */
{ 312776 }, /* pm_lsu3_ldf\000\000other\000LS3 Scalar Loads\000event=0xc086\000\000\000\000\000\000LS3 Scalar Loads 42\000 */
{ 313292 }, /* pm_lsu3_ldx\000\000other\000LS1 Vector Loads\000event=0xc08a\000\000\000\000\000\000LS1 Vector Loads42\000 */
{ 313365 }, /* pm_lsu3_lmq_lhr_merge\000\000other\000LS1 Load Merge with another cacheline request\000event=0xd092\000\000\000\000\000\000LS1 Load Merge with another cacheline request42\000 */
{ 313506 }, /* pm_lsu3_primary_erat_hit\000\000other\000Primary ERAT hit\000event=0xe096\000\000\000\000\000\000Primary ERAT hit42\000 */
{ 313592 }, /* pm_lsu3_reject\000\000other\000LSU3 reject\000event=0x4e05a\000\000\000\000\000\000\000 */
{ 313646 }, /* pm_lsu3_srq_stfwd\000\000other\000LS3 SRQ forwarded data to a load\000event=0xc0a2\000\000\000\000\000\000LS3 SRQ forwarded data to a load42\000 */
{ 313952 }, /* pm_lsu3_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe09e\000\000\000\000\000\000Load tm hit in L142\000 */
{ 314095 }, /* pm_lsu3_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a6\000\000\000\000\000\000Load tm L1 miss42\000 */
{ 314234 }, /* pm_lsu3_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0ae\000\000\000\000\000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000 */
{ 314994 }, /* pm_lsu_erat_miss_pref\000\000other\000Erat miss due to prefetch, on either pipe\000event=0xe880\000\000\000\000\000\000LSU\000 */
{ 318128 }, /* pm_lsu_flush_ust\000\000other\000Unaligned Store Flush on either pipe\000event=0xc8ac\000\000\000\000\000\000LSU\000 */
{ 318680 }, /* pm_lsu_four_tablewalk_cyc\000\000other\000Cycles when four tablewalks pending on this thread\000event=0xd0a4\000\000\000\000\000\000Cycles when four tablewalks pending on this thread42\000 */
{ 318835 }, /* pm_lsu_fx_fin\000\000other\000LSU Finished a FX operation (up to 2 per cycle\000event=0x10066\000\000\000\000\000\000\000 */
{ 318923 }, /* pm_lsu_l1_pref\000\000other\000hw initiated , include sw streaming forms as well , include sw streams as a separate event\000event=0xd8b8\000\000\000\000\000\000LSU\000 */
{ 319058 }, /* pm_lsu_l1_sw_pref\000\000other\000Software L1 Prefetches, including SW Transient Prefetches, on both pipes\000event=0xc898\000\000\000\000\000\000LSU\000 */
{ 319362 }, /* pm_lsu_ldf\000\000other\000FPU loads only on LS2/LS3 ie LU0/LU1\000event=0xc884\000\000\000\000\000\000LSU\000 */
{ 319439 }, /* pm_lsu_ldx\000\000other\000Vector loads can issue only on LS2/LS3\000event=0xc888\000\000\000\000\000\000LSU\000 */
{ 319608 }, /* pm_lsu_lmq_full_cyc\000\000other\000LMQ full\000event=0xd0a2\000\000\000\000\000\000LMQ fullCycles LMQ full\000 */
{ 319686 }, /* pm_lsu_lmq_s0_alloc\000\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd0a1\000\000\000\000\000\0000.0\000 */
{ 320141 }, /* pm_lsu_lmq_s0_valid\000\000other\000Slot 0 of LMQ valid\000event=0xd0a0\000\000\000\000\000\000Slot 0 of LMQ validLMQ slot 0 valid\000 */
{ 320242 }, /* pm_lsu_lmq_srq_empty_all_cyc\000\000other\000ALL threads lsu empty (lmq and srq empty)\000event=0x3001c\000\000\000\000\000\000ALL threads lsu empty (lmq and srq empty). Issue HW016541\000 */
{ 320624 }, /* pm_lsu_lrq_s0_alloc\000\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd09f\000\000\000\000\000\0000.0\000 */
{ 321079 }, /* pm_lsu_lrq_s0_valid\000\000other\000Slot 0 of LRQ valid\000event=0xd09e\000\000\000\000\000\000Slot 0 of LRQ validLRQ slot 0 valid\000 */
{ 321180 }, /* pm_lsu_lrq_s43_alloc\000\000other\000LRQ slot 43 was released\000event=0xf091\000\000\000\000\000\0000.0\000 */
{ 321255 }, /* pm_lsu_lrq_s43_valid\000\000other\000LRQ slot 43 was busy\000event=0xf090\000\000\000\000\000\000LRQ slot 43 was busy42\000 */
{ 321345 }, /* pm_lsu_mrk_derat_miss\000\000other\000DERAT Reloaded (Miss)\000event=0x30162\000\000\000\000\000\000\000 */
{ 321416 }, /* pm_lsu_ncld\000\000other\000count at finish so can return only on ls0 or ls1\000event=0xc88c\000\000\000\000\000\000LSU\000 */
{ 321709 }, /* pm_lsu_ncst\000\000other\000Non-cachable Stores sent to nest\000event=0xc092\000\000\000\000\000\000Non-cachable Stores sent to nest42\000 */
{ 321814 }, /* pm_lsu_reject\000\000other\000LSU Reject (up to 4 per cycle)\000event=0x10064\000\000\000\000\000\000\000 */
{ 322459 }, /* pm_lsu_set_mpred\000\000other\000Line already in cache at reload time\000event=0xd082\000\000\000\000\000\000Line already in cache at reload time42\000 */
{ 322577 }, /* pm_lsu_srq_empty_cyc\000\000other\000ALL threads srq empty\000event=0x40008\000\000\000\000\000\000All threads srq empty\000 */
{ 322979 }, /* pm_lsu_srq_s0_alloc\000\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd09d\000\000\000\000\000\0000.0\000 */
{ 323434 }, /* pm_lsu_srq_s0_valid\000\000other\000Slot 0 of SRQ valid\000event=0xd09c\000\000\000\000\000\000Slot 0 of SRQ validSRQ slot 0 valid\000 */
{ 323535 }, /* pm_lsu_srq_s39_alloc\000\000other\000SRQ slot 39 was released\000event=0xf093\000\000\000\000\000\0000.0\000 */
{ 323610 }, /* pm_lsu_srq_s39_valid\000\000other\000SRQ slot 39 was busy\000event=0xf092\000\000\000\000\000\000SRQ slot 39 was busy42\000 */
{ 323700 }, /* pm_lsu_srq_sync\000\000other\000A sync in the SRQ ended\000event=0xd09b\000\000\000\000\000\0000.0\000 */
{ 323769 }, /* pm_lsu_srq_sync_cyc\000\000other\000A sync is in the SRQ (edge detect to count)\000event=0xd09a\000\000\000\000\000\000A sync is in the SRQ (edge detect to count)SRQ sync duration\000 */
{ 324694 }, /* pm_lsu_store_reject\000\000other\000Store reject on either pipe\000event=0xf084\000\000\000\000\000\000LSU\000 */
{ 324771 }, /* pm_lsu_two_tablewalk_cyc\000\000other\000Cycles when two tablewalks pending on this thread\000event=0xd0a6\000\000\000\000\000\000Cycles when two tablewalks pending on this thread42\000 */
{ 325009 }, /* pm_lwsync\000\000other\000threaded version, IC Misses where we got EA dir hit but no sector valids were on. ICBI took line out\000event=0x5094\000\000\000\000\000\000\000 */
{ 325146 }, /* pm_lwsync_held\000\000other\000LWSYNC held at dispatch\000event=0x209a\000\000\000\000\000\000\000 */
{ 327853 }, /* pm_mrk_cru_fin\000\000other\000IFU non-branch finished\000event=0x3013a\000\000\000\000\000\000IFU non-branch marked instruction finished\000 */
{ 330830 }, /* pm_mrk_data_from_l21_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x4d146\000\000\000\000\000\000\000 */
{ 331006 }, /* pm_mrk_data_from_l21_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x2d126\000\000\000\000\000\000\000 */
{ 331347 }, /* pm_mrk_data_from_l21_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x3d146\000\000\000\000\000\000\000 */
{ 331698 }, /* pm_mrk_data_from_l21_shr_cyc\000\000other\000Duration in cycles to reload with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x2c126\000\000\000\000\000\000\000 */
{ 335990 }, /* pm_mrk_data_from_l31_eco_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x4d144\000\000\000\000\000\000\000 */
{ 336174 }, /* pm_mrk_data_from_l31_eco_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2d124\000\000\000\000\000\000\000 */
{ 336713 }, /* pm_mrk_data_from_l31_eco_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x3d144\000\000\000\000\000\000\000 */
{ 336895 }, /* pm_mrk_data_from_l31_eco_shr_cyc\000\000other\000Duration in cycles to reload with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2c124\000\000\000\000\000\000\000 */
{ 337251 }, /* pm_mrk_data_from_l31_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x2d144\000\000\000\000\000\000\000 */
{ 337596 }, /* pm_mrk_data_from_l31_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x4d124\000\000\000\000\000\000\000 */
{ 337765 }, /* pm_mrk_data_from_l31_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x1d146\000\000\000\000\000\000\000 */
{ 338283 }, /* pm_mrk_data_from_l31_shr_cyc\000\000other\000Duration in cycles to reload with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x4c126\000\000\000\000\000\000\000 */
{ 342565 }, /* pm_mrk_data_from_mem\000\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x201e0\000\000\000\000\000\000\000 */
{ 352461 }, /* pm_mrk_dpteg_from_l21_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a marked data side request\000event=0x4f146\000\000\000\000\000\000\000 */
{ 353239 }, /* pm_mrk_dpteg_from_l21_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a marked data side request\000event=0x3f146\000\000\000\000\000\000\000 */
{ 353825 }, /* pm_mrk_dpteg_from_l2_disp_conflict_ldhitst\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a marked data side request\000event=0x3f140\000\000\000\000\000\000\000 */
{ 354022 }, /* pm_mrk_dpteg_from_l2_disp_conflict_other\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a marked data side request\000event=0x4f140\000\000\000\000\000\000\000 */
{ 355910 }, /* pm_mrk_dpteg_from_l31_eco_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a marked data side request\000event=0x4f144\000\000\000\000\000\000\000 */
{ 356410 }, /* pm_mrk_dpteg_from_l31_eco_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a marked data side request\000event=0x3f144\000\000\000\000\000\000\000 */
{ 356609 }, /* pm_mrk_dpteg_from_l31_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a marked data side request\000event=0x2f144\000\000\000\000\000\000\000 */
{ 357388 }, /* pm_mrk_dpteg_from_l31_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a marked data side request\000event=0x1f146\000\000\000\000\000\000\000 */
{ 365868 }, /* pm_mrk_fab_rsp_match\000\000other\000ttype and cresp matched as specified in MMCR1\000event=0x30156\000\000\000\000\000\000\000 */
{ 365962 }, /* pm_mrk_fab_rsp_match_cyc\000\000other\000cresp/ttype match cycles\000event=0x4f152\000\000\000\000\000\000\000 */
{ 366731 }, /* pm_mrk_filt_match\000\000other\000Marked filter Match\000event=0x2013c\000\000\000\000\000\000\000 */
{ 366796 }, /* pm_mrk_fin_stall_cyc\000\000other\000Marked instruction Finish Stall cycles (marked finish after NTC) (use edge detect to count )\000event=0x1013c\000\000\000\000\000\000Marked instruction Finish Stall cycles (marked finish after NTC) (use edge detect to count #)\000 */
{ 367454 }, /* pm_mrk_grp_cmpl\000\000other\000marked instruction finished (completed)\000event=0x40130\000\000\000\000\000\000\000 */
{ 367537 }, /* pm_mrk_grp_ic_miss\000\000other\000Marked Group experienced I cache miss\000event=0x4013a\000\000\000\000\000\000\000 */
{ 367621 }, /* pm_mrk_grp_ntc\000\000other\000Marked group ntc cycles\000event=0x3013c\000\000\000\000\000\000\000 */
{ 371734 }, /* pm_mrk_ld_miss_exposed\000\000other\000Marked Load exposed Miss (exposed period ended)\000event=0x1013f\000\000\000\000\000\000Marked Load exposed Miss (use edge detect to count #)\000 */
{ 372989 }, /* pm_mrk_lsu_flush\000\000other\000Flush: (marked) : All Cases\000event=0xd180\000\000\000\000\000\000Flush: (marked) : All Cases42\000 */
{ 373089 }, /* pm_mrk_lsu_flush_lrq\000\000other\000Flush: (marked) LRQ\000event=0xd188\000\000\000\000\000\000Flush: (marked) LRQMarked LRQ flushes\000 */
{ 373193 }, /* pm_mrk_lsu_flush_srq\000\000other\000Flush: (marked) SRQ\000event=0xd18a\000\000\000\000\000\000Flush: (marked) SRQMarked SRQ lhs flushes\000 */
{ 373301 }, /* pm_mrk_lsu_flush_uld\000\000other\000Flush: (marked) Unaligned Load\000event=0xd184\000\000\000\000\000\000Flush: (marked) Unaligned LoadMarked unaligned load flushes\000 */
{ 373438 }, /* pm_mrk_lsu_flush_ust\000\000other\000Flush: (marked) Unaligned Store\000event=0xd186\000\000\000\000\000\000Flush: (marked) Unaligned StoreMarked unaligned store flushes\000 */
{ 373578 }, /* pm_mrk_lsu_reject\000\000other\000LSU marked reject (up to 2 per cycle)\000event=0x40164\000\000\000\000\000\000\000 */
{ 373661 }, /* pm_mrk_lsu_reject_erat_miss\000\000other\000LSU marked reject due to ERAT (up to 2 per cycle)\000event=0x30164\000\000\000\000\000\000\000 */
{ 374588 }, /* pm_mrk_src_pref_track_eff\000\000other\000Marked src pref track was effective\000event=0x1d15a\000\000\000\000\000\000\000 */
{ 374677 }, /* pm_mrk_src_pref_track_ineff\000\000other\000Prefetch tracked was ineffective for marked src\000event=0x3d15a\000\000\000\000\000\000\000 */
{ 374780 }, /* pm_mrk_src_pref_track_mod\000\000other\000Prefetch tracked was moderate for marked src\000event=0x4d15c\000\000\000\000\000\000\000 */
{ 374878 }, /* pm_mrk_src_pref_track_mod_l2\000\000other\000Marked src Prefetch Tracked was moderate (source L2)\000event=0x1d15c\000\000\000\000\000\000\000 */
{ 374987 }, /* pm_mrk_src_pref_track_mod_l3\000\000other\000Prefetch tracked was moderate (L3 hit) for marked src\000event=0x3d15c\000\000\000\000\000\000\000 */
{ 378319 }, /* pm_mrk_tgt_pref_track_eff\000\000other\000Marked target pref track was effective\000event=0x1c15a\000\000\000\000\000\000\000 */
{ 378411 }, /* pm_mrk_tgt_pref_track_ineff\000\000other\000Prefetch tracked was ineffective for marked target\000event=0x3c15a\000\000\000\000\000\000\000 */
{ 378517 }, /* pm_mrk_tgt_pref_track_mod\000\000other\000Prefetch tracked was moderate for marked target\000event=0x4c15c\000\000\000\000\000\000\000 */
{ 378618 }, /* pm_mrk_tgt_pref_track_mod_l2\000\000other\000Marked target Prefetch Tracked was moderate (source L2)\000event=0x1c15c\000\000\000\000\000\000\000 */
{ 378730 }, /* pm_mrk_tgt_pref_track_mod_l3\000\000other\000Prefetch tracked was moderate (L3 hit) for marked target\000event=0x3c15c\000\000\000\000\000\000\000 */
{ 381559 }, /* pm_nested_tend\000\000other\000Completion time nested tend\000event=0x20b0\000\000\000\000\000\000\000 */
{ 381726 }, /* pm_non_fav_tbegin\000\000other\000Dispatch time non favored tbegin\000event=0x20b6\000\000\000\000\000\000\000 */
{ 383530 }, /* pm_ntcg_all_fin\000\000other\000Cycles after all instructions have finished to group completed\000event=0x2001a\000\000\000\000\000\000Ccycles after all instructions have finished to group completed\000 */
{ 383699 }, /* pm_outer_tbegin\000\000other\000Completion time outer tbegin\000event=0x20ac\000\000\000\000\000\000\000 */
{ 383770 }, /* pm_outer_tend\000\000other\000Completion time outer tend\000event=0x20ae\000\000\000\000\000\000\000 */
{ 387632 }, /* pm_pref_track_eff\000\000other\000Prefetch Tracked was effective\000event=0x1005a\000\000\000\000\000\000\000 */
{ 387708 }, /* pm_pref_track_ineff\000\000other\000Prefetch tracked was ineffective\000event=0x3005a\000\000\000\000\000\000\000 */
{ 387788 }, /* pm_pref_track_mod\000\000other\000Prefetch tracked was moderate\000event=0x4005a\000\000\000\000\000\000\000 */
{ 387863 }, /* pm_pref_track_mod_l2\000\000other\000Prefetch Tracked was moderate (source L2)\000event=0x1005c\000\000\000\000\000\000\000 */
{ 387953 }, /* pm_pref_track_mod_l3\000\000other\000Prefetch tracked was moderate (L3)\000event=0x3005c\000\000\000\000\000\000\000 */
{ 388036 }, /* pm_pref_tracked\000\000other\000Total number of Prefetch Operations that were tracked\000event=0x2005a\000\000\000\000\000\000\000 */
{ 388506 }, /* pm_pte_prefetch\000\000other\000PTE prefetches\000event=0xe084\000\000\000\000\000\000PTE prefetches42\000 */
{ 393459 }, /* pm_rc0_alloc\000\000other\000RC mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16081\000\000\000\000\000\0000.0\000 */
{ 393706 }, /* pm_rc0_busy\000\000other\000RC mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16080\000\000\000\000\000\000\000 */
{ 393827 }, /* pm_rc_lifetime_exc_1024\000\000other\000Number of times the RC machine for a sampled instruction was active for more than 1024 cycles\000event=0x200301ea\000\000\000\000\000\000Reload latency exceeded 1024 cyc\000 */
{ 394007 }, /* pm_rc_lifetime_exc_2048\000\000other\000Number of times the RC machine for a sampled instruction was active for more than 2048 cycles\000event=0x200401ec\000\000\000\000\000\000Threshold counter exceeded a value of 2048\000 */
{ 394197 }, /* pm_rc_lifetime_exc_256\000\000other\000Number of times the RC machine for a sampled instruction was active for more than 256 cycles\000event=0x200101e8\000\000\000\000\000\000Threshold counter exceed a count of 256\000 */
{ 394382 }, /* pm_rc_lifetime_exc_32\000\000other\000Number of times the RC machine for a sampled instruction was active for more than 32 cycles\000event=0x200201e6\000\000\000\000\000\000Reload latency exceeded 32 cyc\000 */
{ 394775 }, /* pm_rc_usage\000\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 RC machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x36088\000\000\000\000\000\000\000 */
{ 395244 }, /* pm_real_srq_full\000\000other\000Out of real srq entries\000event=0x20004\000\000\000\000\000\000\000 */
{ 395717 }, /* pm_run_cyc_smt2_shrd_mode\000\000other\000cycles this threads run latch is set and the core is in SMT2 shared mode\000event=0x2006a\000\000\000\000\000\000Cycles run latch is set and core is in SMT2-shared mode\000 */
{ 395898 }, /* pm_run_cyc_smt2_split_mode\000\000other\000Cycles run latch is set and core is in SMT2-split mode\000event=0x1006a\000\000\000\000\000\000\000 */
{ 396417 }, /* pm_run_cyc_smt8_mode\000\000other\000Cycles run latch is set and core is in SMT8 mode\000event=0x4006c\000\000\000\000\000\000\000 */
{ 397997 }, /* pm_sec_erat_hit\000\000other\000secondary ERAT Hit\000event=0xf082\000\000\000\000\000\000secondary ERAT Hit42\000 */
{ 398078 }, /* pm_shl_created\000\000other\000Store-Hit-Load Table Entry Created\000event=0x508c\000\000\000\000\000\000\000 */
{ 398154 }, /* pm_shl_st_convert\000\000other\000Store-Hit-Load Table Read Hit with entry Enabled\000event=0x508e\000\000\000\000\000\000\000 */
{ 398344 }, /* pm_shl_st_disable\000\000other\000Store-Hit-Load Table Read Hit with entry Disabled (entry was disabled due to the entry shown to not prevent the flush)\000event=0x5090\000\000\000\000\000\000\000 */
{ 398507 }, /* pm_sn0_alloc\000\000other\000SN mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x26085\000\000\000\000\000\0000.0\000 */
{ 398632 }, /* pm_sn0_busy\000\000other\000SN mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x26084\000\000\000\000\000\000\000 */
{ 399509 }, /* pm_sn_usage\000\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 SN machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x4608c\000\000\000\000\000\000\000 */
{ 399730 }, /* pm_snoop_tlbie\000\000other\000TLBIE snoop\000event=0xd0b2\000\000\000\000\000\000TLBIE snoopSnoop TLBIE\000 */
{ 401776 }, /* pm_stall_end_gct_empty\000\000other\000Count ended because GCT went empty\000event=0x10028\000\000\000\000\000\000\000 */
{ 402557 }, /* pm_stcx_lsu\000\000other\000STCX executed reported at sent to nest\000event=0xc090\000\000\000\000\000\000STCX executed reported at sent to nest42\000 */
{ 403144 }, /* pm_swap_cancel\000\000other\000SWAP cancel , rtag not available\000event=0x3090\000\000\000\000\000\000\000 */
{ 403218 }, /* pm_swap_cancel_gpr\000\000other\000SWAP cancel , rtag not available for gpr\000event=0x3092\000\000\000\000\000\000\000 */
{ 403304 }, /* pm_swap_complete\000\000other\000swap cast in completed\000event=0x308c\000\000\000\000\000\000\000 */
{ 403370 }, /* pm_swap_complete_gpr\000\000other\000swap cast in completed fpr gpr\000event=0x308e\000\000\000\000\000\000\000 */
{ 407133 }, /* pm_tablewalk_cyc_pref\000\000other\000tablewalk qualified for pte prefetches\000event=0xe086\000\000\000\000\000\000tablewalk qualified for pte prefetches42\000 */
{ 407260 }, /* pm_tabort_treclaim\000\000other\000Completion time tabortnoncd, tabortcd, treclaim\000event=0x20b2\000\000\000\000\000\000\000 */
{ 408356 }, /* pm_tend_pend_cyc\000\000other\000TEND latency per thread\000event=0xe0ba\000\000\000\000\000\000TEND latency per thread42\000 */
{ 409004 }, /* pm_thrd_grp_cmpl_both_cyc\000\000other\000Cycles group completed on both completion slots by any thread\000event=0x10012\000\000\000\000\000\000Two threads finished same cycle (gated by run latch)\000 */
{ 409171 }, /* pm_thrd_prio_0_1_cyc\000\000other\000Cycles thread running at priority level 0 or 1\000event=0x40bc\000\000\000\000\000\000\000 */
{ 409265 }, /* pm_thrd_prio_2_3_cyc\000\000other\000Cycles thread running at priority level 2 or 3\000event=0x40be\000\000\000\000\000\000\000 */
{ 409453 }, /* pm_thrd_prio_4_5_cyc\000\000other\000Cycles thread running at priority level 4 or 5\000event=0x5080\000\000\000\000\000\000\000 */
{ 409547 }, /* pm_thrd_prio_6_7_cyc\000\000other\000Cycles thread running at priority level 6 or 7\000event=0x5082\000\000\000\000\000\000\000 */
{ 409735 }, /* pm_thrd_rebal_cyc\000\000other\000cycles rebalance was active\000event=0x3098\000\000\000\000\000\000\000 */
{ 412772 }, /* pm_tm_begin_all\000\000other\000Tm any tbegin\000event=0x20b8\000\000\000\000\000\000\000 */
{ 413035 }, /* pm_tm_end_all\000\000other\000Tm any tend\000event=0x20ba\000\000\000\000\000\000\000 */
{ 413087 }, /* pm_tm_fail_con_tm\000\000other\000TEXAS fail reason @ completion\000event=0x3088\000\000\000\000\000\000\000 */
{ 413162 }, /* pm_tm_fail_conf_non_tm\000\000other\000TEXAS fail reason @ completion\000event=0x3086\000\000\000\000\000\000\000 */
{ 413492 }, /* pm_tm_fail_disallow\000\000other\000TM fail disallow\000event=0xe0b2\000\000\000\000\000\000TM fail disallow42\000 */
{ 413573 }, /* pm_tm_fail_footprint_overflow\000\000other\000TEXAS fail reason @ completion\000event=0x3084\000\000\000\000\000\000\000 */
{ 413817 }, /* pm_tm_fail_non_tx_conflict\000\000other\000Non transactional conflict from LSU whtver gets repoted to texas\000event=0xe0b8\000\000\000\000\000\000Non transactional conflict from LSU whtver gets repoted to texas42\000 */
{ 414115 }, /* pm_tm_fail_self\000\000other\000TEXAS fail reason @ completion\000event=0x308a\000\000\000\000\000\000\000 */
{ 414651 }, /* pm_tm_fail_tlbie\000\000other\000TLBIE hit bloom filter\000event=0xe0b4\000\000\000\000\000\000TLBIE hit bloom filter42\000 */
{ 414959 }, /* pm_tm_fail_tx_conflict\000\000other\000Transactional conflict from LSU, whatever gets reported to texas\000event=0xe0b6\000\000\000\000\000\000Transactional conflict from LSU, whatever gets reported to texas 42\000 */
{ 416728 }, /* pm_tm_tbegin\000\000other\000Tm nested tbegin\000event=0x20bc\000\000\000\000\000\000\000 */
{ 417242 }, /* pm_tm_tresume\000\000other\000Tm resume\000event=0x3080\000\000\000\000\000\000\000 */
{ 417366 }, /* pm_tm_tsuspend\000\000other\000Tm suspend\000event=0x20be\000\000\000\000\000\000\000 */
{ 418118 }, /* pm_up_pref_l3\000\000other\000Micropartition prefetch\000event=0xe08c\000\000\000\000\000\000Micropartition prefetch42\000 */
{ 418207 }, /* pm_up_pref_pointer\000\000other\000Micrpartition pointer prefetches\000event=0xe08e\000\000\000\000\000\000Micrpartition pointer prefetches42\000 */
{ 418841 }, /* pm_vsu0_16flop\000\000other\000Sixteen flops operation (SP vector versions of fdiv,fsqrt)\000event=0xa0a4\000\000\000\000\000\000\000 */
{ 418941 }, /* pm_vsu0_1flop\000\000other\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finished\000event=0xa080\000\000\000\000\000\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finishedDecode into 1,2,4 FLOP according to instr IOP, multiplied by #vector elements according to route( eg x1, x2, x4) Only if instr sends finish to ISU\000 */
{ 419310 }, /* pm_vsu0_2flop\000\000other\000two flops operation (scalar fmadd, fnmadd, fmsub, fnmsub and DP vector versions of single flop instructions)\000event=0xa098\000\000\000\000\000\000\000 */
{ 419459 }, /* pm_vsu0_4flop\000\000other\000four flops operation (scalar fdiv, fsqrt, DP vector version of fmadd, fnmadd, fmsub, fnmsub, SP vector versions of single flop instructions)\000event=0xa09c\000\000\000\000\000\000\000 */
{ 419640 }, /* pm_vsu0_8flop\000\000other\000eight flops operation (DP vector versions of fdiv,fsqrt and SP vector versions of fmadd,fnmadd,fmsub,fnmsub)\000event=0xa0a0\000\000\000\000\000\000\000 */
{ 419789 }, /* pm_vsu0_complex_issued\000\000other\000Complex VMX instruction issued\000event=0xb0a4\000\000\000\000\000\000\000 */
{ 419869 }, /* pm_vsu0_cy_issued\000\000other\000Cryptographic instruction RFC02196 Issued\000event=0xb0b4\000\000\000\000\000\000\000 */
{ 419955 }, /* pm_vsu0_dd_issued\000\000other\00064BIT Decimal Issued\000event=0xb0a8\000\000\000\000\000\000\000 */
{ 420020 }, /* pm_vsu0_dp_2flop\000\000other\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0xa08c\000\000\000\000\000\000\000 */
{ 420140 }, /* pm_vsu0_dp_fma\000\000other\000DP vector version of fmadd,fnmadd,fmsub,fnmsub\000event=0xa090\000\000\000\000\000\000\000 */
{ 420228 }, /* pm_vsu0_dp_fsqrt_fdiv\000\000other\000DP vector versions of fdiv,fsqrt\000event=0xa094\000\000\000\000\000\000\000 */
{ 420309 }, /* pm_vsu0_dq_issued\000\000other\000128BIT Decimal Issued\000event=0xb0ac\000\000\000\000\000\000\000 */
{ 420375 }, /* pm_vsu0_ex_issued\000\000other\000Direct move 32/64b VRFtoGPR RFC02206 Issued\000event=0xb0b0\000\000\000\000\000\000\000 */
{ 420463 }, /* pm_vsu0_fin\000\000other\000VSU0 Finished an instruction\000event=0xa0bc\000\000\000\000\000\000\000 */
{ 420530 }, /* pm_vsu0_fma\000\000other\000two flops operation (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only!\000event=0xa084\000\000\000\000\000\000\000 */
{ 420645 }, /* pm_vsu0_fpscr\000\000other\000Move to/from FPSCR type instruction issued on Pipe 0\000event=0xb098\000\000\000\000\000\000\000 */
{ 420738 }, /* pm_vsu0_fsqrt_fdiv\000\000other\000four flops operation (fdiv,fsqrt) Scalar Instructions only!\000event=0xa088\000\000\000\000\000\000\000 */
{ 420923 }, /* pm_vsu0_permute_issued\000\000other\000Permute VMX Instruction Issued\000event=0xb090\000\000\000\000\000\000\000 */
{ 421003 }, /* pm_vsu0_scalar_dp_issued\000\000other\000Double Precision scalar instruction issued on Pipe0\000event=0xb088\000\000\000\000\000\000\000 */
{ 421106 }, /* pm_vsu0_simple_issued\000\000other\000Simple VMX instruction issued\000event=0xb094\000\000\000\000\000\000\000 */
{ 421184 }, /* pm_vsu0_single\000\000other\000FPU single precision\000event=0xa0a8\000\000\000\000\000\000\000 */
{ 421246 }, /* pm_vsu0_sq\000\000other\000Store Vector Issued\000event=0xb09c\000\000\000\000\000\000\000 */
{ 421303 }, /* pm_vsu0_stf\000\000other\000FPU store (SP or DP) issued on Pipe0\000event=0xb08c\000\000\000\000\000\000\000 */
{ 421378 }, /* pm_vsu0_vector_dp_issued\000\000other\000Double Precision vector instruction issued on Pipe0\000event=0xb080\000\000\000\000\000\000\000 */
{ 421481 }, /* pm_vsu0_vector_sp_issued\000\000other\000Single Precision vector instruction issued (executed)\000event=0xb084\000\000\000\000\000\000\000 */
{ 421586 }, /* pm_vsu1_16flop\000\000other\000Sixteen flops operation (SP vector versions of fdiv,fsqrt)\000event=0xa0a6\000\000\000\000\000\000\000 */
{ 421686 }, /* pm_vsu1_1flop\000\000other\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finished\000event=0xa082\000\000\000\000\000\000\000 */
{ 421818 }, /* pm_vsu1_2flop\000\000other\000two flops operation (scalar fmadd, fnmadd, fmsub, fnmsub and DP vector versions of single flop instructions)\000event=0xa09a\000\000\000\000\000\000\000 */
{ 421967 }, /* pm_vsu1_4flop\000\000other\000four flops operation (scalar fdiv, fsqrt, DP vector version of fmadd, fnmadd, fmsub, fnmsub, SP vector versions of single flop instructions)\000event=0xa09e\000\000\000\000\000\000\000 */
{ 422148 }, /* pm_vsu1_8flop\000\000other\000eight flops operation (DP vector versions of fdiv,fsqrt and SP vector versions of fmadd,fnmadd,fmsub,fnmsub)\000event=0xa0a2\000\000\000\000\000\000\000 */
{ 422297 }, /* pm_vsu1_complex_issued\000\000other\000Complex VMX instruction issued\000event=0xb0a6\000\000\000\000\000\000\000 */
{ 422377 }, /* pm_vsu1_cy_issued\000\000other\000Cryptographic instruction RFC02196 Issued\000event=0xb0b6\000\000\000\000\000\000\000 */
{ 422463 }, /* pm_vsu1_dd_issued\000\000other\00064BIT Decimal Issued\000event=0xb0aa\000\000\000\000\000\000\000 */
{ 422528 }, /* pm_vsu1_dp_2flop\000\000other\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0xa08e\000\000\000\000\000\000\000 */
{ 422648 }, /* pm_vsu1_dp_fma\000\000other\000DP vector version of fmadd,fnmadd,fmsub,fnmsub\000event=0xa092\000\000\000\000\000\000\000 */
{ 422736 }, /* pm_vsu1_dp_fsqrt_fdiv\000\000other\000DP vector versions of fdiv,fsqrt\000event=0xa096\000\000\000\000\000\000\000 */
{ 422817 }, /* pm_vsu1_dq_issued\000\000other\000128BIT Decimal Issued\000event=0xb0ae\000\000\000\000\000\000\000 */
{ 422883 }, /* pm_vsu1_ex_issued\000\000other\000Direct move 32/64b VRFtoGPR RFC02206 Issued\000event=0xb0b2\000\000\000\000\000\000\000 */
{ 422971 }, /* pm_vsu1_fin\000\000other\000VSU1 Finished an instruction\000event=0xa0be\000\000\000\000\000\000\000 */
{ 423038 }, /* pm_vsu1_fma\000\000other\000two flops operation (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only!\000event=0xa086\000\000\000\000\000\000\000 */
{ 423153 }, /* pm_vsu1_fpscr\000\000other\000Move to/from FPSCR type instruction issued on Pipe 0\000event=0xb09a\000\000\000\000\000\000\000 */
{ 423246 }, /* pm_vsu1_fsqrt_fdiv\000\000other\000four flops operation (fdiv,fsqrt) Scalar Instructions only!\000event=0xa08a\000\000\000\000\000\000\000 */
{ 423433 }, /* pm_vsu1_permute_issued\000\000other\000Permute VMX Instruction Issued\000event=0xb092\000\000\000\000\000\000\000 */
{ 423513 }, /* pm_vsu1_scalar_dp_issued\000\000other\000Double Precision scalar instruction issued on Pipe1\000event=0xb08a\000\000\000\000\000\000\000 */
{ 423616 }, /* pm_vsu1_simple_issued\000\000other\000Simple VMX instruction issued\000event=0xb096\000\000\000\000\000\000\000 */
{ 423694 }, /* pm_vsu1_single\000\000other\000FPU single precision\000event=0xa0aa\000\000\000\000\000\000\000 */
{ 423756 }, /* pm_vsu1_sq\000\000other\000Store Vector Issued\000event=0xb09e\000\000\000\000\000\000\000 */
{ 423813 }, /* pm_vsu1_stf\000\000other\000FPU store (SP or DP) issued on Pipe1\000event=0xb08e\000\000\000\000\000\000\000 */
{ 423888 }, /* pm_vsu1_vector_dp_issued\000\000other\000Double Precision vector instruction issued on Pipe1\000event=0xb082\000\000\000\000\000\000\000 */
{ 423991 }, /* pm_vsu1_vector_sp_issued\000\000other\000Single Precision vector instruction issued (executed)\000event=0xb086\000\000\000\000\000\000\000 */
{ 104191 }, /* pm_1plus_ppc_cmpl\000\000pipeline\0001 or more ppc insts finished\000event=0x100f2\000\000\000\000\000\0001 or more ppc insts finished (completed)\000 */
{ 104308 }, /* pm_1plus_ppc_disp\000\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\000\000\000\000\000Cycles at least one Instr Dispatched. Could be a group with only microcode. Issue HW016521\000 */
{ 109464 }, /* pm_any_thrd_run_cyc\000\000pipeline\000One of threads in run_cycles\000event=0x100fa\000\000\000\000\000\000Any thread in run_cycles (was one thread in run_cycles)\000 */
{ 120378 }, /* pm_cmplu_stall\000\000pipeline\000Completion stall\000event=0x4000a\000\000\000\000\000\000\000 */
{ 120666 }, /* pm_cmplu_stall_bru\000\000pipeline\000Completion stall due to a Branch Unit\000event=0x4d018\000\000\000\000\000\000\000 */
{ 121152 }, /* pm_cmplu_stall_dcache_miss\000\000pipeline\000Completion stall by Dcache miss\000event=0x2c012\000\000\000\000\000\000\000 */
{ 122018 }, /* pm_cmplu_stall_dmiss_l21_l31\000\000pipeline\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000event=0x2c018\000\000\000\000\000\000\000 */
{ 122266 }, /* pm_cmplu_stall_dmiss_l2l3\000\000pipeline\000Completion stall by Dcache miss which resolved in L2/L3\000event=0x2c016\000\000\000\000\000\000\000 */
{ 122521 }, /* pm_cmplu_stall_dmiss_l2l3_conflict\000\000pipeline\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000event=0x4c016\000\000\000\000\000\000Completion stall due to cache miss resolving in core's L2/L3 with a conflict\000 */
{ 122857 }, /* pm_cmplu_stall_dmiss_l3miss\000\000pipeline\000Completion stall due to cache miss resolving missed the L3\000event=0x4c01a\000\000\000\000\000\000\000 */
{ 123092 }, /* pm_cmplu_stall_dmiss_lmem\000\000pipeline\000Completion stall due to cache miss that resolves in local memory\000event=0x4c018\000\000\000\000\000\000Completion stall due to cache miss resolving in core's Local Memory\000 */
{ 123418 }, /* pm_cmplu_stall_dmiss_remote\000\000pipeline\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000event=0x2c01c\000\000\000\000\000\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000 */
{ 124568 }, /* pm_cmplu_stall_erat_miss\000\000pipeline\000Completion stall due to LSU reject ERAT miss\000event=0x4c012\000\000\000\000\000\000\000 */
{ 125590 }, /* pm_cmplu_stall_fxlong\000\000pipeline\000Completion stall due to a long latency fixed point instruction\000event=0x4d016\000\000\000\000\000\000\000 */
{ 125899 }, /* pm_cmplu_stall_fxu\000\000pipeline\000Completion stall due to FXU\000event=0x2d016\000\000\000\000\000\000\000 */
{ 125976 }, /* pm_cmplu_stall_hwsync\000\000pipeline\000completion stall due to hwsync\000event=0x30036\000\000\000\000\000\000\000 */
{ 126738 }, /* pm_cmplu_stall_load_finish\000\000pipeline\000Completion stall due to a Load finish\000event=0x4d014\000\000\000\000\000\000\000 */
{ 127576 }, /* pm_cmplu_stall_lsu\000\000pipeline\000Completion stall by LSU instruction\000event=0x2c010\000\000\000\000\000\000\000 */
{ 128331 }, /* pm_cmplu_stall_lwsync\000\000pipeline\000completion stall due to isync/lwsync\000event=0x10036\000\000\000\000\000\000\000 */
{ 129617 }, /* pm_cmplu_stall_other_cmpl\000\000pipeline\000Instructions core completed while this tread was stalled\000event=0x30006\000\000\000\000\000\000Instructions core completed while this thread was stalled\000 */
{ 131320 }, /* pm_cmplu_stall_st_fwd\000\000pipeline\000Completion stall due to store forward\000event=0x4c01c\000\000\000\000\000\000\000 */
{ 132933 }, /* pm_cmplu_stall_thrd\000\000pipeline\000Completion Stalled due to thread conflict. Group ready to complete but it was another thread's turn\000event=0x1001c\000\000\000\000\000\000Completion stall due to thread conflict\000 */
{ 135783 }, /* pm_cyc\000\000pipeline\000Cycles\000event=0x1e\000\000\000\000\000\000\000 */
{ 178569 }, /* pm_disp_held\000\000pipeline\000Dispatch Held\000event=0x10006\000\000\000\000\000\000\000 */
{ 179204 }, /* pm_disp_held_sync_hold\000\000pipeline\000Dispatch held due to SYNC hold\000event=0x4003c\000\000\000\000\000\000\000 */
{ 208028 }, /* pm_ext_int\000\000pipeline\000external interrupt\000event=0x200f8\000\000\000\000\000\000\000 */
{ 208691 }, /* pm_flush\000\000pipeline\000Flush (any type)\000event=0x400f8\000\000\000\000\000\000\000 */
{ 209130 }, /* pm_flush_completion\000\000pipeline\000Completion Flush\000event=0x30012\000\000\000\000\000\000\000 */
{ 210975 }, /* pm_freq_down\000\000pipeline\000Power Management: Below Threshold B\000event=0x3000c\000\000\000\000\000\000Frequency is being slewed down due to Power Management\000 */
{ 211257 }, /* pm_freq_up\000\000pipeline\000Power Management: Above Threshold A\000event=0x4000c\000\000\000\000\000\000Frequency is being slewed up due to Power Management\000 */
{ 218591 }, /* pm_hv_cyc\000\000pipeline\000Cycles in which msr_hv is high. Note that this event does not take msr_pr into consideration\000event=0x2000a\000\000\000\000\000\000cycles in hypervisor mode\000 */
{ 224357 }, /* pm_ifetch_throttle\000\000pipeline\000Cycles in which Instruction fetch throttle was active\000event=0x3405e\000\000\000\000\000\000Cycles instruction fecth was throttled in IFU\000 */
{ 262903 }, /* pm_iops_cmpl\000\000pipeline\000Internal Operations completed\000event=0x10014\000\000\000\000\000\000IOPS Completed\000 */
{ 294555 }, /* pm_larx_fin\000\000pipeline\000Larx finished\000event=0x3c058\000\000\000\000\000\000\000 */
{ 294730 }, /* pm_ld_cmpl\000\000pipeline\000count of Loads completed\000event=0x1002e\000\000\000\000\000\000\000 */
{ 295236 }, /* pm_ld_l3miss_pend_cyc\000\000pipeline\000Cycles L3 miss was pending for this thread\000event=0x10062\000\000\000\000\000\000\000 */
{ 315087 }, /* pm_lsu_fin\000\000pipeline\000LSU Finished an instruction (up to 2 per cycle)\000event=0x30066\000\000\000\000\000\000\000 */
{ 320397 }, /* pm_lsu_lmq_srq_empty_cyc\000\000pipeline\000LSU empty (lmq and srq empty)\000event=0x2003e\000\000\000\000\000\000\000 */
{ 321982 }, /* pm_lsu_reject_erat_miss\000\000pipeline\000LSU Reject due to ERAT (up to 4 per cycles)\000event=0x2e05c\000\000\000\000\000\000\000 */
{ 322080 }, /* pm_lsu_reject_lhs\000\000pipeline\000LSU Reject due to LHS (up to 4 per cycle)\000event=0x4e05c\000\000\000\000\000\000\000 */
{ 322364 }, /* pm_lsu_reject_lmq_full\000\000pipeline\000LSU reject due to LMQ full ( 4 per cycle)\000event=0x1e05c\000\000\000\000\000\000\000 */
{ 322871 }, /* pm_lsu_srq_full_cyc\000\000pipeline\000Storage Queue is full and is blocking dispatch\000event=0x1001a\000\000\000\000\000\000SRQ is Full\000 */
{ 388437 }, /* pm_probe_nop_disp\000\000pipeline\000ProbeNops dispatched\000event=0x40014\000\000\000\000\000\000\000 */
{ 395445 }, /* pm_run_cyc\000\000pipeline\000Run_cycles\000event=0x600f4\000\000\000\000\000\000\000 */
{ 395617 }, /* pm_run_cyc_smt2_mode\000\000pipeline\000Cycles run latch is set and core is in SMT2 mode\000event=0x3006c\000\000\000\000\000\000\000 */
{ 396252 }, /* pm_run_cyc_smt4_mode\000\000pipeline\000cycles this threads run latch is set and the core is in SMT4 mode\000event=0x2006c\000\000\000\000\000\000Cycles run latch is set and core is in SMT4 mode\000 */
{ 396608 }, /* pm_run_cyc_st_mode\000\000pipeline\000Cycles run latch is set and core is in ST mode\000event=0x1006c\000\000\000\000\000\000\000 */
{ 396973 }, /* pm_run_inst_cmpl\000\000pipeline\000Run_Instructions\000event=0x500fa\000\000\000\000\000\000\000 */
{ 400552 }, /* pm_st_cmpl\000\000pipeline\000Store completion count\000event=0x20016\000\000\000\000\000\000\000 */
{ 401133 }, /* pm_st_fin\000\000pipeline\000Store Instructions Finished\000event=0x200f0\000\000\000\000\000\000Store Instructions Finished (store sent to nest)\000 */
{ 401342 }, /* pm_st_fwd\000\000pipeline\000Store forwards that finished\000event=0x20018\000\000\000\000\000\000\000 */
{ 402000 }, /* pm_stcx_fail\000\000pipeline\000stcx failed\000event=0x1e058\000\000\000\000\000\000\000 */
{ 406850 }, /* pm_tablewalk_cyc\000\000pipeline\000Cycles when a tablewalk (I or D) is active\000event=0x10026\000\000\000\000\000\000Tablewalk Active\000 */
{ 408295 }, /* pm_tb_bit_trans\000\000pipeline\000timebase event\000event=0x300f8\000\000\000\000\000\000\000 */
{ 408617 }, /* pm_thrd_all_run_cyc\000\000pipeline\000All Threads in Run_cycles (was both threads in run_cycles)\000event=0x2000c\000\000\000\000\000\000\000 */
{ 412637 }, /* pm_tlbie_fin\000\000pipeline\000tlbie finished\000event=0x30058\000\000\000\000\000\000\000 */
{ 416784 }, /* pm_tm_trans_run_cyc\000\000pipeline\000run cycles in transactional state\000event=0x10060\000\000\000\000\000\000\000 */
{ 417510 }, /* pm_tm_tx_pass_run_cyc\000\000pipeline\000cycles spent in successful transactions\000event=0x2e012\000\000\000\000\000\000run cycles spent in successful transactions\000 */
{ 384096 }, /* pm_pmc1_overflow\000\000pmc\000Overflow from counter 1\000event=0x20010\000\000\000\000\000\000\000 */
{ 384559 }, /* pm_pmc2_overflow\000\000pmc\000Overflow from counter 2\000event=0x30010\000\000\000\000\000\000\000 */
{ 385036 }, /* pm_pmc2_rewind\000\000pmc\000PMC2 Rewind Event (did not match condition)\000event=0x30020\000\000\000\000\000\000\000 */
{ 385319 }, /* pm_pmc2_saved\000\000pmc\000PMC2 Rewind Value saved\000event=0x10022\000\000\000\000\000\000PMC2 Rewind Value saved (matched condition)\000 */
{ 385608 }, /* pm_pmc3_overflow\000\000pmc\000Overflow from counter 3\000event=0x40010\000\000\000\000\000\000\000 */
{ 386469 }, /* pm_pmc4_overflow\000\000pmc\000Overflow from counter 4\000event=0x10010\000\000\000\000\000\000\000 */
{ 386731 }, /* pm_pmc4_rewind\000\000pmc\000PMC4 Rewind Event\000event=0x10020\000\000\000\000\000\000PMC4 Rewind Event (did not match condition)\000 */
{ 387051 }, /* pm_pmc4_saved\000\000pmc\000PMC4 Rewind Value saved (matched condition)\000event=0x30022\000\000\000\000\000\000\000 */
{ 387317 }, /* pm_pmc5_overflow\000\000pmc\000Overflow from counter 5\000event=0x10024\000\000\000\000\000\000\000 */
{ 387566 }, /* pm_pmc6_overflow\000\000pmc\000Overflow from counter 6\000event=0x30024\000\000\000\000\000\000\000 */
{ 397448 }, /* pm_run_purr\000\000pmc\000Run_PURR\000event=0x400f4\000\000\000\000\000\000\000 */
{ 397545 }, /* pm_run_spurr\000\000pmc\000Run SPURR\000event=0x10008\000\000\000\000\000\000\000 */
{ 403100 }, /* pm_suspended\000\000pmc\000Counter OFF\000event=0\000\000\000\000\000\000\000 */
{ 410292 }, /* pm_thresh_exc_1024\000\000pmc\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\000\000\000\000\000\000 */
{ 410466 }, /* pm_thresh_exc_128\000\000pmc\000Threshold counter exceeded a value of 128\000event=0x401ea\000\000\000\000\000\000\000 */
{ 410643 }, /* pm_thresh_exc_2048\000\000pmc\000Threshold counter exceeded a value of 2048\000event=0x401ec\000\000\000\000\000\000\000 */
{ 410908 }, /* pm_thresh_exc_256\000\000pmc\000Threshold counter exceed a count of 256\000event=0x101e8\000\000\000\000\000\000\000 */
{ 410991 }, /* pm_thresh_exc_32\000\000pmc\000Threshold counter exceeded a value of 32\000event=0x201e6\000\000\000\000\000\000\000 */
{ 411252 }, /* pm_thresh_exc_4096\000\000pmc\000Threshold counter exceed a count of 4096\000event=0x101e6\000\000\000\000\000\000\000 */
{ 411512 }, /* pm_thresh_exc_512\000\000pmc\000Threshold counter exceeded a value of 512\000event=0x201e8\000\000\000\000\000\000\000 */
{ 411597 }, /* pm_thresh_exc_64\000\000pmc\000IFU non-branch finished\000event=0x301e8\000\000\000\000\000\000Threshold counter exceeded a value of 64\000 */
{ 411912 }, /* pm_thresh_met\000\000pmc\000threshold exceeded\000event=0x101ec\000\000\000\000\000\000\000 */
{ 412160 }, /* pm_thresh_not_met\000\000pmc\000Threshold counter did not meet threshold\000event=0x4016e\000\000\000\000\000\000\000 */
{ 175737 }, /* pm_derat_miss_16g\000\000translation\000Data ERAT Miss (Data TLB Access) page size 16G\000event=0x4c054\000\000\000\000\000\000\000 */
{ 176193 }, /* pm_derat_miss_16m\000\000translation\000Data ERAT Miss (Data TLB Access) page size 16M\000event=0x3c054\000\000\000\000\000\000\000 */
{ 177003 }, /* pm_derat_miss_4k\000\000translation\000Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1c056\000\000\000\000\000\000\000 */
{ 177427 }, /* pm_derat_miss_64k\000\000translation\000Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2c054\000\000\000\000\000\000\000 */
{ 184750 }, /* pm_dpteg_from_dl2l3_mod\000\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request\000event=0x4e048\000\000\000\000\000\000\000 */
{ 185311 }, /* pm_dpteg_from_dl2l3_shr\000\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request\000event=0x3e048\000\000\000\000\000\000\000 */
{ 187628 }, /* pm_dpteg_from_l2\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 due to a data side request\000event=0x1e042\000\000\000\000\000\000\000 */
{ 188418 }, /* pm_dpteg_from_l2_mepf\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a data side request\000event=0x2e040\000\000\000\000\000\000\000 */
{ 188876 }, /* pm_dpteg_from_l2_no_conflict\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a data side request\000event=0x1e040\000\000\000\000\000\000\000 */
{ 189310 }, /* pm_dpteg_from_l2miss\000\000translation\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a data side request\000event=0x1e04e\000\000\000\000\000\000\000 */
{ 191597 }, /* pm_dpteg_from_l3\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 due to a data side request\000event=0x4e042\000\000\000\000\000\000\000 */
{ 192012 }, /* pm_dpteg_from_l3_disp_conflict\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a data side request\000event=0x3e042\000\000\000\000\000\000\000 */
{ 192478 }, /* pm_dpteg_from_l3_mepf\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a data side request\000event=0x2e042\000\000\000\000\000\000\000 */
{ 192934 }, /* pm_dpteg_from_l3_no_conflict\000\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a data side request\000event=0x1e044\000\000\000\000\000\000\000 */
{ 193774 }, /* pm_dpteg_from_ll4\000\000translation\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a data side request\000event=0x1e04c\000\000\000\000\000\000\000 */
{ 194171 }, /* pm_dpteg_from_lmem\000\000translation\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a data side request\000event=0x2e048\000\000\000\000\000\000\000 */
{ 194602 }, /* pm_dpteg_from_memory\000\000translation\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a data side request\000event=0x2e04c\000\000\000\000\000\000\000 */
{ 195113 }, /* pm_dpteg_from_off_chip_cache\000\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a data side request\000event=0x4e04a\000\000\000\000\000\000\000 */
{ 195640 }, /* pm_dpteg_from_on_chip_cache\000\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a data side request\000event=0x1e048\000\000\000\000\000\000\000 */
{ 196169 }, /* pm_dpteg_from_rl2l3_mod\000\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request\000event=0x2e046\000\000\000\000\000\000\000 */
{ 196719 }, /* pm_dpteg_from_rl2l3_shr\000\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request\000event=0x1e04a\000\000\000\000\000\000\000 */
{ 197218 }, /* pm_dpteg_from_rl4\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a data side request\000event=0x2e04a\000\000\000\000\000\000\000 */
{ 199334 }, /* pm_dtlb_miss\000\000translation\000Data PTEG reload\000event=0x300fc\000\000\000\000\000\000Data PTEG Reloaded (DTLB Miss)\000 */
{ 199643 }, /* pm_dtlb_miss_16g\000\000translation\000Data TLB Miss page size 16G\000event=0x1c058\000\000\000\000\000\000\000 */
{ 199937 }, /* pm_dtlb_miss_16m\000\000translation\000Data TLB Miss page size 16M\000event=0x4c056\000\000\000\000\000\000\000 */
{ 200729 }, /* pm_dtlb_miss_4k\000\000translation\000Data TLB Miss page size 4k\000event=0x2c056\000\000\000\000\000\000\000 */
{ 201021 }, /* pm_dtlb_miss_64k\000\000translation\000Data TLB Miss page size 64K\000event=0x3c056\000\000\000\000\000\000\000 */
{ 314543 }, /* pm_lsu_derat_miss\000\000translation\000DERAT Reloaded due to a DERAT miss\000event=0x200f6\000\000\000\000\000\000DERAT Reloaded (Miss)\000 */
{ 412438 }, /* pm_tlb_miss\000\000translation\000TLB Miss (I + D)\000event=0x20066\000\000\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__power8[] = {
{ 98744 }, /* mem_ecc_delay_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_MEM_ECC_DELAY / PM_RUN_INST_CMPL\000\000\000\000\000\000 */
{ 101331 }, /* ntcg_all_fin_cpi\000cpi_breakdown\000\000PM_NTCG_ALL_FIN / PM_RUN_INST_CMPL\000\000\000\000\000\000 */
{ 101403 }, /* ntcg_flush_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NTCG_FLUSH / PM_RUN_INST_CMPL\000\000\000\000\000\000 */
{ 33093 }, /* any_centaur_ld_hit_ratio\000\000\000PM_DATA_FROM_MEMORY / PM_LD_REF_L1\000Fraction of hits on any Centaur (local, remote, or distant) on either L4 or DRAM per L1 load ref\000\000\000\000\000 */
{ 33256 }, /* any_pump_mpred_percent\000bus_stats\000\000PM_PUMP_MPRED * 100 / (PM_PUMP_CPRED + PM_PUMP_MPRED)\000Percent of chip+group+sys pumps that were incorrectly predicted\000\000\000\000\000 */
{ 33617 }, /* average_dl1miss_latency\000latency\000\000PM_MRK_LD_MISS_L1_CYC / PM_MRK_LD_MISS_L1\000average L1 miss latency using marked events\000\000\000\000\000 */
{ 33740 }, /* average_il1_miss_latency\000latency\000\000PM_IC_DEMAND_CYC / PM_IC_DEMAND_REQ\000Average icache miss latency\000\000\000\000\000 */
{ 33842 }, /* average_sync_cyc\000latency\000\000PM_LSU_SRQ_SYNC_CYC / PM_LSU_SRQ_SYNC\000average service time for SYNC\000\000\000\000\000 */
{ 33940 }, /* avg_lmq_life_time\000latency\000\000PM_LSU_LMQ_S0_VALID / PM_LSU_LMQ_S0_ALLOC\000Cycles LMQ slot0 was active on an average\000\000\000\000\000 */
{ 34055 }, /* avg_lrq_life_time_even\000latency\000\000PM_LSU_LRQ_S0_VALID / PM_LSU_LRQ_S0_ALLOC\000Average number of cycles LRQ stays active for one load.  Slot 0 is VALID ONLY FOR EVEN THREADS\000\000\000\000\000 */
{ 34228 }, /* avg_lrq_life_time_odd\000latency\000\000PM_LSU_LRQ_S43_VALID / PM_LSU_LRQ_S43_ALLOC\000Average number of cycles LRQ stays active for one load.  Slot 43 is valid ONLY FOR ODD THREADS\000\000\000\000\000 */
{ 34402 }, /* avg_srq_life_time_even\000latency\000\000PM_LSU_SRQ_S0_VALID / PM_LSU_SRQ_S0_ALLOC\000Average number of cycles SRQ stays active for one load.  Slot 0 is VALID ONLY FOR EVEN THREADS\000\000\000\000\000 */
{ 34575 }, /* avg_srq_life_time_odd\000latency\000\000PM_LSU_SRQ_S39_VALID / PM_LSU_SRQ_S39_ALLOC\000Average number of cycles SRQ stays active for one load.  Slot 39 is valid ONLY FOR ODD THREADS\000\000\000\000\000 */
{ 34749 }, /* avg_stores_gathered\000l2_stats\000\000PM_ST_CMPL / (PM_L2_ST / 2)\000Average number of stores that gather in the store buffer before being sent to an L2 RC machine\000\000\000\000\000 */
{ 34906 }, /* base_completion_cpi\000\000\000PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000Base Completion Cycles\000\000\000\000\000 */
{ 34992 }, /* bc_8_branch_ratio_percent\000branch_prediction\000\000PM_BR_BC_8_CONV / PM_BRU_FIN * 100\000% of finished branches that were treated as BC+8\000\000\000\000\000 */
{ 35125 }, /* bc_8_not_converted_branch_ratio_percent\000branch_prediction\000\000PM_BR_BC_8 / PM_BRU_FIN * 100\000% of finished branches that were pairable but not treated as BC+8\000\000\000\000\000 */
{ 35284 }, /* bkill_latency\000latency\000\000bkill_ratio_percent\000Marked background kill latency, measured in L2\000\000\000\000\000 */
{ 35378 }, /* bkill_ratio_percent\000\000\000PM_MRK_FAB_RSP_BKILL_CYC / PM_MRK_FAB_RSP_BKILL\000Marked background kill latency, measured in L2\000\000\000\000\000 */
{ 35621 }, /* br_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_CMPL / (PM_BR_PRED_BR0 + PM_BR_PRED_BR1) * 100\000Percent of mispredicted branches out of all predicted (correctly and incorrectly) branches that completed\000\000\000\000\000 */
{ 35919 }, /* br_mpred_flush_rate_percent\000general\000\000PM_FLUSH_BR_MPRED / PM_RUN_INST_CMPL * 100\000Branch Mispredict flushes per instruction\000\000\000\000\000 */
{ 36168 }, /* branch_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_CMPL / PM_RUN_INST_CMPL * 100\000% of Branch miss predictions per instruction\000\000\000\000\000 */
{ 36390 }, /* branches_per_inst\000instruction_mix\000\000PM_BRU_FIN / PM_RUN_INST_CMPL\000% Branches per instruction\000\000\000\000\000 */
{ 36486 }, /* bru_cru_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_BRU_CRU / PM_RUN_INST_CMPL\000Cycles stalled due to CRU or BRU operations\000\000\000\000\000 */
{ 36718 }, /* bru_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_BRU / PM_RUN_INST_CMPL\000Cycles stalled due to ISU Branch Operations\000\000\000\000\000 */
{ 36901 }, /* ccache_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_CCACHE / PM_RUN_INST_CMPL * 100\000Count cache branch misprediction per instruction\000\000\000\000\000 */
{ 37048 }, /* ccache_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_CCACHE / (PM_BR_PRED_CCACHE_BR0 + PM_BR_PRED_CCACHE_BR1) * 100\000Percent of count catch mispredictions out of all completed branches that required count cache predictionn\000\000\000\000\000 */
{ 37411 }, /* chip_pump_cpred_percent\000bus_stats\000\000PM_CHIP_PUMP_CPRED * 100 / PM_L2_CHIP_PUMP\000Percent of chip pumps that were correctly predicted as chip pumps the first time\000\000\000\000\000 */
{ 37698 }, /* completion_cpi\000cpi_breakdown\000\000PM_GRP_CMPL / PM_RUN_INST_CMPL\000Cycles in which a Group Completed\000\000\000\000\000 */
{ 37797 }, /* coq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_COQ_FULL / PM_RUN_INST_CMPL\000Cycles stalled by CO queue full\000\000\000\000\000 */
{ 37910 }, /* cpi\000general\000\000PM_CYC / PM_INST_CMPL\000Cycles per instruction\000\000\000\000\000 */
{ 37972 }, /* cr_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_CR / PM_RUN_INST_CMPL * 100\000CR MisPredictions per Instruction\000\000\000\000\000 */
{ 38096 }, /* cru_stall_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_BRU_CRU - PM_CMPLU_STALL_BRU) / PM_RUN_INST_CMPL\000Cycles stalled due to CRU Operations\000\000\000\000\000 */
{ 38415 }, /* custom_secs\000\000\000PM_RUN_CYC\000cycles\000\000\000\000\000 */
{ 38451 }, /* cyc_grp_completed_percent\000general\000\000PM_GRP_CMPL / PM_CYC * 100\000Percentage Cycles a group completed\000\000\000\000\000 */
{ 38553 }, /* cyc_grp_dispatched_percent\000general\000\000PM_1PLUS_PPC_DISP / PM_CYC * 100\000Percentage Cycles a group dispatched\000\000\000\000\000 */
{ 38663 }, /* cyc_per_group\000general\000\000PM_CYC / PM_1PLUS_PPC_CMPL\000Cycles per group\000\000\000\000\000 */
{ 39031 }, /* dcache_miss_cpi_percent\000estimated_dcache_miss_cpi\000\000lsu_stall_dcache_miss_cpi / run_cpi * 100\000dL1 miss portion of CPI\000\000\000\000\000 */
{ 39343 }, /* dclaim_latency\000latency\000\000PM_MRK_FAB_RSP_DCLAIM_CYC / PM_MRK_FAB_RSP_DCLAIM\000Marked dclaim latency, measured in L2\000\000\000\000\000 */
{ 39459 }, /* derat_16g_miss_rate_percent\000translation\000\000100 * PM_DERAT_MISS_16G / PM_RUN_INST_CMPL\000% DERAT miss ratio for 16G page per inst\000\000\000\000\000 */
{ 39588 }, /* derat_16g_miss_ratio\000translation\000\000PM_DERAT_MISS_16G / PM_LSU_DERAT_MISS\000DERAT miss ratio for 16G page\000\000\000\000\000 */
{ 39694 }, /* derat_16m_miss_rate_percent\000translation\000\000PM_DERAT_MISS_16M * 100 / PM_RUN_INST_CMPL\000% DERAT miss rate for 16M page per inst\000\000\000\000\000 */
{ 39822 }, /* derat_16m_miss_ratio\000translation\000\000PM_DERAT_MISS_16M / PM_LSU_DERAT_MISS\000DERAT miss ratio for 16M page\000\000\000\000\000 */
{ 39928 }, /* derat_4k_miss_rate_percent\000translation\000\000PM_DERAT_MISS_4K * 100 / PM_RUN_INST_CMPL\000% DERAT miss rate for 4K page per inst\000\000\000\000\000 */
{ 40053 }, /* derat_4k_miss_ratio\000translation\000\000PM_DERAT_MISS_4K / PM_LSU_DERAT_MISS\000DERAT miss ratio for 4K page\000\000\000\000\000 */
{ 40156 }, /* derat_64k_miss_rate_percent\000translation\000\000PM_DERAT_MISS_64K * 100 / PM_RUN_INST_CMPL\000% DERAT miss ratio for 64K page per inst\000\000\000\000\000 */
{ 40285 }, /* derat_64k_miss_ratio\000translation\000\000PM_DERAT_MISS_64K / PM_LSU_DERAT_MISS\000DERAT miss ratio for 64K page\000\000\000\000\000 */
{ 40391 }, /* derat_miss_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_LSU_DERAT_MISS * 100 / PM_RUN_INST_CMPL\000DERAT Miss Rate (per run  instruction)(%)\000\000\000\000\000 */
{ 40767 }, /* derat_miss_reload_percent\000pteg_reloads_percent_per_ref\000\000PM_DTLB_MISS * 100 / PM_LSU_DERAT_MISS\000% of DERAT misses that result in an ERAT reload\000\000\000\000\000 */
{ 41447 }, /* disp_flush_rate_percent\000general\000\000PM_FLUSH_DISP / PM_RUN_INST_CMPL * 100\000GCT empty cycles\000\000\000\000\000 */
{ 41674 }, /* distant_centaur_ld_hit_ratio\000\000\000(PM_DATA_FROM_DMEM + PM_DATA_FROM_DL4) / PM_LD_REF_L1\000Fraction of hits on a distant chip's Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000 */
{ 41837 }, /* dl1_miss_reloads_percent\000dl1_reloads_percent_per_ref\000\000PM_L1_DCACHE_RELOAD_VALID * 100 / PM_LD_MISS_L1\000% of DL1 misses that result in a cache reload\000\000\000\000\000 */
{ 41989 }, /* dl1_reload_from_dl2l3_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L2 or L3 (Modified)\000\000\000\000\000 */
{ 42167 }, /* dl1_reload_from_dl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000 */
{ 42347 }, /* dl1_reload_from_dl2l3_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L2 or L3 (Shared)\000\000\000\000\000 */
{ 42523 }, /* dl1_reload_from_dl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000 */
{ 42823 }, /* dl1_reload_from_dl4_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L4\000\000\000\000\000 */
{ 43095 }, /* dl1_reload_from_dl4_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L4 per Inst\000\000\000\000\000 */
{ 43246 }, /* dl1_reload_from_dmem_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant Memory\000\000\000\000\000 */
{ 43401 }, /* dl1_reload_from_dmem_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant Memory per Inst\000\000\000\000\000 */
{ 43558 }, /* dl1_reload_from_l21_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L21_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L2, other core\000\000\000\000\000 */
{ 43723 }, /* dl1_reload_from_l21_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000 */
{ 43894 }, /* dl1_reload_from_l21_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L21_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L2, other core\000\000\000\000\000 */
{ 44059 }, /* dl1_reload_from_l21_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000 */
{ 44230 }, /* dl1_reload_from_l2_lhs_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L2 with a Load-Hit-Store conflict\000\000\000\000\000 */
{ 44431 }, /* dl1_reload_from_l2_lhs_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST * 100 / PM_RUN_INST_CMPL\000Percentage of L2 load hits per instruction where the L2 experienced a Load-Hit-Store conflict\000\000\000\000\000 */
{ 44658 }, /* dl1_reload_from_l2_miss_percent\000\000\000PM_DATA_FROM_L2MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads that came from the L3 and beyond\000\000\000\000\000 */
{ 44969 }, /* dl1_reload_from_l2_miss_rate_percent\000dl1_reloads_percent_per_inst\000\000l2_ld_miss_rate_percent\000% of DL1 reloads from L2 per Inst\000\000\000\000\000 */
{ 45098 }, /* dl1_reload_from_l2_no_conflict_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2_NO_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L2 with no conflicts\000\000\000\000\000 */
{ 45284 }, /* dl1_reload_from_l2_no_conflict_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L2_NO_CONFLICT * 100 / PM_RUN_INST_CMPL\000Percentage of L2 load hits per instruction where the L2 did not experience a conflict\000\000\000\000\000 */
{ 45501 }, /* dl1_reload_from_l2_other_conflict_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L2 with some conflict other than Load-Hit-Store\000\000\000\000\000 */
{ 45725 }, /* dl1_reload_from_l2_other_conflict_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER * 100 / PM_RUN_INST_CMPL\000Percentage of L2 load hits per instruction where the L2 experienced some conflict other than Load-Hit-Store\000\000\000\000\000 */
{ 45975 }, /* dl1_reload_from_l2_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from L2\000\000\000\000\000 */
{ 46110 }, /* dl1_reload_from_l2_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L2 * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from L2 per Inst\000\000\000\000\000 */
{ 46251 }, /* dl1_reload_from_l31_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L31_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L3, other core\000\000\000\000\000 */
{ 46416 }, /* dl1_reload_from_l31_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3 M state, other core per Inst\000\000\000\000\000 */
{ 46595 }, /* dl1_reload_from_l31_rate_percent\000\000\000(PM_DATA_FROM_L31_MOD + PM_DATA_FROM_L31_SHR) * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000 */
{ 46928 }, /* dl1_reload_from_l31_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L31_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L3, other core\000\000\000\000\000 */
{ 47093 }, /* dl1_reload_from_l31_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3 S tate, other core per Inst\000\000\000\000\000 */
{ 47271 }, /* dl1_reload_from_l3_conflict_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3_DISP_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L3 where the load collided with a pending prefetch\000\000\000\000\000 */
{ 47486 }, /* dl1_reload_from_l3_conflict_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L3_DISP_CONFLICT * 100 / PM_RUN_INST_CMPL\000Percentage of L3 load hits per instruction where the load collided with a pending prefetch\000\000\000\000\000 */
{ 47707 }, /* dl1_reload_from_l3_mepf_percent\000\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L3 where the lines were brought into the L3 by a prefetch operation\000\000\000\000\000 */
{ 48323 }, /* dl1_reload_from_l3_mepf_rate_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000Percentage of L3 load hits per instruction where the line was brought into the L3 by a prefetch operation\000\000\000\000\000 */
{ 48545 }, /* dl1_reload_from_l3_miss_percent\000\000\000PM_DATA_FROM_L3MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads from beyond the local L3\000\000\000\000\000 */
{ 48848 }, /* dl1_reload_from_l3_miss_rate_percent\000dl1_reloads_percent_per_inst\000\000l3_ld_miss_rate_percent\000% of DL1 reloads from L3 per Inst\000\000\000\000\000 */
{ 48977 }, /* dl1_reload_from_l3_no_conflict_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3_NO_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000Percentage of DL1 reloads from L3 without conflicts\000\000\000\000\000 */
{ 49163 }, /* dl1_reload_from_l3_no_conflict_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L3_NO_CONFLICT * 100 / PM_RUN_INST_CMPL\000Percentage of L3 load hits per instruction where the L3 did not experience a conflict\000\000\000\000\000 */
{ 49380 }, /* dl1_reload_from_l3_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads from L3\000\000\000\000\000 */
{ 49515 }, /* dl1_reload_from_l3_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L3 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from L3 per Inst\000\000\000\000\000 */
{ 49776 }, /* dl1_reload_from_ll4_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_LL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Local L4\000\000\000\000\000 */
{ 50044 }, /* dl1_reload_from_ll4_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Local L4 per Inst\000\000\000\000\000 */
{ 50193 }, /* dl1_reload_from_lmem_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_LMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Local Memory\000\000\000\000\000 */
{ 50346 }, /* dl1_reload_from_lmem_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Local Memory per Inst\000\000\000\000\000 */
{ 50501 }, /* dl1_reload_from_rl2l3_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L2 or L3 (Modified)\000\000\000\000\000 */
{ 50678 }, /* dl1_reload_from_rl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000 */
{ 50853 }, /* dl1_reload_from_rl2l3_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L2 or L3 (Shared)\000\000\000\000\000 */
{ 51028 }, /* dl1_reload_from_rl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000 */
{ 51324 }, /* dl1_reload_from_rl4_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L4\000\000\000\000\000 */
{ 51598 }, /* dl1_reload_from_rl4_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000 */
{ 51752 }, /* dl1_reload_from_rmem_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote Memory\000\000\000\000\000 */
{ 51906 }, /* dl1_reload_from_rmem_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000 */
{ 52333 }, /* dl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL2L3_MOD / PM_RUN_INST_CMPL * dl2l3_mod_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2l3 distant MOD miss rates with measured DL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 52580 }, /* dl2l3_mod_latency\000latency\000\000PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD\000Marked L2L3 remote Load latency\000\000\000\000\000 */
{ 52703 }, /* dl2l3_mod_ld_hit_ratio\000\000\000PM_DATA_FROM_DL2L3_MOD / PM_LD_REF_L1\000Fraction of hits of a line in the M (exclusive) state on the L2 or L3 of a core on a distant chip per L1 load ref\000\000\000\000\000 */
{ 53155 }, /* dl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL2L3_SHR / PM_RUN_INST_CMPL * dl2l3_shr_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2l3 distant SHR miss rates with measured DL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 53402 }, /* dl2l3_shr_latency\000latency\000\000PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR\000Marked L2L3 distant Load latency\000\000\000\000\000 */
{ 53526 }, /* dl2l3_shr_ld_hit_ratio\000\000\000PM_DATA_FROM_DL2L3_SHR / PM_LD_REF_L1\000Fraction of hits of a line in the S state on the L2 or L3 of a core on a distant chip per L1 load ref\000\000\000\000\000 */
{ 53929 }, /* dl4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL4 / PM_RUN_INST_CMPL * dl4_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of distant L4 miss rates with measured DL4 latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 54145 }, /* dl4_latency\000latency\000\000PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4\000Distant L4 average load latency\000\000\000\000\000 */
{ 54250 }, /* dl4_ld_hit_ratio\000\000\000PM_DATA_FROM_DL4 / PM_LD_REF_L1\000Fraction of hits on a distant Centaur's cache per L1 load ref\000\000\000\000\000 */
{ 54610 }, /* dmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DMEM / PM_RUN_INST_CMPL * dmem_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of distant memory miss rates with measured DMEM latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 54834 }, /* dmem_latency\000latency\000\000PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM\000Marked Dmem Load latency\000\000\000\000\000 */
{ 54935 }, /* dmem_ld_hit_ratio\000\000\000PM_DATA_FROM_DMEM / PM_LD_REF_L1\000Fraction of hits on a distant Centaur's DRAM per L1 load ref\000\000\000\000\000 */
{ 57282 }, /* dpteg_from_l2_rate_percent\000\000\000PM_DPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000Rate of DERAT reloads from L2\000\000\000\000\000 */
{ 57387 }, /* dpteg_from_l3_rate_percent\000\000\000PM_DPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000Rate of DERAT reloads from L3\000\000\000\000\000 */
{ 57492 }, /* dslb_miss_rate_percent\000translation\000\000PM_DSLB_MISS * 100 / PM_RUN_INST_CMPL\000% DSLB_Miss_Rate per inst\000\000\000\000\000 */
{ 57596 }, /* dtlb_miss_rate_percent\000general\000\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000% DTLB miss rate per inst\000\000\000\000\000 */
{ 58408 }, /* erat_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_ERAT_MISS * 100 / PM_RUN_INST_CMPL\000ERAT miss reject ratio\000\000\000\000\000 */
{ 58522 }, /* erat_reject_ratio_percent\000lsu_rejects\000\000PM_LSU_REJECT_ERAT_MISS * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000ERAT miss reject ratio\000\000\000\000\000 */
{ 59548 }, /* expansion_overhead_cpi\000\000\000completion_cpi - base_completion_cpi\000Overhead of expansion cycles\000\000\000\000\000 */
{ 59643 }, /* exposed_dl1miss_latency\000latency\000\000PM_MRK_LD_MISS_EXPOSED_CYC / PM_MRK_LD_MISS_EXPOSED\000estimated exposed miss latency for dL1 misses, ie load miss when we were NTC\000\000\000\000\000 */
{ 59988 }, /* fixed_in_lsu_per_inst\000\000\000PM_LSU_FX_FIN / PM_RUN_INST_CMPL\000Total Fixed point operations executded in the Load/Store Unit following a load/store operation\000\000\000\000\000 */
{ 60224 }, /* fixed_per_inst\000instruction_mix\000\000(PM_FXU0_FIN + PM_FXU1_FIN) / PM_RUN_INST_CMPL\000Total Fixed point operations\000\000\000\000\000 */
{ 60584 }, /* flush_rate_percent\000general\000\000PM_FLUSH * 100 / PM_RUN_INST_CMPL\000Flush rate (%)\000\000\000\000\000 */
{ 60665 }, /* flush_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FLUSH / PM_RUN_INST_CMPL\000Cycles stalled by flushes\000\000\000\000\000 */
{ 60937 }, /* fxu0_balance\000instruction_mix\000\000PM_FXU0_FIN / (PM_FXU0_FIN + PM_FXU1_FIN)\000FXU0 balance\000\000\000\000\000 */
{ 61026 }, /* fxu0_fin\000instruction_mix\000\000PM_FXU0_FIN / PM_RUN_CYC\000Fraction of cycles that FXU0 is in use\000\000\000\000\000 */
{ 61120 }, /* fxu0_only_busy\000instruction_mix\000\000PM_FXU0_BUSY_FXU1_IDLE / PM_CYC\000FXU0 only Busy\000\000\000\000\000 */
{ 61203 }, /* fxu1_fin\000instruction_mix\000\000PM_FXU1_FIN / PM_RUN_CYC\000Fraction of cycles that FXU1 is in use\000\000\000\000\000 */
{ 61297 }, /* fxu1_only_busy\000instruction_mix\000\000PM_FXU1_BUSY_FXU0_IDLE / PM_CYC\000FXU1 only Busy\000\000\000\000\000 */
{ 61486 }, /* fxu_both_busy\000instruction_mix\000\000PM_FXU_BUSY / PM_CYC\000Both FXU Busy\000\000\000\000\000 */
{ 61556 }, /* fxu_both_idle\000instruction_mix\000\000PM_FXU_IDLE / PM_CYC\000Both FXU Idle\000\000\000\000\000 */
{ 61626 }, /* fxu_multi_cyc_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000Cycles stalled by FXU Multi-Cycle Instructions\000\000\000\000\000 */
{ 61863 }, /* fxu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL\000Cycles stalled by FXU\000\000\000\000\000 */
{ 62175 }, /* fxu_stall_other_cpi\000cpi_breakdown\000\000fxu_stall_cpi - fxu_multi_cyc_cpi\000Other cycles stalled by FXU\000\000\000\000\000 */
{ 62276 }, /* gct_empty_br_mpred_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL\000Cycles GCT empty due to Branch Mispredicts\000\000\000\000\000 */
{ 62403 }, /* gct_empty_br_mpred_ic_miss_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000Cycles GCT empty due to Branch Mispredicts and Icache Misses\000\000\000\000\000 */
{ 62563 }, /* gct_empty_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_CYC / PM_RUN_INST_CMPL\000GCT empty cycles\000\000\000\000\000 */
{ 62650 }, /* gct_empty_disp_held_cpi\000cpi_breakdown\000\000(PM_GCT_NOSLOT_DISP_HELD_MAP + PM_GCT_NOSLOT_DISP_HELD_SRQ + PM_GCT_NOSLOT_DISP_HELD_ISSQ + PM_GCT_NOSLOT_DISP_HELD_OTHER) / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held\000\000\000\000\000 */
{ 62876 }, /* gct_empty_disp_held_issq_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held due to issue queue\000\000\000\000\000 */
{ 63032 }, /* gct_empty_disp_held_map_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_DISP_HELD_MAP / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held due to maps\000\000\000\000\000 */
{ 63179 }, /* gct_empty_disp_held_other_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_DISP_HELD_OTHER / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held due to syncs and other effects\000\000\000\000\000 */
{ 63349 }, /* gct_empty_disp_held_srq_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_DISP_HELD_SRQ / PM_RUN_INST_CMPL\000Cycles GCT empty where dispatch was held due to SRQ\000\000\000\000\000 */
{ 63495 }, /* gct_empty_ic_miss_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL\000Cycles stalled by GCT empty due to Icache misses\000\000\000\000\000 */
{ 63626 }, /* gct_empty_ic_miss_l2l3_cpi\000cpi_breakdown\000\000(PM_GCT_NOSLOT_IC_MISS - PM_GCT_NOSLOT_IC_L3MISS) / PM_RUN_INST_CMPL\000Cycles stalled by GCT empty due to Icache misses that resolve in the local L2 or L3\000\000\000\000\000 */
{ 63825 }, /* gct_empty_ic_miss_l3miss_cpi\000cpi_breakdown\000\000PM_GCT_NOSLOT_IC_L3MISS / PM_RUN_INST_CMPL\000Cycles stalled by GCT empty due to Icache misses that resolve off-chip\000\000\000\000\000 */
{ 63987 }, /* gct_empty_other_cpi\000cpi_breakdown\000\000gct_empty_cpi - gct_empty_ic_miss_cpi - gct_empty_br_mpred_cpi - gct_empty_br_mpred_ic_miss_cpi - (gct_empty_disp_held_map_cpi + gct_empty_disp_held_srq_cpi + gct_empty_disp_held_issq_cpi + gct_empty_disp_held_other_cpi)\000Other GCT empty cycles\000\000\000\000\000 */
{ 64270 }, /* gct_empty_percent\000\000\000PM_GCT_NOSLOT_CYC / PM_RUN_CYC * 100\000GCT empty cycles\000\000\000\000\000 */
{ 64348 }, /* gct_util_11to14_slots_percent\000general\000\000PM_GCT_UTIL_11_14_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (11 to 14) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000 */
{ 64545 }, /* gct_util_15to17_slots_percent\000general\000\000PM_GCT_UTIL_15_17_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (15 to 17) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000 */
{ 64742 }, /* gct_util_18plus_slots_percent\000general\000\000PM_GCT_UTIL_18_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization 18+ as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000 */
{ 64929 }, /* gct_util_1to2_slots_percent\000general\000\000PM_GCT_UTIL_1_2_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (1 to 2) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000 */
{ 65120 }, /* gct_util_3to6_slots_percent\000general\000\000PM_GCT_UTIL_3_6_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (3 to 6) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000 */
{ 65311 }, /* gct_util_7to10_slots_percent\000general\000\000PM_GCT_UTIL_7_10_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000GCT slot utilization (7 to 10) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000 */
{ 65505 }, /* group_pump_cpred_percent\000bus_stats\000\000PM_GRP_PUMP_CPRED * 100 / PM_L2_GROUP_PUMP\000Percent of group pumps that were correctly predicted as group pumps the first time\000\000\000\000\000 */
{ 65671 }, /* group_size\000general\000\000inst_per_group\000Avg. group size\000\000\000\000\000 */
{ 65726 }, /* hwsync_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_HWSYNC / PM_RUN_INST_CMPL\000Cycles stalled by heavyweight syncs\000\000\000\000\000 */
{ 65903 }, /* icache_miss_reload\000instruction_stats_percent_per_ref\000\000(PM_L1_ICACHE_MISS - PM_IC_PREF_WRITE) / PM_L1_ICACHE_MISS\000Icache Fetchs per Icache Miss\000\000\000\000\000 */
{ 66050 }, /* icache_pref_percent\000instruction_stats_percent_per_ref\000\000PM_IC_PREF_WRITE * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads due to prefetch\000\000\000\000\000 */
{ 68842 }, /* inst_from_dl2l3_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant L2 or L3 (Modified)\000\000\000\000\000 */
{ 69011 }, /* inst_from_dl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000 */
{ 69195 }, /* inst_from_dl2l3_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant L2 or L3 (Shared)\000\000\000\000\000 */
{ 69362 }, /* inst_from_dl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000 */
{ 69544 }, /* inst_from_dl4_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DL4 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant L4\000\000\000\000\000 */
{ 69684 }, /* inst_from_dl4_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant L4 per Inst\000\000\000\000\000 */
{ 69839 }, /* inst_from_dmem_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DMEM * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant Memory\000\000\000\000\000 */
{ 69985 }, /* inst_from_dmem_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant Memory per Inst\000\000\000\000\000 */
{ 70146 }, /* inst_from_l21_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L21_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L2, other core\000\000\000\000\000 */
{ 70306 }, /* inst_from_l21_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000 */
{ 70481 }, /* inst_from_l21_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L21_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L2, other core\000\000\000\000\000 */
{ 70641 }, /* inst_from_l21_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000 */
{ 70816 }, /* inst_from_l2_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L2 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from L2\000\000\000\000\000 */
{ 70946 }, /* inst_from_l2_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L2 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from L2 per Inst\000\000\000\000\000 */
{ 71091 }, /* inst_from_l31_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L31_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L3, other core\000\000\000\000\000 */
{ 71251 }, /* inst_from_l31_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L3, other core per Inst\000\000\000\000\000 */
{ 71426 }, /* inst_from_l31_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L31_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L3, other core\000\000\000\000\000 */
{ 71586 }, /* inst_from_l31_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L3 other core per Inst\000\000\000\000\000 */
{ 71760 }, /* inst_from_l3_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L3 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from L3\000\000\000\000\000 */
{ 71890 }, /* inst_from_l3_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L3 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from L3 per Inst\000\000\000\000\000 */
{ 72035 }, /* inst_from_ll4_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_LL4 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Local L4\000\000\000\000\000 */
{ 72173 }, /* inst_from_ll4_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Local L4 per Inst\000\000\000\000\000 */
{ 72326 }, /* inst_from_lmem_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_LMEM * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Local Memory\000\000\000\000\000 */
{ 72470 }, /* inst_from_lmem_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Local Memory per Inst\000\000\000\000\000 */
{ 72629 }, /* inst_from_rl2l3_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote L2 or L3 (Modified)\000\000\000\000\000 */
{ 72797 }, /* inst_from_rl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote L2 or L3 (Modified) per Inst\000\000\000\000\000 */
{ 72980 }, /* inst_from_rl2l3_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote L2 or L3 (Shared)\000\000\000\000\000 */
{ 73146 }, /* inst_from_rl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote L2 or L3 (Shared) per Inst\000\000\000\000\000 */
{ 73327 }, /* inst_from_rl4_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RL4 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote L4\000\000\000\000\000 */
{ 73466 }, /* inst_from_rl4_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote L4 per Inst\000\000\000\000\000 */
{ 73620 }, /* inst_from_rmem_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RMEM * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote Memory\000\000\000\000\000 */
{ 73765 }, /* inst_from_rmem_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote Memory per Inst\000\000\000\000\000 */
{ 73925 }, /* inst_per_group\000general\000\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000Instructions per group\000\000\000\000\000 */
{ 74009 }, /* ipc\000general\000\000PM_INST_CMPL / PM_CYC\000Instructions per cycles\000\000\000\000\000 */
{ 74072 }, /* ipteg_from_l2_rate_percent\000\000\000PM_IPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from L2\000\000\000\000\000 */
{ 74177 }, /* ipteg_from_l3_rate_percent\000\000\000PM_IPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from L3\000\000\000\000\000 */
{ 74282 }, /* ipteg_from_ll4_rate_percent\000\000\000PM_IPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from local memory\000\000\000\000\000 */
{ 74399 }, /* ipteg_from_lmem_rate_percent\000\000\000PM_IPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from local memory\000\000\000\000\000 */
{ 74518 }, /* islb_miss_rate_percent\000translation\000\000PM_ISLB_MISS * 100 / PM_RUN_INST_CMPL\000% ISLB miss rate per inst\000\000\000\000\000 */
{ 74738 }, /* itlb_miss_rate_percent\000general\000\000PM_ITLB_MISS / PM_RUN_INST_CMPL * 100\000% ITLB miss rate per inst\000\000\000\000\000 */
{ 74838 }, /* l1_inst_miss_rate_percent\000instruction_misses_percent_per_inst\000\000PM_L1_ICACHE_MISS * 100 / PM_RUN_INST_CMPL\000Instruction Cache Miss Rate (Per run Instruction)(%)\000\000\000\000\000 */
{ 75001 }, /* l1_ld_hit_ratio\000\000\000(PM_LD_REF_L1 - PM_LD_MISS_L1) / PM_LD_REF_L1\000Fraction of L1 hits per load ref\000\000\000\000\000 */
{ 75102 }, /* l1_ld_miss_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_LD_MISS_L1 * 100 / PM_RUN_INST_CMPL\000Percentage of L1 demand load misses per run instruction\000\000\000\000\000 */
{ 75255 }, /* l1_ld_miss_ratio\000\000\000PM_LD_MISS_L1 / PM_LD_REF_L1\000Fraction of L1 load misses per L1 load ref\000\000\000\000\000 */
{ 75468 }, /* l1_ld_miss_ratio_percent\000general\000\000l1_ld_miss_ratio * 100\000Percentage of L1 load misses per L1 load ref\000\000\000\000\000 */
{ 75849 }, /* l1_st_miss_rate_percent\000general\000\000l2_st_miss_rate_percent\000Percentage of L1 store misses per run instruction\000\000\000\000\000 */
{ 75960 }, /* l1_st_miss_ratio_percent\000general\000\000PM_ST_MISS_L1 / PM_ST_FIN * 100\000Percentage of L1 store misses per L1 store ref\000\000\000\000\000 */
{ 76329 }, /* l21_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L21_MOD / PM_RUN_INST_CMPL * l21_mod_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl21 MOD miss rates with measured L21 MOD latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 76559 }, /* l21_mod_latency\000latency\000\000PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD\000Average load latency for all marked demand loads that came from L2.1 in the M state\000\000\000\000\000 */
{ 77089 }, /* l21_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L21_SHR / PM_RUN_INST_CMPL * l21_shr_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl21 SHR miss rates with measured L21 SHR latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 77319 }, /* l21_shr_latency\000latency\000\000PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR\000Average load latency for all marked demand loads that came from L2.1 in the S state\000\000\000\000\000 */
{ 77597 }, /* l2_1_ld_hit_ratio\000\000\000(PM_DATA_FROM_L21_MOD + PM_DATA_FROM_L21_SHR) / PM_LD_REF_L1\000Fraction of hits on another core's L2 on the same chip per L1 load ref\000\000\000\000\000 */
{ 77753 }, /* l2_1_mod_ld_hit_ratio\000\000\000PM_DATA_FROM_L21_MOD / PM_LD_REF_L1\000Fraction of hits of a line in the M (exclusive) state on another core's L2 on the same chip per L1 load ref\000\000\000\000\000 */
{ 77925 }, /* l2_1_shr_ld_hit_ratio\000\000\000PM_DATA_FROM_L21_SHR / PM_LD_REF_L1\000Fraction of hits of a line in the S state on another core's L2 on the same chip per L1 load ref\000\000\000\000\000 */
{ 78085 }, /* l2_co_usage\000\000\000PM_CO_USAGE / PM_RUN_CYC * 16\000Average number of Castout machines used.  1 of 16 CO machines is sampled every L2 cycle\000\000\000\000\000 */
{ 78578 }, /* l2_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L2 / PM_RUN_INST_CMPL * l2_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2 miss rates with measured L2 latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 78928 }, /* l2_disp_conflict_ldhitst_latency\000latency\000\000PM_MRK_DATA_FROM_L2_DISP_CONFLICT_LDHITST_CYC / PM_MRK_DATA_FROM_L2_DISP_CONFLICT_LDHITST\000Average load latency for all marked demand loads that came from the L2 and suffered a conflict at RC machine dispatch time due to load-hit-store\000\000\000\000\000 */
{ 79209 }, /* l2_disp_conflict_other_latency\000latency\000\000PM_MRK_DATA_FROM_L2_DISP_CONFLICT_OTHER_CYC / PM_MRK_DATA_FROM_L2_DISP_CONFLICT_OTHER\000Average load latency for all marked demand loads that came from the L2 and suffered a conflict at RC machine dispatch time NOT due load-hit-store\000\000\000\000\000 */
{ 79485 }, /* l2_inst_miss_rate_percent\000general\000\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000 */
{ 79759 }, /* l2_latency\000latency\000\000PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2\000Average load latency for all marked demand loads that came from the L2\000\000\000\000\000 */
{ 80117 }, /* l2_ld_hit_ratio\000\000\000PM_DATA_FROM_L2 / PM_LD_REF_L1\000Fraction of L2 load hits per L1 load ref\000\000\000\000\000 */
{ 80211 }, /* l2_ld_miss_rate_percent\000general\000\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 dmand  Load Miss Rate (per run instruction)(%)\000\000\000\000\000 */
{ 80474 }, /* l2_ld_miss_ratio\000\000\000PM_DATA_FROM_L2MISS / PM_LD_REF_L1\000Fraction of L2 load misses per L1 load ref\000\000\000\000\000 */
{ 80575 }, /* l2_lhs_ld_hit_ratio\000\000\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST / PM_LD_REF_L1\000Fraction of L2 load hits per L1 load ref where the L2 experienced a Load-Hit-Store conflict\000\000\000\000\000 */
{ 80746 }, /* l2_mepf_latency\000latency\000\000PM_MRK_DATA_FROM_L2_MEPF_CYC / PM_MRK_DATA_FROM_L2\000Average load latency for all marked demand loads that were satisfied by lines prefetched into the L3.  This information is forwarded from the L3\000\000\000\000\000 */
{ 80971 }, /* l2_no_conflict_latency\000latency\000\000PM_MRK_DATA_FROM_L2_NO_CONFLICT_CYC / PM_MRK_DATA_FROM_L2\000Average load latency for all marked demand loads that came from the L2 and suffered no conflicts\000\000\000\000\000 */
{ 81162 }, /* l2_no_conflict_ld_hit_ratio\000\000\000PM_DATA_FROM_L2_NO_CONFLICT / PM_LD_REF_L1\000Fraction of L2 load hits per L1 load ref where the L2 did not experience a conflict\000\000\000\000\000 */
{ 81323 }, /* l2_other_conflict_ld_hit_ratio\000\000\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER / PM_LD_REF_L1\000Fraction of L2 load hits per L1 load ref where the L2 experienced some conflict other than Load-Hit-Store\000\000\000\000\000 */
{ 81517 }, /* l2_pteg_miss_rate_percent\000general\000\000PM_DPTEG_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000 */
{ 81761 }, /* l2_rc_usage\000\000\000PM_RC_USAGE / PM_RUN_CYC * 16\000Average number of Read/Claim machines used.  1 of 16 RC machines is sampled every L2 cycle\000\000\000\000\000 */
{ 82038 }, /* l2_sn_usage\000\000\000PM_SN_USAGE / PM_RUN_CYC * 8\000Average number of Snoop machines used.  1 of 8 SN machines is sampled every L2 cycle\000\000\000\000\000 */
{ 82702 }, /* l2_st_miss_rate_percent\000general\000\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000Percentage of L2 store misses per run instruction\000\000\000\000\000 */
{ 82828 }, /* l2_st_miss_ratio_percent\000l2_stats\000\000PM_L2_ST_MISS / PM_L2_ST * 100\000L2  Store misses  as a % of total L2  Store dispatches (per thread)\000\000\000\000\000 */
{ 83245 }, /* l2_store_miss_ratio_percent\000l2_stats\000\000PM_L2_ST_MISS / (PM_L2_ST / 2)\000Percentage of L2 store misses per drained store.  A drained store may contain multiple individual stores if they target the same line\000\000\000\000\000 */
{ 83452 }, /* l2miss_latency\000latency\000\000PM_MRK_DATA_FROM_L2MISS_CYC / PM_MRK_DATA_FROM_L2MISS\000Average load latency for all marked demand loads that came from the L3 and beyond\000\000\000\000\000 */
{ 83616 }, /* l31_latency\000\000\000(PM_MRK_DATA_FROM_L31_SHR_CYC + PM_MRK_DATA_FROM_L31_MOD_CYC) / (PM_MRK_DATA_FROM_L31_SHR + PM_MRK_DATA_FROM_L31_MOD)\000Marked L31 Load latency\000\000\000\000\000 */
{ 84028 }, /* l31_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L31_MOD / PM_RUN_INST_CMPL * l31_mod_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl31 MOD miss rates with measured L31 MOD latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 84258 }, /* l31_mod_latency\000latency\000\000PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD\000Marked L31 Load latency\000\000\000\000\000 */
{ 84619 }, /* l31_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L31_SHR / PM_RUN_INST_CMPL * l31_shr_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl31 SHR miss rates with measured L31 SHR latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 84849 }, /* l31_shr_latency\000latency\000\000PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR\000Marked L31 Load latency\000\000\000\000\000 */
{ 84958 }, /* l3_1_ld_hit_ratio\000\000\000(PM_DATA_FROM_L31_MOD + PM_DATA_FROM_L31_SHR) / PM_LD_REF_L1\000Fraction of hits on another core's L3 on the same chip per L1 load ref\000\000\000\000\000 */
{ 85114 }, /* l3_1_mod_ld_hit_ratio\000\000\000PM_DATA_FROM_L31_MOD / PM_LD_REF_L1\000Fraction of hits of a line in the M (exclusive) state on another core's L3 on the same chip per L1 load ref\000\000\000\000\000 */
{ 85286 }, /* l3_1_shr_ld_hit_ratio\000\000\000PM_DATA_FROM_L31_SHR / PM_LD_REF_L1\000Fraction of hits of a line in the S state on another core's L3 on the same chip per L1 load ref\000\000\000\000\000 */
{ 85543 }, /* l3_conflict_ld_hit_ratio\000\000\000PM_DATA_FROM_L3_DISP_CONFLICT / PM_LD_REF_L1\000Fraction of L3 load hits per load ref where the demand load collided with a pending prefetch\000\000\000\000\000 */
{ 85935 }, /* l3_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L3 / PM_RUN_INST_CMPL * l3_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl3 miss rates with measured L3 latency as a % of dcache miss cpi\000\000\000\000\000 */
{ 86141 }, /* l3_inst_miss_rate_percent\000general\000\000PM_INST_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000L3 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000 */
{ 86271 }, /* l3_latency\000latency\000\000PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3\000Average load latency for all marked demand loads that came from the L3\000\000\000\000\000 */
{ 86505 }, /* l3_ld_hit_ratio\000\000\000PM_DATA_FROM_L3 / PM_LD_REF_L1\000Fraction of L3 load hits per L1 load ref\000\000\000\000\000 */
{ 86599 }, /* l3_ld_miss_rate_percent\000general\000\000PM_DATA_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000L3 demand Load Miss Rate (per run instruction)(%)\000\000\000\000\000 */
{ 86731 }, /* l3_ld_miss_ratio\000\000\000PM_DATA_FROM_L3MISS / PM_LD_REF_L1\000Fraction of L3 load misses per L1 load ref\000\000\000\000\000 */
{ 86832 }, /* l3_no_conflict_latency\000latency\000\000PM_MRK_DATA_FROM_L3_NO_CONFLICT_CYC / PM_MRK_DATA_FROM_L2\000Average load latency for all marked demand loads that came from the L3 and suffered no conflicts\000\000\000\000\000 */
{ 87023 }, /* l3_no_conflict_ld_hit_ratio\000\000\000PM_DATA_FROM_L3_NO_CONFLICT / PM_LD_REF_L1\000Fraction of L3 load hits per load ref where the L3 did not experience a conflict\000\000\000\000\000 */
{ 87181 }, /* l3_pteg_miss_rate_percent\000general\000\000PM_DPTEG_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000L3 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000 */
{ 87309 }, /* l3miss_latency\000latency\000\000PM_MRK_DATA_FROM_L3MISS_CYC / PM_MRK_DATA_FROM_L3MISS\000Average load latency for all marked demand loads that come from beyond the L3\000\000\000\000\000 */
{ 87469 }, /* l3other_ld_hit_ratio\000\000\000(PM_DATA_FROM_L3 - PM_DATA_FROM_L3_MEPF) / PM_LD_REF_L1\000Fraction of L3 hits on lines that were not in the MEPF state per L1 load ref\000\000\000\000\000 */
{ 87629 }, /* l3pref_latency\000latency\000\000PM_MRK_DATA_FROM_L3_MEPF_CYC / PM_MRK_DATA_FROM_L3_MEPF\000Average latency for marked reloads that hit in the L3 on the MEPF state.  i.e. lines that were prefetched into the L3\000\000\000\000\000 */
{ 87831 }, /* l3pref_ld_hit_ratio\000\000\000PM_DATA_FROM_L3_MEPF / PM_LD_REF_L1\000Fraction of L3 hits on lines that were recently prefetched into the L3 (MEPF state) per L1 load ref\000\000\000\000\000 */
{ 88263 }, /* ld_ll4_per_ld_dmem\000memory\000\000PM_DATA_FROM_LL4 / PM_DATA_FROM_DL4\000Ratio of reloads from local L4 to distant L4\000\000\000\000\000 */
{ 88375 }, /* ld_ll4_per_ld_mem\000memory\000\000PM_DATA_FROM_LL4 / (PM_DATA_FROM_DL4 + PM_DATA_FROM_RL4)\000Ratio of reloads from local L4 to remote+distant L4\000\000\000\000\000 */
{ 88514 }, /* ld_ll4_per_ld_rl4\000memory\000\000PM_DATA_FROM_LL4 / PM_DATA_FROM_RL4\000Ratio of reloads from local L4 to remote L4\000\000\000\000\000 */
{ 88624 }, /* ld_lmem_per_ld_dmem\000memory\000\000PM_DATA_FROM_LMEM / PM_DATA_FROM_DMEM\000Number of loads from local memory per loads from distant memory\000\000\000\000\000 */
{ 88758 }, /* ld_lmem_per_ld_mem\000memory\000\000PM_DATA_FROM_LMEM / (PM_DATA_FROM_DMEM + PM_DATA_FROM_RMEM)\000Number of loads from local memory per loads from remote and distant memory\000\000\000\000\000 */
{ 88924 }, /* ld_lmem_per_ld_rmem\000memory\000\000PM_DATA_FROM_LMEM / PM_DATA_FROM_RMEM\000Number of loads from local memory per loads from remote memory\000\000\000\000\000 */
{ 89057 }, /* ld_rmem_per_ld_dmem\000memory\000\000PM_DATA_FROM_RMEM / PM_DATA_FROM_DMEM\000Number of loads from remote memory per loads from distant memory\000\000\000\000\000 */
{ 89192 }, /* lhs_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_LHS * 100 / PM_RUN_INST_CMPL\000LHS reject ratio\000\000\000\000\000 */
{ 89293 }, /* lhs_reject_ratio_percent\000lsu_rejects\000\000PM_LSU_REJECT_LHS * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000LHS reject ratio\000\000\000\000\000 */
{ 89591 }, /* ll4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_LL4 / PM_RUN_INST_CMPL * ll4_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of Local L4 miss rates with measured LL4 latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 89805 }, /* ll4_latency\000latency\000\000PM_MRK_DATA_FROM_LL4_CYC / PM_MRK_DATA_FROM_LL4\000Local L4 average load latency\000\000\000\000\000 */
{ 89908 }, /* ll4_ld_hit_ratio\000\000\000PM_DATA_FROM_LL4 / PM_LD_REF_L1\000Fraction of hits on a local Centaur's cache per L1 load ref\000\000\000\000\000 */
{ 90264 }, /* lmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_LMEM / PM_RUN_INST_CMPL * lmem_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of Local memory miss rates with measured LMEM latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 90486 }, /* lmem_latency\000latency\000\000PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM\000Marked Lmem Load latency\000\000\000\000\000 */
{ 90587 }, /* lmem_ld_hit_ratio\000\000\000PM_DATA_FROM_LMEM / PM_LD_REF_L1\000Fraction of hits on a local Centaur's DRAM per L1 load ref\000\000\000\000\000 */
{ 90820 }, /* lmq_full_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_RUN_INST_CMPL\000LMQ full reject ratio\000\000\000\000\000 */
{ 90936 }, /* lmq_full_reject_ratio_percent\000lsu_rejects\000\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_LD_REF_L1\000ERAT miss reject ratio\000\000\000\000\000 */
{ 91585 }, /* loads_per_inst\000instruction_mix\000\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000PCT instruction loads\000\000\000\000\000 */
{ 91675 }, /* local_centaur_ld_hit_ratio\000\000\000(PM_DATA_FROM_LMEM + PM_DATA_FROM_LL4) / PM_LD_REF_L1\000Fraction of hits on a local Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000 */
{ 92767 }, /* lstack_mispredict_rate_percent\000branch_prediction\000\000(PM_BR_MPRED_TA - PM_BR_MPRED_CCACHE) / PM_RUN_INST_CMPL * 100\000Link stack branch misprediction\000\000\000\000\000 */
{ 93046 }, /* lstack_misprediction_percent\000branch_prediction\000\000(PM_BR_MPRED_TA - PM_BR_MPRED_CCACHE) / (PM_BR_PRED_LSTACK_BR0 + PM_BR_PRED_LSTACK_BR1) * 100\000Percent of link stack mispredictions out of all completed branches that required link stack prediction\000\000\000\000\000 */
{ 94435 }, /* lsu_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT * 100 / PM_RUN_INST_CMPL\000LSU reject ratio\000\000\000\000\000 */
{ 94532 }, /* lsu_reject_ratio_percent\000lsu_rejects\000\000PM_LSU_REJECT * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000LSU reject ratio\000\000\000\000\000 */
{ 94642 }, /* lsu_stall_avg_cyc_per_l1hit_stfw\000\000\000(PM_CMPLU_STALL_LSU - PM_CMPLU_STALL_REJECT - PM_CMPLU_STALL_DCACHE_MISS - PM_CMPLU_STALL_STORE) / (PM_LD_REF_L1 - PM_LD_MISS_L1)\000Cycles stalled by Other LSU Operations\000\000\000\000\000 */
{ 94957 }, /* lsu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL\000Cycles stalled by LSU\000\000\000\000\000 */
{ 95161 }, /* lsu_stall_dcache_miss_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses\000\000\000\000\000 */
{ 95285 }, /* lsu_stall_dcache_miss_distant_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_DMISS_L3MISS - PM_CMPLU_STALL_DMISS_LMEM - PM_CMPLU_STALL_DMISS_L21_L31 - PM_CMPLU_STALL_DMISS_REMOTE) / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in distant interventions and memory\000\000\000\000\000 */
{ 95559 }, /* lsu_stall_dcache_miss_l21l31_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in remote or distant caches\000\000\000\000\000 */
{ 95734 }, /* lsu_stall_dcache_miss_l2l3_conflict_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3, where there was a conflict\000\000\000\000\000 */
{ 95944 }, /* lsu_stall_dcache_miss_l2l3_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3\000\000\000\000\000 */
{ 96108 }, /* lsu_stall_dcache_miss_l2l3_noconflict_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_DMISS_L2L3 - PM_CMPLU_STALL_DMISS_L2L3_CONFLICT) / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3, where there was no conflict\000\000\000\000\000 */
{ 96351 }, /* lsu_stall_dcache_miss_l3miss_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in other core's caches or memory\000\000\000\000\000 */
{ 96530 }, /* lsu_stall_dcache_miss_lmem_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in local memory or local L4\000\000\000\000\000 */
{ 96700 }, /* lsu_stall_dcache_miss_remote_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_REMOTE / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses that resolved in remote interventions and memory\000\000\000\000\000 */
{ 96881 }, /* lsu_stall_erat_miss_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL\000Cycles stalled by ERAT Translation rejects\000\000\000\000\000 */
{ 97011 }, /* lsu_stall_ld_fin_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000Cycles stalled by LSU load finishes\000\000\000\000\000 */
{ 97133 }, /* lsu_stall_lhs_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_REJECT_LHS / PM_RUN_INST_CMPL\000Cycles stalled by LHS rejects\000\000\000\000\000 */
{ 97245 }, /* lsu_stall_lmq_full_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_REJ_LMQ_FULL / PM_RUN_INST_CMPL\000Cycles stalled by LMQ Full rejects\000\000\000\000\000 */
{ 97369 }, /* lsu_stall_other_cpi\000cpi_breakdown\000\000lsu_stall_cpi - lsu_stall_dcache_miss_cpi - lsu_stall_reject_cpi - lsu_stall_store_cpi - lsu_stall_ld_fin_cpi - lsu_stall_st_fwd_cpi\000Cycles stalled by Other LSU Operations\000\000\000\000\000 */
{ 97580 }, /* lsu_stall_reject_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_REJECT / PM_RUN_INST_CMPL\000Cycles stalled by LSU Rejects\000\000\000\000\000 */
{ 97691 }, /* lsu_stall_reject_other_cpi\000cpi_breakdown\000\000lsu_stall_reject_cpi - lsu_stall_lhs_cpi - lsu_stall_erat_miss_cpi - lsu_stall_lmq_full_cpi\000Cycles stalled by Other LSU Rejects\000\000\000\000\000 */
{ 97865 }, /* lsu_stall_st_fwd_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000Cycles stalled by LSU store forwarding\000\000\000\000\000 */
{ 97985 }, /* lsu_stall_store_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE / PM_RUN_INST_CMPL\000Cycles stalled by LSU Stores\000\000\000\000\000 */
{ 98093 }, /* lwsync_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LWSYNC / PM_RUN_INST_CMPL\000Cycles stalled by lightweight syncs\000\000\000\000\000 */
{ 98836 }, /* mem_locality_percent\000memory\000\000(PM_DATA_FROM_LL4 + PM_DATA_FROM_LMEM) * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_LL4 + PM_DATA_FROM_RMEM + PM_DATA_FROM_RL4 + PM_DATA_FROM_DMEM + PM_DATA_FROM_DL4)\000Memory locality\000\000\000\000\000 */
{ 99832 }, /* no_ntf_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NO_NTF / PM_RUN_INST_CMPL\000Cycles stalled by nops (nothing next to finish)\000\000\000\000\000 */
{ 101483 }, /* off_chip_cache_latency\000latency\000\000PM_MRK_DATA_FROM_OFF_CHIP_CACHE_CYC / PM_MRK_DATA_FROM_OFF_CHIP_CACHE\000Latency for marked reloads that hit in the L2 or L3 of any other core on a different chip\000\000\000\000\000 */
{ 101679 }, /* off_chip_cache_ld_hit_ratio\000\000\000PM_DATA_FROM_OFF_CHIP_CACHE / PM_LD_REF_L1\000Fraction of hits on another core's L2 or L3 on a different chip (remote or distant) per L1 load ref\000\000\000\000\000 */
{ 101856 }, /* on_chip_cache_latency\000latency\000\000PM_MRK_DATA_FROM_ON_CHIP_CACHE_CYC / PM_MRK_DATA_FROM_ON_CHIP_CACHE\000Latency for marked reloads that hit in the L2 or L3 of any other core on the same chip\000\000\000\000\000 */
{ 102046 }, /* on_chip_cache_ld_hit_ratio\000\000\000PM_DATA_FROM_ON_CHIP_CACHE / PM_LD_REF_L1\000Fraction of hits on another core's L2 or L3 on the same chip per L1 load ref\000\000\000\000\000 */
{ 102198 }, /* other_block_stall_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_THRD - PM_CMPLU_STALL_LWSYNC - PM_CMPLU_STALL_HWSYNC - PM_CMPLU_STALL_MEM_ECC_DELAY - PM_CMPLU_STALL_FLUSH - PM_CMPLU_STALL_COQ_FULL) / PM_RUN_INST_CMPL\000Other thread block stall cycles\000\000\000\000\000 */
{ 102579 }, /* other_cpi\000cpi_breakdown\000\000run_cpi - stall_cpi - gct_empty_cpi - ntcg_all_fin_cpi - thread_block_stall_cpi - completion_cpi\000Cycles unaccounted for\000\000\000\000\000 */
{ 102728 }, /* other_stall_cpi\000cpi_breakdown\000\000stall_cpi - bru_cru_stall_cpi - fxu_stall_cpi - vsu_stall_cpi - lsu_stall_cpi - ntcg_flush_cpi - no_ntf_stall_cpi\000Stall cycles unaccounted for\000\000\000\000\000 */
{ 426777 }, /* pteg_from_dl2l3_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant L2 or L3 (Modified)\000\000\000\000\000 */
{ 426936 }, /* pteg_from_dl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant L2 or L3 (Modified) per inst\000\000\000\000\000 */
{ 427114 }, /* pteg_from_dl2l3_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant L2 or L3 (Shared)\000\000\000\000\000 */
{ 427271 }, /* pteg_from_dl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant L2 or L3 (Shared) per inst\000\000\000\000\000 */
{ 427447 }, /* pteg_from_dl4_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DL4 * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant L4\000\000\000\000\000 */
{ 427577 }, /* pteg_from_dl4_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant L4 per inst\000\000\000\000\000 */
{ 427726 }, /* pteg_from_dmem_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DMEM * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant Memory\000\000\000\000\000 */
{ 427862 }, /* pteg_from_dmem_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant Memory per inst\000\000\000\000\000 */
{ 428017 }, /* pteg_from_l21_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L21_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L2, other core\000\000\000\000\000 */
{ 428167 }, /* pteg_from_l21_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000 */
{ 428336 }, /* pteg_from_l21_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L21_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L2, other core\000\000\000\000\000 */
{ 428486 }, /* pteg_from_l21_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000 */
{ 428655 }, /* pteg_from_l2_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L2 * 100 / PM_DTLB_MISS\000% of DERAT reloads from L2\000\000\000\000\000 */
{ 428775 }, /* pteg_from_l2_rate_percent\000pteg_reloads_percent_per_inst\000\000dpteg_from_l2_rate_percent\000% of DERAT reloads from L2 per inst\000\000\000\000\000 */
{ 428899 }, /* pteg_from_l31_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L31_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L3, other core\000\000\000\000\000 */
{ 429049 }, /* pteg_from_l31_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000 */
{ 429218 }, /* pteg_from_l31_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L31_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L3, other core\000\000\000\000\000 */
{ 429368 }, /* pteg_from_l31_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000 */
{ 429537 }, /* pteg_from_l3_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L3 * 100 / PM_DTLB_MISS\000% of DERAT reloads from L3\000\000\000\000\000 */
{ 429657 }, /* pteg_from_l3_rate_percent\000pteg_reloads_percent_per_inst\000\000dpteg_from_l3_rate_percent\000% of DERAT reloads from L3 per inst\000\000\000\000\000 */
{ 429781 }, /* pteg_from_ll4_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_LL4 * 100 / PM_DTLB_MISS\000% of DERAT reloads from Local L4\000\000\000\000\000 */
{ 429909 }, /* pteg_from_ll4_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Local L4 per inst\000\000\000\000\000 */
{ 430056 }, /* pteg_from_lmem_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_LMEM * 100 / PM_DTLB_MISS\000% of DERAT reloads from Local Memory\000\000\000\000\000 */
{ 430190 }, /* pteg_from_lmem_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Local Memory per inst\000\000\000\000\000 */
{ 430343 }, /* pteg_from_rl2l3_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote L2 or L3 (Modified)\000\000\000\000\000 */
{ 430501 }, /* pteg_from_rl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote L2 or L3 (Modified) per inst\000\000\000\000\000 */
{ 430678 }, /* pteg_from_rl2l3_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote L2 or L3 (Shared)\000\000\000\000\000 */
{ 430834 }, /* pteg_from_rl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote L2 or L3 (Shared) per inst\000\000\000\000\000 */
{ 431009 }, /* pteg_from_rl4_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RL4 * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote L4\000\000\000\000\000 */
{ 431138 }, /* pteg_from_rl4_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote L4 per inst\000\000\000\000\000 */
{ 431286 }, /* pteg_from_rmem_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RMEM * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote Memory\000\000\000\000\000 */
{ 431421 }, /* pteg_from_rmem_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote Memory per inst\000\000\000\000\000 */
{ 431575 }, /* remote_centaur_ld_hit_ratio\000\000\000(PM_DATA_FROM_RMEM + PM_DATA_FROM_RL4) / PM_LD_REF_L1\000Fraction of hits on a remote chip's Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000 */
{ 431736 }, /* resource_na_reject_rate_percent\000\000\000PM_ISU_REJECT_RES_NA * 100 / PM_RUN_INST_CMPL\000Percent of all FXU/VSU instructions that got rejected because of unavailable resources or facilities\000\000\000\000\000 */
{ 432191 }, /* rl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL2L3_MOD / PM_RUN_INST_CMPL * rl2l3_mod_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2l3 remote MOD miss rates with measured RL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 432437 }, /* rl2l3_mod_latency\000latency\000\000PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD\000Marked L2L3 remote Load latency\000\000\000\000\000 */
{ 432560 }, /* rl2l3_mod_ld_hit_ratio\000\000\000PM_DATA_FROM_RL2L3_MOD / PM_LD_REF_L1\000Fraction of hits of a line in the M (exclusive) state on the L2 or L3 of a core on a remote chip per L1 load ref\000\000\000\000\000 */
{ 433006 }, /* rl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL2L3_SHR / PM_RUN_INST_CMPL * rl2l3_shr_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of dl2l3 shared miss rates with measured RL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 433248 }, /* rl2l3_shr_latency\000latency\000\000PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR\000Marked L2L3 remote Load latency\000\000\000\000\000 */
{ 433371 }, /* rl2l3_shr_ld_hit_ratio\000\000\000PM_DATA_FROM_RL2L3_SHR / PM_LD_REF_L1\000Fraction of hits of a line in the S state on the L2 or L3 of a core on a remote chip per L1 load ref\000\000\000\000\000 */
{ 433772 }, /* rl4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL4 / PM_RUN_INST_CMPL * rl4_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of remote L4 miss rates with measured RL4 latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 433987 }, /* rl4_latency\000latency\000\000PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4\000Remote L4 average load latency\000\000\000\000\000 */
{ 434091 }, /* rl4_ld_hit_ratio\000\000\000PM_DATA_FROM_RL4 / PM_LD_REF_L1\000Fraction of hits on a remote Centaur's cache per L1 load ref\000\000\000\000\000 */
{ 434449 }, /* rmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RMEM / PM_RUN_INST_CMPL * rmem_latency / lsu_stall_dcache_miss_cpi * 100\000estimate of remote memory miss rates with measured RMEM latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 434672 }, /* rmem_latency\000latency\000\000PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM\000Marked Rmem Load latency\000\000\000\000\000 */
{ 434773 }, /* rmem_ld_hit_ratio\000\000\000PM_DATA_FROM_RMEM / PM_LD_REF_L1\000Fraction of hits on a remote Centaur's DRAM per L1 load ref\000\000\000\000\000 */
{ 434890 }, /* run_cpi\000cpi_breakdown\000\000PM_RUN_CYC / PM_RUN_INST_CMPL\000Run cycles per run instruction\000\000\000\000\000 */
{ 435120 }, /* run_cycles_percent\000general\000\000PM_RUN_CYC / PM_CYC * 100\000Run cycles per cycle\000\000\000\000\000 */
{ 435199 }, /* sar_bypass_reject_rate_percent\000\000\000PM_ISU_REJECT_SAR_BYPASS * 100 / PM_RUN_INST_CMPL\000Percent of all FXU/VSU instructions that got rejected due to SAR Bypass\000\000\000\000\000 */
{ 435725 }, /* smt2_cycles_percent\000general\000\000PM_RUN_CYC_SMT2_MODE / PM_RUN_CYC * 100\000Percentage of cycles spent in SMT2 Mode\000\000\000\000\000 */
{ 435838 }, /* smt4_cycles_percent\000general\000\000PM_RUN_CYC_SMT4_MODE / PM_RUN_CYC * 100\000Percentage of cycles spent in SMT4 Mode\000\000\000\000\000 */
{ 435951 }, /* smt8_cycles_percent\000general\000\000PM_RUN_CYC_SMT8_MODE / PM_RUN_CYC * 100\000Percentage of cycles spent in SMT8 Mode\000\000\000\000\000 */
{ 436064 }, /* smt_benefit\000general\000\000PM_CMPLU_STALL_OTHER_CMPL / PM_RUN_CYC\000IPC of all instructions completed by the core while this thread was stalled\000\000\000\000\000 */
{ 436204 }, /* source_na_reject_rate_percent\000\000\000PM_ISU_REJECT_SRC_NA * 100 / PM_RUN_INST_CMPL\000Percent of all FXU/VSU instructions that got rejected because of unavailable sources\000\000\000\000\000 */
{ 436615 }, /* speculation\000general\000\000PM_INST_DISP / PM_INST_CMPL\000Instruction dispatch-to-completion ratio\000\000\000\000\000 */
{ 437102 }, /* st_cycles_percent\000general\000\000PM_RUN_CYC_ST_MODE / PM_RUN_CYC * 100\000Percentage of cycles spent in Single Thread Mode\000\000\000\000\000 */
{ 437335 }, /* stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL / PM_RUN_INST_CMPL\000Completion Stall Cycles\000\000\000\000\000 */
{ 438385 }, /* store_forward_rate_percent\000\000\000100 * (PM_LSU0_SRQ_STFWD + PM_LSU1_SRQ_STFWD) / PM_RUN_INST_CMPL\000Store forward rate\000\000\000\000\000 */
{ 438502 }, /* store_forward_ratio_percent\000\000\000100 * (PM_LSU0_SRQ_STFWD + PM_LSU1_SRQ_STFWD) / (PM_LD_REF_L1 - PM_LD_MISS_L1)\000Store forward rate\000\000\000\000\000 */
{ 438634 }, /* store_latency\000\000\000(PM_MRK_ST_L2DISP_TO_CMPL_CYC + PM_MRK_ST_DRAIN_TO_L2DISP_CYC) / PM_MRK_ST_NEST\000Marked store latency, from core completion to L2 RC machine completion\000\000\000\000\000 */
{ 439177 }, /* stores_per_inst\000instruction_mix\000\000PM_ST_FIN / PM_RUN_INST_CMPL\000PCT instruction stores\000\000\000\000\000 */
{ 439361 }, /* sync_stall_cpi\000\000\000(PM_CMPLU_STALL_LWSYNC + PM_CMPLU_STALL_HWSYNC) / PM_RUN_INST_CMPL\000Cycles stalled by any sync\000\000\000\000\000 */
{ 439717 }, /* sys_pump_cpred_percent\000bus_stats\000\000PM_SYS_PUMP_CPRED * 100 / PM_L2_GROUP_PUMP\000Percent of system pumps that were correctly predicted as group pumps the first time\000\000\000\000\000 */
{ 439882 }, /* ta_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_TA / PM_RUN_INST_CMPL * 100\000TA MisPredictions per Instruction\000\000\000\000\000 */
{ 440006 }, /* ta_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_TA / (PM_BR_PRED_CCACHE_BR0 + PM_BR_PRED_CCACHE_BR1 + PM_BR_PRED_LSTACK_BR0 + PM_BR_PRED_LSTACK_BR1) * 100\000Percent of target address mispredictions out of all completed branches that required address prediction\000\000\000\000\000 */
{ 440376 }, /* taken_branches_percent\000branch_prediction\000\000PM_BR_TAKEN_CMPL * 100 / PM_BR_CMPL\000Percent of branches completed that were taken\000\000\000\000\000 */
{ 440798 }, /* thread_block_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL\000Cycles a thread was blocked\000\000\000\000\000 */
{ 443063 }, /* vsu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VSU / PM_RUN_INST_CMPL\000Cycles stalled by VSU\000\000\000\000\000 */
{ 443156 }, /* vsu_stall_other_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_VSU - PM_CMPLU_STALL_VECTOR - PM_CMPLU_STALL_SCALAR) / PM_RUN_INST_CMPL\000Cycles stalled by other VSU Operations\000\000\000\000\000 */
{ 443322 }, /* vsu_stall_scalar_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SCALAR / PM_RUN_INST_CMPL\000Cycles stalled by VSU Scalar Operations\000\000\000\000\000 */
{ 443443 }, /* vsu_stall_scalar_long_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SCALAR_LONG / PM_RUN_INST_CMPL\000Cycles stalled by VSU Scalar Long Operations\000\000\000\000\000 */
{ 443579 }, /* vsu_stall_scalar_other_cpi\000cpi_breakdown\000\000vsu_stall_scalar_cpi - vsu_stall_scalar_long_cpi\000Cycles stalled by Other VSU Scalar Operations\000\000\000\000\000 */
{ 443720 }, /* vsu_stall_vector_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VECTOR / PM_RUN_INST_CMPL\000Cycles stalled by VSU Vector Operations\000\000\000\000\000 */
{ 443841 }, /* vsu_stall_vector_long_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VECTOR_LONG / PM_RUN_INST_CMPL\000Cycles stalled by VSU Vector Long Operations\000\000\000\000\000 */
{ 443977 }, /* vsu_stall_vector_other_cpi\000cpi_breakdown\000\000(PM_CMPLU_STALL_VECTOR - PM_CMPLU_STALL_VECTOR_LONG) / PM_RUN_INST_CMPL\000Cycles stalled by other VSU Vector Operations\000\000\000\000\000 */
{ 444141 }, /* wasted_l3_prefetch_percent\000\000\000PM_L3_CO_MEPF / 2 / PM_L3_PREF_ALL * 100\000Percentage of lines that were prefetched into the L3 and evicted before they were consumed\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__power9[] = {
{ 111494 }, /* pm_br_mpred_cmpl\000\000cache\000Number of Branch Mispredicts\000event=0x400f6\000\000\000\000\000\000\000 */
{ 122157 }, /* pm_cmplu_stall_dmiss_l2l3\000\000cache\000Completion stall by Dcache miss which resolved in L2/L3\000event=0x1003c\000\000\000\000\000\000\000 */
{ 122378 }, /* pm_cmplu_stall_dmiss_l2l3_conflict\000\000cache\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000event=0x4c016\000\000\000\000\000\000\000 */
{ 125237 }, /* pm_cmplu_stall_flush_any_thread\000\000cache\000Cycles in which the NTC instruction is not allowed to complete because any of the 4 threads in the same core suffered a flush, which blocks completion\000event=0x1e056\000\000\000\000\000\000\000 */
{ 125447 }, /* pm_cmplu_stall_fxlong\000\000cache\000Completion stall due to a long latency scalar fixed point instruction (division, square root)\000event=0x4d016\000\000\000\000\000\000\000 */
{ 125705 }, /* pm_cmplu_stall_fxu\000\000cache\000Finish stall due to a scalar fixed point or CR instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000event=0x2d016\000\000\000\000\000\000\000 */
{ 126059 }, /* pm_cmplu_stall_larx\000\000cache\000Finish stall because the NTF instruction was a larx waiting to be satisfied\000event=0x1002a\000\000\000\000\000\000\000 */
{ 126182 }, /* pm_cmplu_stall_lhs\000\000cache\000Finish stall because the NTF instruction was a load that hit on an older store and it was waiting for store data\000event=0x2c01a\000\000\000\000\000\000\000 */
{ 126341 }, /* pm_cmplu_stall_lmq_full\000\000cache\000Finish stall because the NTF instruction was a load that missed in the L1 and the LMQ was unable to accept this load miss request because it was full\000event=0x4c014\000\000\000\000\000\000\000 */
{ 126542 }, /* pm_cmplu_stall_load_finish\000\000cache\000Finish stall because the NTF instruction was a load instruction with all its dependencies satisfied just going through the LSU pipe to finish\000event=0x4d014\000\000\000\000\000\000\000 */
{ 255590 }, /* pm_inst_from_on_chip_cache\000\000cache\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14048\000\000\000\000\000\000\000 */
{ 256237 }, /* pm_inst_from_rl2l3_mod\000\000cache\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x24046\000\000\000\000\000\000\000 */
{ 256957 }, /* pm_inst_from_rl2l3_shr\000\000cache\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x1404a\000\000\000\000\000\000\000 */
{ 257671 }, /* pm_inst_from_rl4\000\000cache\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x2404a\000\000\000\000\000\000\000 */
{ 347277 }, /* pm_mrk_data_from_rl4_cyc\000\000cache\000Duration in cycles to reload from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x4d12a\000\000\000\000\000\000\000 */
{ 354211 }, /* pm_mrk_dpteg_from_l2_mepf\000\000cache\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f140\000\000\000\000\000\000\000 */
{ 363854 }, /* pm_mrk_dpteg_from_rmem\000\000cache\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f14a\000\000\000\000\000\000\000 */
{ 364334 }, /* pm_mrk_dtlb_miss\000\000cache\000Marked dtlb miss\000event=0x401e4\000\000\000\000\000\000\000 */
{ 408726 }, /* pm_thrd_conc_run_inst\000\000cache\000PPC Instructions Finished by this thread when all threads in the core had the run-latch set\000event=0x300f4\000\000\000\000\000\000\000 */
{ 410379 }, /* pm_thresh_exc_128\000\000cache\000Threshold counter exceeded a value of 128\000event=0x401ea\000\000\000\000\000\000\000 */
{ 411165 }, /* pm_thresh_exc_4096\000\000cache\000Threshold counter exceed a count of 4096\000event=0x101e6\000\000\000\000\000\000\000 */
{ 208825 }, /* pm_flush_completion\000\000floating point\000The instruction that was next to complete did not complete because it suffered a flush\000event=0x30012\000\000\000\000\000\000\000 */
{ 325519 }, /* pm_mem_loc_thresh_ifu\000\000floating point\000Local Memory above threshold for IFU speculation control\000event=0x10058\000\000\000\000\000\000\000 */
{ 332900 }, /* pm_mrk_data_from_l2_disp_conflict_ldhitst_cyc\000\000floating point\000Duration in cycles to reload from local core's L2 with load hit store conflict due to a marked load\000event=0x1415a\000\000\000\000\000\000\000 */
{ 349564 }, /* pm_mrk_derat_miss_64k\000\000floating point\000Marked Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2d154\000\000\000\000\000\000\000 */
{ 390449 }, /* pm_radix_pwc_l2_pde_from_l2\000\000floating point\000A Page Directory Entry was reloaded to a level 2 page walk cache from the core's L2 data cache\000event=0x2d028\000\000\000\000\000\000\000 */
{ 411970 }, /* pm_thresh_not_met\000\000floating point\000Threshold counter did not meet threshold\000event=0x4016e\000\000\000\000\000\000\000 */
{ 103997 }, /* pm_1plus_ppc_cmpl\000\000frontend\0001 or more ppc insts finished\000event=0x100f2\000\000\000\000\000\000\000 */
{ 116700 }, /* pm_br_taken_cmpl\000\000frontend\000New event for Branch Taken\000event=0x200fa\000\000\000\000\000\000\000 */
{ 127031 }, /* pm_cmplu_stall_lrq_other\000\000frontend\000Finish stall due to LRQ miscellaneous reasons, lost arbitration to LMQ slot, bank collisions, set prediction cleanup, set prediction multihit and others\000event=0x10004\000\000\000\000\000\000\000 */
{ 127239 }, /* pm_cmplu_stall_lsaq_arb\000\000frontend\000Finish stall because the NTF instruction was a load or store that was held in LSAQ because an older instruction from SRQ or LRQ won arbitration to the LSU pipe when this instruction tried to launch\000event=0x4e016\000\000\000\000\000\000\000 */
{ 127491 }, /* pm_cmplu_stall_lsu\000\000frontend\000Completion stall by LSU instruction\000event=0x2c010\000\000\000\000\000\000\000 */
{ 127661 }, /* pm_cmplu_stall_lsu_fin\000\000frontend\000Finish stall because the NTF instruction was an LSU op (other than a load or a store) with all its dependencies met and just going through the LSU pipe to finish\000event=0x1003a\000\000\000\000\000\000\000 */
{ 127876 }, /* pm_cmplu_stall_lsu_flush_next\000\000frontend\000Completion stall of one cycle because the LSU requested to flush the next iop in the sequence. It takes 1 cycle for the ISU to process this request before the LSU instruction is allowed to complete\000event=0x2e01a\000\000\000\000\000\000\000 */
{ 128134 }, /* pm_cmplu_stall_lsu_mfspr\000\000frontend\000Finish stall because the NTF instruction was a mfspr instruction targeting an LSU SPR and it was waiting for the register data to be returned\000event=0x34056\000\000\000\000\000\000\000 */
{ 128514 }, /* pm_cmplu_stall_mtfpscr\000\000frontend\000Completion stall because the ISU is updating the register and notifying the Effective Address Table (EAT)\000event=0x4e012\000\000\000\000\000\000\000 */
{ 131230 }, /* pm_cmplu_stall_st_fwd\000\000frontend\000Completion stall due to store forward\000event=0x4c01c\000\000\000\000\000\000\000 */
{ 131410 }, /* pm_cmplu_stall_stcx\000\000frontend\000Finish stall because the NTF instruction was a stcx waiting for response from L2\000event=0x2d01c\000\000\000\000\000\000\000 */
{ 131701 }, /* pm_cmplu_stall_store_data\000\000frontend\000Finish stall because the next to finish instruction was a store waiting on data\000event=0x30026\000\000\000\000\000\000\000 */
{ 131837 }, /* pm_cmplu_stall_store_fin_arb\000\000frontend\000Finish stall because the NTF instruction was a store waiting for a slot in the store finish pipe. This means the instruction is ready to finish but there are instructions ahead of it, using the finish pipe\000event=0x30014\000\000\000\000\000\000\000 */
{ 132102 }, /* pm_cmplu_stall_store_finish\000\000frontend\000Finish stall because the NTF instruction was a store with all its dependencies met, just waiting to go through the LSU pipe to finish\000event=0x2c014\000\000\000\000\000\000\000 */
{ 132294 }, /* pm_cmplu_stall_store_pipe_arb\000\000frontend\000Finish stall because the NTF instruction was a store waiting for the next relaunch opportunity after an internal reject. This means the instruction is ready to relaunch and tried once but lost arbitration\000event=0x4c010\000\000\000\000\000\000\000 */
{ 132559 }, /* pm_cmplu_stall_sync_pmu_int\000\000frontend\000Cycles in which the NTC instruction is waiting for a synchronous PMU interrupt\000event=0x2c01e\000\000\000\000\000\000\000 */
{ 132696 }, /* pm_cmplu_stall_tend\000\000frontend\000Finish stall because the NTF instruction was a tend instruction awaiting response from L2\000event=0x1e050\000\000\000\000\000\000\000 */
{ 158439 }, /* pm_data_from_l31_eco_mod\000\000frontend\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a demand load\000event=0x4c044\000\000\000\000\000\000\000 */
{ 161829 }, /* pm_data_from_l3_mepf\000\000frontend\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to a demand load\000event=0x2c042\000\000\000\000\000\000\000 */
{ 162320 }, /* pm_data_from_l3_no_conflict\000\000frontend\000The processor's data cache was reloaded from local core's L3 without conflict due to a demand load\000event=0x1c044\000\000\000\000\000\000\000 */
{ 191360 }, /* pm_dpteg_from_l3\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e042\000\000\000\000\000\000\000 */
{ 197398 }, /* pm_dpteg_from_rmem\000\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e04a\000\000\000\000\000\000\000 */
{ 252444 }, /* pm_inst_from_l3miss\000\000frontend\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x300fa\000\000\000\000\000\000\000 */
{ 260791 }, /* pm_inst_pump_cpred\000\000frontend\000Pump prediction correct. Counts across all types of pumps for an instruction fetch\000event=0x14054\000\000\000\000\000\000\000 */
{ 261126 }, /* pm_inst_pump_mpred\000\000frontend\000Pump misprediction. Counts across all types of pumps for an instruction fetch\000event=0x44052\000\000\000\000\000\000\000 */
{ 261501 }, /* pm_inst_sys_pump_cpred\000\000frontend\000Initial and Final Pump Scope was system pump (prediction=correct) for an instruction fetch\000event=0x34050\000\000\000\000\000\000\000 */
{ 262138 }, /* pm_inst_sys_pump_mpred\000\000frontend\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for an instruction fetch\000event=0x34052\000\000\000\000\000\000\000 */
{ 262669 }, /* pm_inst_sys_pump_mpred_rty\000\000frontend\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for an instruction fetch\000event=0x44050\000\000\000\000\000\000\000 */
{ 262830 }, /* pm_iops_cmpl\000\000frontend\000Internal Operations completed\000event=0x24050\000\000\000\000\000\000\000 */
{ 263255 }, /* pm_ipteg_from_dl2l3_mod\000\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x45048\000\000\000\000\000\000\000 */
{ 267205 }, /* pm_ipteg_from_l31_eco_mod\000\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x45044\000\000\000\000\000\000\000 */
{ 267602 }, /* pm_ipteg_from_l31_eco_shr\000\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x35044\000\000\000\000\000\000\000 */
{ 267995 }, /* pm_ipteg_from_l31_mod\000\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a instruction side request\000event=0x25044\000\000\000\000\000\000\000 */
{ 268376 }, /* pm_ipteg_from_l31_shr\000\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a instruction side request\000event=0x15046\000\000\000\000\000\000\000 */
{ 269402 }, /* pm_ipteg_from_l3_mepf\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a instruction side request\000event=0x25042\000\000\000\000\000\000\000 */
{ 269598 }, /* pm_ipteg_from_l3_no_conflict\000\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a instruction side request\000event=0x15044\000\000\000\000\000\000\000 */
{ 269772 }, /* pm_ipteg_from_l3miss\000\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a instruction side request\000event=0x4504e\000\000\000\000\000\000\000 */
{ 295387 }, /* pm_ld_miss_l1\000\000frontend\000Load Missed L1, counted at execution time (can be greater than loads finished). LMQ merges are not included in this count. i.e. if a load instruction misses on an address that is already allocated on the LMQ, this event will not increment for that load). Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x3e054\000\000\000\000\000\000\000 */
{ 322263 }, /* pm_lsu_reject_lmq_full\000\000frontend\000LSU Reject due to LMQ full (up to 4 per cycles)\000event=0x3001c\000\000\000\000\000\000\000 */
{ 322668 }, /* pm_lsu_srq_full_cyc\000\000frontend\000Cycles in which the Store Queue is full on all 4 slices. This is event is not per thread. All the threads will see the same count for this core resource\000event=0x1001a\000\000\000\000\000\000\000 */
{ 333256 }, /* pm_mrk_data_from_l2_disp_conflict_other\000\000frontend\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a marked load\000event=0x2c124\000\000\000\000\000\000\000 */
{ 336528 }, /* pm_mrk_data_from_l31_eco_shr\000\000frontend\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2d14c\000\000\000\000\000\000\000 */
{ 344850 }, /* pm_mrk_data_from_on_chip_cache_cyc\000\000frontend\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x3515a\000\000\000\000\000\000\000 */
{ 346519 }, /* pm_mrk_data_from_rl2l3_shr_cyc\000\000frontend\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4c12a\000\000\000\000\000\000\000 */
{ 346937 }, /* pm_mrk_data_from_rl4\000\000frontend\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x3515c\000\000\000\000\000\000\000 */
{ 348441 }, /* pm_mrk_derat_miss\000\000frontend\000Erat Miss (TLB Access) All page sizes\000event=0x301e6\000\000\000\000\000\000\000 */
{ 365342 }, /* pm_mrk_fab_rsp_claim_rty\000\000frontend\000Sampled store did a rwitm and got a rty\000event=0x3015e\000\000\000\000\000\000\000 */
{ 365530 }, /* pm_mrk_fab_rsp_dclaim\000\000frontend\000Marked store had to do a dclaim\000event=0x30154\000\000\000\000\000\000\000 */
{ 365696 }, /* pm_mrk_fab_rsp_dclaim_cyc\000\000frontend\000cycles L2 RC took for a dclaim\000event=0x2f152\000\000\000\000\000\000\000 */
{ 366039 }, /* pm_mrk_fab_rsp_rd_rty\000\000frontend\000Sampled L2 reads retry count\000event=0x4015e\000\000\000\000\000\000\000 */
{ 366199 }, /* pm_mrk_fab_rsp_rd_t_intv\000\000frontend\000Sampled Read got a T intervention\000event=0x1015e\000\000\000\000\000\000\000 */
{ 366375 }, /* pm_mrk_fab_rsp_rwitm_cyc\000\000frontend\000cycles L2 RC took for a rwitm\000event=0x4f150\000\000\000\000\000\000\000 */
{ 366543 }, /* pm_mrk_fab_rsp_rwitm_rty\000\000frontend\000Sampled store did a rwitm and got a rty\000event=0x2015e\000\000\000\000\000\000\000 */
{ 370837 }, /* pm_mrk_l2_rc_disp\000\000frontend\000Marked Instruction RC dispatched in L2\000event=0x20114\000\000\000\000\000\000\000 */
{ 371211 }, /* pm_mrk_l2_rc_done\000\000frontend\000Marked RC done\000event=0x3012a\000\000\000\000\000\000\000 */
{ 371335 }, /* pm_mrk_l2_tm_req_abort\000\000frontend\000TM abort\000event=0x1e15e\000\000\000\000\000\000\000 */
{ 371397 }, /* pm_mrk_larx_fin\000\000frontend\000Larx finished\000event=0x40116\000\000\000\000\000\000\000 */
{ 371885 }, /* pm_mrk_ld_miss_exposed_cyc\000\000frontend\000Marked Load exposed Miss (use edge detect to count #)\000event=0x1013e\000\000\000\000\000\000\000 */
{ 383146 }, /* pm_ntc_issue_held_darq_full\000\000frontend\000The NTC instruction is being held at dispatch because there are no slots in the DARQ for it\000event=0x1006a\000\000\000\000\000\000\000 */
{ 386286 }, /* pm_pmc4_overflow\000\000frontend\000Overflow from counter 4\000event=0x10010\000\000\000\000\000\000\000 */
{ 386535 }, /* pm_pmc4_rewind\000\000frontend\000PMC4 Rewind Event\000event=0x10020\000\000\000\000\000\000\000 */
{ 403051 }, /* pm_suspended\000\000frontend\000Counter OFF\000event=0\000\000\000\000\000\000\000 */
{ 403448 }, /* pm_sync_mrk_br_link\000\000frontend\000Marked Branch and link branch that can cause a synchronous interrupt\000event=0x15152\000\000\000\000\000\000\000 */
{ 403684 }, /* pm_sync_mrk_br_mpred\000\000frontend\000Marked Branch mispredict that can cause a synchronous interrupt\000event=0x1515c\000\000\000\000\000\000\000 */
{ 409807 }, /* pm_thresh_acc\000\000frontend\000This event increments every time the threshold event counter ticks. Thresholding must be enabled (via MMCRA) and the thresholding start event must occur for this counter to increment. It will stop incrementing when the thresholding stop event occurs or when thresholding is disabled, until the next time a configured thresholding start event occurs\000event=0x24154\000\000\000\000\000\000\000 */
{ 410200 }, /* pm_thresh_exc_1024\000\000frontend\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\000\000\000\000\000\000 */
{ 410730 }, /* pm_thresh_exc_256\000\000frontend\000Threshold counter exceed a count of 256\000event=0x101e8\000\000\000\000\000\000\000 */
{ 411849 }, /* pm_thresh_met\000\000frontend\000threshold exceeded\000event=0x101ec\000\000\000\000\000\000\000 */
{ 412244 }, /* pm_tlb_hit\000\000frontend\000Number of times the TLB had the data required by the instruction. Applies to both HPT and RPT\000event=0x1f054\000\000\000\000\000\000\000 */
{ 417044 }, /* pm_tm_trans_run_inst\000\000frontend\000Run instructions completed in transactional state (gated by the run latch)\000event=0x30060\000\000\000\000\000\000\000 */
{ 418663 }, /* pm_vector_st_cmpl\000\000frontend\000Number of vector store instructions completed\000event=0x44056\000\000\000\000\000\000\000 */
{ 123280 }, /* pm_cmplu_stall_dmiss_remote\000\000marked\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000event=0x2c01c\000\000\000\000\000\000\000 */
{ 123637 }, /* pm_cmplu_stall_dp\000\000marked\000Finish stall because the NTF instruction was a scalar instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Not qualified multicycle. Qualified by NOT vector\000event=0x1005c\000\000\000\000\000\000\000 */
{ 124288 }, /* pm_cmplu_stall_eieio\000\000marked\000Finish stall because the NTF instruction is an EIEIO waiting for response from L2\000event=0x4d01a\000\000\000\000\000\000\000 */
{ 124817 }, /* pm_cmplu_stall_exception\000\000marked\000Cycles in which the NTC instruction is not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000event=0x3003a\000\000\000\000\000\000\000 */
{ 128864 }, /* pm_cmplu_stall_nested_tend\000\000marked\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tend and decrement the TEXASR nested level. This is a short delay\000event=0x3003c\000\000\000\000\000\000\000 */
{ 129146 }, /* pm_cmplu_stall_ntc_disp_fin\000\000marked\000Finish stall because the NTF instruction was one that must finish at dispatch\000event=0x4e018\000\000\000\000\000\000\000 */
{ 129280 }, /* pm_cmplu_stall_ntc_flush\000\000marked\000Completion stall due to ntc flush\000event=0x2e01e\000\000\000\000\000\000\000 */
{ 129502 }, /* pm_cmplu_stall_other_cmpl\000\000marked\000Instructions the core completed while this tread was stalled\000event=0x30006\000\000\000\000\000\000\000 */
{ 129787 }, /* pm_cmplu_stall_paste\000\000marked\000Finish stall because the NTF instruction was a paste waiting for response from L2\000event=0x2c016\000\000\000\000\000\000\000 */
{ 129918 }, /* pm_cmplu_stall_pm\000\000marked\000Finish stall because the NTF instruction was issued to the Permute execution pipe and waiting to finish. Includes permute and decimal fixed point instructions (128 bit BCD arithmetic) + a few 128 bit fixpoint add/subtract instructions with carry. Not qualified by vector or multicycle\000event=0x3000a\000\000\000\000\000\000\000 */
{ 130743 }, /* pm_cmplu_stall_slb\000\000marked\000Finish stall because the NTF instruction was awaiting L2 response for an SLB\000event=0x1e052\000\000\000\000\000\000\000 */
{ 130867 }, /* pm_cmplu_stall_spec_finish\000\000marked\000Finish stall while waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000event=0x30028\000\000\000\000\000\000\000 */
{ 135878 }, /* pm_darq0_0_3_entries\000\000marked\000Cycles in which 3 or less DARQ entries (out of 12) are in use\000event=0x4d04a\000\000\000\000\000\000\000 */
{ 135989 }, /* pm_darq0_10_12_entries\000\000marked\000Cycles in which 10 or more DARQ entries (out of 12) are in use\000event=0x1d058\000\000\000\000\000\000\000 */
{ 136103 }, /* pm_darq0_4_6_entries\000\000marked\000Cycles in which 4, 5, or 6 DARQ entries (out of 12) are in use\000event=0x3504e\000\000\000\000\000\000\000 */
{ 136215 }, /* pm_darq0_7_9_entries\000\000marked\000Cycles in which 7,8, or 9 DARQ entries (out of 12) are in use\000event=0x2e050\000\000\000\000\000\000\000 */
{ 136326 }, /* pm_darq1_0_3_entries\000\000marked\000Cycles in which 3 or fewer DARQ1 entries (out of 12) are in use\000event=0x4c122\000\000\000\000\000\000\000 */
{ 136776 }, /* pm_darq_store_reject\000\000marked\000The DARQ attempted to transmit a store into an LSAQ or SRQ entry but It was rejected. Divide by PM_DARQ_STORE_XMIT to get reject ratio\000event=0x4405e\000\000\000\000\000\000\000 */
{ 136960 }, /* pm_darq_store_xmit\000\000marked\000The DARQ attempted to transmit a store into an LSAQ or SRQ entry. Includes rejects. Not qualified by thread, so it includes counts for the whole core\000event=0x30064\000\000\000\000\000\000\000 */
{ 155459 }, /* pm_data_from_l2\000\000marked\000The processor's data cache was reloaded from local core's L2 due to a demand load\000event=0x1c042\000\000\000\000\000\000\000 */
{ 158990 }, /* pm_data_from_l31_eco_shr\000\000marked\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a demand load\000event=0x3c044\000\000\000\000\000\000\000 */
{ 159533 }, /* pm_data_from_l31_mod\000\000marked\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a demand load\000event=0x2c044\000\000\000\000\000\000\000 */
{ 160062 }, /* pm_data_from_l31_shr\000\000marked\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a demand load\000event=0x1c046\000\000\000\000\000\000\000 */
{ 162572 }, /* pm_data_from_l3miss\000\000marked\000Demand LD - L3 Miss (not L2 hit and not L3 hit)\000event=0x300fe\000\000\000\000\000\000\000 */
{ 163160 }, /* pm_data_from_l3miss_mod\000\000marked\000The processor's data cache was reloaded from a location other than the local core's L3 due to a demand load\000event=0x4c04e\000\000\000\000\000\000\000 */
{ 163744 }, /* pm_data_from_lmem\000\000marked\000The processor's data cache was reloaded from the local chip's Memory due to a demand load\000event=0x2c048\000\000\000\000\000\000\000 */
{ 164380 }, /* pm_data_from_memory\000\000marked\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x400fe\000\000\000\000\000\000\000 */
{ 165492 }, /* pm_data_from_off_chip_cache\000\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a demand load\000event=0x4c04a\000\000\000\000\000\000\000 */
{ 166090 }, /* pm_data_from_on_chip_cache\000\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a demand load\000event=0x1c048\000\000\000\000\000\000\000 */
{ 167569 }, /* pm_data_from_rl4\000\000marked\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a demand load\000event=0x2c04a\000\000\000\000\000\000\000 */
{ 168079 }, /* pm_data_from_rmem\000\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a demand load\000event=0x3c04a\000\000\000\000\000\000\000 */
{ 168966 }, /* pm_data_grp_pump_mpred\000\000marked\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for a demand load\000event=0x2c052\000\000\000\000\000\000\000 */
{ 169520 }, /* pm_data_grp_pump_mpred_rty\000\000marked\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for a demand load\000event=0x1c052\000\000\000\000\000\000\000 */
{ 169975 }, /* pm_data_pump_cpred\000\000marked\000Pump prediction correct. Counts across all types of pumps for a demand load\000event=0x1c054\000\000\000\000\000\000\000 */
{ 170221 }, /* pm_data_pump_mpred\000\000marked\000Pump misprediction. Counts across all types of pumps for a demand load\000event=0x4c052\000\000\000\000\000\000\000 */
{ 170616 }, /* pm_data_sys_pump_cpred\000\000marked\000Initial and Final Pump Scope was system pump (prediction=correct) for a demand load\000event=0x3c050\000\000\000\000\000\000\000 */
{ 170983 }, /* pm_data_sys_pump_mpred\000\000marked\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for a demand load\000event=0x3c052\000\000\000\000\000\000\000 */
{ 171702 }, /* pm_data_sys_pump_mpred_rty\000\000marked\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for a demand load\000event=0x4c050\000\000\000\000\000\000\000 */
{ 178626 }, /* pm_disp_held_hb_full\000\000marked\000Dispatch held due to History Buffer full. Could be GPR/VSR/VMR/FPR/CR/XVF; CR; XVF (XER/VSCR/FPSCR)\000event=0x3d05c\000\000\000\000\000\000\000 */
{ 184034 }, /* pm_disp_starved\000\000marked\000Dispatched Starved\000event=0x30008\000\000\000\000\000\000\000 */
{ 187393 }, /* pm_dpteg_from_l2\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e042\000\000\000\000\000\000\000 */
{ 189960 }, /* pm_dpteg_from_l31_eco_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e044\000\000\000\000\000\000\000 */
{ 190436 }, /* pm_dpteg_from_l31_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e044\000\000\000\000\000\000\000 */
{ 190900 }, /* pm_dpteg_from_l31_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e046\000\000\000\000\000\000\000 */
{ 192670 }, /* pm_dpteg_from_l3_no_conflict\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e044\000\000\000\000\000\000\000 */
{ 193926 }, /* pm_dpteg_from_lmem\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e048\000\000\000\000\000\000\000 */
{ 211182 }, /* pm_freq_up\000\000marked\000Power Management: Above Threshold A\000event=0x4000c\000\000\000\000\000\000\000 */
{ 212652 }, /* pm_fxu_1plus_busy\000\000marked\000At least one of the 4 FXU units is busy\000event=0x3000e\000\000\000\000\000\000\000 */
{ 215763 }, /* pm_grp_pump_cpred\000\000marked\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20050\000\000\000\000\000\000\000 */
{ 240793 }, /* pm_inst_from_dl2l3_mod\000\000marked\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x44048\000\000\000\000\000\000\000 */
{ 241522 }, /* pm_inst_from_dl2l3_shr\000\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x34048\000\000\000\000\000\000\000 */
{ 242161 }, /* pm_inst_from_dl4\000\000marked\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x3404c\000\000\000\000\000\000\000 */
{ 242756 }, /* pm_inst_from_dmem\000\000marked\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x4404c\000\000\000\000\000\000\000 */
{ 244626 }, /* pm_inst_from_l2\000\000marked\000The processor's Instruction cache was reloaded from local core's L2 due to an instruction fetch (not prefetch)\000event=0x14042\000\000\000\000\000\000\000 */
{ 245173 }, /* pm_inst_from_l2_disp_conflict_ldhitst\000\000marked\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to an instruction fetch (not prefetch)\000event=0x34040\000\000\000\000\000\000\000 */
{ 245757 }, /* pm_inst_from_l2_disp_conflict_other\000\000marked\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x44040\000\000\000\000\000\000\000 */
{ 246927 }, /* pm_inst_from_l2_no_conflict\000\000marked\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to an instruction fetch (not prefetch)\000event=0x14040\000\000\000\000\000\000\000 */
{ 248288 }, /* pm_inst_from_l31_eco_shr\000\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x34044\000\000\000\000\000\000\000 */
{ 248902 }, /* pm_inst_from_l31_mod\000\000marked\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x24044\000\000\000\000\000\000\000 */
{ 249502 }, /* pm_inst_from_l31_shr\000\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14046\000\000\000\000\000\000\000 */
{ 253097 }, /* pm_inst_from_l3miss_mod\000\000marked\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x4404e\000\000\000\000\000\000\000 */
{ 253603 }, /* pm_inst_from_ll4\000\000marked\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to an instruction fetch (not prefetch)\000event=0x1404c\000\000\000\000\000\000\000 */
{ 265601 }, /* pm_ipteg_from_l2\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a instruction side request\000event=0x15042\000\000\000\000\000\000\000 */
{ 264702 }, /* pm_ipteg_from_l21_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a instruction side request\000event=0x45046\000\000\000\000\000\000\000 */
{ 265081 }, /* pm_ipteg_from_l21_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a instruction side request\000event=0x35046\000\000\000\000\000\000\000 */
{ 266318 }, /* pm_ipteg_from_l2_mepf\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a instruction side request\000event=0x25040\000\000\000\000\000\000\000 */
{ 267032 }, /* pm_ipteg_from_l2miss\000\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a instruction side request\000event=0x1504e\000\000\000\000\000\000\000 */
{ 268898 }, /* pm_ipteg_from_l3\000\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 due to a instruction side request\000event=0x45042\000\000\000\000\000\000\000 */
{ 274821 }, /* pm_isq_36_44_entries\000\000marked\000Cycles in which 36 or more Issue Queue entries are in use. This is a shared event, not per thread. There are 44 issue queue entries across 4 slices in the whole core\000event=0x4000a\000\000\000\000\000\000\000 */
{ 277543 }, /* pm_itlb_miss\000\000marked\000ITLB Reloaded. Counts 1 per ITLB miss for HPT but multiple for radix depending on number of levels traveresed\000event=0x400fc\000\000\000\000\000\000\000 */
{ 277779 }, /* pm_l1_dcache_reload_valid\000\000marked\000DL1 reloaded due to Demand Load\000event=0x300f6\000\000\000\000\000\000\000 */
{ 277964 }, /* pm_l1_dcache_reloaded_all\000\000marked\000L1 data cache reloaded for demand. If MMCR1[16] is 1, prefetches will be included as well\000event=0x1002c\000\000\000\000\000\000\000 */
{ 278355 }, /* pm_l1_icache_miss\000\000marked\000Demand iCache Miss\000event=0x200fd\000\000\000\000\000\000\000 */
{ 278589 }, /* pm_l1_icache_reloaded_all\000\000marked\000Counts all Icache reloads includes demand, prefetch, prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\000\000\000\000\000\000 */
{ 278888 }, /* pm_l1_icache_reloaded_pref\000\000marked\000Counts all Icache prefetch reloads ( includes demand turned into prefetch)\000event=0x30068\000\000\000\000\000\000\000 */
{ 298117 }, /* pm_lmq_empty_cyc\000\000marked\000Cycles in which the LMQ has no pending load misses for this thread\000event=0x2e05e\000\000\000\000\000\000\000 */
{ 325936 }, /* pm_mem_loc_thresh_lsu_med\000\000marked\000Local memory above threshold for data prefetch\000event=0x1c05e\000\000\000\000\000\000\000 */
{ 326137 }, /* pm_mem_pref\000\000marked\000Memory prefetch for this thread. Includes L4\000event=0x2c058\000\000\000\000\000\000\000 */
{ 327283 }, /* pm_mrk_br_cmpl\000\000marked\000Branch Instruction completed\000event=0x1016e\000\000\000\000\000\000\000 */
{ 327462 }, /* pm_mrk_br_mpred_cmpl\000\000marked\000Marked Branch Mispredicted\000event=0x301e4\000\000\000\000\000\000\000 */
{ 327538 }, /* pm_mrk_br_taken_cmpl\000\000marked\000Marked Branch Taken completed\000event=0x101e2\000\000\000\000\000\000\000 */
{ 327786 }, /* pm_mrk_bru_fin\000\000marked\000bru marked instr finish\000event=0x2013a\000\000\000\000\000\000\000 */
{ 329266 }, /* pm_mrk_data_from_dl2l3_shr_cyc\000\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2c128\000\000\000\000\000\000\000 */
{ 338450 }, /* pm_mrk_data_from_l3\000\000marked\000The processor's data cache was reloaded from local core's L3 due to a marked load\000event=0x4d142\000\000\000\000\000\000\000 */
{ 341310 }, /* pm_mrk_data_from_l3miss_cyc\000\000marked\000Duration in cycles to reload from a location other than the local core's L3 due to a marked load\000event=0x1415e\000\000\000\000\000\000\000 */
{ 341616 }, /* pm_mrk_data_from_ll4\000\000marked\000The processor's data cache was reloaded from the local chip's L4 cache due to a marked load\000event=0x1d14c\000\000\000\000\000\000\000 */
{ 341757 }, /* pm_mrk_data_from_ll4_cyc\000\000marked\000Duration in cycles to reload from the local chip's L4 cache due to a marked load\000event=0x2c12e\000\000\000\000\000\000\000 */
{ 355609 }, /* pm_mrk_dpteg_from_l31_eco_mod\000\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f144\000\000\000\000\000\000\000 */
{ 356111 }, /* pm_mrk_dpteg_from_l31_eco_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f144\000\000\000\000\000\000\000 */
{ 359383 }, /* pm_mrk_dpteg_from_l3miss\000\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14e\000\000\000\000\000\000\000 */
{ 359836 }, /* pm_mrk_dpteg_from_ll4\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14c\000\000\000\000\000\000\000 */
{ 360252 }, /* pm_mrk_dpteg_from_lmem\000\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f148\000\000\000\000\000\000\000 */
{ 362820 }, /* pm_mrk_dpteg_from_rl2l3_shr\000\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14a\000\000\000\000\000\000\000 */
{ 367773 }, /* pm_mrk_inst\000\000marked\000An instruction was marked. Includes both Random Instruction Sampling (RIS) at decode time and Random Event Sampling (RES) at the time the configured event happens\000event=0x24158\000\000\000\000\000\000\000 */
{ 367976 }, /* pm_mrk_inst_cmpl\000\000marked\000marked instruction completed\000event=0x401e0\000\000\000\000\000\000\000 */
{ 368050 }, /* pm_mrk_inst_decoded\000\000marked\000An instruction was marked at decode time. Random Instruction Sampling (RIS) only\000event=0x20130\000\000\000\000\000\000\000 */
{ 368563 }, /* pm_mrk_inst_disp\000\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\000\000\000\000\000\000 */
{ 368906 }, /* pm_mrk_inst_fin\000\000marked\000marked instruction finished\000event=0x30130\000\000\000\000\000\000\000 */
{ 369912 }, /* pm_mrk_inst_issued\000\000marked\000Marked instruction issued\000event=0x10132\000\000\000\000\000\000\000 */
{ 370088 }, /* pm_mrk_inst_timeo\000\000marked\000marked Instruction finish timeout (instruction lost)\000event=0x40134\000\000\000\000\000\000\000 */
{ 376097 }, /* pm_mrk_st_fwd\000\000marked\000Marked st forwards\000event=0x3012c\000\000\000\000\000\000\000 */
{ 376250 }, /* pm_mrk_st_l2disp_to_cmpl_cyc\000\000marked\000cycles from L2 rc disp to l2 rc completion\000event=0x1f150\000\000\000\000\000\000\000 */
{ 376565 }, /* pm_mrk_st_nest\000\000marked\000Marked store sent to nest\000event=0x20138\000\000\000\000\000\000\000 */
{ 376780 }, /* pm_mrk_stall_cmplu_cyc\000\000marked\000Number of cycles the marked instruction is experiencing a stall while it is next to complete (NTC)\000event=0x3013e\000\000\000\000\000\000\000 */
{ 377515 }, /* pm_mrk_stcx_fail\000\000marked\000marked stcx failed\000event=0x3e158\000\000\000\000\000\000\000 */
{ 377731 }, /* pm_mrk_stcx_fin\000\000marked\000Number of marked stcx instructions finished. This includes instructions in the speculative path of a branch that may be flushed\000event=0x24156\000\000\000\000\000\000\000 */
{ 381882 }, /* pm_non_math_flop_cmpl\000\000marked\000Non FLOP operation completed\000event=0x4d05a\000\000\000\000\000\000\000 */
{ 383296 }, /* pm_ntc_issue_held_other\000\000marked\000The NTC instruction is being held at dispatch during regular pipeline cycles, or because the VSU is busy with multi-cycle instructions, or because of a write-back collision with VSU\000event=0x3d05a\000\000\000\000\000\000\000 */
{ 390063 }, /* pm_radix_pwc_l1_pde_from_l3\000\000marked\000A Page Directory Entry was reloaded to a level 1 page walk cache from the core's L3 data cache\000event=0x3f058\000\000\000\000\000\000\000 */
{ 390214 }, /* pm_radix_pwc_l1_pde_from_l3miss\000\000marked\000A Page Directory Entry was reloaded to a level 1 page walk cache from beyond the core's L3 data cache. The source could be local/remote/distant memory or another core's cache\000event=0x4f056\000\000\000\000\000\000\000 */
{ 391002 }, /* pm_radix_pwc_l2_pte_from_l3\000\000marked\000A Page Table Entry was reloaded to a level 2 page walk cache from the core's L3 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation\000event=0x4f058\000\000\000\000\000\000\000 */
{ 391563 }, /* pm_radix_pwc_l3_pde_from_l2\000\000marked\000A Page Directory Entry was reloaded to a level 3 page walk cache from the core's L2 data cache\000event=0x2d02a\000\000\000\000\000\000\000 */
{ 391714 }, /* pm_radix_pwc_l3_pde_from_l3\000\000marked\000A Page Directory Entry was reloaded to a level 3 page walk cache from the core's L3 data cache\000event=0x1f05c\000\000\000\000\000\000\000 */
{ 391865 }, /* pm_radix_pwc_l3_pte_from_l2\000\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from the core's L2 data cache. This implies that a level 4 PWC access was not necessary for this translation\000event=0x2d02e\000\000\000\000\000\000\000 */
{ 392091 }, /* pm_radix_pwc_l3_pte_from_l3\000\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from the core's L3 data cache. This implies that a level 4 PWC access was not necessary for this translation\000event=0x3f05e\000\000\000\000\000\000\000 */
{ 392317 }, /* pm_radix_pwc_l3_pte_from_l3miss\000\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from beyond the core's L3 data cache. This implies that a level 4 PWC access was not necessary for this translation. The source could be local/remote/distant memory or another core's cache\000event=0x4f05e\000\000\000\000\000\000\000 */
{ 392627 }, /* pm_radix_pwc_l4_pte_from_l2\000\000marked\000A Page Table Entry was reloaded to a level 4 page walk cache from the core's L2 data cache. This is the deepest level of PWC possible for a translation\000event=0x1f05a\000\000\000\000\000\000\000 */
{ 392835 }, /* pm_radix_pwc_l4_pte_from_l3\000\000marked\000A Page Table Entry was reloaded to a level 4 page walk cache from the core's L3 data cache. This is the deepest level of PWC possible for a translation\000event=0x4f05a\000\000\000\000\000\000\000 */
{ 396514 }, /* pm_run_cyc_st_mode\000\000marked\000Cycles run latch is set and core is in ST mode\000event=0x1006c\000\000\000\000\000\000\000 */
{ 397399 }, /* pm_run_purr\000\000marked\000Run_PURR\000event=0x400f4\000\000\000\000\000\000\000 */
{ 400103 }, /* pm_sp_flop_cmpl\000\000marked\000SP instruction completed\000event=0x4505a\000\000\000\000\000\000\000 */
{ 404750 }, /* pm_sync_mrk_probe_nop\000\000marked\000Marked probeNops which can cause synchronous interrupts\000event=0x15150\000\000\000\000\000\000\000 */
{ 404856 }, /* pm_sys_pump_cpred\000\000marked\000Initial and Final Pump Scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30050\000\000\000\000\000\000\000 */
{ 405381 }, /* pm_sys_pump_mpred\000\000marked\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30052\000\000\000\000\000\000\000 */
{ 418319 }, /* pm_vector_flop_cmpl\000\000marked\000Vector FP instruction completed\000event=0x4d058\000\000\000\000\000\000\000 */
{ 136554 }, /* pm_darq1_4_6_entries\000\000memory\000Cycles in which 4, 5, or 6 DARQ1 entries (out of 12) are in use\000event=0x3e050\000\000\000\000\000\000\000 */
{ 136667 }, /* pm_darq1_7_9_entries\000\000memory\000Cycles in which 7 to 9 DARQ1 entries (out of 12) are in use\000event=0x2005a\000\000\000\000\000\000\000 */
{ 151638 }, /* pm_data_chip_pump_cpred\000\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for a demand load\000event=0x1c050\000\000\000\000\000\000\000 */
{ 152214 }, /* pm_data_from_dl2l3_mod\000\000memory\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x4c048\000\000\000\000\000\000\000 */
{ 152869 }, /* pm_data_from_dl2l3_shr\000\000memory\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x3c048\000\000\000\000\000\000\000 */
{ 156441 }, /* pm_data_from_l2_disp_conflict_other\000\000memory\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a demand load\000event=0x4c040\000\000\000\000\000\000\000 */
{ 156972 }, /* pm_data_from_l2_mepf\000\000memory\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to a demand load\000event=0x2c040\000\000\000\000\000\000\000 */
{ 157461 }, /* pm_data_from_l2_no_conflict\000\000memory\000The processor's data cache was reloaded from local core's L2 without conflict due to a demand load\000event=0x1c040\000\000\000\000\000\000\000 */
{ 160852 }, /* pm_data_from_l3\000\000memory\000The processor's data cache was reloaded from local core's L3 due to a demand load\000event=0x4c042\000\000\000\000\000\000\000 */
{ 258651 }, /* pm_inst_from_rmem\000\000memory\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x3404a\000\000\000\000\000\000\000 */
{ 259096 }, /* pm_inst_grp_pump_cpred\000\000memory\000Initial and Final Pump Scope was group pump (prediction=correct) for an instruction fetch (demand only)\000event=0x2c05c\000\000\000\000\000\000\000 */
{ 294361 }, /* pm_larx_fin\000\000memory\000Larx finished\000event=0x3c058\000\000\000\000\000\000\000 */
{ 294666 }, /* pm_ld_cmpl\000\000memory\000count of Loads completed\000event=0x4003e\000\000\000\000\000\000\000 */
{ 298326 }, /* pm_lrq_reject\000\000memory\000Internal LSU reject from LRQ. Rejects cause the load to go back to LRQ, but it stays contained within the LSU once it gets issued. This event counts the number of times the LRQ attempts to relaunch an instruction after a reject. Any load can suffer multiple rejects\000event=0x2e05a\000\000\000\000\000\000\000 */
{ 314462 }, /* pm_lsu_derat_miss\000\000memory\000DERAT Reloaded due to a DERAT miss\000event=0x200f6\000\000\000\000\000\000\000 */
{ 321886 }, /* pm_lsu_reject_erat_miss\000\000memory\000LSU Reject due to ERAT (up to 4 per cycles)\000event=0x2e05c\000\000\000\000\000\000\000 */
{ 374485 }, /* pm_mrk_run_cyc\000\000memory\000Run cycles in which a marked instruction is in the pipeline\000event=0x1d15e\000\000\000\000\000\000\000 */
{ 375339 }, /* pm_mrk_st_cmpl\000\000memory\000Marked store completed and sent to nest\000event=0x301e2\000\000\000\000\000\000\000 */
{ 381467 }, /* pm_nest_ref_clk\000\000memory\000Multiply by 4 to obtain the number of PB cycles\000event=0x3006e\000\000\000\000\000\000\000 */
{ 381803 }, /* pm_non_fma_flop_cmpl\000\000memory\000Non FMA instruction completed\000event=0x4d056\000\000\000\000\000\000\000 */
{ 383917 }, /* pm_pmc1_overflow\000\000memory\000Overflow from counter 1\000event=0x20010\000\000\000\000\000\000\000 */
{ 384162 }, /* pm_pmc1_rewind\000\000memory\000PMC1 rewind event\000event=0x4d02c\000\000\000\000\000\000\000 */
{ 385674 }, /* pm_pmc3_rewind\000\000memory\000PMC3 rewind event. A rewind happens when a speculative event (such as latency or CPI stack) is selected on PMC3 and the stall reason or reload source did not match the one programmed in PMC3. When this occurs, the count in PMC3 will not change\000event=0x1000a\000\000\000\000\000\000\000 */
{ 397494 }, /* pm_run_spurr\000\000memory\000Run SPURR\000event=0x10008\000\000\000\000\000\000\000 */
{ 404244 }, /* pm_sync_mrk_l2hit\000\000memory\000Marked L2 Hits that can throw a synchronous interrupt\000event=0x15158\000\000\000\000\000\000\000 */
{ 109359 }, /* pm_any_thrd_run_cyc\000\000other\000Cycles in which at least one thread has the run latch set\000event=0x100fa\000\000\000\000\000\000\000 */
{ 109733 }, /* pm_back_br_cmpl\000\000other\000Branch instruction completed with a target address less than current instruction address\000event=0x2505e\000\000\000\000\000\000\000 */
{ 109865 }, /* pm_bank_conflict\000\000other\000Read blocked due to interleave conflict.  The ifar logic will detect an interleave conflict and kill the data that was read that cycle\000event=0x4880\000\000\000\000\000\000\000 */
{ 110220 }, /* pm_bfu_busy\000\000other\000Cycles in which all 4 Binary Floating Point units are busy. The BFU is running at capacity\000event=0x3005c\000\000\000\000\000\000\000 */
{ 110805 }, /* pm_br_cmpl\000\000other\000Any Branch instruction completed\000event=0x4d05e\000\000\000\000\000\000\000 */
{ 110961 }, /* pm_br_corect_pred_taken_cmpl\000\000other\000Conditional Branch Completed in which the HW correctly predicted the direction as taken.  Counted at completion time\000event=0x489c\000\000\000\000\000\000\000 */
{ 111250 }, /* pm_br_mpred_ccache\000\000other\000Conditional Branch Completed that was Mispredicted due to the Count Cache Target Prediction\000event=0x40ac\000\000\000\000\000\000\000 */
{ 111925 }, /* pm_br_mpred_lstack\000\000other\000Conditional Branch Completed that was Mispredicted due to the Link Stack Target Prediction\000event=0x48ac\000\000\000\000\000\000\000 */
{ 112061 }, /* pm_br_mpred_pcache\000\000other\000Conditional Branch Completed that was Mispredicted due to pattern cache prediction\000event=0x48b0\000\000\000\000\000\000\000 */
{ 112411 }, /* pm_br_mpred_taken_cr\000\000other\000A Conditional Branch that resolved to taken was mispredicted as not taken (due to the BHT Direction Prediction)\000event=0x40b8\000\000\000\000\000\000\000 */
{ 112570 }, /* pm_br_mpred_taken_ta\000\000other\000Conditional Branch Completed that was Mispredicted due to the Target Address Prediction from the Count Cache or Link Stack.  Only XL-form branches that resolved Taken set this event\000event=0x48b8\000\000\000\000\000\000\000 */
{ 112865 }, /* pm_br_pred\000\000other\000Conditional Branch Executed in which the HW predicted the Direction or Target.  Includes taken and not taken and is counted at execution time\000event=0x409c\000\000\000\000\000\000\000 */
{ 113649 }, /* pm_br_pred_ccache\000\000other\000Conditional Branch Completed that used the Count Cache for Target Prediction\000event=0x40a4\000\000\000\000\000\000\000 */
{ 114980 }, /* pm_br_pred_lstack\000\000other\000Conditional Branch Completed  that used the Link Stack for Target Prediction\000event=0x40a8\000\000\000\000\000\000\000 */
{ 115555 }, /* pm_br_pred_pcache\000\000other\000Conditional branch completed that used pattern cache prediction\000event=0x48a0\000\000\000\000\000\000\000 */
{ 115663 }, /* pm_br_pred_ta\000\000other\000Conditional Branch Completed that had its target address predicted. Only XL-form branches set this event.  This equal the sum of CCACHE, LSTACK, and PCACHE\000event=0x40b4\000\000\000\000\000\000\000 */
{ 116333 }, /* pm_br_pred_taken_cr\000\000other\000Conditional Branch that had its direction predicted. I-form branches do not set this event.  In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b0\000\000\000\000\000\000\000 */
{ 116774 }, /* pm_br_uncond\000\000other\000Unconditional Branch Completed. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was covenrted to a Resolve\000event=0x40a0\000\000\000\000\000\000\000 */
{ 117881 }, /* pm_btac_bad_result\000\000other\000BTAC thinks branch will be taken but it is either predicted not-taken by the BHT, or the target address is wrong (less common).  In both cases, a redirect will happen\000event=0x50b0\000\000\000\000\000\000\000 */
{ 118093 }, /* pm_btac_good_result\000\000other\000BTAC predicts a taken branch and the BHT agrees, and the target address is correct\000event=0x58b0\000\000\000\000\000\000\000 */
{ 118926 }, /* pm_clb_held\000\000other\000CLB (control logic block - indicates quadword fetch block) Hold: Any Reason\000event=0x208c\000\000\000\000\000\000\000 */
{ 120521 }, /* pm_cmplu_stall_any_sync\000\000other\000Cycles in which the NTC sync instruction (isync, lwsync or hwsync) is not allowed to complete\000event=0x1e05a\000\000\000\000\000\000\000 */
{ 122743 }, /* pm_cmplu_stall_dmiss_l3miss\000\000other\000Completion stall due to cache miss resolving missed the L3\000event=0x4c01a\000\000\000\000\000\000\000 */
{ 122974 }, /* pm_cmplu_stall_dmiss_lmem\000\000other\000Completion stall due to cache miss that resolves in local memory\000event=0x30038\000\000\000\000\000\000\000 */
{ 125039 }, /* pm_cmplu_stall_exec_unit\000\000other\000Completion stall due to execution units (FXU/VSU/CRU)\000event=0x2d018\000\000\000\000\000\000\000 */
{ 126833 }, /* pm_cmplu_stall_lrq_full\000\000other\000Finish stall because the NTF instruction was a load that was held in LSAQ (load-store address queue) because the LRQ (load-reorder queue) was full\000event=0x2d014\000\000\000\000\000\000\000 */
{ 128673 }, /* pm_cmplu_stall_nested_tbegin\000\000other\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tbegin. This is a short delay, and it includes ROT\000event=0x1e05c\000\000\000\000\000\000\000 */
{ 131079 }, /* pm_cmplu_stall_srq_full\000\000other\000Finish stall because the NTF instruction was a store that was held in LSAQ because the SRQ was full\000event=0x30016\000\000\000\000\000\000\000 */
{ 132836 }, /* pm_cmplu_stall_thrd\000\000other\000Completion Stalled because the thread was blocked\000event=0x1001c\000\000\000\000\000\000\000 */
{ 134673 }, /* pm_co0_busy\000\000other\000CO mach 0 Busy. Used by PMU to sample ave CO lifetime (mach0 used as sample point)\000event=0x3608c\000\000\000\000\000\000\000 */
{ 134916 }, /* pm_co_disp_fail\000\000other\000CO dispatch failed due to all CO machines being busy\000event=0x16886\000\000\000\000\000\000\000 */
{ 135012 }, /* pm_co_tm_sc_footprint\000\000other\000L2 did a cleanifdirty CO to the L3 (ie created an SC line in the L3) OR L2 TM_store hit dirty HPC line and L3 indicated SC line formed in L3 on RDR bus\000event=0x26086\000\000\000\000\000\000\000 */
{ 135213 }, /* pm_co_usage\000\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each CO machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x2688c\000\000\000\000\000\000\000 */
{ 136439 }, /* pm_darq1_10_12_entries\000\000other\000Cycles in which 10 or  more DARQ1 entries (out of 12) are in use\000event=0x20058\000\000\000\000\000\000\000 */
{ 155932 }, /* pm_data_from_l2_disp_conflict_ldhitst\000\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a demand load\000event=0x3c040\000\000\000\000\000\000\000 */
{ 161305 }, /* pm_data_from_l3_disp_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a demand load\000event=0x3c042\000\000\000\000\000\000\000 */
{ 163608 }, /* pm_data_from_ll4\000\000other\000The processor's data cache was reloaded from the local chip's L4 cache due to a demand load\000event=0x1c04c\000\000\000\000\000\000\000 */
{ 167359 }, /* pm_data_from_rl2l3_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x1c04a\000\000\000\000\000\000\000 */
{ 168833 }, /* pm_data_grp_pump_cpred\000\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for a demand load\000event=0x2c050\000\000\000\000\000\000\000 */
{ 170526 }, /* pm_data_store\000\000other\000All ops that drain from s2q to L2 containing data\000event=0xf0a0\000\000\000\000\000\000\000 */
{ 172236 }, /* pm_data_tablewalk_cyc\000\000other\000Data Tablewalk Cycles.  Could be 1 or 2 active tablewalks. Includes data prefetches\000event=0x3001a\000\000\000\000\000\000\000 */
{ 172457 }, /* pm_dc_dealloc_no_conf\000\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0xf8ac\000\000\000\000\000\000\000 */
{ 172734 }, /* pm_dc_pref_conf\000\000other\000A demand load referenced a line in an active prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software. Includes forwards and backwards streams\000event=0xf0a8\000\000\000\000\000\000\000 */
{ 172976 }, /* pm_dc_pref_cons_alloc\000\000other\000Prefetch stream allocated in the conservative phase by either the hardware prefetch mechanism or software prefetch. The sum of this pair subtracted from the total number of allocs will give the total allocs in normal phase\000event=0xf0b4\000\000\000\000\000\000\000 */
{ 173247 }, /* pm_dc_pref_fuzzy_conf\000\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0xf8a8\000\000\000\000\000\000\000 */
{ 173524 }, /* pm_dc_pref_hw_alloc\000\000other\000Prefetch stream allocated by the hardware prefetch mechanism\000event=0xf0a4\000\000\000\000\000\000\000 */
{ 174568 }, /* pm_dc_pref_strided_conf\000\000other\000A demand load referenced a line in an active strided prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software\000event=0xf0ac\000\000\000\000\000\000\000 */
{ 174785 }, /* pm_dc_pref_sw_alloc\000\000other\000Prefetch stream allocated by software prefetching\000event=0xf8a4\000\000\000\000\000\000\000 */
{ 174881 }, /* pm_dc_pref_xcons_alloc\000\000other\000Prefetch stream allocated in the Ultra conservative phase by either the hardware prefetch mechanism or software prefetch\000event=0xf8b4\000\000\000\000\000\000\000 */
{ 175051 }, /* pm_decode_fusion_const_gen\000\000other\00032-bit constant generation\000event=0x48b4\000\000\000\000\000\000\000 */
{ 175131 }, /* pm_decode_fusion_ld_st_disp\000\000other\00032-bit displacement D-form and 16-bit displacement X-form\000event=0x48a8\000\000\000\000\000\000\000 */
{ 175243 }, /* pm_decode_hold_ict_full\000\000other\000Counts the number of cycles in which the IFU was not able to decode and transmit one or more instructions because all itags were in use.  This means the ICT is full for this thread\000event=0x58a8\000\000\000\000\000\000\000 */
{ 175835 }, /* pm_derat_miss_16g_1g\000\000other\000Data ERAT Miss (Data TLB Access) page size 16G (hpt mode) or 1G (radix mode)\000event=0x4c054\000\000\000\000\000\000\000 */
{ 177945 }, /* pm_disp_clb_held_bal\000\000other\000Dispatch/CLB Hold: Balance Flush\000event=0x288c\000\000\000\000\000\000\000 */
{ 178174 }, /* pm_disp_clb_held_sb\000\000other\000Dispatch/CLB Hold: Scoreboard\000event=0x2090\000\000\000\000\000\000\000 */
{ 178492 }, /* pm_disp_clb_held_tlbie\000\000other\000Dispatch Hold: Due to TLBIE\000event=0x2890\000\000\000\000\000\000\000 */
{ 178857 }, /* pm_disp_held_issq_full\000\000other\000Dispatch held due to Issue q full. Includes issue queue and branch queue\000event=0x20006\000\000\000\000\000\000\000 */
{ 179288 }, /* pm_disp_held_tbegin\000\000other\000This outer tbegin transaction cannot be dispatched until the previous tend instruction completes\000event=0x28b0\000\000\000\000\000\000\000 */
{ 188133 }, /* pm_dpteg_from_l2_mepf\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e040\000\000\000\000\000\000\000 */
{ 189046 }, /* pm_dpteg_from_l2miss\000\000other\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04e\000\000\000\000\000\000\000 */
{ 189481 }, /* pm_dpteg_from_l31_eco_mod\000\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e044\000\000\000\000\000\000\000 */
{ 194791 }, /* pm_dpteg_from_off_chip_cache\000\000other\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04a\000\000\000\000\000\000\000 */
{ 195342 }, /* pm_dpteg_from_on_chip_cache\000\000other\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e048\000\000\000\000\000\000\000 */
{ 196945 }, /* pm_dpteg_from_rl4\000\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e04a\000\000\000\000\000\000\000 */
{ 197859 }, /* pm_dside_l2memacc\000\000other\000Valid when first beat of data comes in for an D-side fetch where data came EXCLUSIVELY from memory (excluding hpcread64 accesses), i.e., total memory accesses by RCs\000event=0x36092\000\000\000\000\000\000\000 */
{ 198070 }, /* pm_dside_mru_touch\000\000other\000D-side L2 MRU touch commands sent to the L2\000event=0x26884\000\000\000\000\000\000\000 */
{ 198160 }, /* pm_dside_other_64b_l2memacc\000\000other\000Valid when first beat of data comes in for an D-side fetch where data came EXCLUSIVELY from memory that was for hpc_read64, (RC had to fetch other 64B of a line from MC) i.e., number of times RC had to go to memory to get 'missing' 64B\000event=0x36892\000\000\000\000\000\000\000 */
{ 201284 }, /* pm_eat_force_mispred\000\000other\000XL-form branch was mispredicted due to the predicted target address missing from EAT.  The EAT forces a mispredict in this case since there is no predicated target to validate.  This is a rare case that may occur when the EAT is full and a branch is issued\000event=0x50a8\000\000\000\000\000\000\000 */
{ 202031 }, /* pm_eat_full_cyc\000\000other\000Cycles No room in EAT\000event=0x4084\000\000\000\000\000\000\000 */
{ 202095 }, /* pm_ee_off_ext_int\000\000other\000CyclesMSR[EE] is off and external interrupts are active\000event=0x2080\000\000\000\000\000\000\000 */
{ 209252 }, /* pm_flush_disp\000\000other\000Dispatch flush\000event=0x2880\000\000\000\000\000\000\000 */
{ 209307 }, /* pm_flush_disp_sb\000\000other\000Dispatch Flush: Scoreboard\000event=0x2088\000\000\000\000\000\000\000 */
{ 209581 }, /* pm_flush_disp_tlbie\000\000other\000Dispatch Flush: TLBIE\000event=0x2888\000\000\000\000\000\000\000 */
{ 209649 }, /* pm_flush_hb_restore_cyc\000\000other\000Cycles in which no new instructions can be dispatched to the ICT after a flush.  History buffer recovery\000event=0x2084\000\000\000\000\000\000\000 */
{ 209866 }, /* pm_flush_lsu\000\000other\000LSU flushes.  Includes all lsu flushes\000event=0x58a4\000\000\000\000\000\000\000 */
{ 209944 }, /* pm_flush_mpred\000\000other\000Branch mispredict flushes.  Includes target and address misprecition\000event=0x50a4\000\000\000\000\000\000\000 */
{ 210233 }, /* pm_fma_cmpl\000\000other\000two flops operation completed (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only. \000event=0x45054\000\000\000\000\000\000\000 */
{ 217320 }, /* pm_grp_pump_mpred_rty\000\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10052\000\000\000\000\000\000\000 */
{ 218749 }, /* pm_hwsync\000\000other\000A hwsync instruction was decoded and transferred\000event=0xd0b0\000\000\000\000\000\000\000 */
{ 219200 }, /* pm_ibuf_full_cyc\000\000other\000Cycles No room in ibuff\000event=0x4884\000\000\000\000\000\000\000 */
{ 219569 }, /* pm_ic_demand_l2_bht_redirect\000\000other\000L2 I cache demand request due to BHT redirect, branch redirect ( 2 bubbles 3 cycles)\000event=0x4098\000\000\000\000\000\000\000 */
{ 219831 }, /* pm_ic_demand_l2_br_redirect\000\000other\000L2 I cache demand request due to branch Mispredict ( 15 cycle path)\000event=0x4898\000\000\000\000\000\000\000 */
{ 219953 }, /* pm_ic_demand_req\000\000other\000Demand Instruction fetch request\000event=0x4088\000\000\000\000\000\000\000 */
{ 220092 }, /* pm_ic_invalidate\000\000other\000Ic line invalidated\000event=0x5888\000\000\000\000\000\000\000 */
{ 220252 }, /* pm_ic_miss_icbi\000\000other\000threaded version, IC Misses where we got EA dir hit but no sector valids were on. ICBI took line out\000event=0x5094\000\000\000\000\000\000\000 */
{ 220479 }, /* pm_ic_pref_cancel_hit\000\000other\000Prefetch Canceled due to icache hit\000event=0x4890\000\000\000\000\000\000\000 */
{ 220563 }, /* pm_ic_pref_cancel_l2\000\000other\000L2 Squashed a demand or prefetch request\000event=0x4094\000\000\000\000\000\000\000 */
{ 220718 }, /* pm_ic_pref_cancel_page\000\000other\000Prefetch Canceled due to page boundary\000event=0x4090\000\000\000\000\000\000\000 */
{ 220877 }, /* pm_ic_pref_req\000\000other\000Instruction prefetch requests\000event=0x4888\000\000\000\000\000\000\000 */
{ 221029 }, /* pm_ic_pref_write\000\000other\000Instruction prefetch written into IL1\000event=0x488c\000\000\000\000\000\000\000 */
{ 221110 }, /* pm_ic_reload_private\000\000other\000Reloading line was brought in private for a specific thread.  Most lines are brought in shared for all eight threads.  If RA does not match then invalidates and then brings it shared to other thread. In P7 line brought in private , then line was invalidat\000event=0x4894\000\000\000\000\000\000\000 */
{ 222303 }, /* pm_ict_noslot_disp_held_hb_full\000\000other\000Ict empty for this thread due to dispatch holds because the History Buffer was full. Could be GPR/VSR/VMR/FPR/CR/XVF; CR; XVF (XER/VSCR/FPSCR)\000event=0x30018\000\000\000\000\000\000\000 */
{ 222505 }, /* pm_ict_noslot_disp_held_issq\000\000other\000Ict empty for this thread due to dispatch hold on this thread due to Issue q full, BRQ full, XVCF Full, Count cache, Link, Tar full\000event=0x2d01e\000\000\000\000\000\000\000 */
{ 224097 }, /* pm_ierat_reload_4k\000\000other\000IERAT reloaded (after a miss) for 4K pages\000event=0x20064\000\000\000\000\000\000\000 */
{ 224273 }, /* pm_ierat_reload_64k\000\000other\000IERAT Reloaded (Miss) for a 64k page\000event=0x3006a\000\000\000\000\000\000\000 */
{ 240114 }, /* pm_inst_disp\000\000other\000# PPC Dispatched\000event=0x200f2\000\000\000\000\000\000\000 */
{ 242955 }, /* pm_inst_from_l1\000\000other\000Instruction fetches from L1.  L1 instruction hit\000event=0x4080\000\000\000\000\000\000\000 */
{ 243514 }, /* pm_inst_from_l21_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x44046\000\000\000\000\000\000\000 */
{ 246364 }, /* pm_inst_from_l2_mepf\000\000other\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24040\000\000\000\000\000\000\000 */
{ 248079 }, /* pm_inst_from_l31_eco_mod\000\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x44044\000\000\000\000\000\000\000 */
{ 254099 }, /* pm_inst_from_lmem\000\000other\000The processor's Instruction cache was reloaded from the local chip's Memory due to an instruction fetch (not prefetch)\000event=0x24048\000\000\000\000\000\000\000 */
{ 255348 }, /* pm_inst_from_off_chip_cache\000\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to an instruction fetch (not prefetch)\000event=0x4404a\000\000\000\000\000\000\000 */
{ 259662 }, /* pm_inst_grp_pump_mpred\000\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for an instruction fetch (demand only)\000event=0x2c05e\000\000\000\000\000\000\000 */
{ 260408 }, /* pm_inst_imc_match_cmpl\000\000other\000IMC Match Count\000event=0x4001c\000\000\000\000\000\000\000 */
{ 263725 }, /* pm_ipteg_from_dl2l3_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x35048\000\000\000\000\000\000\000 */
{ 264143 }, /* pm_ipteg_from_dl4\000\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a instruction side request\000event=0x3504c\000\000\000\000\000\000\000 */
{ 264516 }, /* pm_ipteg_from_dmem\000\000other\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a instruction side request\000event=0x4504c\000\000\000\000\000\000\000 */
{ 266686 }, /* pm_ipteg_from_l2_no_conflict\000\000other\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a instruction side request\000event=0x15040\000\000\000\000\000\000\000 */
{ 269223 }, /* pm_ipteg_from_l3_disp_conflict\000\000other\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a instruction side request\000event=0x35042\000\000\000\000\000\000\000 */
{ 270103 }, /* pm_ipteg_from_ll4\000\000other\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a instruction side request\000event=0x1504c\000\000\000\000\000\000\000 */
{ 270411 }, /* pm_ipteg_from_lmem\000\000other\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a instruction side request\000event=0x25048\000\000\000\000\000\000\000 */
{ 273524 }, /* pm_iside_disp\000\000other\000All I-side-instruction-fetch dispatch attempts for this thread\000event=0x1688a\000\000\000\000\000\000\000 */
{ 273628 }, /* pm_iside_disp_fail_addr\000\000other\000All I-side-instruction-fetch dispatch attempts for this thread that failed due to an address collision conflict with an L2 machine already working on this line (e.g. ld-hit-stq or RC/CO/SN machines)\000event=0x2608a\000\000\000\000\000\000\000 */
{ 273878 }, /* pm_iside_disp_fail_other\000\000other\000All I-side-instruction-fetch dispatch attempts for this thread that failed due to reasons other than an address collision conflict with an L2 machine (e.g. no available RC/CO machines)\000event=0x2688a\000\000\000\000\000\000\000 */
{ 274115 }, /* pm_iside_l2memacc\000\000other\000Valid when first beat of data comes in for an I-side fetch where data came from memory\000event=0x26890\000\000\000\000\000\000\000 */
{ 274383 }, /* pm_iside_mru_touch\000\000other\000I-side L2 MRU touch sent to L2 for this thread I-side L2 MRU touch commands sent to the L2 for this thread\000event=0x46880\000\000\000\000\000\000\000 */
{ 274589 }, /* pm_islb_miss\000\000other\000Instruction SLB Miss - Total of all segment sizes\000event=0xd8a8\000\000\000\000\000\000\000 */
{ 274678 }, /* pm_isq_0_8_entries\000\000other\000Cycles in which 8 or less Issue Queue entries are in use. This is a shared event, not per thread\000event=0x3005a\000\000\000\000\000\000\000 */
{ 275559 }, /* pm_isu0_iss_hold_all\000\000other\000All ISU rejects\000event=0x3080\000\000\000\000\000\000\000 */
{ 275622 }, /* pm_isu1_iss_hold_all\000\000other\000All ISU rejects\000event=0x3084\000\000\000\000\000\000\000 */
{ 275685 }, /* pm_isu2_iss_hold_all\000\000other\000All ISU rejects\000event=0x3880\000\000\000\000\000\000\000 */
{ 275748 }, /* pm_isu3_iss_hold_all\000\000other\000All ISU rejects\000event=0x3884\000\000\000\000\000\000\000 */
{ 276751 }, /* pm_isync\000\000other\000Isync completion count per thread\000event=0x2884\000\000\000\000\000\000\000 */
{ 278199 }, /* pm_l1_demand_write\000\000other\000Instruction Demand sectors written into IL1\000event=0x408c\000\000\000\000\000\000\000 */
{ 279018 }, /* pm_l1_pref\000\000other\000A data line was written to the L1 due to a hardware or software prefetch\000event=0x20054\000\000\000\000\000\000\000 */
{ 279129 }, /* pm_l1_sw_pref\000\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xe880\000\000\000\000\000\000\000 */
{ 279842 }, /* pm_l1pf_l2memacc\000\000other\000Valid when first beat of data comes in for an L1PF where data came from memory\000event=0x16890\000\000\000\000\000\000\000 */
{ 280094 }, /* pm_l2_castout_mod\000\000other\000L2 Castouts - Modified (M,Mu,Me)\000event=0x16082\000\000\000\000\000\000\000 */
{ 280172 }, /* pm_l2_castout_shr\000\000other\000L2 Castouts - Shared (Tx,Sx)\000event=0x16882\000\000\000\000\000\000\000 */
{ 280246 }, /* pm_l2_chip_pump\000\000other\000RC requests that were local (aka chip) pump attempts\000event=0x46088\000\000\000\000\000\000\000 */
{ 280435 }, /* pm_l2_dc_inv\000\000other\000D-cache invalidates sent over the reload bus to the core\000event=0x26882\000\000\000\000\000\000\000 */
{ 280532 }, /* pm_l2_disp_all_l2miss\000\000other\000All successful D-side-Ld/St or I-side-instruction-fetch dispatches for this thread that were an L2 miss\000event=0x46080\000\000\000\000\000\000\000 */
{ 280773 }, /* pm_l2_group_pump\000\000other\000RC requests that were on group (aka nodel) pump attempts\000event=0x46888\000\000\000\000\000\000\000 */
{ 280874 }, /* pm_l2_grp_guess_correct\000\000other\000L2 guess grp (GS or NNS) and guess was correct (data intra-group AND ^on-chip)\000event=0x26088\000\000\000\000\000\000\000 */
{ 281004 }, /* pm_l2_grp_guess_wrong\000\000other\000L2 guess grp (GS or NNS) and guess was not correct (ie data on-chip OR beyond-group)\000event=0x26888\000\000\000\000\000\000\000 */
{ 281138 }, /* pm_l2_ic_inv\000\000other\000I-cache Invalidates sent over the realod bus to the core\000event=0x26082\000\000\000\000\000\000\000 */
{ 281235 }, /* pm_l2_inst\000\000other\000All successful I-side-instruction-fetch (e.g. i-demand, i-prefetch) dispatches for this thread\000event=0x36080\000\000\000\000\000\000\000 */
{ 281368 }, /* pm_l2_inst_miss\000\000other\000All successful I-side-instruction-fetch (e.g. i-demand, i-prefetch) dispatches for this thread that were an L2 miss\000event=0x36880\000\000\000\000\000\000\000 */
{ 281527 }, /* pm_l2_ld\000\000other\000All successful D-side Load dispatches for this thread (L2 miss + L2 hits)\000event=0x16080\000\000\000\000\000\000\000 */
{ 281637 }, /* pm_l2_ld_disp\000\000other\000All successful D-side-Ld or I-side-instruction-fetch dispatches for this thread\000event=0x36082\000\000\000\000\000\000\000 */
{ 281758 }, /* pm_l2_ld_hit\000\000other\000All successful D-side-Ld or I-side-instruction-fetch dispatches for this thread that were L2 hits\000event=0x36882\000\000\000\000\000\000\000 */
{ 281896 }, /* pm_l2_ld_miss\000\000other\000All successful D-Side Load dispatches that were an L2 miss for this thread\000event=0x26080\000\000\000\000\000\000\000 */
{ 282012 }, /* pm_l2_ld_miss_128b\000\000other\000All successful D-side load dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 128B (i.e., M=0)\000event=0x16092\000\000\000\000\000\000\000 */
{ 282213 }, /* pm_l2_ld_miss_64b\000\000other\000All successful D-side load dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 64B(i.e., M=1)\000event=0x26092\000\000\000\000\000\000\000 */
{ 282411 }, /* pm_l2_loc_guess_correct\000\000other\000L2 guess local (LNS) and guess was correct (ie data local)\000event=0x16088\000\000\000\000\000\000\000 */
{ 282521 }, /* pm_l2_loc_guess_wrong\000\000other\000L2 guess local (LNS) and guess was not correct (ie data not on chip)\000event=0x16888\000\000\000\000\000\000\000 */
{ 282639 }, /* pm_l2_rc_st_done\000\000other\000Read-claim machine did store to line that was in Tx or Sx (Tagged or Shared state)\000event=0x36086\000\000\000\000\000\000\000 */
{ 282766 }, /* pm_l2_rcld_disp\000\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread\000event=0x16084\000\000\000\000\000\000\000 */
{ 282885 }, /* pm_l2_rcld_disp_fail_addr\000\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread that failed due to an address collision conflicts with an L2 machines already working on this line (e.g. ld-hit-stq or Read-claim/Castout/Snoop machines)\000event=0x16884\000\000\000\000\000\000\000 */
{ 283168 }, /* pm_l2_rcld_disp_fail_other\000\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread that failed due to reasons other than an address collision conflicts with an L2 machines (e.g. Read-Claim/Snoop machine not available)\000event=0x26084\000\000\000\000\000\000\000 */
{ 283433 }, /* pm_l2_rcst_disp\000\000other\000All D-side store dispatch attempts for this thread\000event=0x36084\000\000\000\000\000\000\000 */
{ 283527 }, /* pm_l2_rcst_disp_fail_addr\000\000other\000All D-side store dispatch attempts for this thread that failed due to address collision with RC/CO/SN/SQ\000event=0x36884\000\000\000\000\000\000\000 */
{ 283685 }, /* pm_l2_rcst_disp_fail_other\000\000other\000All D-side store dispatch attempts for this thread that failed due to reason other than address collision\000event=0x46084\000\000\000\000\000\000\000 */
{ 283845 }, /* pm_l2_rty_ld\000\000other\000RC retries on PB for any load from core (excludes DCBFs)\000event=0x3688a\000\000\000\000\000\000\000 */
{ 283942 }, /* pm_l2_rty_st\000\000other\000RC retries on PB for any store from core (excludes DCBFs)\000event=0x3608a\000\000\000\000\000\000\000 */
{ 284121 }, /* pm_l2_sn_m_rd_done\000\000other\000Snoop dispatched for a read and was M (true M)\000event=0x46086\000\000\000\000\000\000\000 */
{ 284214 }, /* pm_l2_sn_m_wr_done\000\000other\000SNP dispatched for a write and was M (true M); for DMA cacheinj this will pulse if rty/push is required (won't pulse if cacheinj is accepted)\000event=0x16086\000\000\000\000\000\000\000 */
{ 284402 }, /* pm_l2_sn_sx_i_done\000\000other\000Snoop dispatched and went from Sx to Ix\000event=0x36886\000\000\000\000\000\000\000 */
{ 284488 }, /* pm_l2_st\000\000other\000All successful D-side store dispatches for this thread (L2 miss + L2 hits)\000event=0x16880\000\000\000\000\000\000\000 */
{ 284690 }, /* pm_l2_st_disp\000\000other\000All successful D-side store dispatches for this thread\000event=0x46082\000\000\000\000\000\000\000 */
{ 284786 }, /* pm_l2_st_hit\000\000other\000All successful D-side store dispatches for this thread that were L2 hits\000event=0x46882\000\000\000\000\000\000\000 */
{ 284899 }, /* pm_l2_st_miss\000\000other\000All successful D-Side Store dispatches that were an L2 miss for this thread\000event=0x26880\000\000\000\000\000\000\000 */
{ 285130 }, /* pm_l2_st_miss_128b\000\000other\000All successful D-side store dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 128B (i.e., M=0)\000event=0x16892\000\000\000\000\000\000\000 */
{ 285332 }, /* pm_l2_st_miss_64b\000\000other\000All successful D-side store dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 64B (i.e., M=1)\000event=0x26892\000\000\000\000\000\000\000 */
{ 285532 }, /* pm_l2_sys_guess_correct\000\000other\000L2 guess system (VGS or RNS) and guess was correct (ie data beyond-group)\000event=0x36088\000\000\000\000\000\000\000 */
{ 285657 }, /* pm_l2_sys_guess_wrong\000\000other\000L2 guess system (VGS or RNS) and guess was not correct (ie data ^beyond-group)\000event=0x36888\000\000\000\000\000\000\000 */
{ 285785 }, /* pm_l2_sys_pump\000\000other\000RC requests that were system pump attempts\000event=0x4688a\000\000\000\000\000\000\000 */
{ 285999 }, /* pm_l3_ci_hit\000\000other\000L3 Castins Hit (total count)\000event=0x260a2\000\000\000\000\000\000\000 */
{ 286068 }, /* pm_l3_ci_miss\000\000other\000L3 castins miss (total count)\000event=0x268a2\000\000\000\000\000\000\000 */
{ 286139 }, /* pm_l3_ci_usage\000\000other\000Rotating sample of 16 CI or CO actives\000event=0x168ac\000\000\000\000\000\000\000 */
{ 286302 }, /* pm_l3_cinj\000\000other\000L3 castin of cache inject\000event=0x368a4\000\000\000\000\000\000\000 */
{ 286615 }, /* pm_l3_co\000\000other\000L3 castout occurring (does not include casthrough or log writes (cinj/dmaw))\000event=0x360a8\000\000\000\000\000\000\000 */
{ 286452 }, /* pm_l3_co0_busy\000\000other\000Lifetime, sample of CO machine 0 valid\000event=0x368ac\000\000\000\000\000\000\000 */
{ 286810 }, /* pm_l3_co_l31\000\000other\000L3 CO to L3.1 OR of port 0 and 1 (lossy = may undercount if two cresps come in the same cyc)\000event=0x268a0\000\000\000\000\000\000\000 */
{ 286943 }, /* pm_l3_co_lco\000\000other\000Total L3 COs occurred on LCO L3.1 (good cresp, may end up in mem on a retry)\000event=0x360a4\000\000\000\000\000\000\000 */
{ 287144 }, /* pm_l3_co_mem\000\000other\000L3 CO to memory OR of port 0 and 1 (lossy = may undercount if two cresp come in the same cyc)\000event=0x260a0\000\000\000\000\000\000\000 */
{ 287369 }, /* pm_l3_co_mepf\000\000other\000L3 CO of line in Mep state (includes casthrough to memory).  The Mepf state indicates that a line was brought in to satisfy an L3 prefetch request\000event=0x3e05e\000\000\000\000\000\000\000 */
{ 287557 }, /* pm_l3_grp_guess_correct\000\000other\000Prefetch scope predictor selected GS or NNS and was correct\000event=0x168b2\000\000\000\000\000\000\000 */
{ 287668 }, /* pm_l3_grp_guess_wrong_high\000\000other\000Prefetch scope predictor selected GS or NNS, but was wrong because scope was VGS or RNS\000event=0x368b2\000\000\000\000\000\000\000 */
{ 287810 }, /* pm_l3_grp_guess_wrong_low\000\000other\000Prefetch scope predictor selected GS or NNS, but was wrong because scope was LNS\000event=0x360b2\000\000\000\000\000\000\000 */
{ 287944 }, /* pm_l3_hit\000\000other\000L3 Hits (L2 miss hitting L3, including data/instrn/xlate)\000event=0x160a4\000\000\000\000\000\000\000 */
{ 288039 }, /* pm_l3_l2_co_hit\000\000other\000L2 CO hits\000event=0x360a2\000\000\000\000\000\000\000 */
{ 288093 }, /* pm_l3_l2_co_miss\000\000other\000L2 CO miss\000event=0x368a2\000\000\000\000\000\000\000 */
{ 288148 }, /* pm_l3_lat_ci_hit\000\000other\000L3 Lateral Castins Hit\000event=0x460a2\000\000\000\000\000\000\000 */
{ 288215 }, /* pm_l3_lat_ci_miss\000\000other\000L3 Lateral Castins Miss\000event=0x468a2\000\000\000\000\000\000\000 */
{ 288284 }, /* pm_l3_ld_hit\000\000other\000L3 Hits for demand LDs\000event=0x260a4\000\000\000\000\000\000\000 */
{ 288347 }, /* pm_l3_ld_miss\000\000other\000L3 Misses for demand LDs\000event=0x268a4\000\000\000\000\000\000\000 */
{ 288473 }, /* pm_l3_ld_pref\000\000other\000L3 load prefetch, sourced from a hardware or software stream, was sent to the nest\000event=0xf0b0\000\000\000\000\000\000\000 */
{ 288596 }, /* pm_l3_loc_guess_correct\000\000other\000Prefetch scope predictor selected LNS and was correct\000event=0x160b2\000\000\000\000\000\000\000 */
{ 288701 }, /* pm_l3_loc_guess_wrong\000\000other\000Prefetch scope predictor selected LNS, but was wrong\000event=0x268b2\000\000\000\000\000\000\000 */
{ 288803 }, /* pm_l3_miss\000\000other\000L3 Misses (L2 miss also missing L3, including data/instrn/xlate)\000event=0x168a4\000\000\000\000\000\000\000 */
{ 288906 }, /* pm_l3_p0_co_l31\000\000other\000L3 CO to L3.1 (LCO) port 0 with or without data\000event=0x460aa\000\000\000\000\000\000\000 */
{ 288997 }, /* pm_l3_p0_co_mem\000\000other\000L3 CO to memory port 0 with or without data\000event=0x360aa\000\000\000\000\000\000\000 */
{ 289084 }, /* pm_l3_p0_co_rty\000\000other\000L3 CO received retry port 0 (memory only), every retry counted\000event=0x360ae\000\000\000\000\000\000\000 */
{ 289190 }, /* pm_l3_p0_grp_pump\000\000other\000L3 PF sent with grp scope port 0, counts even retried requests\000event=0x260b0\000\000\000\000\000\000\000 */
{ 289298 }, /* pm_l3_p0_lco_data\000\000other\000LCO sent with data port 0\000event=0x260aa\000\000\000\000\000\000\000 */
{ 289369 }, /* pm_l3_p0_lco_no_data\000\000other\000Dataless L3 LCO sent port 0\000event=0x160aa\000\000\000\000\000\000\000 */
{ 289445 }, /* pm_l3_p0_lco_rty\000\000other\000L3 initiated LCO received retry on port 0 (can try 4 times)\000event=0x160b4\000\000\000\000\000\000\000 */
{ 289549 }, /* pm_l3_p0_node_pump\000\000other\000L3 PF sent with nodal scope port 0, counts even retried requests\000event=0x160b0\000\000\000\000\000\000\000 */
{ 289660 }, /* pm_l3_p0_pf_rty\000\000other\000L3 PF received retry port 0, every retry counted\000event=0x160ae\000\000\000\000\000\000\000 */
{ 289752 }, /* pm_l3_p0_sys_pump\000\000other\000L3 PF sent with sys scope port 0, counts even retried requests\000event=0x360b0\000\000\000\000\000\000\000 */
{ 289860 }, /* pm_l3_p1_co_l31\000\000other\000L3 CO to L3.1 (LCO) port 1 with or without data\000event=0x468aa\000\000\000\000\000\000\000 */
{ 289951 }, /* pm_l3_p1_co_mem\000\000other\000L3 CO to memory port 1 with or without data\000event=0x368aa\000\000\000\000\000\000\000 */
{ 290038 }, /* pm_l3_p1_co_rty\000\000other\000L3 CO received retry port 1 (memory only), every retry counted\000event=0x368ae\000\000\000\000\000\000\000 */
{ 290144 }, /* pm_l3_p1_grp_pump\000\000other\000L3 PF sent with grp scope port 1, counts even retried requests\000event=0x268b0\000\000\000\000\000\000\000 */
{ 290252 }, /* pm_l3_p1_lco_data\000\000other\000LCO sent with data port 1\000event=0x268aa\000\000\000\000\000\000\000 */
{ 290323 }, /* pm_l3_p1_lco_no_data\000\000other\000Dataless L3 LCO sent port 1\000event=0x168aa\000\000\000\000\000\000\000 */
{ 290399 }, /* pm_l3_p1_lco_rty\000\000other\000L3 initiated LCO received retry on port 1 (can try 4 times)\000event=0x168b4\000\000\000\000\000\000\000 */
{ 290503 }, /* pm_l3_p1_node_pump\000\000other\000L3 PF sent with nodal scope port 1, counts even retried requests\000event=0x168b0\000\000\000\000\000\000\000 */
{ 290614 }, /* pm_l3_p1_pf_rty\000\000other\000L3 PF received retry port 1, every retry counted\000event=0x168ae\000\000\000\000\000\000\000 */
{ 290706 }, /* pm_l3_p1_sys_pump\000\000other\000L3 PF sent with sys scope port 1, counts even retried requests\000event=0x368b0\000\000\000\000\000\000\000 */
{ 290814 }, /* pm_l3_p2_co_rty\000\000other\000L3 CO received retry port 2 (memory only), every retry counted\000event=0x460ae\000\000\000\000\000\000\000 */
{ 290920 }, /* pm_l3_p2_lco_rty\000\000other\000L3 initiated LCO received retry on port 2 (can try 4 times)\000event=0x260b4\000\000\000\000\000\000\000 */
{ 291024 }, /* pm_l3_p2_pf_rty\000\000other\000L3 PF received retry port 2, every retry counted\000event=0x260ae\000\000\000\000\000\000\000 */
{ 291116 }, /* pm_l3_p3_co_rty\000\000other\000L3 CO received retry port 3 (memory only), every retry counted\000event=0x468ae\000\000\000\000\000\000\000 */
{ 291222 }, /* pm_l3_p3_lco_rty\000\000other\000L3 initiated LCO received retry on port 3 (can try 4 times)\000event=0x268b4\000\000\000\000\000\000\000 */
{ 291326 }, /* pm_l3_p3_pf_rty\000\000other\000L3 PF received retry port 3, every retry counted\000event=0x268ae\000\000\000\000\000\000\000 */
{ 291504 }, /* pm_l3_pf0_busy\000\000other\000Lifetime, sample of PF machine 0 valid\000event=0x360b4\000\000\000\000\000\000\000 */
{ 291667 }, /* pm_l3_pf_hit_l3\000\000other\000L3 PF hit in L3 (abandoned)\000event=0x260a8\000\000\000\000\000\000\000 */
{ 291738 }, /* pm_l3_pf_miss_l3\000\000other\000L3 PF missed in L3\000event=0x160a0\000\000\000\000\000\000\000 */
{ 291870 }, /* pm_l3_pf_off_chip_cache\000\000other\000L3 PF from Off chip cache\000event=0x368a0\000\000\000\000\000\000\000 */
{ 292030 }, /* pm_l3_pf_off_chip_mem\000\000other\000L3 PF from Off chip memory\000event=0x468a0\000\000\000\000\000\000\000 */
{ 292188 }, /* pm_l3_pf_on_chip_cache\000\000other\000L3 PF from On chip cache\000event=0x360a0\000\000\000\000\000\000\000 */
{ 292344 }, /* pm_l3_pf_on_chip_mem\000\000other\000L3 PF from On chip memory\000event=0x460a0\000\000\000\000\000\000\000 */
{ 292498 }, /* pm_l3_pf_usage\000\000other\000Rotating sample of 32 PF actives\000event=0x260ac\000\000\000\000\000\000\000 */
{ 292812 }, /* pm_l3_rd0_busy\000\000other\000Lifetime, sample of RD machine 0 valid\000event=0x368b4\000\000\000\000\000\000\000 */
{ 292975 }, /* pm_l3_rd_usage\000\000other\000Rotating sample of 16 RD actives\000event=0x268ac\000\000\000\000\000\000\000 */
{ 293217 }, /* pm_l3_sn0_busy\000\000other\000Lifetime, sample of snooper machine 0 valid\000event=0x360ac\000\000\000\000\000\000\000 */
{ 293390 }, /* pm_l3_sn_usage\000\000other\000Rotating sample of 16 snoop valids\000event=0x160ac\000\000\000\000\000\000\000 */
{ 293669 }, /* pm_l3_sw_pref\000\000other\000L3 load prefetch, sourced from a software prefetch stream, was sent to the nest\000event=0xf8b0\000\000\000\000\000\000\000 */
{ 293789 }, /* pm_l3_sys_guess_correct\000\000other\000Prefetch scope predictor selected VGS or RNS and was correct\000event=0x260b2\000\000\000\000\000\000\000 */
{ 293901 }, /* pm_l3_sys_guess_wrong\000\000other\000Prefetch scope predictor selected VGS or RNS, but was wrong\000event=0x460b2\000\000\000\000\000\000\000 */
{ 294010 }, /* pm_l3_trans_pf\000\000other\000L3 Transient prefetch received from L2\000event=0x468a4\000\000\000\000\000\000\000 */
{ 294186 }, /* pm_l3_wi0_busy\000\000other\000Rotating sample of 8 WI valid (duplicate)\000event=0x160b6\000\000\000\000\000\000\000 */
{ 294270 }, /* pm_l3_wi_usage\000\000other\000Lifetime, sample of Write Inject machine 0 valid\000event=0x168a8\000\000\000\000\000\000\000 */
{ 295815 }, /* pm_ld_miss_l1_fin\000\000other\000Number of load instructions that finished with an L1 miss. Note that even if a load spans multiple slices this event will increment only once per load op\000event=0x2c04e\000\000\000\000\000\000\000 */
{ 296287 }, /* pm_ld_ref_l1\000\000other\000All L1 D cache load references counted at finish, gated by reject\000event=0x100fc\000\000\000\000\000\000\000 */
{ 297388 }, /* pm_link_stack_correct\000\000other\000Link stack predicts right address\000event=0x58a0\000\000\000\000\000\000\000 */
{ 297615 }, /* pm_link_stack_invalid_ptr\000\000other\000It is most often caused by certain types of flush where the pointer is not available. Can result in the data in the link stack becoming unusable\000event=0x5898\000\000\000\000\000\000\000 */
{ 297812 }, /* pm_link_stack_wrong_add_pred\000\000other\000Link stack predicts wrong address, because of link stack design limitation or software violating the coding conventions\000event=0x5098\000\000\000\000\000\000\000 */
{ 298229 }, /* pm_lmq_merge\000\000other\000A demand miss collides with a prefetch for the same line\000event=0x1002e\000\000\000\000\000\000\000 */
{ 298634 }, /* pm_ls0_dc_collisions\000\000other\000Read-write data cache collisions\000event=0xd090\000\000\000\000\000\000\000 */
{ 298823 }, /* pm_ls0_erat_miss_pref\000\000other\000LS0 Erat miss due to prefetch\000event=0xe084\000\000\000\000\000\000\000 */
{ 299162 }, /* pm_ls0_launch_held_pref\000\000other\000Number of times a load or store instruction was unable to launch/relaunch because a high priority prefetch used that relaunch cycle\000event=0xc09c\000\000\000\000\000\000\000 */
{ 299344 }, /* pm_ls0_ld_vector_fin\000\000other\000LS0 finished load vector op\000event=0xc080\000\000\000\000\000\000\000 */
{ 299419 }, /* pm_ls0_pte_tablewalk_cyc\000\000other\000Cycles when a tablewalk is pending on this thread on table 0\000event=0xe0bc\000\000\000\000\000\000\000 */
{ 299531 }, /* pm_ls0_tm_disallow\000\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe0b4\000\000\000\000\000\000\000 */
{ 299667 }, /* pm_ls0_unaligned_ld\000\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc094\000\000\000\000\000\000\000 */
{ 299971 }, /* pm_ls0_unaligned_st\000\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf0b8\000\000\000\000\000\000\000 */
{ 300278 }, /* pm_ls1_dc_collisions\000\000other\000Read-write data cache collisions\000event=0xd890\000\000\000\000\000\000\000 */
{ 300467 }, /* pm_ls1_erat_miss_pref\000\000other\000LS1 Erat miss due to prefetch\000event=0xe884\000\000\000\000\000\000\000 */
{ 300806 }, /* pm_ls1_launch_held_pref\000\000other\000Number of times a load or store instruction was unable to launch/relaunch because a high priority prefetch used that relaunch cycle\000event=0xc89c\000\000\000\000\000\000\000 */
{ 300988 }, /* pm_ls1_ld_vector_fin\000\000other\000LS1 finished load vector op\000event=0xc880\000\000\000\000\000\000\000 */
{ 301063 }, /* pm_ls1_pte_tablewalk_cyc\000\000other\000Cycles when a tablewalk is pending on this thread on table 1\000event=0xe8bc\000\000\000\000\000\000\000 */
{ 301175 }, /* pm_ls1_tm_disallow\000\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe8b4\000\000\000\000\000\000\000 */
{ 301311 }, /* pm_ls1_unaligned_ld\000\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc894\000\000\000\000\000\000\000 */
{ 301615 }, /* pm_ls1_unaligned_st\000\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf8b8\000\000\000\000\000\000\000 */
{ 301922 }, /* pm_ls2_dc_collisions\000\000other\000Read-write data cache collisions\000event=0xd094\000\000\000\000\000\000\000 */
{ 302002 }, /* pm_ls2_erat_miss_pref\000\000other\000LS0 Erat miss due to prefetch\000event=0xe088\000\000\000\000\000\000\000 */
{ 302080 }, /* pm_ls2_ld_vector_fin\000\000other\000LS2 finished load vector op\000event=0xc084\000\000\000\000\000\000\000 */
{ 302155 }, /* pm_ls2_tm_disallow\000\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe0b8\000\000\000\000\000\000\000 */
{ 302291 }, /* pm_ls2_unaligned_ld\000\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc098\000\000\000\000\000\000\000 */
{ 302595 }, /* pm_ls2_unaligned_st\000\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf0bc\000\000\000\000\000\000\000 */
{ 302902 }, /* pm_ls3_dc_collisions\000\000other\000Read-write data cache collisions\000event=0xd894\000\000\000\000\000\000\000 */
{ 302982 }, /* pm_ls3_erat_miss_pref\000\000other\000LS1 Erat miss due to prefetch\000event=0xe888\000\000\000\000\000\000\000 */
{ 303060 }, /* pm_ls3_ld_vector_fin\000\000other\000LS3 finished load vector op\000event=0xc884\000\000\000\000\000\000\000 */
{ 303135 }, /* pm_ls3_tm_disallow\000\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe8b8\000\000\000\000\000\000\000 */
{ 303271 }, /* pm_ls3_unaligned_ld\000\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc898\000\000\000\000\000\000\000 */
{ 303575 }, /* pm_ls3_unaligned_st\000\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf8bc\000\000\000\000\000\000\000 */
{ 303882 }, /* pm_lsu0_1_lrqf_full_cyc\000\000other\000Counts the number of cycles the LRQF is full.  LRQF is the queue that holds loads between finish and completion.  If it fills up, instructions stay in LRQ until completion, potentially backing up the LRQ\000event=0xd0bc\000\000\000\000\000\000\000 */
{ 304136 }, /* pm_lsu0_erat_hit\000\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe08c\000\000\000\000\000\000\000 */
{ 304225 }, /* pm_lsu0_false_lhs\000\000other\000False LHS match detected\000event=0xc0a0\000\000\000\000\000\000\000 */
{ 304814 }, /* pm_lsu0_l1_cam_cancel\000\000other\000ls0 l1 tm cam cancel\000event=0xf090\000\000\000\000\000\000\000 */
{ 304954 }, /* pm_lsu0_ldmx_fin\000\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd088\000\000\000\000\000\000\000 */
{ 305539 }, /* pm_lsu0_lmq_s0_valid\000\000other\000Slot 0 of LMQ valid\000event=0xd8b8\000\000\000\000\000\000\000 */
{ 305606 }, /* pm_lsu0_lrq_s0_valid_cyc\000\000other\000Slot 0 of LRQ valid\000event=0xd8b4\000\000\000\000\000\000\000 */
{ 305961 }, /* pm_lsu0_srq_s0_valid_cyc\000\000other\000Slot 0 of SRQ valid\000event=0xd0b4\000\000\000\000\000\000\000 */
{ 306165 }, /* pm_lsu0_store_reject\000\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf088\000\000\000\000\000\000\000 */
{ 306442 }, /* pm_lsu0_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe094\000\000\000\000\000\000\000 */
{ 306585 }, /* pm_lsu0_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe09c\000\000\000\000\000\000\000 */
{ 306952 }, /* pm_lsu1_erat_hit\000\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe88c\000\000\000\000\000\000\000 */
{ 307041 }, /* pm_lsu1_false_lhs\000\000other\000False LHS match detected\000event=0xc8a0\000\000\000\000\000\000\000 */
{ 307632 }, /* pm_lsu1_l1_cam_cancel\000\000other\000ls1 l1 tm cam cancel\000event=0xf890\000\000\000\000\000\000\000 */
{ 307772 }, /* pm_lsu1_ldmx_fin\000\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd888\000\000\000\000\000\000\000 */
{ 308772 }, /* pm_lsu1_store_reject\000\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf888\000\000\000\000\000\000\000 */
{ 309130 }, /* pm_lsu1_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe894\000\000\000\000\000\000\000 */
{ 309270 }, /* pm_lsu1_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe89c\000\000\000\000\000\000\000 */
{ 309559 }, /* pm_lsu2_3_lrqf_full_cyc\000\000other\000Counts the number of cycles the LRQF is full.  LRQF is the queue that holds loads between finish and completion.  If it fills up, instructions stay in LRQ until completion, potentially backing up the LRQ\000event=0xd8bc\000\000\000\000\000\000\000 */
{ 309813 }, /* pm_lsu2_erat_hit\000\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe090\000\000\000\000\000\000\000 */
{ 309902 }, /* pm_lsu2_false_lhs\000\000other\000False LHS match detected\000event=0xc0a4\000\000\000\000\000\000\000 */
{ 310309 }, /* pm_lsu2_l1_cam_cancel\000\000other\000ls2 l1 tm cam cancel\000event=0xf094\000\000\000\000\000\000\000 */
{ 310522 }, /* pm_lsu2_ldmx_fin\000\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd08c\000\000\000\000\000\000\000 */
{ 311431 }, /* pm_lsu2_store_reject\000\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf08c\000\000\000\000\000\000\000 */
{ 311626 }, /* pm_lsu2_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe098\000\000\000\000\000\000\000 */
{ 311769 }, /* pm_lsu2_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe0a0\000\000\000\000\000\000\000 */
{ 312136 }, /* pm_lsu3_erat_hit\000\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe890\000\000\000\000\000\000\000 */
{ 312225 }, /* pm_lsu3_false_lhs\000\000other\000False LHS match detected\000event=0xc8a4\000\000\000\000\000\000\000 */
{ 312636 }, /* pm_lsu3_l1_cam_cancel\000\000other\000ls3 l1 tm cam cancel\000event=0xf894\000\000\000\000\000\000\000 */
{ 312850 }, /* pm_lsu3_ldmx_fin\000\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd88c\000\000\000\000\000\000\000 */
{ 313757 }, /* pm_lsu3_store_reject\000\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf88c\000\000\000\000\000\000\000 */
{ 314033 }, /* pm_lsu3_tm_l1_hit\000\000other\000Load tm hit in L1\000event=0xe898\000\000\000\000\000\000\000 */
{ 314173 }, /* pm_lsu3_tm_l1_miss\000\000other\000Load tm L1 miss\000event=0xe8a0\000\000\000\000\000\000\000 */
{ 314650 }, /* pm_lsu_dtlb_miss_16g_1g\000\000other\000Data TLB Miss page size 16G (HPT) or 1G (Radix)\000event=0xc88c\000\000\000\000\000\000\000 */
{ 314748 }, /* pm_lsu_dtlb_miss_16m_2m\000\000other\000Data TLB Miss page size 16M (HPT) or 2M (Radix)\000event=0xc08c\000\000\000\000\000\000\000 */
{ 314846 }, /* pm_lsu_dtlb_miss_4k\000\000other\000Data TLB Miss page size 4K\000event=0xc088\000\000\000\000\000\000\000 */
{ 314919 }, /* pm_lsu_dtlb_miss_64k\000\000other\000Data TLB Miss page size 64K\000event=0xc888\000\000\000\000\000\000\000 */
{ 315367 }, /* pm_lsu_flush_atomic\000\000other\000Quad-word loads (lq) are considered atomic because they always span at least 2 slices.  If a snoop or store from another thread changes the data the load is accessing between the 2 or 3 pieces of the lq instruction, the lq will be flushed\000event=0xc8a8\000\000\000\000\000\000\000 */
{ 315652 }, /* pm_lsu_flush_ci\000\000other\000Load was not issued to LSU as a cache inhibited (non-cacheable) load but it was later determined to be cache inhibited\000event=0xc0a8\000\000\000\000\000\000\000 */
{ 315813 }, /* pm_lsu_flush_emsh\000\000other\000An ERAT miss was detected after a set-p hit. Erat tracker indicates fail due to tlbmiss and the instruction gets flushed because the instruction was working on the wrong address\000event=0xc0ac\000\000\000\000\000\000\000 */
{ 316035 }, /* pm_lsu_flush_larx_stcx\000\000other\000A larx is flushed because an older larx has an LMQ reservation for the same thread.  A stcx is flushed because an older stcx is in the LMQ.  The flush happens when the older larx/stcx relaunches\000event=0xc8b8\000\000\000\000\000\000\000 */
{ 316279 }, /* pm_lsu_flush_lhl_shl\000\000other\000The instruction was flushed because of a sequential load/store consistency.  If a load or store hits on an older load that has either been snooped (for loads) or has stale data (for stores)\000event=0xc8b4\000\000\000\000\000\000\000 */
{ 316516 }, /* pm_lsu_flush_lhs\000\000other\000Effective Address alias flush : no EA match but Real Address match.  If the data has not yet been returned for this load, the instruction will just be rejected, but if it has returned data, it will be flushed\000event=0xc8b0\000\000\000\000\000\000\000 */
{ 316768 }, /* pm_lsu_flush_next\000\000other\000LSU flush next reported at flush time.  Sometimes these also come with an exception\000event=0x20b0\000\000\000\000\000\000\000 */
{ 316896 }, /* pm_lsu_flush_other\000\000other\000Other LSU flushes including: Sync (sync ack from L2 caused search of LRQ for oldest snooped load, This will either signal a Precise Flush of the oldest snooped loa or a Flush Next PPC); Data Valid Flush Next (several cases of this, one example is store and reload are lined up such that a store-hit-reload scenario exists and the CDF has already launched and has gotten bad/stale data); Bad Data Valid Flush Next (might be a few cases of this, one example is a larxa (D$ hit) return data and dval but can't allocate to LMQ (LMQ full or other reason). Already gave dval but can't watch it for snoop_hit_larx. Need to take the “bad dval” back and flush all younger ops)\000event=0xc0bc\000\000\000\000\000\000\000 */
{ 317613 }, /* pm_lsu_flush_relaunch_miss\000\000other\000If a load that has already returned data and has to relaunch for any reason then gets a miss (erat, setp, data cache), it will often be flushed at relaunch time because the data might be inconsistent\000event=0xc8ac\000\000\000\000\000\000\000 */
{ 317866 }, /* pm_lsu_flush_sao\000\000other\000A load-hit-load condition with Strong Address Ordering will have address compare disabled and flush\000event=0xc0b8\000\000\000\000\000\000\000 */
{ 318009 }, /* pm_lsu_flush_ue\000\000other\000Correctable ECC error on reload data, reported at critical data forward time\000event=0xc0b0\000\000\000\000\000\000\000 */
{ 318211 }, /* pm_lsu_flush_wrk_arnd\000\000other\000LSU workaround flush.  These flushes are setup with programmable scan only latches to perform various actions when the flush macro receives a trigger from the dbg macros. These actions include things like flushing the next op encountered for a particular thread or flushing the next op that is NTC op that is encountered on a particular slice. The kind of flush that the workaround is setup to perform is highly variable\000event=0xc0b4\000\000\000\000\000\000\000 */
{ 319518 }, /* pm_lsu_lmq_full_cyc\000\000other\000Counts the number of cycles the LMQ is full\000event=0xd0b8\000\000\000\000\000\000\000 */
{ 321506 }, /* pm_lsu_ncst\000\000other\000Asserts when a i=1 store op is sent to the nest. No record of issue pipe (LS0/LS1) is maintained so this is for both pipes. Probably don't need separate LS0 and LS1\000event=0xc890\000\000\000\000\000\000\000 */
{ 324469 }, /* pm_lsu_stcx\000\000other\000STCX sent to nest, i.e. total\000event=0xc090\000\000\000\000\000\000\000 */
{ 324537 }, /* pm_lsu_stcx_fail\000\000other\000The LSU detects the condition that a stcx instruction failed. No requirement to wait for a response from the nest\000event=0xf080\000\000\000\000\000\000\000 */
{ 324923 }, /* pm_lwsync\000\000other\000An lwsync instruction was decoded and transferred\000event=0xd8ac\000\000\000\000\000\000\000 */
{ 325211 }, /* pm_math_flop_cmpl\000\000other\000Math flop instruction completed\000event=0x4505c\000\000\000\000\000\000\000 */
{ 326653 }, /* pm_mem_rwitm\000\000other\000Memory Read With Intent to Modify for this thread\000event=0x3c05e\000\000\000\000\000\000\000 */
{ 326955 }, /* pm_mrk_back_br_cmpl\000\000other\000Marked branch instruction completed with a target address less than current instruction address\000event=0x3515e\000\000\000\000\000\000\000 */
{ 327098 }, /* pm_mrk_br_2path\000\000other\000marked branches which are not strongly biased\000event=0x10138\000\000\000\000\000\000\000 */
{ 328182 }, /* pm_mrk_data_from_dl2l3_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x3d14e\000\000\000\000\000\000\000 */
{ 328616 }, /* pm_mrk_data_from_dl2l3_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x4d12e\000\000\000\000\000\000\000 */
{ 329048 }, /* pm_mrk_data_from_dl2l3_shr\000\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x1d150\000\000\000\000\000\000\000 */
{ 329650 }, /* pm_mrk_data_from_dl4\000\000other\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x1d152\000\000\000\000\000\000\000 */
{ 329986 }, /* pm_mrk_data_from_dl4_cyc\000\000other\000Duration in cycles to reload from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x2c12c\000\000\000\000\000\000\000 */
{ 330324 }, /* pm_mrk_data_from_dmem\000\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x3d14c\000\000\000\000\000\000\000 */
{ 330664 }, /* pm_mrk_data_from_dmem_cyc\000\000other\000Duration in cycles to reload from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x4e11e\000\000\000\000\000\000\000 */
{ 332165 }, /* pm_mrk_data_from_l2\000\000other\000The processor's data cache was reloaded from local core's L2 due to a marked load\000event=0x2c126\000\000\000\000\000\000\000 */
{ 330830 }, /* pm_mrk_data_from_l21_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x4d146\000\000\000\000\000\000\000 */
{ 332417 }, /* pm_mrk_data_from_l2_cyc\000\000other\000Duration in cycles to reload from local core's L2 due to a marked load\000event=0x14156\000\000\000\000\000\000\000 */
{ 332720 }, /* pm_mrk_data_from_l2_disp_conflict_ldhitst\000\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a marked load\000event=0x2d148\000\000\000\000\000\000\000 */
{ 333770 }, /* pm_mrk_data_from_l2_disp_conflict_other_cyc\000\000other\000Duration in cycles to reload from local core's L2 with dispatch conflict due to a marked load\000event=0x3d140\000\000\000\000\000\000\000 */
{ 334473 }, /* pm_mrk_data_from_l2_mepf_cyc\000\000other\000Duration in cycles to reload from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x3d144\000\000\000\000\000\000\000 */
{ 334805 }, /* pm_mrk_data_from_l2_no_conflict\000\000other\000The processor's data cache was reloaded from local core's L2 without conflict due to a marked load\000event=0x2c120\000\000\000\000\000\000\000 */
{ 335115 }, /* pm_mrk_data_from_l2_no_conflict_cyc\000\000other\000Duration in cycles to reload from local core's L2 without conflict due to a marked load\000event=0x14158\000\000\000\000\000\000\000 */
{ 335344 }, /* pm_mrk_data_from_l2miss\000\000other\000The processor's data cache was reloaded from a location other than the local core's L2 due to a marked load\000event=0x401e8\000\000\000\000\000\000\000 */
{ 335838 }, /* pm_mrk_data_from_l2miss_cyc\000\000other\000Duration in cycles to reload from a location other than the local core's L2 due to a marked load\000event=0x35152\000\000\000\000\000\000\000 */
{ 335990 }, /* pm_mrk_data_from_l31_eco_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x4d144\000\000\000\000\000\000\000 */
{ 336351 }, /* pm_mrk_data_from_l31_eco_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x35158\000\000\000\000\000\000\000 */
{ 337251 }, /* pm_mrk_data_from_l31_mod\000\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x2d144\000\000\000\000\000\000\000 */
{ 337427 }, /* pm_mrk_data_from_l31_mod_cyc\000\000other\000Duration in cycles to reload with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x1d140\000\000\000\000\000\000\000 */
{ 338116 }, /* pm_mrk_data_from_l31_shr_cyc\000\000other\000Duration in cycles to reload with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x35156\000\000\000\000\000\000\000 */
{ 338703 }, /* pm_mrk_data_from_l3_cyc\000\000other\000Duration in cycles to reload from local core's L3 due to a marked load\000event=0x35154\000\000\000\000\000\000\000 */
{ 338992 }, /* pm_mrk_data_from_l3_disp_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a marked load\000event=0x1d144\000\000\000\000\000\000\000 */
{ 339318 }, /* pm_mrk_data_from_l3_disp_conflict_cyc\000\000other\000Duration in cycles to reload from local core's L3 with dispatch conflict due to a marked load\000event=0x2c122\000\000\000\000\000\000\000 */
{ 339658 }, /* pm_mrk_data_from_l3_mepf\000\000other\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x2d142\000\000\000\000\000\000\000 */
{ 340012 }, /* pm_mrk_data_from_l3_mepf_cyc\000\000other\000Duration in cycles to reload from local core's L3 without dispatch conflicts hit on Mepf state due to a marked load\000event=0x1415c\000\000\000\000\000\000\000 */
{ 340343 }, /* pm_mrk_data_from_l3_no_conflict\000\000other\000The processor's data cache was reloaded from local core's L3 without conflict due to a marked load\000event=0x3d146\000\000\000\000\000\000\000 */
{ 340653 }, /* pm_mrk_data_from_l3_no_conflict_cyc\000\000other\000Duration in cycles to reload from local core's L3 without conflict due to a marked load\000event=0x4c124\000\000\000\000\000\000\000 */
{ 340964 }, /* pm_mrk_data_from_l3miss\000\000other\000The processor's data cache was reloaded from a location other than the local core's L3 due to a marked load\000event=0x201e4\000\000\000\000\000\000\000 */
{ 342917 }, /* pm_mrk_data_from_memory\000\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x201e0\000\000\000\000\000\000\000 */
{ 343434 }, /* pm_mrk_data_from_memory_cyc\000\000other\000Duration in cycles to reload from a memory location including L4 from local remote or distant due to a marked load\000event=0x1d146\000\000\000\000\000\000\000 */
{ 343822 }, /* pm_mrk_data_from_off_chip_cache\000\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x2d120\000\000\000\000\000\000\000 */
{ 344250 }, /* pm_mrk_data_from_off_chip_cache_cyc\000\000other\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x1d14e\000\000\000\000\000\000\000 */
{ 347774 }, /* pm_mrk_data_from_rmem\000\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x1d148\000\000\000\000\000\000\000 */
{ 348114 }, /* pm_mrk_data_from_rmem_cyc\000\000other\000Duration in cycles to reload from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x2c12a\000\000\000\000\000\000\000 */
{ 350124 }, /* pm_mrk_dfu_fin\000\000other\000Decimal Unit marked Instruction Finish\000event=0x20132\000\000\000\000\000\000\000 */
{ 352949 }, /* pm_mrk_dpteg_from_l21_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f146\000\000\000\000\000\000\000 */
{ 357097 }, /* pm_mrk_dpteg_from_l31_shr\000\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f146\000\000\000\000\000\000\000 */
{ 363570 }, /* pm_mrk_dpteg_from_rl4\000\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f14a\000\000\000\000\000\000\000 */
{ 365098 }, /* pm_mrk_fab_rsp_bkill\000\000other\000Marked store had to do a bkill\000event=0x40154\000\000\000\000\000\000\000 */
{ 365260 }, /* pm_mrk_fab_rsp_bkill_cyc\000\000other\000cycles L2 RC took for a bkill\000event=0x1f152\000\000\000\000\000\000\000 */
{ 367250 }, /* pm_mrk_fxu_fin\000\000other\000fxu marked instr finish\000event=0x20134\000\000\000\000\000\000\000 */
{ 367687 }, /* pm_mrk_ic_miss\000\000other\000Marked instruction experienced I cache miss\000event=0x4013a\000\000\000\000\000\000\000 */
{ 369289 }, /* pm_mrk_inst_from_l3miss\000\000other\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x401e6\000\000\000\000\000\000\000 */
{ 370436 }, /* pm_mrk_l1_icache_miss\000\000other\000sampled Instruction suffered an icache Miss\000event=0x101e4\000\000\000\000\000\000\000 */
{ 370694 }, /* pm_mrk_l1_reload_valid\000\000other\000Marked demand reload\000event=0x101ea\000\000\000\000\000\000\000 */
{ 372610 }, /* pm_mrk_ld_miss_l1_cyc\000\000other\000Marked ld latency\000event=0x1d156\000\000\000\000\000\000\000 */
{ 372677 }, /* pm_mrk_lsu_derat_miss\000\000other\000Marked derat reload (miss) for any page size\000event=0x30162\000\000\000\000\000\000\000 */
{ 375560 }, /* pm_mrk_st_cmpl_int\000\000other\000marked store finished with intervention\000event=0x30134\000\000\000\000\000\000\000 */
{ 375916 }, /* pm_mrk_st_drain_to_l2disp_cyc\000\000other\000cycles to drain st from core to L2\000event=0x3f150\000\000\000\000\000\000\000 */
{ 378213 }, /* pm_mrk_tend_fail\000\000other\000Nested or not nested tend failed for a marked tend instruction\000event=0x28a4\000\000\000\000\000\000\000 */
{ 378939 }, /* pm_mrk_vsu_fin\000\000other\000VSU marked instr finish\000event=0x30132\000\000\000\000\000\000\000 */
{ 381297 }, /* pm_mult_mrk\000\000other\000mult marked instr\000event=0x3d15e\000\000\000\000\000\000\000 */
{ 381628 }, /* pm_non_data_store\000\000other\000All ops that drain from s2q to L2 and contain no data\000event=0xf8a0\000\000\000\000\000\000\000 */
{ 382043 }, /* pm_non_tm_rst_sc\000\000other\000Non-TM snoop hits line in L3 that is TM_SC state and causes it to be invalidated\000event=0x260a6\000\000\000\000\000\000\000 */
{ 382168 }, /* pm_ntc_all_fin\000\000other\000Cycles after instruction finished to instruction completed\000event=0x2001a\000\000\000\000\000\000\000 */
{ 383837 }, /* pm_partial_st_fin\000\000other\000Any store finished by an LSU slice\000event=0x34054\000\000\000\000\000\000\000 */
{ 386092 }, /* pm_pmc3_saved\000\000other\000PMC3 Rewind Value saved\000event=0x4d012\000\000\000\000\000\000\000 */
{ 388371 }, /* pm_probe_nop_disp\000\000other\000ProbeNops dispatched\000event=0x40014\000\000\000\000\000\000\000 */
{ 388579 }, /* pm_pte_prefetch\000\000other\000PTE prefetches\000event=0xf084\000\000\000\000\000\000\000 */
{ 388636 }, /* pm_ptesync\000\000other\000A ptesync instruction was counted when the instruction is decoded and transmitted\000event=0xd8b0\000\000\000\000\000\000\000 */
{ 389913 }, /* pm_radix_pwc_l1_pde_from_l2\000\000other\000A Page Directory Entry was reloaded to a level 1 page walk cache from the core's L2 data cache\000event=0x2d026\000\000\000\000\000\000\000 */
{ 391241 }, /* pm_radix_pwc_l2_pte_from_l3miss\000\000other\000A Page Table Entry was reloaded to a level 2 page walk cache from beyond the core's L3 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation. The source could be local/remote/distant memory or another core's cache\000event=0x4f05c\000\000\000\000\000\000\000 */
{ 393043 }, /* pm_radix_pwc_l4_pte_from_l3miss\000\000other\000A Page Table Entry was reloaded to a level 4 page walk cache from beyond the core's L3 data cache. This is the deepest level of PWC possible for a translation. The source could be local/remote/distant memory or another core's cache\000event=0x3f054\000\000\000\000\000\000\000 */
{ 393334 }, /* pm_radix_pwc_miss\000\000other\000A radix translation attempt missed in the TLB and all levels of page walk cache\000event=0x4f054\000\000\000\000\000\000\000 */
{ 393584 }, /* pm_rc0_busy\000\000other\000RC mach 0 Busy. Used by PMU to sample ave RC lifetime (mach0 used as sample point)\000event=0x1608c\000\000\000\000\000\000\000 */
{ 394556 }, /* pm_rc_usage\000\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each RC machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x1688c\000\000\000\000\000\000\000 */
{ 394996 }, /* pm_rd_clearing_sc\000\000other\000Core TM load hits line in L3 in TM_SC state and causes it to be invalidated\000event=0x468a6\000\000\000\000\000\000\000 */
{ 395117 }, /* pm_rd_forming_sc\000\000other\000Doesn't occur\000event=0x460a6\000\000\000\000\000\000\000 */
{ 395175 }, /* pm_rd_hit_pf\000\000other\000RD machine hit L3 PF machine\000event=0x268a8\000\000\000\000\000\000\000 */
{ 396007 }, /* pm_run_cyc_smt4_mode\000\000other\000Cycles in which this thread's run latch is set and the core is in SMT4 mode\000event=0x2006c\000\000\000\000\000\000\000 */
{ 396813 }, /* pm_run_inst_cmpl\000\000other\000Run_Instructions\000event=0x400fa\000\000\000\000\000\000\000 */
{ 397593 }, /* pm_s2q_full\000\000other\000Cycles during which the S2Q is full\000event=0xe080\000\000\000\000\000\000\000 */
{ 397667 }, /* pm_scalar_flop_cmpl\000\000other\000Scalar flop operation completed\000event=0x45056\000\000\000\000\000\000\000 */
{ 398078 }, /* pm_shl_created\000\000other\000Store-Hit-Load Table Entry Created\000event=0x508c\000\000\000\000\000\000\000 */
{ 398247 }, /* pm_shl_st_dep_created\000\000other\000Store-Hit-Load Table Read Hit with entry Enabled\000event=0x588c\000\000\000\000\000\000\000 */
{ 398753 }, /* pm_sn0_busy\000\000other\000SN mach 0 Busy. Used by PMU to sample ave SN lifetime (mach0 used as sample point)\000event=0x16090\000\000\000\000\000\000\000 */
{ 398875 }, /* pm_sn_hit\000\000other\000Any port snooper hit L3.  Up to 4 can happen in a cycle but we only count 1\000event=0x460a8\000\000\000\000\000\000\000 */
{ 398988 }, /* pm_sn_invl\000\000other\000Any port snooper detects a store to a line in the Sx state and invalidates the line.  Up to 4 can happen in a cycle but we only count 1\000event=0x368a8\000\000\000\000\000\000\000 */
{ 399162 }, /* pm_sn_miss\000\000other\000Any port snooper L3 miss or collision.  Up to 4 can happen in a cycle but we only count 1\000event=0x468a8\000\000\000\000\000\000\000 */
{ 399290 }, /* pm_sn_usage\000\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each SN machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x3688c\000\000\000\000\000\000\000 */
{ 399805 }, /* pm_snoop_tlbie\000\000other\000TLBIE snoop\000event=0xf880\000\000\000\000\000\000\000 */
{ 399858 }, /* pm_snp_tm_hit_m\000\000other\000TM snoop that is a store hits line in L3 in M or Mu state (exclusive modified)\000event=0x360a6\000\000\000\000\000\000\000 */
{ 399980 }, /* pm_snp_tm_hit_t\000\000other\000TM snoop that is a store hits line in L3 in T, Tn or Te state (shared modified)\000event=0x368a6\000\000\000\000\000\000\000 */
{ 400271 }, /* pm_srq_empty_cyc\000\000other\000Cycles in which the SRQ has at least one (out of four) empty slice\000event=0x40008\000\000\000\000\000\000\000 */
{ 400382 }, /* pm_srq_sync_cyc\000\000other\000A sync is in the S2Q (edge detect to count)\000event=0xd0ac\000\000\000\000\000\000\000 */
{ 400468 }, /* pm_st_caused_fail\000\000other\000Non-TM Store caused any thread to fail\000event=0x1608e\000\000\000\000\000\000\000 */
{ 402256 }, /* pm_stcx_fin\000\000other\000Number of stcx instructions finished. This includes instructions in the speculative path of a branch that may be flushed\000event=0x2e014\000\000\000\000\000\000\000 */
{ 402817 }, /* pm_stcx_success_cmpl\000\000other\000Number of stcx instructions that completed successfully\000event=0xc8bc\000\000\000\000\000\000\000 */
{ 402920 }, /* pm_stop_fetch_pending_cyc\000\000other\000Fetching is stopped due to an incoming instruction that will result in a flush\000event=0x48a4\000\000\000\000\000\000\000 */
{ 404445 }, /* pm_sync_mrk_l2miss\000\000other\000Marked L2 Miss that can throw a synchronous interrupt\000event=0x1515a\000\000\000\000\000\000\000 */
{ 404648 }, /* pm_sync_mrk_l3miss\000\000other\000Marked L3 misses that can throw a synchronous interrupt\000event=0x15154\000\000\000\000\000\000\000 */
{ 407045 }, /* pm_tablewalk_cyc_pref\000\000other\000tablewalk qualified for pte  prefetches\000event=0xf884\000\000\000\000\000\000\000 */
{ 407353 }, /* pm_tage_correct\000\000other\000The TAGE overrode BHT direction prediction and it was correct.   Includes taken and not taken and is counted at execution time\000event=0x58b4\000\000\000\000\000\000\000 */
{ 407522 }, /* pm_tage_correct_taken_cmpl\000\000other\000The TAGE overrode BHT direction prediction and it was correct.  Counted at completion for taken branches only\000event=0x50b4\000\000\000\000\000\000\000 */
{ 407685 }, /* pm_tage_override_wrong\000\000other\000The TAGE overrode BHT direction prediction but it was incorrect.  Counted at completion for taken branches only\000event=0x50b8\000\000\000\000\000\000\000 */
{ 407846 }, /* pm_tage_override_wrong_spec\000\000other\000The TAGE overrode BHT direction prediction and it was correct.   Includes taken and not taken and is counted at execution time\000event=0x58b8\000\000\000\000\000\000\000 */
{ 408027 }, /* pm_taken_br_mpred_cmpl\000\000other\000Total number of taken branches that were incorrectly predicted as not-taken. This event counts branches completed and does not include speculative instructions\000event=0x20056\000\000\000\000\000\000\000 */
{ 408237 }, /* pm_tb_bit_trans\000\000other\000timebase event\000event=0x300f8\000\000\000\000\000\000\000 */
{ 408448 }, /* pm_tend_pend_cyc\000\000other\000TEND latency per thread\000event=0xe8b0\000\000\000\000\000\000\000 */
{ 408515 }, /* pm_thrd_all_run_cyc\000\000other\000Cycles in which all the threads have the run latch set\000event=0x2000c\000\000\000\000\000\000\000 */
{ 409171 }, /* pm_thrd_prio_0_1_cyc\000\000other\000Cycles thread running at priority level 0 or 1\000event=0x40bc\000\000\000\000\000\000\000 */
{ 409359 }, /* pm_thrd_prio_2_3_cyc\000\000other\000Cycles thread running at priority level 2 or 3\000event=0x48bc\000\000\000\000\000\000\000 */
{ 409453 }, /* pm_thrd_prio_4_5_cyc\000\000other\000Cycles thread running at priority level 4 or 5\000event=0x5080\000\000\000\000\000\000\000 */
{ 409641 }, /* pm_thrd_prio_6_7_cyc\000\000other\000Cycles thread running at priority level 6 or 7\000event=0x5880\000\000\000\000\000\000\000 */
{ 411337 }, /* pm_thresh_exc_512\000\000other\000Threshold counter exceeded a value of 512\000event=0x201e8\000\000\000\000\000\000\000 */
{ 412828 }, /* pm_tm_cam_overflow\000\000other\000L3 TM CAM is full when a L2 castout of TM_SC line occurs.  Line is pushed to memory\000event=0x168a6\000\000\000\000\000\000\000 */
{ 412958 }, /* pm_tm_cap_overflow\000\000other\000TM Footprint Capacity Overflow\000event=0x4608e\000\000\000\000\000\000\000 */
{ 413242 }, /* pm_tm_fail_conf_non_tm\000\000other\000TM aborted because a conflict occurred with a non-transactional access by another processor\000event=0x28a8\000\000\000\000\000\000\000 */
{ 413383 }, /* pm_tm_fail_conf_tm\000\000other\000TM aborted because a conflict occurred with another transaction\000event=0x20ac\000\000\000\000\000\000\000 */
{ 413660 }, /* pm_tm_fail_footprint_overflow\000\000other\000TM aborted because the tracking limit for transactional storage accesses was exceeded.. Asynchronous\000event=0x20a8\000\000\000\000\000\000\000 */
{ 414001 }, /* pm_tm_fail_non_tx_conflict\000\000other\000Non transactional conflict from LSU, gets reported to TEXASR\000event=0xe0b0\000\000\000\000\000\000\000 */
{ 414188 }, /* pm_tm_fail_self\000\000other\000TM aborted because a self-induced conflict occurred in Suspended state, due to one of the following: a store to a storage location that was previously accessed transactionally; a dcbf, dcbi, or icbi specify- ing a block that was previously accessed transactionally; a dcbst specifying a block that was previously written transactionally; or a tlbie that specifies a translation that was pre- viously used transactionally\000event=0x28ac\000\000\000\000\000\000\000 */
{ 414741 }, /* pm_tm_fail_tlbie\000\000other\000Transaction failed because there was a TLBIE hit in the bloom filter\000event=0xe0ac\000\000\000\000\000\000\000 */
{ 414853 }, /* pm_tm_fail_tx_conflict\000\000other\000Transactional conflict from LSU, gets reported to TEXASR\000event=0xe8ac\000\000\000\000\000\000\000 */
{ 415140 }, /* pm_tm_fav_caused_fail\000\000other\000TM Load (fav) caused another thread to fail\000event=0x2688e\000\000\000\000\000\000\000 */
{ 415233 }, /* pm_tm_fav_tbegin\000\000other\000Dispatch time Favored tbegin\000event=0x209c\000\000\000\000\000\000\000 */
{ 415305 }, /* pm_tm_ld_caused_fail\000\000other\000Non-TM Load caused any thread to fail\000event=0x1688e\000\000\000\000\000\000\000 */
{ 415391 }, /* pm_tm_ld_conf\000\000other\000TM Load (fav or non-fav) ran into conflict (failed)\000event=0x2608e\000\000\000\000\000\000\000 */
{ 415484 }, /* pm_tm_nested_tbegin\000\000other\000Completion Tm nested tbegin\000event=0x20a0\000\000\000\000\000\000\000 */
{ 415558 }, /* pm_tm_nested_tend\000\000other\000Completion time nested tend\000event=0x2098\000\000\000\000\000\000\000 */
{ 415630 }, /* pm_tm_non_fav_tbegin\000\000other\000Dispatch time non favored tbegin\000event=0x289c\000\000\000\000\000\000\000 */
{ 415710 }, /* pm_tm_outer_tbegin\000\000other\000Completion time outer tbegin\000event=0x2094\000\000\000\000\000\000\000 */
{ 415784 }, /* pm_tm_outer_tbegin_disp\000\000other\000Number of outer tbegin instructions dispatched. The dispatch unit determines whether the tbegin instruction is outer or nested. This is a speculative count, which includes flushed instructions\000event=0x4e05e\000\000\000\000\000\000\000 */
{ 416028 }, /* pm_tm_outer_tend\000\000other\000Completion time outer tend\000event=0x2894\000\000\000\000\000\000\000 */
{ 416098 }, /* pm_tm_passed\000\000other\000Number of TM transactions that passed\000event=0x2e052\000\000\000\000\000\000\000 */
{ 416176 }, /* pm_tm_rst_sc\000\000other\000TM snoop hits line in L3 that is TM_SC state and causes it to be invalidated\000event=0x268a6\000\000\000\000\000\000\000 */
{ 416293 }, /* pm_tm_sc_co\000\000other\000L3 castout of line that was StoreCopy (original value of speculatively written line) in a Transaction\000event=0x160a6\000\000\000\000\000\000\000 */
{ 416434 }, /* pm_tm_st_caused_fail\000\000other\000TM Store (fav or non-fav) caused another thread to fail\000event=0x3688e\000\000\000\000\000\000\000 */
{ 416538 }, /* pm_tm_st_conf\000\000other\000TM Store (fav or non-fav) ran into conflict (failed)\000event=0x3608e\000\000\000\000\000\000\000 */
{ 416632 }, /* pm_tm_tabort_treclaim\000\000other\000Completion time tabortnoncd, tabortcd, treclaim\000event=0x2898\000\000\000\000\000\000\000 */
{ 417170 }, /* pm_tm_tresume\000\000other\000TM resume instruction completed\000event=0x20a4\000\000\000\000\000\000\000 */
{ 417292 }, /* pm_tm_tsuspend\000\000other\000TM suspend instruction completed\000event=0x28a0\000\000\000\000\000\000\000 */
{ 417748 }, /* pm_tma_req_l2\000\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0a4\000\000\000\000\000\000\000 */
{ 418492 }, /* pm_vector_ld_cmpl\000\000other\000Number of vector load instructions completed\000event=0x44054\000\000\000\000\000\000\000 */
{ 424344 }, /* pm_vsu_fin\000\000other\000VSU instruction finished. Up to 4 per cycle\000event=0x2505c\000\000\000\000\000\000\000 */
{ 426235 }, /* pm_xlate_hpt_mode\000\000other\000LSU reports every cycle the thread is in HPT translation mode (as opposed to radix mode)\000event=0xf098\000\000\000\000\000\000\000 */
{ 426368 }, /* pm_xlate_miss\000\000other\000The LSU requested a line from L2 for translation.  It may be satisfied from any source beyond L2.  Includes speculative instructions. Includes instruction, prefetch and demand\000event=0xf89c\000\000\000\000\000\000\000 */
{ 426584 }, /* pm_xlate_radix_mode\000\000other\000LSU reports every cycle the thread is in radix translation mode (as opposed to HPT mode)\000event=0xf898\000\000\000\000\000\000\000 */
{ 104483 }, /* pm_1plus_ppc_disp\000\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\000\000\000\000\000\000 */
{ 104568 }, /* pm_2flop_cmpl\000\000pipeline\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg \000event=0x4d052\000\000\000\000\000\000\000 */
{ 117812 }, /* pm_bru_fin\000\000pipeline\000Branch Instruction Finished\000event=0x10068\000\000\000\000\000\000\000 */
{ 118725 }, /* pm_chip_pump_cpred\000\000pipeline\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10050\000\000\000\000\000\000\000 */
{ 120440 }, /* pm_cmplu_stall\000\000pipeline\000Nothing completed and ICT not empty\000event=0x1e054\000\000\000\000\000\000\000 */
{ 121417 }, /* pm_cmplu_stall_dflong\000\000pipeline\000Finish stall because the NTF instruction was a multi-cycle instruction issued to the Decimal Floating Point execution pipe and waiting to finish. Includes decimal floating point instructions + 128 bit binary floating point instructions. Qualified by multicycle\000event=0x1005a\000\000\000\000\000\000\000 */
{ 121730 }, /* pm_cmplu_stall_dfu\000\000pipeline\000Finish stall because the NTF instruction was issued to the Decimal Floating Point execution pipe and waiting to finish. Includes decimal floating point instructions + 128 bit binary floating point instructions. Not qualified by multicycle\000event=0x2d012\000\000\000\000\000\000\000 */
{ 122018 }, /* pm_cmplu_stall_dmiss_l21_l31\000\000pipeline\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000event=0x2c018\000\000\000\000\000\000\000 */
{ 123959 }, /* pm_cmplu_stall_dplong\000\000pipeline\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Qualified by NOT vector AND multicycle\000event=0x3405c\000\000\000\000\000\000\000 */
{ 124419 }, /* pm_cmplu_stall_emq_full\000\000pipeline\000Finish stall because the next to finish instruction suffered an ERAT miss and the EMQ was full\000event=0x30004\000\000\000\000\000\000\000 */
{ 124668 }, /* pm_cmplu_stall_erat_miss\000\000pipeline\000Finish stall because the NTF instruction was a load or store that suffered a translation miss\000event=0x4c012\000\000\000\000\000\000\000 */
{ 153434 }, /* pm_data_from_dl4\000\000pipeline\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a demand load\000event=0x3c04c\000\000\000\000\000\000\000 */
{ 153958 }, /* pm_data_from_dmem\000\000pipeline\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a demand load\000event=0x4c04c\000\000\000\000\000\000\000 */
{ 166714 }, /* pm_data_from_rl2l3_mod\000\000pipeline\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x2c046\000\000\000\000\000\000\000 */
{ 176291 }, /* pm_derat_miss_16m_2m\000\000pipeline\000Data ERAT Miss (Data TLB Access) page size 16M (HPT mode) or 2M (Radix mode)\000event=0x3c054\000\000\000\000\000\000\000 */
{ 176910 }, /* pm_derat_miss_4k\000\000pipeline\000Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1c056\000\000\000\000\000\000\000 */
{ 177332 }, /* pm_derat_miss_64k\000\000pipeline\000Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2c054\000\000\000\000\000\000\000 */
{ 177582 }, /* pm_dfu_busy\000\000pipeline\000Cycles in which all 4 Decimal Floating Point units are busy. The DFU is running at capacity\000event=0x4d04c\000\000\000\000\000\000\000 */
{ 178569 }, /* pm_disp_held\000\000pipeline\000Dispatch Held\000event=0x10006\000\000\000\000\000\000\000 */
{ 186647 }, /* pm_dpteg_from_l21_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e046\000\000\000\000\000\000\000 */
{ 187111 }, /* pm_dpteg_from_l21_shr\000\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e046\000\000\000\000\000\000\000 */
{ 188610 }, /* pm_dpteg_from_l2_no_conflict\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e040\000\000\000\000\000\000\000 */
{ 191738 }, /* pm_dpteg_from_l3_disp_conflict\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e042\000\000\000\000\000\000\000 */
{ 192190 }, /* pm_dpteg_from_l3_mepf\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e042\000\000\000\000\000\000\000 */
{ 195845 }, /* pm_dpteg_from_rl2l3_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e046\000\000\000\000\000\000\000 */
{ 196397 }, /* pm_dpteg_from_rl2l3_shr\000\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04a\000\000\000\000\000\000\000 */
{ 198590 }, /* pm_dslb_miss\000\000pipeline\000gate_and(sd_pc_c0_comp_valid AND sd_pc_c0_comp_thread(0:1)=tid,sd_pc_c0_comp_ppc_count(0:3)) + gate_and(sd_pc_c1_comp_valid AND sd_pc_c1_comp_thread(0:1)=tid,sd_pc_c1_comp_ppc_count(0:3))\000event=0xd0a8\000\000\000\000\000\000\000 */
{ 199274 }, /* pm_dtlb_miss\000\000pipeline\000Data PTEG reload\000event=0x300fc\000\000\000\000\000\000\000 */
{ 201099 }, /* pm_dummy1_remove_me\000\000pipeline\000Space holder for L2_PC_PM_MK_LDST_SCOPE_PRED_STATUS\000event=0x40062\000\000\000\000\000\000\000 */
{ 201201 }, /* pm_dummy2_remove_me\000\000pipeline\000Space holder for LS_PC_RELOAD_RA\000event=0x40064\000\000\000\000\000\000\000 */
{ 208028 }, /* pm_ext_int\000\000pipeline\000external interrupt\000event=0x200f8\000\000\000\000\000\000\000 */
{ 208459 }, /* pm_flop_cmpl\000\000pipeline\000Floating Point Operation Finished\000event=0x4505e\000\000\000\000\000\000\000 */
{ 208691 }, /* pm_flush\000\000pipeline\000Flush (any type)\000event=0x400f8\000\000\000\000\000\000\000 */
{ 212810 }, /* pm_fxu_busy\000\000pipeline\000Cycles in which all 4 FXUs are busy. The FXU is running at capacity\000event=0x2000e\000\000\000\000\000\000\000 */
{ 212920 }, /* pm_fxu_fin\000\000pipeline\000The fixed point unit Unit finished an instruction. Instructions that finish may not necessary complete\000event=0x40004\000\000\000\000\000\000\000 */
{ 213136 }, /* pm_fxu_idle\000\000pipeline\000Cycles in which FXU0, FXU1, FXU2, and FXU3 are all idle\000event=0x24052\000\000\000\000\000\000\000 */
{ 216656 }, /* pm_grp_pump_mpred\000\000pipeline\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20052\000\000\000\000\000\000\000 */
{ 218458 }, /* pm_hv_cyc\000\000pipeline\000Cycles in which msr_hv is high. Note that this event does not take msr_pr into consideration\000event=0x2000a\000\000\000\000\000\000\000 */
{ 219496 }, /* pm_ic_demand_cyc\000\000pipeline\000Icache miss demand cycles\000event=0x10018\000\000\000\000\000\000\000 */
{ 220155 }, /* pm_ic_miss_cmpl\000\000pipeline\000Non-speculative icache miss, counted at completion\000event=0x45058\000\000\000\000\000\000\000 */
{ 221715 }, /* pm_ict_empty_cyc\000\000pipeline\000Cycles in which the ICT is completely empty. No itags are assigned to any thread\000event=0x20008\000\000\000\000\000\000\000 */
{ 221843 }, /* pm_ict_noslot_br_mpred\000\000pipeline\000Ict empty for this thread due to branch mispred\000event=0x4d01e\000\000\000\000\000\000\000 */
{ 221944 }, /* pm_ict_noslot_br_mpred_icmiss\000\000pipeline\000Ict empty for this thread due to Icache Miss and branch mispred\000event=0x34058\000\000\000\000\000\000\000 */
{ 222068 }, /* pm_ict_noslot_cyc\000\000pipeline\000Number of cycles the ICT has no itags assigned to this thread\000event=0x100f8\000\000\000\000\000\000\000 */
{ 222178 }, /* pm_ict_noslot_disp_held\000\000pipeline\000Cycles in which the NTC instruction is held at dispatch for any reason\000event=0x4e01a\000\000\000\000\000\000\000 */
{ 222693 }, /* pm_ict_noslot_disp_held_sync\000\000pipeline\000Dispatch held due to a synchronizing instruction at dispatch\000event=0x4d01c\000\000\000\000\000\000\000 */
{ 222813 }, /* pm_ict_noslot_disp_held_tbegin\000\000pipeline\000the NTC instruction is being held at dispatch because it is a tbegin instruction and there is an older tbegin in the pipeline that must complete before the younger tbegin can dispatch\000event=0x10064\000\000\000\000\000\000\000 */
{ 223058 }, /* pm_ict_noslot_ic_l3\000\000pipeline\000Ict empty for this thread due to icache misses that were sourced from the local L3\000event=0x3e052\000\000\000\000\000\000\000 */
{ 223191 }, /* pm_ict_noslot_ic_l3miss\000\000pipeline\000Ict empty for this thread due to icache misses that were sourced from beyond the local L3. The source could be local/remote/distant memory or another core's cache\000event=0x4e010\000\000\000\000\000\000\000 */
{ 223408 }, /* pm_ict_noslot_ic_miss\000\000pipeline\000Ict empty for this thread due to Icache Miss\000event=0x2d01a\000\000\000\000\000\000\000 */
{ 223723 }, /* pm_ierat_reload\000\000pipeline\000Number of I-ERAT reloads\000event=0x100f6\000\000\000\000\000\000\000 */
{ 223881 }, /* pm_ierat_reload_16m\000\000pipeline\000IERAT Reloaded (Miss) for a 16M page\000event=0x4006a\000\000\000\000\000\000\000 */
{ 239632 }, /* pm_inst_chip_pump_cpred\000\000pipeline\000Initial and Final Pump Scope was chip pump (prediction=correct) for an instruction fetch\000event=0x14050\000\000\000\000\000\000\000 */
{ 239897 }, /* pm_inst_cmpl\000\000pipeline\000Number of PowerPC Instructions that completed\000event=0x2\000\000\000\000\000\000\000 */
{ 254667 }, /* pm_inst_from_memory\000\000pipeline\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to an instruction fetch (not prefetch)\000event=0x2404c\000\000\000\000\000\000\000 */
{ 260160 }, /* pm_inst_grp_pump_mpred_rty\000\000pipeline\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for an instruction fetch\000event=0x14052\000\000\000\000\000\000\000 */
{ 295236 }, /* pm_ld_l3miss_pend_cyc\000\000pipeline\000Cycles L3 miss was pending for this thread\000event=0x10062\000\000\000\000\000\000\000 */
{ 325446 }, /* pm_mem_co\000\000pipeline\000Memory castouts from this thread\000event=0x4c058\000\000\000\000\000\000\000 */
{ 326443 }, /* pm_mem_read\000\000pipeline\000Reads from Memory from this thread (includes data/inst/xlate/l1prefetch/inst prefetch). Includes L4\000event=0x10056\000\000\000\000\000\000\000 */
{ 331175 }, /* pm_mrk_data_from_l21_mod_cyc\000\000pipeline\000Duration in cycles to reload with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x3d148\000\000\000\000\000\000\000 */
{ 331521 }, /* pm_mrk_data_from_l21_shr\000\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x2d14e\000\000\000\000\000\000\000 */
{ 331865 }, /* pm_mrk_data_from_l21_shr_cyc\000\000pipeline\000Duration in cycles to reload with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x1d154\000\000\000\000\000\000\000 */
{ 334116 }, /* pm_mrk_data_from_l2_mepf\000\000pipeline\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x4c120\000\000\000\000\000\000\000 */
{ 337939 }, /* pm_mrk_data_from_l31_shr\000\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x4d124\000\000\000\000\000\000\000 */
{ 344654 }, /* pm_mrk_data_from_on_chip_cache\000\000pipeline\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x4d140\000\000\000\000\000\000\000 */
{ 345443 }, /* pm_mrk_data_from_rl2l3_mod\000\000pipeline\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x1d14a\000\000\000\000\000\000\000 */
{ 346302 }, /* pm_mrk_data_from_rl2l3_shr\000\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x35150\000\000\000\000\000\000\000 */
{ 348715 }, /* pm_mrk_derat_miss_16g_1g\000\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 16G (hpt mode) and 1G (radix mode)\000event=0x4c15c\000\000\000\000\000\000\000 */
{ 348959 }, /* pm_mrk_derat_miss_16m_2m\000\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 16M (hpt mode) or 2M (radix mode)\000event=0x3d154\000\000\000\000\000\000\000 */
{ 349460 }, /* pm_mrk_derat_miss_4k\000\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 4K\000event=0x2d150\000\000\000\000\000\000\000 */
{ 351162 }, /* pm_mrk_dpteg_from_dl2l3_shr\000\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f148\000\000\000\000\000\000\000 */
{ 351688 }, /* pm_mrk_dpteg_from_dl4\000\000pipeline\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f14c\000\000\000\000\000\000\000 */
{ 352169 }, /* pm_mrk_dpteg_from_dmem\000\000pipeline\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14c\000\000\000\000\000\000\000 */
{ 353577 }, /* pm_mrk_dpteg_from_l2\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f142\000\000\000\000\000\000\000 */
{ 352654 }, /* pm_mrk_dpteg_from_l21_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f146\000\000\000\000\000\000\000 */
{ 354881 }, /* pm_mrk_dpteg_from_l2_no_conflict\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f140\000\000\000\000\000\000\000 */
{ 356802 }, /* pm_mrk_dpteg_from_l31_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f144\000\000\000\000\000\000\000 */
{ 358631 }, /* pm_mrk_dpteg_from_l3_mepf\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f142\000\000\000\000\000\000\000 */
{ 359106 }, /* pm_mrk_dpteg_from_l3_no_conflict\000\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f144\000\000\000\000\000\000\000 */
{ 360860 }, /* pm_mrk_dpteg_from_memory\000\000pipeline\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f14c\000\000\000\000\000\000\000 */
{ 361391 }, /* pm_mrk_dpteg_from_off_chip_cache\000\000pipeline\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14a\000\000\000\000\000\000\000 */
{ 361938 }, /* pm_mrk_dpteg_from_on_chip_cache\000\000pipeline\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f148\000\000\000\000\000\000\000 */
{ 362485 }, /* pm_mrk_dpteg_from_rl2l3_mod\000\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f146\000\000\000\000\000\000\000 */
{ 372226 }, /* pm_mrk_ld_miss_l1\000\000pipeline\000Marked DL1 Demand Miss counted at exec time. Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x201e2\000\000\000\000\000\000\000 */
{ 382729 }, /* pm_ntc_fin\000\000pipeline\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. This event is used to account for cycles in which work is being completed in the CPI stack\000event=0x2405a\000\000\000\000\000\000\000 */
{ 382932 }, /* pm_ntc_issue_held_arb\000\000pipeline\000The NTC instruction is being held at dispatch because it lost arbitration onto the issue pipe to another instruction (from the same thread or a different thread)\000event=0x2e016\000\000\000\000\000\000\000 */
{ 384814 }, /* pm_pmc2_rewind\000\000pipeline\000PMC2 Rewind Event (did not match condition)\000event=0x30020\000\000\000\000\000\000\000 */
{ 385120 }, /* pm_pmc2_saved\000\000pipeline\000PMC2 Rewind Value saved\000event=0x10022\000\000\000\000\000\000\000 */
{ 385425 }, /* pm_pmc3_overflow\000\000pipeline\000Overflow from counter 3\000event=0x40010\000\000\000\000\000\000\000 */
{ 386832 }, /* pm_pmc4_saved\000\000pipeline\000PMC4 Rewind Value saved (matched condition)\000event=0x30022\000\000\000\000\000\000\000 */
{ 387134 }, /* pm_pmc5_overflow\000\000pipeline\000Overflow from counter 5\000event=0x10024\000\000\000\000\000\000\000 */
{ 387383 }, /* pm_pmc6_overflow\000\000pipeline\000Overflow from counter 6\000event=0x30024\000\000\000\000\000\000\000 */
{ 389216 }, /* pm_pump_cpred\000\000pipeline\000Pump prediction correct. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10054\000\000\000\000\000\000\000 */
{ 389728 }, /* pm_pump_mpred\000\000pipeline\000Pump misprediction. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40052\000\000\000\000\000\000\000 */
{ 390608 }, /* pm_radix_pwc_l2_pde_from_l3\000\000pipeline\000A Page Directory Entry was reloaded to a level 2 page walk cache from the core's L3 data cache\000event=0x3f05a\000\000\000\000\000\000\000 */
{ 390761 }, /* pm_radix_pwc_l2_pte_from_l2\000\000pipeline\000A Page Table Entry was reloaded to a level 2 page walk cache from the core's L2 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation\000event=0x1f058\000\000\000\000\000\000\000 */
{ 395393 }, /* pm_run_cyc\000\000pipeline\000Run_cycles\000event=0x200f4\000\000\000\000\000\000\000 */
{ 404027 }, /* pm_sync_mrk_fx_divide\000\000pipeline\000Marked fixed point divide that can cause a synchronous interrupt\000event=0x15156\000\000\000\000\000\000\000 */
{ 410551 }, /* pm_thresh_exc_2048\000\000pipeline\000Threshold counter exceeded a value of 2048\000event=0x401ec\000\000\000\000\000\000\000 */
{ 412379 }, /* pm_tlb_miss\000\000pipeline\000TLB Miss (I + D)\000event=0x20066\000\000\000\000\000\000\000 */
{ 412637 }, /* pm_tlbie_fin\000\000pipeline\000tlbie finished\000event=0x30058\000\000\000\000\000\000\000 */
{ 412695 }, /* pm_tm_aborts\000\000pipeline\000Number of TM transactions aborted\000event=0x30056\000\000\000\000\000\000\000 */
{ 417418 }, /* pm_tm_tx_pass_run_cyc\000\000pipeline\000cycles spent in successful transactions\000event=0x2e012\000\000\000\000\000\000\000 */
{ 424263 }, /* pm_vsu_dp_fsqrt_fdiv\000\000pipeline\000vector versions of fdiv,fsqrt\000event=0x3d058\000\000\000\000\000\000\000 */
{ 424491 }, /* pm_vsu_fsqrt_fdiv\000\000pipeline\000four flops operation (fdiv,fsqrt) Scalar Instructions only\000event=0x4d04e\000\000\000\000\000\000\000 */
{ 424755 }, /* pm_vsu_non_flop_cmpl\000\000pipeline\000Non FLOP operation completed\000event=0x4d050\000\000\000\000\000\000\000 */
{ 103733 }, /* pm_1flop_cmpl\000\000pmc\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation completed\000event=0x45050\000\000\000\000\000\000\000 */
{ 104990 }, /* pm_4flop_cmpl\000\000pmc\0004 FLOP instruction completed\000event=0x45052\000\000\000\000\000\000\000 */
{ 105396 }, /* pm_8flop_cmpl\000\000pmc\0008 FLOP instruction completed\000event=0x4d054\000\000\000\000\000\000\000 */
{ 110408 }, /* pm_br_2path\000\000pmc\000Branches that are not strongly biased\000event=0x20036\000\000\000\000\000\000\000 */
{ 120753 }, /* pm_cmplu_stall_bru\000\000pmc\000Completion stall due to a Branch Unit\000event=0x4d018\000\000\000\000\000\000\000 */
{ 120998 }, /* pm_cmplu_stall_crypto\000\000pmc\000Finish stall because the NTF instruction was routed to the crypto execution pipe and was waiting to finish\000event=0x4c01e\000\000\000\000\000\000\000 */
{ 121241 }, /* pm_cmplu_stall_dcache_miss\000\000pmc\000Finish stall because the NTF instruction was a load that missed the L1 and was waiting for the data to return from the nest\000event=0x2c012\000\000\000\000\000\000\000 */
{ 193269 }, /* pm_dpteg_from_l3miss\000\000pmc\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04e\000\000\000\000\000\000\000 */
{ 193531 }, /* pm_dpteg_from_ll4\000\000pmc\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04c\000\000\000\000\000\000\000 */
{ 194322 }, /* pm_dpteg_from_memory\000\000pmc\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e04c\000\000\000\000\000\000\000 */
{ 211108 }, /* pm_freq_down\000\000pmc\000Power Management: Below Threshold B\000event=0x3000c\000\000\000\000\000\000\000 */
{ 325840 }, /* pm_mem_loc_thresh_lsu_high\000\000pmc\000Local memory above threshold for LSU medium\000event=0x40056\000\000\000\000\000\000\000 */
{ 342165 }, /* pm_mrk_data_from_lmem\000\000pmc\000The processor's data cache was reloaded from the local chip's Memory due to a marked load\000event=0x3d142\000\000\000\000\000\000\000 */
{ 342435 }, /* pm_mrk_data_from_lmem_cyc\000\000pmc\000Duration in cycles to reload from the local chip's Memory due to a marked load\000event=0x4d128\000\000\000\000\000\000\000 */
{ 348362 }, /* pm_mrk_dcache_reload_intv\000\000pmc\000Combined Intervention event\000event=0x40118\000\000\000\000\000\000\000 */
{ 350592 }, /* pm_mrk_dpteg_from_dl2l3_mod\000\000pmc\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f148\000\000\000\000\000\000\000 */
{ 355335 }, /* pm_mrk_dpteg_from_l2miss\000\000pmc\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14e\000\000\000\000\000\000\000 */
{ 357726 }, /* pm_mrk_dpteg_from_l3\000\000pmc\000A Page Table Entry was loaded into the TLB from local core's L3 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f142\000\000\000\000\000\000\000 */
{ 358153 }, /* pm_mrk_dpteg_from_l3_disp_conflict\000\000pmc\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f142\000\000\000\000\000\000\000 */
{ 406636 }, /* pm_sys_pump_mpred_rty\000\000pmc\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40050\000\000\000\000\000\000\000 */
{ 406956 }, /* pm_tablewalk_cyc\000\000pmc\000Cycles when an instruction tablewalk is active\000event=0x10026\000\000\000\000\000\000\000 */
{ 411703 }, /* pm_thresh_exc_64\000\000pmc\000Threshold counter exceeded a value of 64\000event=0x301e8\000\000\000\000\000\000\000 */
{ 416868 }, /* pm_tm_trans_run_cyc\000\000pmc\000run cycles in transactional state\000event=0x10060\000\000\000\000\000\000\000 */
{ 133122 }, /* pm_cmplu_stall_tlbie\000\000translation\000Finish stall because the NTF instruction was a tlbie waiting for response from L2\000event=0x2e01c\000\000\000\000\000\000\000 */
{ 133258 }, /* pm_cmplu_stall_vdp\000\000translation\000Finish stall because the NTF instruction was a vector instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Not qualified multicycle. Qualified by vector\000event=0x4405c\000\000\000\000\000\000\000 */
{ 133582 }, /* pm_cmplu_stall_vdplong\000\000translation\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Qualified by NOT vector AND multicycle\000event=0x3c05a\000\000\000\000\000\000\000 */
{ 134117 }, /* pm_cmplu_stall_vfxlong\000\000translation\000Completion stall due to a long latency vector fixed point instruction (division, square root)\000event=0x2e018\000\000\000\000\000\000\000 */
{ 134267 }, /* pm_cmplu_stall_vfxu\000\000translation\000Finish stall due to a vector fixed point instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000event=0x3c05c\000\000\000\000\000\000\000 */
{ 135824 }, /* pm_cyc\000\000translation\000Processor cycles\000event=0x1e\000\000\000\000\000\000\000 */
{ 154486 }, /* pm_data_from_l21_mod\000\000translation\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a demand load\000event=0x4c046\000\000\000\000\000\000\000 */
{ 155016 }, /* pm_data_from_l21_shr\000\000translation\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a demand load\000event=0x3c046\000\000\000\000\000\000\000 */
{ 157696 }, /* pm_data_from_l2miss\000\000translation\000Demand LD - L2 Miss (not L2 hit)\000event=0x200fe\000\000\000\000\000\000\000 */
{ 158274 }, /* pm_data_from_l2miss_mod\000\000translation\000The processor's data cache was reloaded from a location other than the local core's L2 due to a demand load\000event=0x1c04e\000\000\000\000\000\000\000 */
{ 184204 }, /* pm_dp_qp_flop_cmpl\000\000translation\000Double-Precion or Quad-Precision instruction completed\000event=0x4d05c\000\000\000\000\000\000\000 */
{ 184419 }, /* pm_dpteg_from_dl2l3_mod\000\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e048\000\000\000\000\000\000\000 */
{ 184982 }, /* pm_dpteg_from_dl2l3_shr\000\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e048\000\000\000\000\000\000\000 */
{ 185719 }, /* pm_dpteg_from_dl4\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e04c\000\000\000\000\000\000\000 */
{ 186181 }, /* pm_dpteg_from_dmem\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04c\000\000\000\000\000\000\000 */
{ 244109 }, /* pm_inst_from_l21_shr\000\000translation\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x34046\000\000\000\000\000\000\000 */
{ 247479 }, /* pm_inst_from_l2miss\000\000translation\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to an instruction fetch (not prefetch)\000event=0x1404e\000\000\000\000\000\000\000 */
{ 250408 }, /* pm_inst_from_l3\000\000translation\000The processor's Instruction cache was reloaded from local core's L3 due to an instruction fetch (not prefetch)\000event=0x44042\000\000\000\000\000\000\000 */
{ 250940 }, /* pm_inst_from_l3_disp_conflict\000\000translation\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x34042\000\000\000\000\000\000\000 */
{ 251546 }, /* pm_inst_from_l3_mepf\000\000translation\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24042\000\000\000\000\000\000\000 */
{ 252115 }, /* pm_inst_from_l3_no_conflict\000\000translation\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to an instruction fetch (not prefetch)\000event=0x14044\000\000\000\000\000\000\000 */
{ 270756 }, /* pm_ipteg_from_memory\000\000translation\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a instruction side request\000event=0x2504c\000\000\000\000\000\000\000 */
{ 271185 }, /* pm_ipteg_from_off_chip_cache\000\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a instruction side request\000event=0x4504a\000\000\000\000\000\000\000 */
{ 271630 }, /* pm_ipteg_from_on_chip_cache\000\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a instruction side request\000event=0x15048\000\000\000\000\000\000\000 */
{ 272074 }, /* pm_ipteg_from_rl2l3_mod\000\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x25046\000\000\000\000\000\000\000 */
{ 272539 }, /* pm_ipteg_from_rl2l3_shr\000\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x1504a\000\000\000\000\000\000\000 */
{ 272956 }, /* pm_ipteg_from_rl4\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a instruction side request\000event=0x2504a\000\000\000\000\000\000\000 */
{ 273332 }, /* pm_ipteg_from_rmem\000\000translation\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a instruction side request\000event=0x3504a\000\000\000\000\000\000\000 */
{ 315272 }, /* pm_lsu_fin\000\000translation\000LSU Finished a PPC instruction (up to 4 per cycle)\000event=0x30066\000\000\000\000\000\000\000 */
{ 320482 }, /* pm_lsu_lmq_srq_empty_cyc\000\000translation\000Cycles in which the LSU is empty for all threads (lmq and srq are completely empty)\000event=0x2003e\000\000\000\000\000\000\000 */
{ 322170 }, /* pm_lsu_reject_lhs\000\000translation\000LSU Reject due to LHS (up to 4 per cycle)\000event=0x4e05c\000\000\000\000\000\000\000 */
{ 337070 }, /* pm_mrk_data_from_l31_eco_shr_cyc\000\000translation\000Duration in cycles to reload with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x1d142\000\000\000\000\000\000\000 */
{ 345872 }, /* pm_mrk_data_from_rl2l3_mod_cyc\000\000translation\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x2d14a\000\000\000\000\000\000\000 */
{ 372913 }, /* pm_mrk_lsu_fin\000\000translation\000lsu marked instr PPC finish\000event=0x40132\000\000\000\000\000\000\000 */
{ 373766 }, /* pm_mrk_ntc_cyc\000\000translation\000Cycles during which the marked instruction is next to complete (completion is held up because the marked instruction hasn't completed yet)\000event=0x2011c\000\000\000\000\000\000\000 */
{ 374342 }, /* pm_mrk_probe_nop_cmpl\000\000translation\000Marked probeNops completed\000event=0x1f15e\000\000\000\000\000\000\000 */
{ 384354 }, /* pm_pmc1_saved\000\000translation\000PMC1 Rewind Value saved\000event=0x4d010\000\000\000\000\000\000\000 */
{ 384625 }, /* pm_pmc2_overflow\000\000translation\000Overflow from counter 2\000event=0x30010\000\000\000\000\000\000\000 */
{ 401039 }, /* pm_st_cmpl\000\000translation\000Stores completed from S2Q (2nd-level store queue)\000event=0x200f0\000\000\000\000\000\000\000 */
{ 401249 }, /* pm_st_fin\000\000translation\000Store finish count. Includes speculative activity\000event=0x20016\000\000\000\000\000\000\000 */
{ 401411 }, /* pm_st_fwd\000\000translation\000Store forwards that finished\000event=0x20018\000\000\000\000\000\000\000 */
{ 401540 }, /* pm_st_miss_l1\000\000translation\000Store Missed L1\000event=0x300f0\000\000\000\000\000\000\000 */
{ 401861 }, /* pm_stall_end_ict_empty\000\000translation\000The number a times the core transitioned from a stall to ICT-empty for this thread\000event=0x10028\000\000\000\000\000\000\000 */
{ 402055 }, /* pm_stcx_fail\000\000translation\000stcx failed\000event=0x1e058\000\000\000\000\000\000\000 */
{ 411074 }, /* pm_thresh_exc_32\000\000translation\000Threshold counter exceeded a value of 32\000event=0x201e6\000\000\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__power9[] = {
{ 4904 }, /* CPM_CS_32MHZ_CYC\000\000\000hv_24x7@CPM_CS_32MHZ_CYC\\,domain\\=3\\,core\\=?@\000\000\0001MHz\000\0002\000 */
{ 20858 }, /* Memory-bandwidth-MCS\000memory-bandwidth\000\000nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT23@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT23@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT23@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000 */
{ 21284 }, /* Memory_RD_BW_Chip\000Memory_BW\000\000hv_24x7@PM_MCS01_128B_RD_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS01_128B_RD_DISP_PORT23\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_RD_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_RD_DISP_PORT23\\,chip\\=?@\000\000\0001.6e-2MB\000\0001\000 */
{ 21795 }, /* Memory_WR_BW_Chip\000Memory_BW\000\000hv_24x7@PM_MCS01_128B_WR_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS01_128B_WR_DISP_PORT23\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_WR_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_WR_DISP_PORT23\\,chip\\=?@\000\000\0001.6e-2MB\000\0001\000 */
{ 22864 }, /* PowerBUS_Frequency\000\000\000hv_24x7@PM_PB_CYC\\,chip\\=?@\000\000\0002.5e-7GHz\000\0001\000 */
{ 35834 }, /* br_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_CMPL / PM_BR_PRED * 100\000\000\000\000\000\000 */
{ 58156 }, /* emq_stall_cpi\000cpi_breakdown\000\000erat_miss_stall_cpi + emq_full_stall_cpi\000\000\000\000\000\000 */
{ 74622 }, /* issue_hold_cpi\000cpi_breakdown\000\000ntc_issue_held_darq_full_cpi + ntc_issue_held_arb_cpi + ntc_issue_held_other_cpi\000\000\000\000\000\000 */
{ 92243 }, /* lrq_stall_cpi\000cpi_breakdown\000\000lmq_full_stall_cpi + st_fwd_stall_cpi + lhs_stall_cpi + lsu_mfspr_stall_cpi + larx_stall_cpi + lrq_other_stall_cpi\000\000\000\000\000\000 */
{ 92671 }, /* lsaq_stall_cpi\000cpi_breakdown\000\000lrq_full_stall_cpi + srq_full_stall_cpi + lsaq_arb_stall_cpi\000\000\000\000\000\000 */
{ 98206 }, /* mcs01-read\000memory-bandwidth\000\000nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000 */
{ 98340 }, /* mcs01-write\000memory-bandwidth\000\000nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000 */
{ 98475 }, /* mcs23-read\000memory-bandwidth\000\000nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000 */
{ 98609 }, /* mcs23-write\000memory-bandwidth\000\000nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT23@\000\000\0006.1e-5MB\000\000\000 */
{ 426719 }, /* powerbus_freq\000\000\000nest_powerbus0_imc@PM_PB_CYC@\000\000\0001e-9GHz\000\000\000 */
{ 435358 }, /* scalar_stall_cpi\000cpi_breakdown\000\000fxu_stall_cpi + dp_stall_cpi + dfu_stall_cpi + pm_stall_cpi + crypto_stall_cpi\000\000\000\000\000\000 */
{ 436890 }, /* srq_stall_cpi\000cpi_breakdown\000\000store_data_stall_cpi + eieio_stall_cpi + stcx_stall_cpi + slb_stall_cpi + tend_stall_cpi + paste_stall_cpi + tlbie_stall_cpi + store_pipe_arb_stall_cpi + store_fin_arb_stall_cpi\000\000\000\000\000\000 */
{ 442485 }, /* vector_stall_cpi\000cpi_breakdown\000\000vfxu_stall_cpi + vdp_stall_cpi\000\000\000\000\000\000 */
{ 33412 }, /* any_sync_stall_cpi\000\000\000PM_CMPLU_STALL_ANY_SYNC / PM_RUN_INST_CMPL\000ANY_SYNC_STALL_CPI\000\000\000\000\000 */
{ 33499 }, /* average_completed_instruction_set_size\000\000\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000Avg. more than 1 instructions completed\000\000\000\000\000 */
{ 33740 }, /* average_il1_miss_latency\000latency\000\000PM_IC_DEMAND_CYC / PM_IC_DEMAND_REQ\000Average icache miss latency\000\000\000\000\000 */
{ 36045 }, /* br_mpred_flush_rate_percent\000general\000\000PM_FLUSH_MPRED / PM_RUN_INST_CMPL * 100\000Branch Mispredict flushes per instruction\000\000\000\000\000 */
{ 36309 }, /* branches_per_inst\000\000\000PM_BRU_FIN / PM_RUN_INST_CMPL\000% Branches per instruction\000\000\000\000\000 */
{ 36609 }, /* bru_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_BRU / PM_RUN_INST_CMPL\000Completion stall due to a Branch Unit\000\000\000\000\000 */
{ 36901 }, /* ccache_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_CCACHE / PM_RUN_INST_CMPL * 100\000Count cache branch misprediction per instruction\000\000\000\000\000 */
{ 37281 }, /* ccache_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_CCACHE / PM_BR_PRED_CCACHE * 100\000Count cache branch misprediction\000\000\000\000\000 */
{ 37574 }, /* completion_cpi\000\000\000PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000Cycles in which at least one instruction completes in this thread\000\000\000\000\000 */
{ 37910 }, /* cpi\000general\000\000PM_CYC / PM_INST_CMPL\000Cycles per instruction\000\000\000\000\000 */
{ 38231 }, /* crypto_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_CRYPTO / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was routed to the crypto execution pipe and was waiting to finish\000\000\000\000\000 */
{ 38415 }, /* custom_secs\000\000\000PM_RUN_CYC\000cycles\000\000\000\000\000 */
{ 38734 }, /* cycles_atleast_one_inst_dispatched_percent\000\000\000PM_1PLUS_PPC_DISP / PM_CYC * 100\000Percentage Cycles at least one instruction dispatched\000\000\000\000\000 */
{ 38870 }, /* cycles_per_completed_instructions_set\000\000\000PM_CYC / PM_1PLUS_PPC_CMPL\000Cycles per instruction group\000\000\000\000\000 */
{ 39152 }, /* dcache_miss_stall_cpi\000cpi_breakdown\000\000lsu_stall_dcache_miss_cpi\000Finish stall because the NTF instruction was a load that missed the L1 and was waiting for the data to return from the nest\000\000\000\000\000 */
{ 39928 }, /* derat_4k_miss_rate_percent\000translation\000\000PM_DERAT_MISS_4K * 100 / PM_RUN_INST_CMPL\000% DERAT miss rate for 4K page per inst\000\000\000\000\000 */
{ 40053 }, /* derat_4k_miss_ratio\000translation\000\000PM_DERAT_MISS_4K / PM_LSU_DERAT_MISS\000DERAT miss ratio for 4K page\000\000\000\000\000 */
{ 40156 }, /* derat_64k_miss_rate_percent\000translation\000\000PM_DERAT_MISS_64K * 100 / PM_RUN_INST_CMPL\000% DERAT miss ratio for 64K page per inst\000\000\000\000\000 */
{ 40285 }, /* derat_64k_miss_ratio\000translation\000\000PM_DERAT_MISS_64K / PM_LSU_DERAT_MISS\000DERAT miss ratio for 64K page\000\000\000\000\000 */
{ 40535 }, /* derat_miss_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_LSU_DERAT_MISS * 100 / PM_RUN_INST_CMPL\000DERAT Miss Rate (per run instruction)(%)\000\000\000\000\000 */
{ 40678 }, /* derat_miss_ratio\000translation\000\000PM_LSU_DERAT_MISS / PM_LSU_DERAT_MISS\000DERAT miss ratio\000\000\000\000\000 */
{ 40767 }, /* derat_miss_reload_percent\000pteg_reloads_percent_per_ref\000\000PM_DTLB_MISS * 100 / PM_LSU_DERAT_MISS\000% of DERAT misses that result in an ERAT reload\000\000\000\000\000 */
{ 40914 }, /* dflong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DFLONG / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a multi-cycle instruction issued to the Decimal Floating Point execution pipe and waiting to finish\000\000\000\000\000 */
{ 41136 }, /* dfu_other_stall_cpi\000cpi_breakdown\000\000dfu_stall_cpi - dflong_stall_cpi\000Stalls due to short latency decimal floating ops\000\000\000\000\000 */
{ 41257 }, /* dfu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DFU / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was issued to the Decimal Floating Point execution pipe and waiting to finish\000\000\000\000\000 */
{ 41447 }, /* disp_flush_rate_percent\000general\000\000PM_FLUSH_DISP / PM_RUN_INST_CMPL * 100\000GCT empty cycles\000\000\000\000\000 */
{ 41837 }, /* dl1_miss_reloads_percent\000dl1_reloads_percent_per_ref\000\000PM_L1_DCACHE_RELOAD_VALID * 100 / PM_LD_MISS_L1\000% of DL1 misses that result in a cache reload\000\000\000\000\000 */
{ 41989 }, /* dl1_reload_from_dl2l3_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L2 or L3 (Modified)\000\000\000\000\000 */
{ 42167 }, /* dl1_reload_from_dl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000 */
{ 42347 }, /* dl1_reload_from_dl2l3_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L2 or L3 (Shared)\000\000\000\000\000 */
{ 42523 }, /* dl1_reload_from_dl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000 */
{ 42701 }, /* dl1_reload_from_dl4_percent\000\000\000PM_DATA_FROM_DL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant L4\000\000\000\000\000 */
{ 42972 }, /* dl1_reload_from_dl4_rate_percent\000\000\000PM_DATA_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant L4 per Inst\000\000\000\000\000 */
{ 43246 }, /* dl1_reload_from_dmem_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_DMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Distant Memory\000\000\000\000\000 */
{ 43401 }, /* dl1_reload_from_dmem_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Distant Memory per Inst\000\000\000\000\000 */
{ 43558 }, /* dl1_reload_from_l21_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L21_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L2, other core\000\000\000\000\000 */
{ 43723 }, /* dl1_reload_from_l21_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000 */
{ 43894 }, /* dl1_reload_from_l21_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L21_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L2, other core\000\000\000\000\000 */
{ 44059 }, /* dl1_reload_from_l21_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000 */
{ 44800 }, /* dl1_reload_from_l2_miss_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads from sources beyond the local L2\000\000\000\000\000 */
{ 44969 }, /* dl1_reload_from_l2_miss_rate_percent\000dl1_reloads_percent_per_inst\000\000l2_ld_miss_rate_percent\000% of DL1 reloads from L2 per Inst\000\000\000\000\000 */
{ 45975 }, /* dl1_reload_from_l2_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L2 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from L2\000\000\000\000\000 */
{ 46110 }, /* dl1_reload_from_l2_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L2 * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from L2 per Inst\000\000\000\000\000 */
{ 46251 }, /* dl1_reload_from_l31_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L31_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L3, other core\000\000\000\000\000 */
{ 46416 }, /* dl1_reload_from_l31_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3 M state, other core per Inst\000\000\000\000\000 */
{ 46759 }, /* dl1_reload_from_l31_rate_percent\000\000\000dl1_reload_from_l31_mod_rate_percent + dl1_reload_from_l31_shr_rate_percent\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000 */
{ 46928 }, /* dl1_reload_from_l31_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L31_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 reloads from Private L3, other core\000\000\000\000\000 */
{ 47093 }, /* dl1_reload_from_l31_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3 S tate, other core per Inst\000\000\000\000\000 */
{ 47899 }, /* dl1_reload_from_l3_mepf_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads that came from L3 and were brought into the L3 by a prefetch\000\000\000\000\000 */
{ 48097 }, /* dl1_reload_from_l3_mepf_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads that came from the L3 and were brought into the L3 by a prefetch, per instruction completed\000\000\000\000\000 */
{ 48679 }, /* dl1_reload_from_l3_miss_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads from sources beyond the local L3\000\000\000\000\000 */
{ 48848 }, /* dl1_reload_from_l3_miss_rate_percent\000dl1_reloads_percent_per_inst\000\000l3_ld_miss_rate_percent\000% of DL1 reloads from L3 per Inst\000\000\000\000\000 */
{ 49380 }, /* dl1_reload_from_l3_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_L3 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 Reloads from L3\000\000\000\000\000 */
{ 49515 }, /* dl1_reload_from_l3_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_L3 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from L3 per Inst\000\000\000\000\000 */
{ 49656 }, /* dl1_reload_from_ll4_percent\000\000\000PM_DATA_FROM_LL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Local L4\000\000\000\000\000 */
{ 49923 }, /* dl1_reload_from_ll4_rate_percent\000\000\000PM_DATA_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Local L4 per Inst\000\000\000\000\000 */
{ 50193 }, /* dl1_reload_from_lmem_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_LMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Local Memory\000\000\000\000\000 */
{ 50346 }, /* dl1_reload_from_lmem_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Local Memory per Inst\000\000\000\000\000 */
{ 50501 }, /* dl1_reload_from_rl2l3_mod_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L2 or L3 (Modified)\000\000\000\000\000 */
{ 50678 }, /* dl1_reload_from_rl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000 */
{ 50853 }, /* dl1_reload_from_rl2l3_shr_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L2 or L3 (Shared)\000\000\000\000\000 */
{ 51028 }, /* dl1_reload_from_rl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000 */
{ 51203 }, /* dl1_reload_from_rl4_percent\000\000\000PM_DATA_FROM_RL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote L4\000\000\000\000\000 */
{ 51472 }, /* dl1_reload_from_rl4_rate_percent\000\000\000PM_DATA_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000 */
{ 51752 }, /* dl1_reload_from_rmem_percent\000dl1_reloads_percent_per_ref\000\000PM_DATA_FROM_RMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000% of DL1 dL1_Reloads from Remote Memory\000\000\000\000\000 */
{ 51906 }, /* dl1_reload_from_rmem_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_DATA_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000 */
{ 52062 }, /* dl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL2L3_MOD * PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2l3 distant MOD miss rates with measured DL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 52580 }, /* dl2l3_mod_latency\000latency\000\000PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD\000Marked L2L3 remote Load latency\000\000\000\000\000 */
{ 52884 }, /* dl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL2L3_SHR * PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2l3 distant SHR miss rates with measured DL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 53402 }, /* dl2l3_shr_latency\000latency\000\000PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR\000Marked L2L3 distant Load latency\000\000\000\000\000 */
{ 53695 }, /* dl4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DL4 * PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4 / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of distant L4 miss rates with measured DL4 latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 54145 }, /* dl4_latency\000latency\000\000PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4\000Distant L4 average load latency\000\000\000\000\000 */
{ 54367 }, /* dmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_DMEM * PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of distant memory miss rates with measured DMEM latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 54834 }, /* dmem_latency\000latency\000\000PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM\000Marked Dmem Load latency\000\000\000\000\000 */
{ 55053 }, /* dmiss_distant_stall_cpi\000cpi_breakdown\000\000dmiss_non_local_stall_cpi - dmiss_remote_stall_cpi\000Completion stall by Dcache miss which resolved off node memory/cache\000\000\000\000\000 */
{ 55216 }, /* dmiss_l21_l31_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000\000\000\000\000 */
{ 55387 }, /* dmiss_l2l3_conflict_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000\000\000\000\000 */
{ 55571 }, /* dmiss_l2l3_noconflict_stall_cpi\000cpi_breakdown\000\000dmiss_l2l3_stall_cpi - dmiss_l2l3_conflict_stall_cpi\000Completion stall due to cache miss that resolves in the L2 or L3 without conflict\000\000\000\000\000 */
{ 55757 }, /* dmiss_l2l3_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000Completion stall by Dcache miss which resolved in L2/L3\000\000\000\000\000 */
{ 55898 }, /* dmiss_l3miss_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000Completion stall due to cache miss resolving missed the L3\000\000\000\000\000 */
{ 56046 }, /* dmiss_lmem_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000Completion stall due to cache miss that resolves in local memory\000\000\000\000\000 */
{ 56196 }, /* dmiss_non_local_stall_cpi\000cpi_breakdown\000\000dmiss_l3miss_stall_cpi - dmiss_l21_l31_stall_cpi - dmiss_lmem_stall_cpi\000Completion stall by Dcache miss which resolved outside of local memory\000\000\000\000\000 */
{ 56384 }, /* dmiss_remote_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DMISS_REMOTE / PM_RUN_INST_CMPL\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000\000\000\000\000 */
{ 56555 }, /* dp_other_stall_cpi\000cpi_breakdown\000\000dp_stall_cpi - dplong_stall_cpi\000Stalls due to short latency double precision ops\000\000\000\000\000 */
{ 56674 }, /* dp_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DP / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a scalar instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000 */
{ 56968 }, /* dplong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_DPLONG / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000 */
{ 57282 }, /* dpteg_from_l2_rate_percent\000\000\000PM_DPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000Rate of DERAT reloads from L2\000\000\000\000\000 */
{ 57387 }, /* dpteg_from_l3_rate_percent\000\000\000PM_DPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000Rate of DERAT reloads from L3\000\000\000\000\000 */
{ 57492 }, /* dslb_miss_rate_percent\000translation\000\000PM_DSLB_MISS * 100 / PM_RUN_INST_CMPL\000% DSLB_Miss_Rate per inst\000\000\000\000\000 */
{ 57596 }, /* dtlb_miss_rate_percent\000general\000\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000% DTLB miss rate per inst\000\000\000\000\000 */
{ 57696 }, /* eieio_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_EIEIO / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction is an EIEIO waiting for response from L2\000\000\000\000\000 */
{ 57980 }, /* emq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_EMQ_FULL / PM_RUN_INST_CMPL\000Finish stall because the next to finish instruction suffered an ERAT miss and the EMQ was full\000\000\000\000\000 */
{ 58231 }, /* erat_miss_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load or store that suffered a translation miss\000\000\000\000\000 */
{ 58408 }, /* erat_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_ERAT_MISS * 100 / PM_RUN_INST_CMPL\000ERAT miss reject ratio\000\000\000\000\000 */
{ 58649 }, /* estimated_dl1miss_latency\000latency\000\000PM_MRK_LD_MISS_L1_CYC / PM_MRK_LD_MISS_L1\000average L1 miss latency using marked events\000\000\000\000\000 */
{ 58998 }, /* exception_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_EXCEPTION / PM_RUN_INST_CMPL\000Cycles in which the NTC instruction is not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000\000\000\000\000 */
{ 59250 }, /* exec_unit_other_stall_cpi\000cpi_breakdown\000\000exec_unit_stall_cpi - scalar_stall_cpi - vector_stall_cpi\000Completion stall due to execution units for other reasons\000\000\000\000\000 */
{ 59411 }, /* exec_unit_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_EXEC_UNIT / PM_RUN_INST_CMPL\000Completion stall due to execution units (FXU/VSU/CRU)\000\000\000\000\000 */
{ 59809 }, /* finish_to_cmpl_cpi\000\000\000PM_NTC_ALL_FIN / PM_RUN_INST_CMPL\000Cycles in which the oldest instruction is finished and ready to complete for waiting to get through the completion pipe\000\000\000\000\000 */
{ 60144 }, /* fixed_per_inst\000\000\000PM_FXU_FIN / PM_RUN_INST_CMPL\000Total Fixed point operations\000\000\000\000\000 */
{ 60336 }, /* flush_any_thread_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FLUSH_ANY_THREAD / PM_RUN_INST_CMPL\000Cycles in which the NTC instruction is not allowed to complete because any of the 4 threads in the same core suffered a flush, which blocks completion\000\000\000\000\000 */
{ 60584 }, /* flush_rate_percent\000general\000\000PM_FLUSH * 100 / PM_RUN_INST_CMPL\000Flush rate (%)\000\000\000\000\000 */
{ 60766 }, /* fxlong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000Completion stall due to a long latency scalar fixed point instruction (division, square root)\000\000\000\000\000 */
{ 61380 }, /* fxu_all_busy\000\000\000PM_FXU_BUSY / PM_CYC\000All FXU Busy\000\000\000\000\000 */
{ 61433 }, /* fxu_all_idle\000\000\000PM_FXU_IDLE / PM_CYC\000All FXU Idle\000\000\000\000\000 */
{ 61751 }, /* fxu_other_stall_cpi\000cpi_breakdown\000\000fxu_stall_cpi - fxlong_stall_cpi\000Stalls due to short latency integer ops\000\000\000\000\000 */
{ 61956 }, /* fxu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL\000Finish stall due to a scalar fixed point or CR instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000\000\000\000\000 */
{ 65903 }, /* icache_miss_reload\000instruction_stats_percent_per_ref\000\000(PM_L1_ICACHE_MISS - PM_IC_PREF_WRITE) / PM_L1_ICACHE_MISS\000Icache Fetchs per Icache Miss\000\000\000\000\000 */
{ 66050 }, /* icache_pref_percent\000instruction_stats_percent_per_ref\000\000PM_IC_PREF_WRITE * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads due to prefetch\000\000\000\000\000 */
{ 66188 }, /* ict_noslot_br_mpred_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to branch mispred\000\000\000\000\000 */
{ 66346 }, /* ict_noslot_br_mpred_icmiss_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to Icache Miss and branch mispred\000\000\000\000\000 */
{ 66534 }, /* ict_noslot_cyc_other_cpi\000cpi_breakdown\000\000nothing_dispatched_cpi - ict_noslot_ic_miss_cpi - ict_noslot_br_mpred_icmiss_cpi - ict_noslot_br_mpred_cpi - ict_noslot_disp_held_cpi\000Instruction Completion Table other stalls\000\000\000\000\000 */
{ 66754 }, /* ict_noslot_disp_held_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD / PM_RUN_INST_CMPL\000Cycles in which the NTC instruciton is held at dispatch for any reason\000\000\000\000\000 */
{ 66912 }, /* ict_noslot_disp_held_hb_full_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD_HB_FULL / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to dispatch holds because the History Buffer was full. Could be GPR/VSR/VMR/FPR/CR/XVF\000\000\000\000\000 */
{ 67157 }, /* ict_noslot_disp_held_issq_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to dispatch hold on this thread due to Issue q full, BRQ full, XVCF Full, Count cache, Link, Tar full\000\000\000\000\000 */
{ 67411 }, /* ict_noslot_disp_held_other_cpi\000cpi_breakdown\000\000ict_noslot_disp_held_cpi - ict_noslot_disp_held_hb_full_cpi - ict_noslot_disp_held_sync_cpi - ict_noslot_disp_held_tbegin_cpi - ict_noslot_disp_held_issq_cpi\000ICT_NOSLOT_DISP_HELD_OTHER_CPI\000\000\000\000\000 */
{ 67650 }, /* ict_noslot_disp_held_sync_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD_SYNC / PM_RUN_INST_CMPL\000Dispatch held due to a synchronizing instruction at dispatch\000\000\000\000\000 */
{ 67808 }, /* ict_noslot_disp_held_tbegin_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_DISP_HELD_TBEGIN / PM_RUN_INST_CMPL\000the NTC instruction is being held at dispatch because it is a tbegin instruction and there is an older tbegin in the pipeline that must complete before the younger tbegin can dispatch\000\000\000\000\000 */
{ 68093 }, /* ict_noslot_ic_l2_cpi\000cpi_breakdown\000\000ict_noslot_ic_miss_cpi - ict_noslot_ic_l3_cpi - ict_noslot_ic_l3miss_cpi\000ICT_NOSLOT_IC_L2_CPI\000\000\000\000\000 */
{ 68227 }, /* ict_noslot_ic_l3_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_IC_L3 / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to icache misses that were sourced from the local L3\000\000\000\000\000 */
{ 68414 }, /* ict_noslot_ic_l3miss_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_IC_L3MISS / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to icache misses that were sourced from beyond the local L3. The source could be local/remote/distant memory or another core's cache\000\000\000\000\000 */
{ 68689 }, /* ict_noslot_ic_miss_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL\000Instruction Completion Table empty for this thread due to Icache Miss\000\000\000\000\000 */
{ 68842 }, /* inst_from_dl2l3_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant L2 or L3 (Modified)\000\000\000\000\000 */
{ 69011 }, /* inst_from_dl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000 */
{ 69195 }, /* inst_from_dl2l3_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant L2 or L3 (Shared)\000\000\000\000\000 */
{ 69362 }, /* inst_from_dl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000 */
{ 69544 }, /* inst_from_dl4_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DL4 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant L4\000\000\000\000\000 */
{ 69684 }, /* inst_from_dl4_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant L4 per Inst\000\000\000\000\000 */
{ 69839 }, /* inst_from_dmem_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_DMEM * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Distant Memory\000\000\000\000\000 */
{ 69985 }, /* inst_from_dmem_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Distant Memory per Inst\000\000\000\000\000 */
{ 70146 }, /* inst_from_l21_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L21_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L2, other core\000\000\000\000\000 */
{ 70306 }, /* inst_from_l21_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000 */
{ 70481 }, /* inst_from_l21_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L21_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L2, other core\000\000\000\000\000 */
{ 70641 }, /* inst_from_l21_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000 */
{ 70816 }, /* inst_from_l2_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L2 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from L2\000\000\000\000\000 */
{ 70946 }, /* inst_from_l2_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L2 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from L2 per Inst\000\000\000\000\000 */
{ 71091 }, /* inst_from_l31_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L31_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L3, other core\000\000\000\000\000 */
{ 71251 }, /* inst_from_l31_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L3, other core per Inst\000\000\000\000\000 */
{ 71426 }, /* inst_from_l31_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L31_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Private L3, other core\000\000\000\000\000 */
{ 71586 }, /* inst_from_l31_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Private L3 other core per Inst\000\000\000\000\000 */
{ 71760 }, /* inst_from_l3_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_L3 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from L3\000\000\000\000\000 */
{ 71890 }, /* inst_from_l3_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_L3 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from L3 per Inst\000\000\000\000\000 */
{ 72035 }, /* inst_from_ll4_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_LL4 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Local L4\000\000\000\000\000 */
{ 72173 }, /* inst_from_ll4_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Local L4 per Inst\000\000\000\000\000 */
{ 72326 }, /* inst_from_lmem_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_LMEM * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Local Memory\000\000\000\000\000 */
{ 72470 }, /* inst_from_lmem_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Local Memory per Inst\000\000\000\000\000 */
{ 72629 }, /* inst_from_rl2l3_mod_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote L2 or L3 (Modified)\000\000\000\000\000 */
{ 72797 }, /* inst_from_rl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote L2 or L3 (Modified) per Inst\000\000\000\000\000 */
{ 72980 }, /* inst_from_rl2l3_shr_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote L2 or L3 (Shared)\000\000\000\000\000 */
{ 73146 }, /* inst_from_rl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote L2 or L3 (Shared) per Inst\000\000\000\000\000 */
{ 73327 }, /* inst_from_rl4_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RL4 * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote L4\000\000\000\000\000 */
{ 73466 }, /* inst_from_rl4_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote L4 per Inst\000\000\000\000\000 */
{ 73620 }, /* inst_from_rmem_percent\000instruction_stats_percent_per_ref\000\000PM_INST_FROM_RMEM * 100 / PM_L1_ICACHE_MISS\000% of ICache reloads from Remote Memory\000\000\000\000\000 */
{ 73765 }, /* inst_from_rmem_rate_percent\000instruction_misses_percent_per_inst\000\000PM_INST_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000% of ICache reloads from Remote Memory per Inst\000\000\000\000\000 */
{ 74009 }, /* ipc\000general\000\000PM_INST_CMPL / PM_CYC\000Instructions per cycles\000\000\000\000\000 */
{ 74072 }, /* ipteg_from_l2_rate_percent\000\000\000PM_IPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from L2\000\000\000\000\000 */
{ 74177 }, /* ipteg_from_l3_rate_percent\000\000\000PM_IPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from L3\000\000\000\000\000 */
{ 74282 }, /* ipteg_from_ll4_rate_percent\000\000\000PM_IPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from local memory\000\000\000\000\000 */
{ 74399 }, /* ipteg_from_lmem_rate_percent\000\000\000PM_IPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000Rate of IERAT reloads from local memory\000\000\000\000\000 */
{ 74518 }, /* islb_miss_rate_percent\000translation\000\000PM_ISLB_MISS * 100 / PM_RUN_INST_CMPL\000% ISLB miss rate per inst\000\000\000\000\000 */
{ 74738 }, /* itlb_miss_rate_percent\000general\000\000PM_ITLB_MISS / PM_RUN_INST_CMPL * 100\000% ITLB miss rate per inst\000\000\000\000\000 */
{ 74838 }, /* l1_inst_miss_rate_percent\000instruction_misses_percent_per_inst\000\000PM_L1_ICACHE_MISS * 100 / PM_RUN_INST_CMPL\000Instruction Cache Miss Rate (Per run Instruction)(%)\000\000\000\000\000 */
{ 75102 }, /* l1_ld_miss_rate_percent\000dl1_reloads_percent_per_inst\000\000PM_LD_MISS_L1 * 100 / PM_RUN_INST_CMPL\000Percentage of L1 demand load misses per run instruction\000\000\000\000\000 */
{ 75350 }, /* l1_ld_miss_ratio_percent\000general\000\000PM_LD_MISS_L1 / PM_LD_REF_L1 * 100\000Percentage of L1 load misses per L1 load ref\000\000\000\000\000 */
{ 75574 }, /* l1_prefetch_rate_percent\000prefetch\000\000PM_L1_PREF / PM_RUN_INST_CMPL * 100\000L1 Prefetches issued by the prefetch machine per instruction (per thread)\000\000\000\000\000 */
{ 75723 }, /* l1_st_miss_rate_percent\000general\000\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000Percentage of L1 store misses per run instruction\000\000\000\000\000 */
{ 75960 }, /* l1_st_miss_ratio_percent\000general\000\000PM_ST_MISS_L1 / PM_ST_FIN * 100\000Percentage of L1 store misses per L1 store ref\000\000\000\000\000 */
{ 76077 }, /* l21_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L21_MOD * PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl21 MOD miss rates with measured L21 MOD latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 76728 }, /* l21_mod_latency\000latency\000\000PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD\000Marked L21 Load latency\000\000\000\000\000 */
{ 76837 }, /* l21_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L21_SHR * PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl21 SHR miss rates with measured L21 SHR latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 77488 }, /* l21_shr_latency\000latency\000\000PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR\000Marked L21 Load latency\000\000\000\000\000 */
{ 78221 }, /* l2_co_usage\000\000\000PM_CO_USAGE / PM_RUN_CYC * 16\000Average number of Castout machines used. 1 of 16 CO machines is sampled every L2 cycle\000\000\000\000\000 */
{ 78356 }, /* l2_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L2 * PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2 / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2 miss rates with measured L2 latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 78783 }, /* l2_dem_ld_disp_percent\000l2_stats\000\000PM_L1_DCACHE_RELOAD_VALID / (PM_L2_LD / 2) * 100\000Demand load misses as a % of L2 LD dispatches (per thread)\000\000\000\000\000 */
{ 79485 }, /* l2_inst_miss_rate_percent\000general\000\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000 */
{ 79615 }, /* l2_instr_commands_percent\000\000\000PM_ISIDE_DISP * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000Percent of instruction reads out of all L2 commands\000\000\000\000\000 */
{ 79900 }, /* l2_latency\000latency\000\000PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2\000Marked L2 Load latency\000\000\000\000\000 */
{ 79993 }, /* l2_ld_commands_percent\000\000\000PM_L2_LD * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000Percent of loads out of all L2 commands\000\000\000\000\000 */
{ 80343 }, /* l2_ld_miss_rate_percent\000general\000\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 dmand Load Miss Rate (per run instruction)(%)\000\000\000\000\000 */
{ 81517 }, /* l2_pteg_miss_rate_percent\000general\000\000PM_DPTEG_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000L2 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000 */
{ 81645 }, /* l2_rc_st_disp_fail_rate_percent\000\000\000l2_st_disp_fail_rate_percent\000Rate of L2 store dispatches that failed per core\000\000\000\000\000 */
{ 81900 }, /* l2_rc_usage\000\000\000PM_RC_USAGE / PM_RUN_CYC * 16\000Average number of Read/Claim machines used. 1 of 16 RC machines is sampled every L2 cycle\000\000\000\000\000 */
{ 82170 }, /* l2_sn_usage\000\000\000PM_SN_USAGE / PM_RUN_CYC * 8\000Average number of Snoop machines used. 1 of 8 SN machines is sampled every L2 cycle\000\000\000\000\000 */
{ 82301 }, /* l2_st_commands_percent\000\000\000PM_L2_ST * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000Percent of stores out of all L2 commands\000\000\000\000\000 */
{ 82426 }, /* l2_st_disp_fail_rate_percent\000\000\000100 * (PM_L2_RCST_DISP_FAIL_ADDR + PM_L2_RCST_DISP_FAIL_OTHER) / 2 / PM_RUN_INST_CMPL\000Rate of L2 store dispatches that failed per core\000\000\000\000\000 */
{ 82596 }, /* l2_st_disp_rate_percent\000\000\000100 * PM_L2_RCST_DISP / 2 / PM_RUN_INST_CMPL\000Rate of L2 dispatches per core\000\000\000\000\000 */
{ 82966 }, /* l2_st_miss_ratio_percent\000l2_stats\000\000PM_L2_ST_MISS / PM_L2_ST * 100\000L2 Store misses as a % of total L2 Store dispatches (per thread)\000\000\000\000\000 */
{ 83101 }, /* l2_st_wr_util\000l2_stats\000\000PM_L2_ST_DISP / 2 * 4 / PM_RUN_CYC * 100\000L2 stores that require a cache write (4 pclks per disp attempt) % of pclks\000\000\000\000\000 */
{ 83616 }, /* l31_latency\000\000\000(PM_MRK_DATA_FROM_L31_SHR_CYC + PM_MRK_DATA_FROM_L31_MOD_CYC) / (PM_MRK_DATA_FROM_L31_SHR + PM_MRK_DATA_FROM_L31_MOD)\000Marked L31 Load latency\000\000\000\000\000 */
{ 83776 }, /* l31_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L31_MOD * PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl31 MOD miss rates with measured L31 MOD latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 84258 }, /* l31_mod_latency\000latency\000\000PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD\000Marked L31 Load latency\000\000\000\000\000 */
{ 84367 }, /* l31_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L31_SHR * PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl31 SHR miss rates with measured L31 SHR latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 84849 }, /* l31_shr_latency\000latency\000\000PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR\000Marked L31 Load latency\000\000\000\000\000 */
{ 85712 }, /* l3_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_L3 * PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3 / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl3 miss rates with measured L3 latency as a % of dcache miss cpi\000\000\000\000\000 */
{ 86141 }, /* l3_inst_miss_rate_percent\000general\000\000PM_INST_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000L3 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000 */
{ 86412 }, /* l3_latency\000latency\000\000PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3\000Marked L3 Load latency\000\000\000\000\000 */
{ 86599 }, /* l3_ld_miss_rate_percent\000general\000\000PM_DATA_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000L3 demand Load Miss Rate (per run instruction)(%)\000\000\000\000\000 */
{ 87181 }, /* l3_pteg_miss_rate_percent\000general\000\000PM_DPTEG_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000L3 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000 */
{ 87993 }, /* l4_locality\000memory\000\000PM_DATA_FROM_LL4 * 100 / (PM_DATA_FROM_LL4 + PM_DATA_FROM_RL4 + PM_DATA_FROM_DL4)\000L4 locality(%)\000\000\000\000\000 */
{ 88114 }, /* larx_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LARX / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a larx waiting to be satisfied\000\000\000\000\000 */
{ 88263 }, /* ld_ll4_per_ld_dmem\000memory\000\000PM_DATA_FROM_LL4 / PM_DATA_FROM_DL4\000Ratio of reloads from local L4 to distant L4\000\000\000\000\000 */
{ 88375 }, /* ld_ll4_per_ld_mem\000memory\000\000PM_DATA_FROM_LL4 / (PM_DATA_FROM_DL4 + PM_DATA_FROM_RL4)\000Ratio of reloads from local L4 to remote+distant L4\000\000\000\000\000 */
{ 88514 }, /* ld_ll4_per_ld_rl4\000memory\000\000PM_DATA_FROM_LL4 / PM_DATA_FROM_RL4\000Ratio of reloads from local L4 to remote L4\000\000\000\000\000 */
{ 88624 }, /* ld_lmem_per_ld_dmem\000memory\000\000PM_DATA_FROM_LMEM / PM_DATA_FROM_DMEM\000Number of loads from local memory per loads from distant memory\000\000\000\000\000 */
{ 88758 }, /* ld_lmem_per_ld_mem\000memory\000\000PM_DATA_FROM_LMEM / (PM_DATA_FROM_DMEM + PM_DATA_FROM_RMEM)\000Number of loads from local memory per loads from remote and distant memory\000\000\000\000\000 */
{ 88924 }, /* ld_lmem_per_ld_rmem\000memory\000\000PM_DATA_FROM_LMEM / PM_DATA_FROM_RMEM\000Number of loads from local memory per loads from remote memory\000\000\000\000\000 */
{ 89057 }, /* ld_rmem_per_ld_dmem\000memory\000\000PM_DATA_FROM_RMEM / PM_DATA_FROM_DMEM\000Number of loads from remote memory per loads from distant memory\000\000\000\000\000 */
{ 89192 }, /* lhs_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_LHS * 100 / PM_RUN_INST_CMPL\000LHS reject ratio\000\000\000\000\000 */
{ 89407 }, /* lhs_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LHS / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load that hit on an older store and it was waiting for store data\000\000\000\000\000 */
{ 89805 }, /* ll4_latency\000latency\000\000PM_MRK_DATA_FROM_LL4_CYC / PM_MRK_DATA_FROM_LL4\000Local L4 average load latency\000\000\000\000\000 */
{ 90023 }, /* lmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_LMEM * PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of Local memory miss rates with measured LMEM latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 90486 }, /* lmem_latency\000latency\000\000PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM\000Marked Lmem Load latency\000\000\000\000\000 */
{ 90703 }, /* lmq_full_reject_rate_percent\000lsu_rejects\000\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_RUN_INST_CMPL\000ERAT miss reject ratio\000\000\000\000\000 */
{ 90936 }, /* lmq_full_reject_ratio_percent\000lsu_rejects\000\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_LD_REF_L1\000ERAT miss reject ratio\000\000\000\000\000 */
{ 91050 }, /* lmq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LMQ_FULL / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load that missed in the L1 and the LMQ was unable to accept this load miss request because it was full\000\000\000\000\000 */
{ 91281 }, /* load_finish_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load instruction with all its dependencies satisfied just going through the LSU pipe to finish\000\000\000\000\000 */
{ 91510 }, /* loads_per_inst\000\000\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000PCT instruction loads\000\000\000\000\000 */
{ 91827 }, /* lrq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LRQ_FULL / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load that was held in LSAQ because the LRQ was full\000\000\000\000\000 */
{ 92007 }, /* lrq_other_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LRQ_OTHER / PM_RUN_INST_CMPL\000Finish stall due to LRQ miscellaneous reasons, lost arbitration to LMQ slot, bank collisions, set prediction cleanup, set prediction multihit and others\000\000\000\000\000 */
{ 92392 }, /* lsaq_arb_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSAQ_ARB / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a load or store that was held in LSAQ because an older instruction from SRQ or LRQ won arbitration to the LSU pipe when this instruction tried to launch\000\000\000\000\000 */
{ 92916 }, /* lstack_mispredict_rate_percent\000branch_prediction\000\000PM_BR_MPRED_LSTACK / PM_RUN_INST_CMPL * 100\000Link stack branch misprediction\000\000\000\000\000 */
{ 93295 }, /* lstack_misprediction_percent\000branch_prediction\000\000PM_BR_MPRED_LSTACK / PM_BR_PRED_LSTACK * 100\000Link stack branch misprediction\000\000\000\000\000 */
{ 93424 }, /* lsu_fin_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU_FIN / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was an LSU op (other than a load or a store) with all its dependencies met and just going through the LSU pipe to finish\000\000\000\000\000 */
{ 93665 }, /* lsu_flush_next_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU_FLUSH_NEXT / PM_RUN_INST_CMPL\000Completion stall of one cycle because the LSU requested to flush the next iop in the sequence. It takes 1 cycle for the ISU to process this request before the LSU instruction is allowed to complete\000\000\000\000\000 */
{ 93956 }, /* lsu_mfspr_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU_MFSPR / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a mfspr instruction targeting an LSU SPR and it was waiting for the register data to be returned\000\000\000\000\000 */
{ 94181 }, /* lsu_other_stall_cpi\000cpi_breakdown\000\000lsu_stall_cpi - lsu_fin_stall_cpi - store_finish_stall_cpi - srq_stall_cpi - load_finish_stall_cpi + lsu_stall_dcache_miss_cpi - lrq_stall_cpi + emq_stall_cpi - lsaq_stall_cpi\000Completion LSU stall for other reasons\000\000\000\000\000 */
{ 94850 }, /* lsu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL\000Completion stall by LSU instruction\000\000\000\000\000 */
{ 95050 }, /* lsu_stall_dcache_miss_cpi\000\000\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000Cycles stalled by D-Cache Misses\000\000\000\000\000 */
{ 99049 }, /* mem_locality_percent\000memory\000\000PM_DATA_FROM_LMEM * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_RMEM + PM_DATA_FROM_DMEM)\000Memory locality\000\000\000\000\000 */
{ 99184 }, /* mtfpscr_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_MTFPSCR / PM_RUN_INST_CMPL\000Completion stall because the ISU is updating the register and notifying the Effective Address Table (EAT)\000\000\000\000\000 */
{ 99369 }, /* nested_tbegin_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NESTED_TBEGIN / PM_RUN_INST_CMPL\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tbegin. This is a short delay, and it includes ROT\000\000\000\000\000 */
{ 99595 }, /* nested_tend_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NESTED_TEND / PM_RUN_INST_CMPL\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tend and decrement the TEXASR nested level. This is a short delay\000\000\000\000\000 */
{ 99957 }, /* nothing_dispatched_cpi\000cpi_breakdown\000\000PM_ICT_NOSLOT_CYC / PM_RUN_INST_CMPL\000Number of cycles the Instruction Completion Table has no itags assigned to this thread\000\000\000\000\000 */
{ 100123 }, /* ntc_disp_fin_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NTC_DISP_FIN / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was one that must finish at dispatch\000\000\000\000\000 */
{ 100290 }, /* ntc_fin_cpi\000cpi_breakdown\000\000PM_NTC_FIN / PM_RUN_INST_CMPL\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. This event is used to account for cycles in which work is being completed in the CPI stack\000\000\000\000\000 */
{ 100513 }, /* ntc_flush_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_NTC_FLUSH / PM_RUN_INST_CMPL\000Completion stall due to ntc flush\000\000\000\000\000 */
{ 100630 }, /* ntc_issue_held_arb_cpi\000cpi_breakdown\000\000PM_NTC_ISSUE_HELD_ARB / PM_RUN_INST_CMPL\000The NTC instruction is being held at dispatch because it lost arbitration onto the issue pipe to another instruction (from the same thread or a different thread)\000\000\000\000\000 */
{ 100875 }, /* ntc_issue_held_darq_full_cpi\000cpi_breakdown\000\000PM_NTC_ISSUE_HELD_DARQ_FULL / PM_RUN_INST_CMPL\000The NTC instruction is being held at dispatch because there are no slots in the DARQ for it\000\000\000\000\000 */
{ 101062 }, /* ntc_issue_held_other_cpi\000cpi_breakdown\000\000PM_NTC_ISSUE_HELD_OTHER / PM_RUN_INST_CMPL\000The NTC instruction is being held at dispatch during regular pipeline cycles, or because the VSU is busy with multi-cycle instructions, or because of a write-back collision with VSU\000\000\000\000\000 */
{ 102440 }, /* other_cpi\000cpi_breakdown\000\000run_cpi - completion_cpi - thread_block_stall_cpi - stall_cpi - nothing_dispatched_cpi\000Cycles unaccounted for\000\000\000\000\000 */
{ 102906 }, /* other_stall_cpi\000cpi_breakdown\000\000stall_cpi - ntc_disp_fin_stall_cpi - ntc_flush_stall_cpi - lsu_stall_cpi - exec_unit_stall_cpi - bru_stall_cpi\000Completion stall for other reasons\000\000\000\000\000 */
{ 103087 }, /* other_thread_cmpl_stall\000\000\000thread_block_stall_cpi - exception_stall_cpi - any_sync_stall_cpi - sync_pmu_int_stall_cpi - spec_finish_stall_cpi - flush_any_thread_stall_cpi - lsu_flush_next_stall_cpi - nested_tbegin_stall_cpi - nested_tend_stall_cpi - mtfpscr_stall_cpi\000Completion stall because a different thread was using the completion pipe\000\000\000\000\000 */
{ 103432 }, /* paste_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_PASTE / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a paste waiting for response from L2\000\000\000\000\000 */
{ 401603 }, /* pm_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_PM / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was issued to the Permute execution pipe and waiting to finish\000\000\000\000\000 */
{ 426777 }, /* pteg_from_dl2l3_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant L2 or L3 (Modified)\000\000\000\000\000 */
{ 426936 }, /* pteg_from_dl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant L2 or L3 (Modified) per inst\000\000\000\000\000 */
{ 427114 }, /* pteg_from_dl2l3_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant L2 or L3 (Shared)\000\000\000\000\000 */
{ 427271 }, /* pteg_from_dl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant L2 or L3 (Shared) per inst\000\000\000\000\000 */
{ 427447 }, /* pteg_from_dl4_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DL4 * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant L4\000\000\000\000\000 */
{ 427577 }, /* pteg_from_dl4_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant L4 per inst\000\000\000\000\000 */
{ 427726 }, /* pteg_from_dmem_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_DMEM * 100 / PM_DTLB_MISS\000% of DERAT reloads from Distant Memory\000\000\000\000\000 */
{ 427862 }, /* pteg_from_dmem_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Distant Memory per inst\000\000\000\000\000 */
{ 428017 }, /* pteg_from_l21_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L21_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L2, other core\000\000\000\000\000 */
{ 428167 }, /* pteg_from_l21_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000 */
{ 428336 }, /* pteg_from_l21_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L21_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L2, other core\000\000\000\000\000 */
{ 428486 }, /* pteg_from_l21_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000 */
{ 428655 }, /* pteg_from_l2_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L2 * 100 / PM_DTLB_MISS\000% of DERAT reloads from L2\000\000\000\000\000 */
{ 428775 }, /* pteg_from_l2_rate_percent\000pteg_reloads_percent_per_inst\000\000dpteg_from_l2_rate_percent\000% of DERAT reloads from L2 per inst\000\000\000\000\000 */
{ 428899 }, /* pteg_from_l31_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L31_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L3, other core\000\000\000\000\000 */
{ 429049 }, /* pteg_from_l31_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000 */
{ 429218 }, /* pteg_from_l31_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L31_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Private L3, other core\000\000\000\000\000 */
{ 429368 }, /* pteg_from_l31_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000 */
{ 429537 }, /* pteg_from_l3_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_L3 * 100 / PM_DTLB_MISS\000% of DERAT reloads from L3\000\000\000\000\000 */
{ 429657 }, /* pteg_from_l3_rate_percent\000pteg_reloads_percent_per_inst\000\000dpteg_from_l3_rate_percent\000% of DERAT reloads from L3 per inst\000\000\000\000\000 */
{ 429781 }, /* pteg_from_ll4_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_LL4 * 100 / PM_DTLB_MISS\000% of DERAT reloads from Local L4\000\000\000\000\000 */
{ 429909 }, /* pteg_from_ll4_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Local L4 per inst\000\000\000\000\000 */
{ 430056 }, /* pteg_from_lmem_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_LMEM * 100 / PM_DTLB_MISS\000% of DERAT reloads from Local Memory\000\000\000\000\000 */
{ 430190 }, /* pteg_from_lmem_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Local Memory per inst\000\000\000\000\000 */
{ 430343 }, /* pteg_from_rl2l3_mod_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote L2 or L3 (Modified)\000\000\000\000\000 */
{ 430501 }, /* pteg_from_rl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote L2 or L3 (Modified) per inst\000\000\000\000\000 */
{ 430678 }, /* pteg_from_rl2l3_shr_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote L2 or L3 (Shared)\000\000\000\000\000 */
{ 430834 }, /* pteg_from_rl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote L2 or L3 (Shared) per inst\000\000\000\000\000 */
{ 431009 }, /* pteg_from_rl4_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RL4 * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote L4\000\000\000\000\000 */
{ 431138 }, /* pteg_from_rl4_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote L4 per inst\000\000\000\000\000 */
{ 431286 }, /* pteg_from_rmem_percent\000pteg_reloads_percent_per_ref\000\000PM_DPTEG_FROM_RMEM * 100 / PM_DTLB_MISS\000% of DERAT reloads from Remote Memory\000\000\000\000\000 */
{ 431421 }, /* pteg_from_rmem_rate_percent\000pteg_reloads_percent_per_inst\000\000PM_DPTEG_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000% of DERAT reloads from Remote Memory per inst\000\000\000\000\000 */
{ 431921 }, /* rl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL2L3_MOD * PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2l3 remote MOD miss rates with measured RL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 432437 }, /* rl2l3_mod_latency\000latency\000\000PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD\000Marked L2L3 remote Load latency\000\000\000\000\000 */
{ 432740 }, /* rl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL2L3_SHR * PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of dl2l3 shared miss rates with measured RL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 433248 }, /* rl2l3_shr_latency\000latency\000\000PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR\000Marked L2L3 remote Load latency\000\000\000\000\000 */
{ 433539 }, /* rl4_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RL4 * PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4 / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of remote L4 miss rates with measured RL4 latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 433987 }, /* rl4_latency\000latency\000\000PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4\000Remote L4 average load latency\000\000\000\000\000 */
{ 434207 }, /* rmem_cpi_percent\000estimated_dcache_miss_cpi\000\000PM_DATA_FROM_RMEM * PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000estimate of remote memory miss rates with measured RMEM latency as a %of dcache miss cpi\000\000\000\000\000 */
{ 434672 }, /* rmem_latency\000latency\000\000PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM\000Marked Rmem Load latency\000\000\000\000\000 */
{ 434978 }, /* run_cpi\000cpi_breakdown\000\000run_cyc_cpi\000Run cycles per run instruction\000\000\000\000\000 */
{ 435048 }, /* run_cyc_cpi\000cpi_breakdown\000\000PM_RUN_CYC / PM_RUN_INST_CMPL\000Run_cycles\000\000\000\000\000 */
{ 435120 }, /* run_cycles_percent\000general\000\000PM_RUN_CYC / PM_CYC * 100\000Run cycles per cycle\000\000\000\000\000 */
{ 435577 }, /* slb_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SLB / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was awaiting L2 response for an SLB\000\000\000\000\000 */
{ 436371 }, /* spec_finish_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SPEC_FINISH / PM_RUN_INST_CMPL\000Finish stall while waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000\000\000\000\000 */
{ 436615 }, /* speculation\000general\000\000PM_INST_DISP / PM_INST_CMPL\000Instruction dispatch-to-completion ratio\000\000\000\000\000 */
{ 436709 }, /* srq_full_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_SRQ_FULL / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a store that was held in LSAQ because the SRQ was full\000\000\000\000\000 */
{ 437220 }, /* st_fwd_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000Completion stall due to store forward\000\000\000\000\000 */
{ 437422 }, /* stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL / PM_RUN_INST_CMPL\000Nothing completed and Instruction Completion Table not empty\000\000\000\000\000 */
{ 437546 }, /* stcx_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STCX / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a stcx waiting for response from L2\000\000\000\000\000 */
{ 437700 }, /* store_data_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE_DATA / PM_RUN_INST_CMPL\000Finish stall because the next to finish instruction was a store waiting on data\000\000\000\000\000 */
{ 437865 }, /* store_fin_arb_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE_FIN_ARB / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a store waiting for a slot in the store finish pipe. This means the instruction is ready to finish but there are instructions ahead of it, using the finish pipe\000\000\000\000\000 */
{ 438162 }, /* store_finish_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE_FINISH / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a store with all its dependencies met, just waiting to go through the LSU pipe to finish\000\000\000\000\000 */
{ 438805 }, /* store_pipe_arb_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_STORE_PIPE_ARB / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a store waiting for the next relaunch opportunity after an internal reject. This means the instruction is ready to relaunch and tried once but lost arbitration\000\000\000\000\000 */
{ 439103 }, /* stores_per_inst\000\000\000PM_ST_FIN / PM_RUN_INST_CMPL\000PCT instruction stores\000\000\000\000\000 */
{ 439266 }, /* sync_pmu_int_stall_cpi\000\000\000PM_CMPLU_STALL_SYNC_PMU_INT / PM_RUN_INST_CMPL\000ANY_SYNC_STALL_CPI\000\000\000\000\000 */
{ 440277 }, /* taken_branches_percent\000branch_prediction\000\000PM_BR_TAKEN_CMPL * 100 / PM_BRU_FIN\000% Branches Taken\000\000\000\000\000 */
{ 440504 }, /* tend_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_TEND / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a tend instruction awaiting response from L2\000\000\000\000\000 */
{ 440667 }, /* thread_block_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL\000Completion Stalled because the thread was blocked\000\000\000\000\000 */
{ 440907 }, /* tlbie_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_TLBIE / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a tlbie waiting for response from L2\000\000\000\000\000 */
{ 441835 }, /* vdp_other_stall_cpi\000cpi_breakdown\000\000vdp_stall_cpi - vdplong_stall_cpi\000Vector stalls due to small latency double precision ops\000\000\000\000\000 */
{ 441964 }, /* vdp_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VDP / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a vector instruction issued to the Double Precision execution pipe and waiting to finish\000\000\000\000\000 */
{ 442169 }, /* vdplong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VDPLONG / PM_RUN_INST_CMPL\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000 */
{ 442553 }, /* vfxlong_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VFXLONG / PM_RUN_INST_CMPL\000Completion stall due to a long latency vector fixed point instruction (division, square root)\000\000\000\000\000 */
{ 442726 }, /* vfxu_other_stall_cpi\000cpi_breakdown\000\000vfxu_stall_cpi - vfxlong_stall_cpi\000Vector stalls due to small latency integer ops\000\000\000\000\000 */
{ 442848 }, /* vfxu_stall_cpi\000cpi_breakdown\000\000PM_CMPLU_STALL_VFXU / PM_RUN_INST_CMPL\000Finish stall due to a vector fixed point instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__power10[] = {
{ 111387 }, /* pm_br_mpred_cmpl\000\000cache\000A mispredicted branch completed. Includes direction and target\000event=0x400f6\000\000\000\000\000\000\000 */
{ 202961 }, /* pm_exec_stall_dmiss_l21_l31\000\000cache\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from another core's L2 or L3 on the same chip\000event=0x1e054\000\000\000\000\000\000\000 */
{ 203156 }, /* pm_exec_stall_dmiss_l2l3\000\000cache\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from either the local L2 or local L3\000event=0x1003c\000\000\000\000\000\000\000 */
{ 203339 }, /* pm_exec_stall_dmiss_l2l3_conflict\000\000cache\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local L2 or local L3, with a dispatch conflict\000event=0x4c016\000\000\000\000\000\000\000 */
{ 203550 }, /* pm_exec_stall_dmiss_l2l3_noconflict\000\000cache\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local L2 or local L3, without a dispatch conflict\000event=0x34054\000\000\000\000\000\000\000 */
{ 204706 }, /* pm_exec_stall_load\000\000cache\000Cycles in which the oldest instruction in the pipeline was a load instruction executing in the Load Store Unit\000event=0x4d014\000\000\000\000\000\000\000 */
{ 204863 }, /* pm_exec_stall_load_finish\000\000cache\000Cycles in which the oldest instruction in the pipeline was finishing a load after its data was reloaded from a data source beyond the local L1; cycles in which the LSU was processing an L1-hit; cycles in which the NTF instruction merged with another load in the LMQ; cycles in which the NTF instruction is waiting for a data reload for a load miss, but the data comes back with a non-NTF instruction\000event=0x34056\000\000\000\000\000\000\000 */
{ 206049 }, /* pm_exec_stall_ptesync\000\000cache\000Cycles in which the oldest instruction in the pipeline was a PTESYNC instruction executing in the Load Store Unit\000event=0x4d016\000\000\000\000\000\000\000 */
{ 395497 }, /* pm_run_cyc_smt2_mode\000\000cache\000Cycles when this thread's run latch is set and the core is in SMT2 mode\000event=0x3006c\000\000\000\000\000\000\000 */
{ 397037 }, /* pm_run_inst_cmpl_conc\000\000cache\000PowerPC instructions completed by this thread when all threads in the core had the run-latch set\000event=0x300f4\000\000\000\000\000\000\000 */
{ 410379 }, /* pm_thresh_exc_128\000\000cache\000Threshold counter exceeded a value of 128\000event=0x401ea\000\000\000\000\000\000\000 */
{ 412065 }, /* pm_thresh_not_met\000\000floating_point\000Threshold counter did not meet threshold\000event=0x4016e\000\000\000\000\000\000\000 */
{ 104074 }, /* pm_1plus_ppc_cmpl\000\000frontend\000Cycles in which at least one instruction is completed by this thread\000event=0x100f2\000\000\000\000\000\000\000 */
{ 116618 }, /* pm_br_taken_cmpl\000\000frontend\000Branch Taken instruction completed\000event=0x200fa\000\000\000\000\000\000\000 */
{ 180121 }, /* pm_disp_stall_br_mpred\000\000frontend\000Cycles when dispatch was stalled for this thread due to a mispredicted branch\000event=0x4d01e\000\000\000\000\000\000\000 */
{ 180252 }, /* pm_disp_stall_br_mpred_ic_l2\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from the local L2 after suffering a branch mispredict\000event=0x1003a\000\000\000\000\000\000\000 */
{ 180432 }, /* pm_disp_stall_br_mpred_ic_l3\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from the local L3 after suffering a branch mispredict\000event=0x2c01e\000\000\000\000\000\000\000 */
{ 180612 }, /* pm_disp_stall_br_mpred_ic_l3miss\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from sources beyond the local L3 after suffering a mispredicted branch\000event=0x4c010\000\000\000\000\000\000\000 */
{ 180813 }, /* pm_disp_stall_br_mpred_icmiss\000\000frontend\000Cycles when dispatch was stalled after a mispredicted branch resulted in an instruction cache miss\000event=0x34058\000\000\000\000\000\000\000 */
{ 180972 }, /* pm_disp_stall_cyc\000\000frontend\000Cycles the ICT has no itags assigned to this thread (no instructions were dispatched during these cycles)\000event=0x100f8\000\000\000\000\000\000\000 */
{ 181126 }, /* pm_disp_stall_fetch\000\000frontend\000Cycles when dispatch was stalled for this thread because Fetch was being held\000event=0x2e018\000\000\000\000\000\000\000 */
{ 181254 }, /* pm_disp_stall_flush\000\000frontend\000Cycles when dispatch was stalled because of a flush that happened to an instruction(s) that was not yet NTC. PM_EXEC_STALL_NTC_FLUSH only includes instructions that were flushed after becoming NTC\000event=0x30004\000\000\000\000\000\000\000 */
{ 181501 }, /* pm_disp_stall_held_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch for any reason\000event=0x4e01a\000\000\000\000\000\000\000 */
{ 181625 }, /* pm_disp_stall_held_halt_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because of power management\000event=0x1d05e\000\000\000\000\000\000\000 */
{ 181767 }, /* pm_disp_stall_held_issq_full_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch due to Issue queue full. Includes issue queue and branch queue\000event=0x20006\000\000\000\000\000\000\000 */
{ 181949 }, /* pm_disp_stall_held_other_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch for any other reason\000event=0x10006\000\000\000\000\000\000\000 */
{ 182085 }, /* pm_disp_stall_held_rename_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because the mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR and XVFC\000event=0x3d05c\000\000\000\000\000\000\000 */
{ 182290 }, /* pm_disp_stall_held_scoreboard_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch while waiting on the Scoreboard. This event combines VSCR and FPSCR together\000event=0x30018\000\000\000\000\000\000\000 */
{ 182487 }, /* pm_disp_stall_held_stf_mapper_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because the STF mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR\000event=0x1e050\000\000\000\000\000\000\000 */
{ 182691 }, /* pm_disp_stall_held_sync_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because of a synchronizing instruction that requires the ICT to be empty before dispatch\000event=0x4003c\000\000\000\000\000\000\000 */
{ 182894 }, /* pm_disp_stall_held_xvfc_mapper_cyc\000\000frontend\000Cycles in which the NTC instruction is held at dispatch because the XVFC mapper/SRB was full\000event=0x2e01a\000\000\000\000\000\000\000 */
{ 183052 }, /* pm_disp_stall_ic_l2\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from the local L2\000event=0x10064\000\000\000\000\000\000\000 */
{ 183187 }, /* pm_disp_stall_ic_l3\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from the local L3\000event=0x3e052\000\000\000\000\000\000\000 */
{ 183322 }, /* pm_disp_stall_ic_l3miss\000\000frontend\000Cycles when dispatch was stalled while the instruction was fetched from any source beyond the local L3\000event=0x4e010\000\000\000\000\000\000\000 */
{ 183479 }, /* pm_disp_stall_ic_miss\000\000frontend\000Cycles when dispatch was stalled for this thread due to an Icache Miss\000event=0x2d01a\000\000\000\000\000\000\000 */
{ 183602 }, /* pm_disp_stall_ierat_only_miss\000\000frontend\000Cycles when dispatch was stalled while waiting to resolve an instruction ERAT miss\000event=0x2c016\000\000\000\000\000\000\000 */
{ 183745 }, /* pm_disp_stall_itlb_miss\000\000frontend\000Cycles when dispatch was stalled while waiting to resolve an instruction TLB miss\000event=0x3000a\000\000\000\000\000\000\000 */
{ 183881 }, /* pm_disp_stall_translation\000\000frontend\000Cycles when dispatch was stalled for this thread because the MMU was handling a translation miss\000event=0x10038\000\000\000\000\000\000\000 */
{ 198820 }, /* pm_dtlb_hit\000\000frontend\000The PTE required by the instruction was resident in the TLB (data TLB access). When MMCR1[16]=0 this event counts only demand hits. When MMCR1[16]=1 this event includes demand and prefetch. Applies to both HPT and RPT\000event=0x1f054\000\000\000\000\000\000\000 */
{ 205316 }, /* pm_exec_stall_lsu\000\000frontend\000Cycles in which the oldest instruction in the pipeline was executing in the Load Store Unit. This does not include simple fixed point instructions\000event=0x2c010\000\000\000\000\000\000\000 */
{ 206391 }, /* pm_exec_stall_store\000\000frontend\000Cycles in which the oldest instruction in the pipeline was a store instruction executing in the Load Store Unit\000event=0x30014\000\000\000\000\000\000\000 */
{ 206553 }, /* pm_exec_stall_store_miss\000\000frontend\000Cycles in which the oldest instruction in the pipeline was a store whose cache line was not resident in the L1 and was waiting for allocation of the missing line into the L1\000event=0x30026\000\000\000\000\000\000\000 */
{ 207457 }, /* pm_exec_stall_translation\000\000frontend\000Cycles in which the oldest instruction in the pipeline suffered a TLB miss or ERAT miss and waited for it to resolve\000event=0x10004\000\000\000\000\000\000\000 */
{ 208968 }, /* pm_flush_completion\000\000frontend\000The instruction that was next to complete (oldest in the pipeline) did not complete because it suffered a flush\000event=0x30012\000\000\000\000\000\000\000 */
{ 223505 }, /* pm_ierat_miss\000\000frontend\000IERAT Reloaded to satisfy an IERAT miss. All page sizes are counted by this event\000event=0x100f6\000\000\000\000\000\000\000 */
{ 252567 }, /* pm_inst_from_l3miss\000\000frontend\000The processor's instruction cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss\000event=0x300fa\000\000\000\000\000\000\000 */
{ 262990 }, /* pm_iops_disp\000\000frontend\000Internal Operations dispatched. PM_IOPS_DISP / PM_INST_DISP will show the average number of internal operations per PowerPC instruction\000event=0x24050\000\000\000\000\000\000\000 */
{ 275036 }, /* pm_issue_cancel\000\000frontend\000An instruction issued and the issue was later cancelled. Only one cancel per PowerPC instruction\000event=0x2405e\000\000\000\000\000\000\000 */
{ 275179 }, /* pm_issue_kill\000\000frontend\000Cycles in which an instruction or group of instructions were cancelled after being issued. This event increments once per occurrence, regardless of how many instructions are included in the issue group\000event=0x40006\000\000\000\000\000\000\000 */
{ 277189 }, /* pm_itlb_hit_1g\000\000frontend\000Instruction TLB hit (IERAT reload) page size 1G, which implies Radix Page Table translation is in use. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x3f046\000\000\000\000\000\000\000 */
{ 295387 }, /* pm_ld_miss_l1\000\000frontend\000Load Missed L1, counted at execution time (can be greater than loads finished). LMQ merges are not included in this count. i.e. if a load instruction misses on an address that is already allocated on the LMQ, this event will not increment for that load). Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x3e054\000\000\000\000\000\000\000 */
{ 370924 }, /* pm_mrk_l2_rc_disp\000\000frontend\000Marked instruction RC dispatched in L2\000event=0x20114\000\000\000\000\000\000\000 */
{ 371096 }, /* pm_mrk_l2_rc_done\000\000frontend\000L2 RC machine completed the transaction for the marked instruction\000event=0x3012a\000\000\000\000\000\000\000 */
{ 371457 }, /* pm_mrk_larx_fin\000\000frontend\000Marked load and reserve instruction (LARX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x40116\000\000\000\000\000\000\000 */
{ 380127 }, /* pm_mrk_xfer_from_src_pmc2\000\000frontend\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[15:27]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x2c142\000\000\000\000\000\000\000 */
{ 386357 }, /* pm_pmc4_overflow\000\000frontend\000The event selected for PMC4 caused the event counter to overflow\000event=0x10010\000\000\000\000\000\000\000 */
{ 386598 }, /* pm_pmc4_rewind\000\000frontend\000The speculative event selected for PMC4 rewinds and the counter for PMC4 is not charged\000event=0x10020\000\000\000\000\000\000\000 */
{ 410200 }, /* pm_thresh_exc_1024\000\000frontend\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\000\000\000\000\000\000 */
{ 410818 }, /* pm_thresh_exc_256\000\000frontend\000Threshold counter exceeded a count of 256\000event=0x101e8\000\000\000\000\000\000\000 */
{ 411786 }, /* pm_thresh_met\000\000frontend\000Threshold exceeded\000event=0x101ec\000\000\000\000\000\000\000 */
{ 418757 }, /* pm_vector_st_cmpl\000\000frontend\000Vector store instructions completed\000event=0x44056\000\000\000\000\000\000\000 */
{ 402113 }, /* pm_stcx_fail_fin\000\000locks\000Conditional store instruction (STCX) failed. LARX and STCX are instructions used to acquire a lock\000event=0x1e058\000\000\000\000\000\000\000 */
{ 402674 }, /* pm_stcx_pass_fin\000\000locks\000Conditional store instruction (STCX) passed. LARX and STCX are instructions used to acquire a lock\000event=0x4e050\000\000\000\000\000\000\000 */
{ 162668 }, /* pm_data_from_l3miss\000\000marked\000The processor's data cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss\000event=0x300fe\000\000\000\000\000\000\000 */
{ 164554 }, /* pm_data_from_memory\000\000marked\000The processor's data cache was reloaded from local, remote, or distant memory due to a demand miss\000event=0x400fe\000\000\000\000\000\000\000 */
{ 204180 }, /* pm_exec_stall_dmiss_off_chip\000\000marked\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a remote chip\000event=0x2c01c\000\000\000\000\000\000\000 */
{ 278355 }, /* pm_l1_icache_miss\000\000marked\000Demand iCache Miss\000event=0x200fd\000\000\000\000\000\000\000 */
{ 278589 }, /* pm_l1_icache_reloaded_all\000\000marked\000Counts all Icache reloads includes demand, prefetch, prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\000\000\000\000\000\000 */
{ 278888 }, /* pm_l1_icache_reloaded_pref\000\000marked\000Counts all Icache prefetch reloads ( includes demand turned into prefetch)\000event=0x30068\000\000\000\000\000\000\000 */
{ 294796 }, /* pm_ld_demand_miss_l1\000\000marked\000The L1 cache was reloaded with a line that fulfills a demand miss request. Counted at reload time, before finish\000event=0x300f6\000\000\000\000\000\000\000 */
{ 296014 }, /* pm_ld_prefetch_cache_line_miss\000\000marked\000The L1 cache was reloaded with a line that fulfills a prefetch request\000event=0x1002c\000\000\000\000\000\000\000 */
{ 327187 }, /* pm_mrk_br_cmpl\000\000marked\000A marked branch completed. All branches are included\000event=0x2415c\000\000\000\000\000\000\000 */
{ 327355 }, /* pm_mrk_br_mpred_cmpl\000\000marked\000Marked Branch Mispredicted. Includes direction and target\000event=0x301e4\000\000\000\000\000\000\000 */
{ 327617 }, /* pm_mrk_br_taken_cmpl\000\000marked\000Marked Branch Taken instruction completed\000event=0x101e2\000\000\000\000\000\000\000 */
{ 327708 }, /* pm_mrk_bru_fin\000\000marked\000Marked Branch instruction finished\000event=0x2013a\000\000\000\000\000\000\000 */
{ 367773 }, /* pm_mrk_inst\000\000marked\000An instruction was marked. Includes both Random Instruction Sampling (RIS) at decode time and Random Event Sampling (RES) at the time the configured event happens\000event=0x24158\000\000\000\000\000\000\000 */
{ 367976 }, /* pm_mrk_inst_cmpl\000\000marked\000marked instruction completed\000event=0x401e0\000\000\000\000\000\000\000 */
{ 368563 }, /* pm_mrk_inst_disp\000\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\000\000\000\000\000\000 */
{ 368672 }, /* pm_mrk_inst_fin\000\000marked\000marked instruction finished. Excludes instructions that finish at dispatch. Note that stores always finish twice since the address gets issued to the LSU and the data gets issued to the VSU\000event=0x30130\000\000\000\000\000\000\000 */
{ 369614 }, /* pm_mrk_inst_issued\000\000marked\000Marked instruction issued. Note that stores always get issued twice, the address gets issued to the LSU and the data gets issued to the VSU. Also, issues can sometimes get killed/cancelled and cause multiple sequential issues for the same instruction\000event=0x10132\000\000\000\000\000\000\000 */
{ 369985 }, /* pm_mrk_inst_timeo\000\000marked\000Marked instruction finish timeout (instruction was lost)\000event=0x40134\000\000\000\000\000\000\000 */
{ 371668 }, /* pm_mrk_ld_cmpl\000\000marked\000Marked loads completed\000event=0x34146\000\000\000\000\000\000\000 */
{ 374173 }, /* pm_mrk_ntf_fin\000\000marked\000The marked instruction became the oldest in the pipeline before it finished. It excludes instructions that finish at dispatch\000event=0x20112\000\000\000\000\000\000\000 */
{ 376008 }, /* pm_mrk_st_fin\000\000marked\000The marked instruction was a store of any kind\000event=0x3e15a\000\000\000\000\000\000\000 */
{ 376350 }, /* pm_mrk_st_nest\000\000marked\000A store has been sampled/marked and is at the point of execution where it has completed in the core and can no longer be flushed. At this point the store is sent to the L2\000event=0x20138\000\000\000\000\000\000\000 */
{ 377364 }, /* pm_mrk_stcx_fail\000\000marked\000Marked conditional store instruction (STCX) failed. LARX and STCX are instructions used to acquire a lock\000event=0x3e158\000\000\000\000\000\000\000 */
{ 377579 }, /* pm_mrk_stcx_fin\000\000marked\000Marked conditional store instruction (STCX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x24156\000\000\000\000\000\000\000 */
{ 379293 }, /* pm_mrk_xfer_from_src_cyc_pmc2\000\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[15:27]\000event=0x2c144\000\000\000\000\000\000\000 */
{ 381961 }, /* pm_non_math_flop_cmpl\000\000marked\000Non Math instructions completed\000event=0x4d05a\000\000\000\000\000\000\000 */
{ 400172 }, /* pm_sp_flop_cmpl\000\000marked\000Single Precision floating point instructions completed\000event=0x4505a\000\000\000\000\000\000\000 */
{ 418399 }, /* pm_vector_flop_cmpl\000\000marked\000Vector floating point instructions completed\000event=0x4d058\000\000\000\000\000\000\000 */
{ 175474 }, /* pm_derat_miss\000\000memory\000DERAT Reloaded to satisfy a DERAT miss. All page sizes are counted by this event. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x200f6\000\000\000\000\000\000\000 */
{ 175960 }, /* pm_derat_miss_16m\000\000memory\000Data ERAT Miss (Data TLB Access) page size 16M. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c054\000\000\000\000\000\000\000 */
{ 176679 }, /* pm_derat_miss_4k\000\000memory\000Data ERAT Miss (Data TLB Access) page size 4K. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c056\000\000\000\000\000\000\000 */
{ 177099 }, /* pm_derat_miss_64k\000\000memory\000Data ERAT Miss (Data TLB Access) page size 64K. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c054\000\000\000\000\000\000\000 */
{ 199080 }, /* pm_dtlb_miss\000\000memory\000The DPTEG required for the load/store instruction in execution was missing from the TLB. It includes pages of all sizes for demand and prefetch activity\000event=0x300fc\000\000\000\000\000\000\000 */
{ 199427 }, /* pm_dtlb_miss_16g\000\000memory\000Data TLB reload (after a miss) page size 16G. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c058\000\000\000\000\000\000\000 */
{ 199721 }, /* pm_dtlb_miss_16m\000\000memory\000Data TLB reload (after a miss) page size 16M. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c056\000\000\000\000\000\000\000 */
{ 200015 }, /* pm_dtlb_miss_1g\000\000memory\000Data TLB reload (after a miss) page size 1G. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c05a\000\000\000\000\000\000\000 */
{ 200265 }, /* pm_dtlb_miss_2m\000\000memory\000Data TLB reload (after a miss) page size 2M. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c05c\000\000\000\000\000\000\000 */
{ 200515 }, /* pm_dtlb_miss_4k\000\000memory\000Data TLB reload (after a miss) page size 4K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c056\000\000\000\000\000\000\000 */
{ 200805 }, /* pm_dtlb_miss_64k\000\000memory\000Data TLB reload (after a miss) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c056\000\000\000\000\000\000\000 */
{ 202639 }, /* pm_exec_stall_derat_dtlb_miss\000\000memory\000Cycles in which the oldest instruction in the pipeline suffered a TLB miss and waited for it resolve\000event=0x30016\000\000\000\000\000\000\000 */
{ 206782 }, /* pm_exec_stall_store_pipe\000\000memory\000Cycles in which the oldest instruction in the pipeline was executing in the store unit. This does not include cycles spent handling store misses, PTESYNC instructions or TLBIE instructions\000event=0x1e056\000\000\000\000\000\000\000 */
{ 276878 }, /* pm_itlb_hit\000\000memory\000The PTE required to translate the instruction address was resident in the TLB (instruction TLB access/IERAT reload). Applies to both HPT and RPT. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x2001a\000\000\000\000\000\000\000 */
{ 294415 }, /* pm_larx_fin\000\000memory\000Load and reserve instruction (LARX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x3c058\000\000\000\000\000\000\000 */
{ 294611 }, /* pm_ld_cmpl\000\000memory\000Loads completed\000event=0x4003e\000\000\000\000\000\000\000 */
{ 295143 }, /* pm_ld_l3miss_pend_cyc\000\000memory\000Cycles L3 miss was pending for this thread\000event=0x10062\000\000\000\000\000\000\000 */
{ 349098 }, /* pm_mrk_derat_miss_2m\000\000memory\000Data ERAT Miss (Data TLB Access) page size 2M for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x40164\000\000\000\000\000\000\000 */
{ 349780 }, /* pm_mrk_derat_miss_64k\000\000memory\000Data ERAT Miss (Data TLB Access) page size 64K for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2d154\000\000\000\000\000\000\000 */
{ 364791 }, /* pm_mrk_dtlb_miss_64k\000\000memory\000Marked Data TLB reload (after a miss) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c15e\000\000\000\000\000\000\000 */
{ 375202 }, /* pm_mrk_st_cmpl\000\000memory\000Marked store completed and sent to nest. Note that this count excludes cache-inhibited stores\000event=0x301e2\000\000\000\000\000\000\000 */
{ 376158 }, /* pm_mrk_st_l2_cyc\000\000memory\000Cycles from L2 RC dispatch to L2 RC completion\000event=0x1f150\000\000\000\000\000\000\000 */
{ 379139 }, /* pm_mrk_xfer_from_src_cyc_pmc1\000\000memory\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[0:12]\000event=0x1c144\000\000\000\000\000\000\000 */
{ 379448 }, /* pm_mrk_xfer_from_src_cyc_pmc3\000\000memory\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[30:42]\000event=0x3c144\000\000\000\000\000\000\000 */
{ 379603 }, /* pm_mrk_xfer_from_src_cyc_pmc4\000\000memory\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[45:57]\000event=0x4c144\000\000\000\000\000\000\000 */
{ 379758 }, /* pm_mrk_xfer_from_src_pmc1\000\000memory\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[0:12]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x1c142\000\000\000\000\000\000\000 */
{ 380499 }, /* pm_mrk_xfer_from_src_pmc3\000\000memory\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[30:42]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x3c142\000\000\000\000\000\000\000 */
{ 380869 }, /* pm_mrk_xfer_from_src_pmc4\000\000memory\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[45:57]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x4c142\000\000\000\000\000\000\000 */
{ 381803 }, /* pm_non_fma_flop_cmpl\000\000memory\000Non FMA instruction completed\000event=0x4d056\000\000\000\000\000\000\000 */
{ 383986 }, /* pm_pmc1_overflow\000\000memory\000The event selected for PMC1 caused the event counter to overflow\000event=0x20010\000\000\000\000\000\000\000 */
{ 384223 }, /* pm_pmc1_rewind\000\000memory\000The speculative event selected for PMC1 rewinds and the counter for PMC1 is not charged\000event=0x4d02c\000\000\000\000\000\000\000 */
{ 385961 }, /* pm_pmc3_rewind\000\000memory\000The speculative event selected for PMC3 rewinds and the counter for PMC3 is not charged\000event=0x1000a\000\000\000\000\000\000\000 */
{ 388755 }, /* pm_ptesync_fin\000\000memory\000Ptesync instruction finished in the store unit. Only one ptesync can finish at a time\000event=0x2003e\000\000\000\000\000\000\000 */
{ 424932 }, /* pm_xfer_from_src_pmc1\000\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[0:12]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x1c040\000\000\000\000\000\000\000 */
{ 425257 }, /* pm_xfer_from_src_pmc2\000\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[15:27]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x2c040\000\000\000\000\000\000\000 */
{ 425583 }, /* pm_xfer_from_src_pmc3\000\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[30:42]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x3c040\000\000\000\000\000\000\000 */
{ 425909 }, /* pm_xfer_from_src_pmc4\000\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[45:57]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x4c040\000\000\000\000\000\000\000 */
{ 105555 }, /* pm_adjunct_cyc\000\000others\000Cycles in which the thread is in Adjunct state. MSR[S HV PR] bits = 011\000event=0x10066\000\000\000\000\000\000\000 */
{ 105670 }, /* pm_adjunct_inst_cmpl\000\000others\000PowerPC instructions that completed while the thread is in Adjunct state\000event=0x2e010\000\000\000\000\000\000\000 */
{ 110876 }, /* pm_br_cmpl\000\000others\000A branch completed. All branches are included\000event=0x4d05e\000\000\000\000\000\000\000 */
{ 135731 }, /* pm_cyc\000\000others\000Processor cycles\000event=0x100f0\000\000\000\000\000\000\000 */
{ 179520 }, /* pm_disp_ss0_2_instr_cyc\000\000others\000Cycles in which Superslice 0 dispatches either 1 or 2 instructions\000event=0x1f056\000\000\000\000\000\000\000 */
{ 179639 }, /* pm_disp_ss0_4_instr_cyc\000\000others\000Cycles in which Superslice 0 dispatches either 3 or 4 instructions\000event=0x3f054\000\000\000\000\000\000\000 */
{ 179758 }, /* pm_disp_ss0_8_instr_cyc\000\000others\000Cycles in which Superslice 0 dispatches either 5, 6, 7 or 8 instructions\000event=0x3f056\000\000\000\000\000\000\000 */
{ 179883 }, /* pm_disp_ss1_2_instr_cyc\000\000others\000Cycles in which Superslice 1 dispatches either 1 or 2 instructions\000event=0x2f054\000\000\000\000\000\000\000 */
{ 180002 }, /* pm_disp_ss1_4_instr_cyc\000\000others\000Cycles in which Superslice 1 dispatches either 3 or 4 instructions\000event=0x2f056\000\000\000\000\000\000\000 */
{ 203963 }, /* pm_exec_stall_dmiss_lmem\000\000others\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local memory, local OpenCapp cache, or local OpenCapp memory\000event=0x30038\000\000\000\000\000\000\000 */
{ 204350 }, /* pm_exec_stall_dmiss_off_node\000\000others\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a distant chip\000event=0x4c01a\000\000\000\000\000\000\000 */
{ 208260 }, /* pm_flop_cmpl\000\000others\000Floating Point Operations Completed. Includes any type. It counts once for each 1, 2, 4 or 8 flop instruction. Use PM_1|2|4|8_FLOP_CMPL events to count flops\000event=0x100f4\000\000\000\000\000\000\000 */
{ 210361 }, /* pm_fma_cmpl\000\000others\000Two floating point instructions completed (FMA class of instructions: fmadd, fnmadd, fmsub, fnmsub). Scalar instructions only\000event=0x45054\000\000\000\000\000\000\000 */
{ 218946 }, /* pm_hypervisor_inst_cmpl\000\000others\000PowerPC instructions that completed while the thread is in hypervisor state\000event=0x4d022\000\000\000\000\000\000\000 */
{ 240171 }, /* pm_inst_disp\000\000others\000PowerPC instructions dispatched\000event=0x200f2\000\000\000\000\000\000\000 */
{ 240244 }, /* pm_inst_fin\000\000others\000Instructions finished\000event=0x40030\000\000\000\000\000\000\000 */
{ 294958 }, /* pm_ld_demand_miss_l1_fin\000\000others\000Load Missed L1, counted at finish time\000event=0x400f0\000\000\000\000\000\000\000 */
{ 295050 }, /* pm_ld_hit_l1\000\000others\000Loads that finished without experiencing an L1 miss\000event=0x1505e\000\000\000\000\000\000\000 */
{ 296393 }, /* pm_ld_ref_l1\000\000others\000All L1 D cache load references counted at finish, gated by reject. In P9 and earlier this event counted only cacheable loads but in P10 both cacheable and non-cacheable loads are included\000event=0x100fc\000\000\000\000\000\000\000 */
{ 324379 }, /* pm_lsu_st5_fin\000\000others\000LSU Finished an internal operation in ST2 port\000event=0x3f04a\000\000\000\000\000\000\000 */
{ 325288 }, /* pm_math_flop_cmpl\000\000others\000Math floating point instructions completed\000event=0x4505c\000\000\000\000\000\000\000 */
{ 335503 }, /* pm_mrk_data_from_l2miss\000\000others\000The processor's data cache was reloaded from a source other than the local core's L1 or L2 due to a demand miss for a marked load\000event=0x401e8\000\000\000\000\000\000\000 */
{ 341123 }, /* pm_mrk_data_from_l3miss\000\000others\000The processor's data cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss for a marked load\000event=0x201e4\000\000\000\000\000\000\000 */
{ 343094 }, /* pm_mrk_data_from_memory\000\000others\000The processor's data cache was reloaded from local, remote, or distant memory due to a demand miss for a marked load\000event=0x201e0\000\000\000\000\000\000\000 */
{ 350205 }, /* pm_mrk_dfu_issue\000\000others\000The marked instruction was a decimal floating point operation issued to the VSU. Measured at issue time\000event=0x20132\000\000\000\000\000\000\000 */
{ 367316 }, /* pm_mrk_fxu_issue\000\000others\000The marked instruction was a fixed point operation issued to the VSU. Measured at issue time\000event=0x20134\000\000\000\000\000\000\000 */
{ 368296 }, /* pm_mrk_inst_decoded\000\000others\000An instruction was marked at decode time. Random Instruction Sampling (RIS) only\000event=0x20130\000\000\000\000\000\000\000 */
{ 369078 }, /* pm_mrk_inst_flushed\000\000others\000The marked instruction was flushed\000event=0x4e15e\000\000\000\000\000\000\000 */
{ 369413 }, /* pm_mrk_inst_from_l3miss\000\000others\000The processor's instruction cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss for a marked instruction\000event=0x401e6\000\000\000\000\000\000\000 */
{ 370187 }, /* pm_mrk_issue_dependent_load\000\000others\000The marked instruction was dependent on a load. It is eligible for issue kill\000event=0x30162\000\000\000\000\000\000\000 */
{ 370529 }, /* pm_mrk_l1_icache_miss\000\000others\000Marked Instruction suffered an icache Miss\000event=0x101e4\000\000\000\000\000\000\000 */
{ 370765 }, /* pm_mrk_l1_reload_valid\000\000others\000Marked demand reload\000event=0x101ea\000\000\000\000\000\000\000 */
{ 375646 }, /* pm_mrk_st_done_l2\000\000others\000Marked stores completed in L2 (RC machine done)\000event=0x10134\000\000\000\000\000\000\000 */
{ 375740 }, /* pm_mrk_st_drain_cyc\000\000others\000cycles to drain st from core to L2\000event=0x3f150\000\000\000\000\000\000\000 */
{ 377039 }, /* pm_mrk_start_probe_nop_disp\000\000others\000Marked Start probe nop dispatched. Instruction AND R0,R0,R0\000event=0x40114\000\000\000\000\000\000\000 */
{ 377155 }, /* pm_mrk_stcx_core_cyc\000\000others\000Cycles spent in the core portion of a marked Stcx instruction. It starts counting when the instruction is decoded and stops counting when it drains into the L2\000event=0x44146\000\000\000\000\000\000\000 */
{ 377903 }, /* pm_mrk_stcx_l2_cyc\000\000others\000Cycles spent in the nest portion of a marked Stcx instruction. It starts counting when the operation starts to drain to the L2 and it stops counting when the instruction retires from the Instruction Completion Table (ICT) in the Instruction Sequencing Unit (ISU)\000event=0x1f15c\000\000\000\000\000\000\000 */
{ 379005 }, /* pm_mrk_vsu_fin\000\000others\000VSU marked instructions finished. Excludes simple FX instructions issued to the Store Unit\000event=0x30132\000\000\000\000\000\000\000 */
{ 386157 }, /* pm_pmc3_saved\000\000others\000The conditions for the speculative event selected for PMC3 are met and PMC3 is charged\000event=0x4d012\000\000\000\000\000\000\000 */
{ 388133 }, /* pm_privileged_cyc\000\000others\000Cycles when the thread is in Privileged state. MSR[S HV PR]=x00\000event=0x4d028\000\000\000\000\000\000\000 */
{ 388243 }, /* pm_privileged_inst_cmpl\000\000others\000PowerPC Instructions that completed while the thread is in Privileged state\000event=0x3405a\000\000\000\000\000\000\000 */
{ 396131 }, /* pm_run_cyc_smt4_mode\000\000others\000Cycles when this thread's run latch is set and the core is in SMT4 mode\000event=0x2006c\000\000\000\000\000\000\000 */
{ 396874 }, /* pm_run_inst_cmpl\000\000others\000Completed PowerPC instructions gated by the run latch\000event=0x500fa\000\000\000\000\000\000\000 */
{ 397183 }, /* pm_run_latch_all_threads_cyc\000\000others\000Cycles when the run latch is set for all threads\000event=0x2000c\000\000\000\000\000\000\000 */
{ 397289 }, /* pm_run_latch_any_thread_cyc\000\000others\000Cycles when at least one thread has the run latch set\000event=0x100fa\000\000\000\000\000\000\000 */
{ 397746 }, /* pm_scalar_flop_cmpl\000\000others\000Scalar floating point instructions completed\000event=0x45056\000\000\000\000\000\000\000 */
{ 402416 }, /* pm_stcx_fin\000\000others\000Conditional store instruction (STCX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x2e014\000\000\000\000\000\000\000 */
{ 411424 }, /* pm_thresh_exc_512\000\000others\000Threshold counter exceeded a value of 512\000event=0x201e8\000\000\000\000\000\000\000 */
{ 417879 }, /* pm_ultravisor_cyc\000\000others\000Cycles when the thread is in Ultravisor state. MSR[S HV PR]=110\000event=0x4d026\000\000\000\000\000\000\000 */
{ 417989 }, /* pm_ultravisor_inst_cmpl\000\000others\000PowerPC instructions that completed while the thread was in ultravisor state\000event=0x1001c\000\000\000\000\000\000\000 */
{ 418582 }, /* pm_vector_ld_cmpl\000\000others\000Vector load instructions completed\000event=0x44054\000\000\000\000\000\000\000 */
{ 420843 }, /* pm_vsu0_issue\000\000others\000VSU instructions issued to VSU pipe 0\000event=0x10016\000\000\000\000\000\000\000 */
{ 424426 }, /* pm_vsu_fin\000\000others\000VSU instructions finished\000event=0x4001c\000\000\000\000\000\000\000 */
{ 424598 }, /* pm_vsu_issue\000\000others\000At least one VSU instruction was issued to one of the VSU pipes. Up to 4 per cycle. Includes fixed point operations\000event=0x2505c\000\000\000\000\000\000\000 */
{ 104483 }, /* pm_1plus_ppc_disp\000\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\000\000\000\000\000\000 */
{ 104691 }, /* pm_2flop_cmpl\000\000pipeline\000Double Precision vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg completed\000event=0x4d052\000\000\000\000\000\000\000 */
{ 111133 }, /* pm_br_fin\000\000pipeline\000A branch instruction finished. Includes predicted/mispredicted/unconditional\000event=0x10068\000\000\000\000\000\000\000 */
{ 119099 }, /* pm_cmpl_stall\000\000pipeline\000Cycles in which the oldest instruction in the pipeline cannot complete because the thread was blocked for any reason\000event=0x4c018\000\000\000\000\000\000\000 */
{ 119260 }, /* pm_cmpl_stall_exception\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000event=0x3003a\000\000\000\000\000\000\000 */
{ 119503 }, /* pm_cmpl_stall_hwsync\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a hwsync waiting for response from L2 before completing\000event=0x4d01a\000\000\000\000\000\000\000 */
{ 119669 }, /* pm_cmpl_stall_lwsync\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a lwsync waiting to complete\000event=0x1e05a\000\000\000\000\000\000\000 */
{ 119808 }, /* pm_cmpl_stall_mem_ecc\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000event=0x30028\000\000\000\000\000\000\000 */
{ 120057 }, /* pm_cmpl_stall_special\000\000pipeline\000Cycles in which the oldest instruction in the pipeline required special handling before completing\000event=0x2c014\000\000\000\000\000\000\000 */
{ 120208 }, /* pm_cmpl_stall_stcx\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a stcx waiting for resolution from the nest before completing\000event=0x2d01c\000\000\000\000\000\000\000 */
{ 176419 }, /* pm_derat_miss_2m\000\000pipeline\000Data ERAT Miss (Data TLB Access) page size 2M. Implies radix translation. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c05a\000\000\000\000\000\000\000 */
{ 202269 }, /* pm_exec_stall\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting to finish in one of the execution units (BRU, LSU, VSU). Only cycles between issue and finish are counted in this category\000event=0x30008\000\000\000\000\000\000\000 */
{ 202503 }, /* pm_exec_stall_bru\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the Branch unit\000event=0x4d018\000\000\000\000\000\000\000 */
{ 202798 }, /* pm_exec_stall_derat_only_miss\000\000pipeline\000Cycles in which the oldest instruction in the pipeline suffered an ERAT miss and waited for it resolve\000event=0x4c012\000\000\000\000\000\000\000 */
{ 203766 }, /* pm_exec_stall_dmiss_l3miss\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a source beyond the local L2 or local L3\000event=0x2c018\000\000\000\000\000\000\000 */
{ 204521 }, /* pm_exec_stall_fin_at_disp\000\000pipeline\000Cycles in which the oldest instruction in the pipeline finished at dispatch and did not require execution in the LSU, BRU or VSU\000event=0x10058\000\000\000\000\000\000\000 */
{ 205511 }, /* pm_exec_stall_ntc_flush\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in any unit before it was flushed. Note that if the flush of the oldest instruction happens after finish, the cycles from dispatch to issue will be included in PM_DISP_STALL and the cycles from issue to finish will be included in PM_EXEC_STALL and its corresponding children. This event will also count cycles when the previous NTF instruction is still completing and the new NTF instruction is stalled at dispatch\000event=0x2e01e\000\000\000\000\000\000\000 */
{ 206212 }, /* pm_exec_stall_simple_fx\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a simple fixed point instruction executing in the Load Store Unit\000event=0x30036\000\000\000\000\000\000\000 */
{ 207189 }, /* pm_exec_stall_tlbiel\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was a TLBIEL instruction executing in the Load Store Unit. TLBIEL instructions have lower overhead than TLBIE instructions because they don't get set to the nest\000event=0x4d01c\000\000\000\000\000\000\000 */
{ 207630 }, /* pm_exec_stall_unknown\000\000pipeline\000Cycles in which the oldest instruction in the pipeline completed without an ntf_type pulse. The ntf_pulse was missed by the ISU because the NTF finishes and completions came too close together\000event=0x4e012\000\000\000\000\000\000\000 */
{ 207875 }, /* pm_exec_stall_vsu\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the VSU (includes FXU, VSU, CRU)\000event=0x2d018\000\000\000\000\000\000\000 */
{ 208691 }, /* pm_flush\000\000pipeline\000Flush (any type)\000event=0x400f8\000\000\000\000\000\000\000 */
{ 210054 }, /* pm_flush_mpred\000\000pipeline\000A flush occurred due to a mispredicted branch. Includes target and direction\000event=0x1005a\000\000\000\000\000\000\000 */
{ 212169 }, /* pm_fx_lsu_fin\000\000pipeline\000Simple fixed point instruction issued to the store unit. Measured at finish time\000event=0x1006a\000\000\000\000\000\000\000 */
{ 213234 }, /* pm_fxu_issue\000\000pipeline\000A fixed point instruction was issued to the VSU\000event=0x40004\000\000\000\000\000\000\000 */
{ 218834 }, /* pm_hypervisor_cyc\000\000pipeline\000Cycles when the thread is in Hypervisor state. MSR[S HV PR]=010\000event=0x2000a\000\000\000\000\000\000\000 */
{ 219375 }, /* pm_ic_demand_cyc\000\000pipeline\000Cycles in which an instruction reload is pending to satisfy a demand miss\000event=0x10018\000\000\000\000\000\000\000 */
{ 220155 }, /* pm_ic_miss_cmpl\000\000pipeline\000Non-speculative icache miss, counted at completion\000event=0x45058\000\000\000\000\000\000\000 */
{ 239982 }, /* pm_inst_cmpl\000\000pipeline\000PowerPC instructions completed\000event=0x100fe\000\000\000\000\000\000\000 */
{ 275425 }, /* pm_issue_stall\000\000pipeline\000Cycles in which the oldest instruction in the pipeline was dispatched but not issued yet\000event=0x20004\000\000\000\000\000\000\000 */
{ 315176 }, /* pm_lsu_fin\000\000pipeline\000LSU Finished an internal operation (up to 4 per cycle)\000event=0x30066\000\000\000\000\000\000\000 */
{ 319178 }, /* pm_lsu_ld0_fin\000\000pipeline\000LSU Finished an internal operation in LD0 port\000event=0x1000c\000\000\000\000\000\000\000 */
{ 319270 }, /* pm_lsu_ld1_fin\000\000pipeline\000LSU Finished an internal operation in LD1 port\000event=0x2000e\000\000\000\000\000\000\000 */
{ 323919 }, /* pm_lsu_st0_fin\000\000pipeline\000LSU Finished an internal operation in ST0 port\000event=0x10012\000\000\000\000\000\000\000 */
{ 324011 }, /* pm_lsu_st1_fin\000\000pipeline\000LSU Finished an internal operation in ST1 port\000event=0x2d010\000\000\000\000\000\000\000 */
{ 324103 }, /* pm_lsu_st2_fin\000\000pipeline\000LSU Finished an internal operation in ST2 port\000event=0x3001a\000\000\000\000\000\000\000 */
{ 324195 }, /* pm_lsu_st3_fin\000\000pipeline\000LSU Finished an internal operation in ST3 port\000event=0x4c01e\000\000\000\000\000\000\000 */
{ 324287 }, /* pm_lsu_st4_fin\000\000pipeline\000LSU Finished an internal operation in ST4 port\000event=0x10014\000\000\000\000\000\000\000 */
{ 326743 }, /* pm_mma_issued\000\000pipeline\000MMA instructions issued\000event=0x1000e\000\000\000\000\000\000\000 */
{ 367030 }, /* pm_mrk_fx_lsu_fin\000\000pipeline\000The marked instruction was simple fixed point that was issued to the store unit. Measured at finish time\000event=0x2013c\000\000\000\000\000\000\000 */
{ 372448 }, /* pm_mrk_ld_miss_l1\000\000pipeline\000Marked DL1 Demand Miss counted at finish time\000event=0x201e2\000\000\000\000\000\000\000 */
{ 372838 }, /* pm_mrk_lsu_fin\000\000pipeline\000LSU marked instruction finish\000event=0x40132\000\000\000\000\000\000\000 */
{ 382269 }, /* pm_ntc_all_fin\000\000pipeline\000Cycles in which both instructions in the ICT entry pair show as finished. These are the cycles between finish and completion for the oldest pair of instructions in the pipeline\000event=0x40008\000\000\000\000\000\000\000 */
{ 382491 }, /* pm_ntc_fin\000\000pipeline\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. Note that instructions can finish out of order, therefore not all the instructions that finish have a Next-to-complete status\000event=0x2405a\000\000\000\000\000\000\000 */
{ 384903 }, /* pm_pmc2_rewind\000\000pipeline\000The speculative event selected for PMC2 rewinds and the counter for PMC2 is not charged\000event=0x30020\000\000\000\000\000\000\000 */
{ 385188 }, /* pm_pmc2_saved\000\000pipeline\000The conditions for the speculative event selected for PMC2 are met and PMC2 is charged\000event=0x10022\000\000\000\000\000\000\000 */
{ 385496 }, /* pm_pmc3_overflow\000\000pipeline\000The event selected for PMC3 caused the event counter to overflow\000event=0x40010\000\000\000\000\000\000\000 */
{ 386920 }, /* pm_pmc4_saved\000\000pipeline\000The conditions for the speculative event selected for PMC4 are met and PMC4 is charged\000event=0x30022\000\000\000\000\000\000\000 */
{ 387205 }, /* pm_pmc5_overflow\000\000pipeline\000The event selected for PMC5 caused the event counter to overflow\000event=0x10024\000\000\000\000\000\000\000 */
{ 387454 }, /* pm_pmc6_overflow\000\000pipeline\000The event selected for PMC6 caused the event counter to overflow\000event=0x30024\000\000\000\000\000\000\000 */
{ 395312 }, /* pm_run_cyc\000\000pipeline\000Processor cycles gated by the run latch\000event=0x200f4\000\000\000\000\000\000\000 */
{ 396704 }, /* pm_run_cyc_st_mode\000\000pipeline\000Cycles when the run latch is set and the core is in ST mode\000event=0x1006c\000\000\000\000\000\000\000 */
{ 397839 }, /* pm_scalar_fsqrt_fdiv_issue\000\000pipeline\000Scalar versions of four floating point operations: fdiv,fsqrt (xvdivdp, xvdivsp, xvsqrtdp, xvsqrtsp)\000event=0x3d058\000\000\000\000\000\000\000 */
{ 412500 }, /* pm_tlbie_fin\000\000pipeline\000TLBIE instructions finished in the LSU. Two TLBIEs can finish each cycle. All will be counted\000event=0x30058\000\000\000\000\000\000\000 */
{ 423351 }, /* pm_vsu1_issue\000\000pipeline\000VSU instructions issued to VSU pipe 1\000event=0x2d012\000\000\000\000\000\000\000 */
{ 424096 }, /* pm_vsu2_issue\000\000pipeline\000VSU instructions issued to VSU pipe 2\000event=0x3f044\000\000\000\000\000\000\000 */
{ 424178 }, /* pm_vsu3_issue\000\000pipeline\000VSU instruction was issued to VSU pipe 3\000event=0x4d020\000\000\000\000\000\000\000 */
{ 424835 }, /* pm_vsu_non_flop_cmpl\000\000pipeline\000Non-floating point VSU instructions completed\000event=0x4d050\000\000\000\000\000\000\000 */
{ 103589 }, /* pm_1flop_cmpl\000\000pmc\000One floating point instruction completed (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg)\000event=0x45050\000\000\000\000\000\000\000 */
{ 105058 }, /* pm_4flop_cmpl\000\000pmc\000Four floating point instructions completed (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg)\000event=0x45052\000\000\000\000\000\000\000 */
{ 105464 }, /* pm_8flop_cmpl\000\000pmc\000Four Double Precision vector instructions completed\000event=0x4d054\000\000\000\000\000\000\000 */
{ 411703 }, /* pm_thresh_exc_64\000\000pmc\000Threshold counter exceeded a value of 64\000event=0x301e8\000\000\000\000\000\000\000 */
{ 157782 }, /* pm_data_from_l2miss\000\000translation\000The processor's data cache was reloaded from a source other than the local core's L1 or L2 due to a demand miss\000event=0x200fe\000\000\000\000\000\000\000 */
{ 184311 }, /* pm_dpp_flop_cmpl\000\000translation\000Double-Precision or Quad-Precision instructions completed\000event=0x4d05c\000\000\000\000\000\000\000 */
{ 207024 }, /* pm_exec_stall_tlbie\000\000translation\000Cycles in which the oldest instruction in the pipeline was a TLBIE instruction executing in the Load Store Unit\000event=0x2e01c\000\000\000\000\000\000\000 */
{ 373953 }, /* pm_mrk_ntf_cyc\000\000translation\000Cycles during which the marked instruction is the oldest in the pipeline (NTF or NTC)\000event=0x2011c\000\000\000\000\000\000\000 */
{ 376930 }, /* pm_mrk_start_probe_nop_cmpl\000\000translation\000Marked Start probe nop (AND R0,R0,R0) completed\000event=0x1f15e\000\000\000\000\000\000\000 */
{ 384425 }, /* pm_pmc1_saved\000\000translation\000The conditions for the speculative event selected for PMC1 are met and PMC1 is charged\000event=0x4d010\000\000\000\000\000\000\000 */
{ 384699 }, /* pm_pmc2_overflow\000\000translation\000The event selected for PMC2 caused the event counter to overflow\000event=0x30010\000\000\000\000\000\000\000 */
{ 400616 }, /* pm_st_cmpl\000\000translation\000Stores completed from S2Q (2nd-level store queue). This event includes regular stores, stcx and cache inhibited stores. The following operations are excluded (pteupdate, snoop tlbie complete, store atomics, miso, load atomic payloads, tlbie, tlbsync, slbieg, isync, msgsnd, slbiag, cpabort, copy, tcheck, tend, stsync, dcbst, icbi, dcbf, hwsync, lwsync, ptesync, eieio, msgsync)\000event=0x200f0\000\000\000\000\000\000\000 */
{ 401249 }, /* pm_st_fin\000\000translation\000Store finish count. Includes speculative activity\000event=0x20016\000\000\000\000\000\000\000 */
{ 401411 }, /* pm_st_fwd\000\000translation\000Store forwards that finished\000event=0x20018\000\000\000\000\000\000\000 */
{ 411074 }, /* pm_thresh_exc_32\000\000translation\000Threshold counter exceeded a value of 32\000event=0x201e6\000\000\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__power10[] = {
{ 0 }, /* ALINK0_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK0_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 244 }, /* ALINK0_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK0_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 497 }, /* ALINK1_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK1_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 741 }, /* ALINK1_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK1_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 994 }, /* ALINK2_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK2_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 1238 }, /* ALINK2_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK2_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 1491 }, /* ALINK3_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK3_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 1735 }, /* ALINK3_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK3_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 1988 }, /* ALINK4_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK4_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 2232 }, /* ALINK4_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK4_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 2485 }, /* ALINK5_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK5_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 2729 }, /* ALINK5_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK5_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 2982 }, /* ALINK6_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK6_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 3226 }, /* ALINK6_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK6_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 3479 }, /* ALINK7_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_ALINK7_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 3723 }, /* ALINK7_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_ALINK7_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 16757 }, /* GROUP_PUMP_RETRY_RATIO_P01\000\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PB_GROUP_PUMP01\\,chip\\=?@ * 100\000\000\0001%\000\0001\000 */
{ 16880 }, /* GROUP_PUMP_RETRY_RATIO_P23\000\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PB_GROUP_PUMP23\\,chip\\=?@ * 100\000\000\0001%\000\0001\000 */
{ 19771 }, /* LOCAL_NODE_PUMP_RETRY_RATIO_P01\000\000\000hv_24x7@PM_PB_RTY_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PB_LNS_PUMP01\\,chip\\=?@ * 100\000\000\0001%\000\0001\000 */
{ 19895 }, /* LOCAL_NODE_PUMP_RETRY_RATIO_P23\000\000\000hv_24x7@PM_PB_RTY_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PB_LNS_PUMP23\\,chip\\=?@ * 100\000\000\0001%\000\0001\000 */
{ 21521 }, /* Memory_RD_BW_Chip\000Memory_BW\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000 */
{ 22032 }, /* Memory_WR_BW_Chip\000Memory_BW\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000 */
{ 22798 }, /* PowerBUS_Frequency\000\000\000hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0002.56e-7GHz\000\0001\000 */
{ 22928 }, /* REMOTE_NODE_PUMPS_RETRIES_RATIO_P01\000\000\000hv_24x7@PM_PB_RTY_RNS_PUMP01\\,chip\\=?@ / (1 + hv_24x7@PM_PB_RNS_PUMP01\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 23062 }, /* REMOTE_NODE_PUMPS_RETRIES_RATIO_P23\000\000\000hv_24x7@PM_PB_RTY_RNS_PUMP23\\,chip\\=?@ / (1 + hv_24x7@PM_PB_RNS_PUMP23\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 25608 }, /* TOTAL_DATA_BANDWIDTH_TRANSFERRED_OVER_PB_PCI0\000\000\000hv_24x7@PM_PCI0_32B_INOUT\\,chip\\=?@\000\000\0003.28e-2MB\000\0001\000 */
{ 25707 }, /* TOTAL_DATA_BANDWIDTH_TRANSFERRED_OVER_PB_PCI1\000\000\000hv_24x7@PM_PCI1_32B_INOUT\\,chip\\=?@\000\000\0003.28e-2MB\000\0001\000 */
{ 25806 }, /* TOTAL_GROUP_PUMPS_P01\000\000\000hv_24x7@PM_PB_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 25905 }, /* TOTAL_GROUP_PUMPS_P23\000\000\000hv_24x7@PM_PB_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 26004 }, /* TOTAL_GROUP_PUMPS_RETRIES_P01\000\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 26115 }, /* TOTAL_GROUP_PUMPS_RETRIES_P23\000\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 26226 }, /* TOTAL_INT_PB_BW\000\000\000hv_24x7@PM_PB_INT_DATA_XFER\\,chip\\=?@\000\000\0002.09MB\000\0001\000 */
{ 26294 }, /* TOTAL_LOCAL_NODE_PUMPS_P01\000\000\000hv_24x7@PM_PB_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 26396 }, /* TOTAL_LOCAL_NODE_PUMPS_P23\000\000\000hv_24x7@PM_PB_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 26498 }, /* TOTAL_LOCAL_NODE_PUMPS_RETRIES_P01\000\000\000hv_24x7@PM_PB_RTY_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 26612 }, /* TOTAL_LOCAL_NODE_PUMPS_RETRIES_P23\000\000\000hv_24x7@PM_PB_RTY_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 26726 }, /* TOTAL_MCS_READ_BW_MC0_CHAN01\000\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000 */
{ 26828 }, /* TOTAL_MCS_READ_BW_MC1_CHAN01\000\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000 */
{ 26930 }, /* TOTAL_MCS_READ_BW_MC2_CHAN01\000\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000 */
{ 27032 }, /* TOTAL_MCS_READ_BW_MC3_CHAN01\000\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\0005.24e-1MB\000\0001\000 */
{ 27134 }, /* TOTAL_MCS_WRITE_BW_MC0_CHAN01\000\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000 */
{ 27235 }, /* TOTAL_MCS_WRITE_BW_MC1_CHAN01\000\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000 */
{ 27336 }, /* TOTAL_MCS_WRITE_BW_MC2_CHAN01\000\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000 */
{ 27437 }, /* TOTAL_MCS_WRITE_BW_MC3_CHAN01\000\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\0002.6e-1MB\000\0001\000 */
{ 27538 }, /* TOTAL_NEAR_NODE_PUMPS_P01\000\000\000hv_24x7@PM_PB_NNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 27639 }, /* TOTAL_NEAR_NODE_PUMPS_P23\000\000\000hv_24x7@PM_PB_NNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 27740 }, /* TOTAL_REMOTE_NODE_PUMPS_P01\000\000\000hv_24x7@PM_PB_RNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 27843 }, /* TOTAL_REMOTE_NODE_PUMPS_P23\000\000\000hv_24x7@PM_PB_RNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 27946 }, /* TOTAL_VECTOR_GROUP_PUMPS_P01\000\000\000hv_24x7@PM_PB_VG_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 28049 }, /* TOTAL_VECTOR_GROUP_PUMPS_P23\000\000\000hv_24x7@PM_PB_VG_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 28152 }, /* TOTAL_VECTOR_GROUP_PUMPS_RETRIES_P01\000\000\000hv_24x7@PM_PB_RTY_VG_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 28267 }, /* TOTAL_VECTOR_GROUP_PUMPS_RETRIES_P23\000\000\000hv_24x7@PM_PB_RTY_VG_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\0004\000\0001\000 */
{ 28580 }, /* VEC_GROUP_PUMP_RETRY_RATIO_P01\000\000\000hv_24x7@PM_PB_RTY_VG_PUMP01\\,chip\\=?@ / (1 + hv_24x7@PM_PB_VG_PUMP01\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 28707 }, /* VEC_GROUP_PUMP_RETRY_RATIO_P23\000\000\000hv_24x7@PM_PB_RTY_VG_PUMP23\\,chip\\=?@ / (1 + hv_24x7@PM_PB_VG_PUMP23\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 29117 }, /* XLINK0_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK0_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 29361 }, /* XLINK0_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK0_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 29614 }, /* XLINK1_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK1_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 29858 }, /* XLINK1_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK1_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 30111 }, /* XLINK2_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK2_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 30355 }, /* XLINK2_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK2_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 30608 }, /* XLINK3_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK3_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 30852 }, /* XLINK3_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK3_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 31105 }, /* XLINK4_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK4_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 31349 }, /* XLINK4_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK4_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 31602 }, /* XLINK5_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK5_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 31846 }, /* XLINK5_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK5_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 32099 }, /* XLINK6_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK6_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 32343 }, /* XLINK6_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK6_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 32596 }, /* XLINK7_OUT_DATA_UTILIZATION\000\000\000(hv_24x7@PM_XLINK7_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001.063%\000\0001\000 */
{ 32840 }, /* XLINK7_OUT_TOTAL_UTILIZATION\000\000\000(hv_24x7@PM_XLINK7_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\0001%\000\0001\000 */
{ 3976 }, /* AVERAGE_COMPLETED_INSTRUCTION_SET_SIZE\000General\000\000PM_RUN_INST_CMPL / PM_1PLUS_PPC_CMPL\000Average number of completed instructions per instruction group\000\000\000\000\000 */
{ 4128 }, /* BRANCHES_PER_INST\000General\000\000PM_BR_FIN / PM_RUN_INST_CMPL\000Average number of finished branches per completed instruction\000\000\000\000\000 */
{ 4250 }, /* BRANCH_MISPREDICTION_RATE\000Others\000\000PM_BR_MPRED_CMPL / PM_RUN_INST_CMPL\000Percentage of branch mispredictions per completed instruction\000\000\000\000\000 */
{ 4386 }, /* BRU_STALL_CPI\000CPI\000\000PM_EXEC_STALL_BRU / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing in the branch unit\000\000\000\000\000 */
{ 4544 }, /* BR_MPRED_FLUSH_RATE\000Others\000\000PM_FLUSH_MPRED / PM_RUN_INST_CMPL * 100\000Percentage of flushes due to a branch mispredict per completed instruction\000\0001%\000\000\000 */
{ 4693 }, /* COMPLETION_STALL_CPI\000CPI;CPI_STALL_RATIO\000\000PM_CMPL_STALL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction cannot complete because the thread was blocked\000\000\000\000\000 */
{ 4979 }, /* CYCLES_ATLEAST_ONE_INST_DISPATCHED\000General\000\000PM_1PLUS_PPC_DISP / PM_RUN_CYC * 100\000Percentage of cycles when at least 1 instruction dispatched\000\0001%\000\000\000 */
{ 5126 }, /* CYCLES_PER_COMPLETED_INSTRUCTIONS_SET\000General\000\000PM_CYC / PM_1PLUS_PPC_CMPL\000Average number of cycles per completed instruction group\000\000\000\000\000 */
{ 5261 }, /* CYCLES_PER_INSTRUCTION\000CPI\000\000PM_CYC / PM_INST_CMPL\000Average cycles per completed instruction\000\000\000\000\000 */
{ 5356 }, /* DCACHE_MISS_CPI\000General\000\000DMISS_L3MISS_STALL_CPI / RUN_CPI * 100\000Percentage of cycles stalled due to the NTC instruction waiting for a load miss to resolve from a source beyond the local L2 and local L3\000\0001%\000\000\000 */
{ 5979 }, /* DERAT_16M_MISS_RATE\000Translation\000\000PM_DERAT_MISS_16M / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses with 16M page size per completed instruction\000\0001%\000\000\000 */
{ 6133 }, /* DERAT_16M_MISS_RATIO\000Translation\000\000PM_DERAT_MISS_16M / PM_DERAT_MISS\000DERAT miss ratio for 16M page size\000\000\000\000\000 */
{ 6240 }, /* DERAT_2M_MISS_RATE\000Translation\000\000PM_DERAT_MISS_2M / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses with 2M page size per completed instruction\000\0001%\000\000\000 */
{ 6391 }, /* DERAT_2M_MISS_RATIO\000Translation\000\000PM_DERAT_MISS_2M / PM_DERAT_MISS\000DERAT miss ratio for 2M page size\000\000\000\000\000 */
{ 6495 }, /* DERAT_4K_MISS_RATE\000Translation\000\000PM_DERAT_MISS_4K / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses with 4k page size per completed instruction\000\0001%\000\000\000 */
{ 6646 }, /* DERAT_4K_MISS_RATIO\000Translation\000\000PM_DERAT_MISS_4K / PM_DERAT_MISS\000DERAT miss ratio for 4K page size\000\000\000\000\000 */
{ 6750 }, /* DERAT_64K_MISS_RATE\000Translation\000\000PM_DERAT_MISS_64K / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses with 64k page size per completed instruction\000\0001%\000\000\000 */
{ 6904 }, /* DERAT_64K_MISS_RATIO\000Translation\000\000PM_DERAT_MISS_64K / PM_DERAT_MISS\000DERAT miss ratio for 64K page size\000\000\000\000\000 */
{ 7011 }, /* DERAT_DTLB_MISS_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DERAT_DTLB_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is recovering from a TLB miss\000\000\000\000\000 */
{ 7191 }, /* DERAT_MISS_RATE\000Translation\000\000PM_DERAT_MISS / PM_RUN_INST_CMPL * 100\000Percentage of DERAT misses per completed instruction\000\0001%\000\000\000 */
{ 7318 }, /* DERAT_MISS_RELOAD\000Translation\000\000PM_DTLB_MISS / PM_DERAT_MISS * 100\000Percentage of DERAT misses that resulted in TLB reloads\000\0001%\000\000\000 */
{ 7446 }, /* DERAT_ONLY_MISS_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DERAT_ONLY_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a load or store that suffered a translation miss\000\000\000\000\000 */
{ 7648 }, /* DISPATCHED_BR_MPRED_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled due to a branch mispredict\000\000\000\000\000 */
{ 7817 }, /* DISPATCHED_BR_MPRED_ICMISS_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled due to an icache miss after a branch mispredict\000\000\000\000\000 */
{ 8021 }, /* DISPATCHED_BR_MPRED_IC_L2_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED_IC_L2 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from the local L2 after suffering a branch mispredict\000\000\000\000\000 */
{ 8259 }, /* DISPATCHED_BR_MPRED_IC_L3MISS_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED_IC_L3MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from any source beyond the local L3 after suffering a branch mispredict\000\000\000\000\000 */
{ 8523 }, /* DISPATCHED_BR_MPRED_IC_L3_CPI\000CPI\000\000PM_DISP_STALL_BR_MPRED_IC_L3 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from the local L3 after suffering a branch mispredict\000\000\000\000\000 */
{ 8761 }, /* DISPATCHED_CPI\000CPI;CPI_STALL_RATIO\000\000PM_DISP_STALL_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled for any reason\000\000\000\000\000 */
{ 8920 }, /* DISPATCHED_FETCH_CPI\000CPI\000\000PM_DISP_STALL_FETCH / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled because fetch was being held, so there was nothing in the pipeline for this thread\000\000\000\000\000 */
{ 9139 }, /* DISPATCHED_FLUSH_CPI\000CPI\000\000PM_DISP_STALL_FLUSH / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled because there was a flush\000\000\000\000\000 */
{ 9301 }, /* DISPATCHED_HELD_CPI\000CPI\000\000PM_DISP_STALL_HELD_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch for any reason\000\000\000\000\000 */
{ 9474 }, /* DISPATCHED_HELD_HALT_CPI\000CPI\000\000PM_DISP_STALL_HELD_HALT_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because of power management\000\000\000\000\000 */
{ 9670 }, /* DISPATCHED_HELD_OTHER_CPI\000CPI\000\000PM_DISP_STALL_HELD_OTHER_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch for any other reason\000\000\000\000\000 */
{ 9861 }, /* DISPATCHED_HELD_RENAME_CPI\000CPI\000\000PM_DISP_STALL_HELD_RENAME_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the mapper/SRB was full\000\000\000\000\000 */
{ 10065 }, /* DISPATCHED_HELD_STF_MAPPER_CPI\000CPI\000\000PM_DISP_STALL_HELD_STF_MAPPER_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the STF mapper/SRB was full\000\000\000\000\000 */
{ 10281 }, /* DISPATCHED_HELD_XVFC_MAPPER_CPI\000CPI\000\000PM_DISP_STALL_HELD_XVFC_MAPPER_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the XVFC mapper/SRB was full\000\000\000\000\000 */
{ 10500 }, /* DISPATCHED_IC_L2_CPI\000CPI\000\000PM_DISP_STALL_IC_L2 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from the local L2\000\000\000\000\000 */
{ 10688 }, /* DISPATCHED_IC_L3MISS_CPI\000CPI\000\000PM_DISP_STALL_IC_L3MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from any source beyond the local L3\000\000\000\000\000 */
{ 10902 }, /* DISPATCHED_IC_L3_CPI\000CPI\000\000PM_DISP_STALL_IC_L3 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from the local L3\000\000\000\000\000 */
{ 11090 }, /* DISPATCHED_IC_MISS_CPI\000CPI\000\000PM_DISP_STALL_IC_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled due to an icache miss\000\000\000\000\000 */
{ 11252 }, /* DISPATCHED_IERAT_ONLY_MISS_CPI\000CPI\000\000PM_DISP_STALL_IERAT_ONLY_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled waiting to resolve an instruction ERAT miss\000\000\000\000\000 */
{ 11452 }, /* DISPATCHED_ITLB_MISS_CPI\000CPI\000\000PM_DISP_STALL_ITLB_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled waiting to resolve an instruction TLB miss\000\000\000\000\000 */
{ 11639 }, /* DISPATCHED_TRANSLATION_CPI\000CPI\000\000PM_DISP_STALL_TRANSLATION / PM_RUN_INST_CMPL\000Average cycles per completed instruction when dispatch was stalled because the MMU was handling a translation miss\000\000\000\000\000 */
{ 11835 }, /* DISPATCH_PER_INST_CMPL\000General\000\000PM_INST_DISP / PM_RUN_INST_CMPL\000Average number of completed instructions dispatched per instruction completed\000\000\000\000\000 */
{ 11981 }, /* DISP_HELD_STALL_ISSQ_FULL_CPI\000CPI\000\000PM_DISP_STALL_HELD_ISSQ_FULL_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch due to issue queue full\000\000\000\000\000 */
{ 12183 }, /* DISP_HELD_STALL_SCOREBOARD_CPI\000CPI\000\000PM_DISP_STALL_HELD_SCOREBOARD_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch while waiting on the scoreboard\000\000\000\000\000 */
{ 12395 }, /* DISP_HELD_STALL_SYNC_CPI\000CPI\000\000PM_DISP_STALL_HELD_SYNC_CYC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction was held at dispatch because of a synchronizing instruction that requires the ICT to be empty before dispatch\000\000\000\000\000 */
{ 12652 }, /* DL1_MISS_RELOADS\000General\000\000PM_LD_DEMAND_MISS_L1 / PM_LD_MISS_L1 * 100\000Percentage of demand load misses that reloaded the L1 cache\000\0001%\000\000\000 */
{ 12787 }, /* DL1_RELOAD_FROM_L2_MISS\000dL1_Reloads\000\000PM_DATA_FROM_L2MISS / PM_LD_DEMAND_MISS_L1 * 100\000Percentage of demand load misses that reloaded from beyond the local L2\000\0001%\000\000\000 */
{ 12951 }, /* DL1_RELOAD_FROM_L2_MISS_RATE\000dL1_Reloads\000\000PM_DATA_FROM_L2MISS / PM_RUN_INST_CMPL * 100\000Percentage of demand loads that reloaded from beyond the L2 per completed instruction\000\0001%\000\000\000 */
{ 13130 }, /* DL1_RELOAD_FROM_L3_MISS\000dL1_Reloads\000\000PM_DATA_FROM_L3MISS / PM_LD_DEMAND_MISS_L1 * 100\000Percentage of demand load misses that reloaded from beyond the local L3\000\0001%\000\000\000 */
{ 13294 }, /* DL1_RELOAD_FROM_L3_MISS_RATE\000dL1_Reloads\000\000L3_LD_MISS_RATE\000Percentage of demand loads that reloaded from beyond the L3 per completed instruction\000\0001%\000\000\000 */
{ 13444 }, /* DMISS_L21_L31_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a neighbor chiplet's L2 or L3 in the same chip\000\000\000\000\000 */
{ 13680 }, /* DMISS_L2L3_CONFLICT_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3, with an RC dispatch conflict\000\000\000\000\000 */
{ 13943 }, /* DMISS_L2L3_NOCONFLICT_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L2L3_NOCONFLICT / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3, without an RC dispatch conflict\000\000\000\000\000 */
{ 14213 }, /* DMISS_L2L3_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3\000\000\000\000\000 */
{ 14428 }, /* DMISS_L3MISS_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a source beyond the local L2 and local L3\000\000\000\000\000 */
{ 14657 }, /* DMISS_LMEM_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from L4, local memory or OpenCAPI chip\000\000\000\000\000 */
{ 14874 }, /* DMISS_OFF_CHIP_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_OFF_CHIP / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a remote chip (cache, L4, memory or OpenCAPI) in the same group\000\000\000\000\000 */
{ 15129 }, /* DMISS_OFF_NODE_STALL_CPI\000CPI\000\000PM_EXEC_STALL_DMISS_OFF_NODE / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a distant chip (cache, L4, memory or OpenCAPI chip)\000\000\000\000\000 */
{ 15372 }, /* DTLB_MISS_RATE\000Others\000\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000Percentage of completed instructions when the DPTEG required for the load/store instruction in execution was missing from the TLB\000\0001%\000\000\000 */
{ 15569 }, /* EXCEPTION_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_EXCEPTION / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction cannot complete because it was interrupted by ANY exception\000\000\000\000\000 */
{ 15778 }, /* EXECUTION_STALL_CPI\000CPI;CPI_STALL_RATIO\000\000PM_EXEC_STALL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting to be finished in one of the execution units\000\000\000\000\000 */
{ 15978 }, /* EXEC_STALL_UNKOWN_CPI\000General\000\000PM_EXEC_STALL_UNKNOWN / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTF instruction is completing and the finish was overlooked\000\000\000\000\000 */
{ 16164 }, /* FIN_AT_DISP_STALL_CPI\000CPI\000\000PM_EXEC_STALL_FIN_AT_DISP / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTF instruction finishes at dispatch\000\000\000\000\000 */
{ 16327 }, /* FLUSH_RATE\000Others\000\000PM_FLUSH / PM_RUN_INST_CMPL * 100\000Percentage of flushes per completed instruction\000\0001%\000\000\000 */
{ 16434 }, /* FX_PER_INST\000General\000\000PM_FX_LSU_FIN / PM_RUN_INST_CMPL\000Average number of simple fixed-point instructions finshed in the store unit per completed instruction\000\000\000\000\000 */
{ 17003 }, /* HWSYNC_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_HWSYNC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a HWSYNC instruction stuck at finish waiting for a response from the L2\000\000\000\000\000 */
{ 17221 }, /* INST_FIN_PER_CMPL\000General\000\000PM_INST_FIN / PM_RUN_INST_CMPL\000Average number of finished instructions per completed instructions\000\000\000\000\000 */
{ 17350 }, /* INST_FROM_L3_MISS\000Instruction_Misses\000\000PM_INST_FROM_L3MISS / PM_L1_ICACHE_MISS * 100\000Percentage of icache misses that were reloaded from beyond the local L3\000\0001%\000\000\000 */
{ 17512 }, /* INST_FROM_L3_MISS_RATE\000Instruction_Misses\000\000PM_INST_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000Percentage of icache reloads from the beyond the L3 per completed instruction\000\0001%\000\000\000 */
{ 17684 }, /* IPC\000General\000\000PM_INST_CMPL / PM_CYC\000Average number of completed instructions per cycle\000\000\000\000\000 */
{ 17834 }, /* ISSUE_STALL_CPI\000CPI;CPI_STALL_RATIO\000\000PM_ISSUE_STALL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction has been dispatched but not issued for any reason\000\000\000\000\000 */
{ 18093 }, /* L1_INST_MISS_RATE\000Instruction_Misses\000\000PM_L1_ICACHE_MISS / PM_RUN_INST_CMPL * 100\000Percentage of completed instructions that were demand fetches that missed the L1 icache\000\0001%\000\000\000 */
{ 18268 }, /* L1_LD_MISS_RATE\000Others\000\000PM_LD_MISS_L1 / PM_RUN_INST_CMPL * 100\000Percentage of completed instructions that were loads that missed the L1\000\0001%\000\000\000 */
{ 18409 }, /* L1_LD_MISS_RATIO\000Others\000\000PM_LD_MISS_L1 / PM_LD_REF_L1 * 100\000Percentage of finished loads that missed in the L1\000\0001%\000\000\000 */
{ 18526 }, /* L2_LD_MISS_RATE\000General\000\000DL1_RELOAD_FROM_L2_MISS_RATE\000Percentage of completed instructions that were a demand load that did not hit in the L1 or L2\000\0001%\000\000\000 */
{ 18680 }, /* L3_INST_MISS_RATE\000General\000\000INST_FROM_L3_MISS_RATE\000Percentage of completed instructions that were demand fetches that reloaded from beyond the L3 icache\000\0001%\000\000\000 */
{ 18838 }, /* L3_LD_MISS_RATE\000General\000\000PM_DATA_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000Percentage of completed instructions that were a demand load that did not hit in the L1, L2, or the L3\000\0001%\000\000\000 */
{ 19017 }, /* LARX_PER_INST\000General\000\000PM_LARX_FIN / PM_RUN_INST_CMPL\000Average number of LARX instructions finshed per completed instruction\000\000\000\000\000 */
{ 19145 }, /* LOADS_PER_INST\000General\000\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000Average number of finished loads per completed instruction\000\000\000\000\000 */
{ 19264 }, /* LOAD_FINISH_STALL_CPI\000CPI\000\000PM_EXEC_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is finishing a load after its data has been reloaded from a data source beyond the local L1, OR when the LSU is processing an L1-hit, OR when the NTF instruction merged with another load in the LMQ\000\000\000\000\000 */
{ 19604 }, /* LOAD_STALL_CPI\000CPI\000\000PM_EXEC_STALL_LOAD / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a load that is executing in the LSU\000\000\000\000\000 */
{ 20019 }, /* LSU_PER_INST\000General\000\000PM_LSU_FIN / PM_RUN_INST_CMPL\000Average number of instructions finished in the LSU per completed instruction\000\000\000\000\000 */
{ 20152 }, /* LSU_STALL_CPI\000CPI\000\000PM_EXEC_STALL_LSU / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing in the LSU\000\000\000\000\000 */
{ 20302 }, /* LWSYNC_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_LWSYNC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a LWSYNC instruction waiting to complete\000\000\000\000\000 */
{ 20544 }, /* MEM_ECC_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_MEM_ECC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is stuck at finish waiting for the non-speculative finish of either a STCX instruction waiting for its result or a load waiting for non-critical sectors of data and ECC\000\000\000\000\000 */
{ 22301 }, /* NTC_FLUSH_STALL_CPI\000CPI\000\000PM_EXEC_STALL_NTC_FLUSH / PM_RUN_INST_CMPL\000Average cycles per completed instruction spent executing an NTC instruction that gets flushed some time after dispatch\000\000\000\000\000 */
{ 22492 }, /* PTESYNC_PER_INST\000General\000\000PM_PTESYNC_FIN / PM_RUN_INST_CMPL\000Average number of PTESYNC instructions finshed per completed instruction\000\000\000\000\000 */
{ 22629 }, /* PTESYNC_STALL_CPI\000CPI\000\000PM_EXEC_STALL_PTESYNC / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing a PTESYNC instruction\000\000\000\000\000 */
{ 23196 }, /* RUN_CPI\000General\000\000PM_RUN_CYC / PM_RUN_INST_CMPL\000Average number of run cycles per completed instruction\000\000\000\000\000 */
{ 23302 }, /* RUN_CYCLES_RATE\000General\000\000PM_RUN_CYC / PM_CYC * 100\000Percentage of cycles that are run cycles\000\0001%\000\000\000 */
{ 23400 }, /* RUN_IPC\000General\000\000PM_RUN_INST_CMPL / PM_RUN_CYC\000Average number of completed instructions per run cycle\000\000\000\000\000 */
{ 23506 }, /* SIMPLE_FX_STALL_CPI\000CPI\000\000PM_EXEC_STALL_SIMPLE_FX / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a simple fixed point instruction that is executing in the LSU\000\000\000\000\000 */
{ 23709 }, /* SPECIAL_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_SPECIAL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction required special handling before completion\000\000\000\000\000 */
{ 23898 }, /* STCX_COMPLETION_STALL_CPI\000CPI\000\000PM_CMPL_STALL_STCX / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a STCX instruction waiting for resolution from the nest\000\000\000\000\000 */
{ 24096 }, /* STORES_PER_INST\000General\000\000PM_ST_FIN / PM_RUN_INST_CMPL\000Average number of finished stores per completed instruction\000\000\000\000\000 */
{ 24214 }, /* STORE_MISS_STALL_CPI\000CPI\000\000PM_EXEC_STALL_STORE_MISS / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a store whose cache line was not resident in the L1 and had to wait for allocation of the missing line into the L1\000\000\000\000\000 */
{ 24472 }, /* STORE_PIPE_STALL_CPI\000CPI\000\000PM_EXEC_STALL_STORE_PIPE / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is in the store unit outside of handling store misses or other special store operations\000\000\000\000\000 */
{ 24700 }, /* STORE_STALL_CPI\000CPI\000\000PM_EXEC_STALL_STORE / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a store that is executing in the LSU\000\000\000\000\000 */
{ 24870 }, /* STXC_PER_INST\000General\000\000PM_STCX_FIN / PM_RUN_INST_CMPL\000Average number of STCX instructions finshed per completed instruction\000\000\000\000\000 */
{ 24998 }, /* TAKEN_BRANCHES\000General\000\000PM_BR_TAKEN_CMPL / PM_BR_FIN * 100\000Percentage of finished branches that were taken\000\0001%\000\000\000 */
{ 25111 }, /* TLBIEL_STALL_CPI\000CPI\000\000PM_EXEC_STALL_TLBIEL / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing a TLBIEL instruction\000\000\000\000\000 */
{ 25277 }, /* TLBIE_PER_INST\000General\000\000PM_TLBIE_FIN / PM_RUN_INST_CMPL\000Average number of TLBIE instructions finished in the LSU per completed instruction\000\000\000\000\000 */
{ 25420 }, /* TLBIE_STALL_CPI\000CPI\000\000PM_EXEC_STALL_TLBIE / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is a TLBIE instruction waiting for a response from the L2\000\000\000\000\000 */
{ 28382 }, /* TRANSLATION_STALL_CPI\000CPI\000\000PM_EXEC_STALL_TRANSLATION / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is waiting to be finished in one of the execution units\000\000\000\000\000 */
{ 28834 }, /* VSU_PER_INST\000General\000\000PM_VSU_FIN / PM_RUN_INST_CMPL\000Average number of instructions finished in the VSU per completed instruction\000\000\000\000\000 */
{ 28967 }, /* VSU_STALL_CPI\000CPI\000\000PM_EXEC_STALL_VSU / PM_RUN_INST_CMPL\000Average cycles per completed instruction when the NTC instruction is executing in the VSU\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__test_soc_sys[] = {
{ 439476 }, /* sys_ccn_pmu.read_cycles\000uncore_sys_ccn_pmu\000uncore\000ccn read-cycles event. Unit: uncore_sys_ccn_pmu \000config=0x2c\000\0000x01\000\000\000\000\000 */
{ 439597 }, /* sys_ddr_pmu.write_cycles\000uncore_sys_ddr_pmu\000uncore\000ddr write-cycles event. Unit: uncore_sys_ddr_pmu \000event=0x2b\000\000v8\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__test_soc_cpu[] = {
{ 35499 }, /* bp_l1_btb_correct\000\000branch\000L1 BTB Correction\000event=0x8a\000\000\000\000\000\000\000 */
{ 35560 }, /* bp_l2_btb_correct\000\000branch\000L2 BTB Correction\000event=0x8b\000\000\000\000\000\000\000 */
{ 85446 }, /* l3_cache_rd\000\000cache\000L3 cache access, read\000event=0x40\000\000\000\000\000\000Attributable Level 3 cache access, read\000 */
{ 41540 }, /* dispatch_blocked.any\000\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=0x9,period=200000,umask=0x20\000\000\000\000\000\000\000 */
{ 57853 }, /* eist_trans\000\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000,umask=0x0\000\000\000\000\000\000\000 */
{ 435474 }, /* segment_reg_loads.any\000\000other\000Number of segment register loads\000event=0x6,period=200000,umask=0x80\000\000\000\000\000\000\000 */
{ 58774 }, /* event-hyphen\000uncore_cbox\000uncore\000UNC_CBO_HYPHEN. Unit: uncore_cbox \000event=0xe0,umask=0x00\000\000\000\000\000\000UNC_CBO_HYPHEN\000 */
{ 58883 }, /* event-two-hyph\000uncore_cbox\000uncore\000UNC_CBO_TWO_HYPH. Unit: uncore_cbox \000event=0xc0,umask=0x00\000\000\000\000\000\000UNC_CBO_TWO_HYPH\000 */
{ 441064 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\000\000\000\000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000 */
{ 441328 }, /* uncore_hisi_ddrc.flux_wcmd\000hisi_sccl,ddrc\000uncore\000DDRC write commands. Unit: hisi_sccl,ddrc \000event=0x2\000\000\000\000\000\000DDRC write commands\000 */
{ 441455 }, /* uncore_hisi_l3c.rd_hit_cpipe\000hisi_sccl,l3c\000uncore\000Total read hits. Unit: hisi_sccl,l3c \000event=0x7\000\000\000\000\000\000Total read hits\000 */
{ 441574 }, /* uncore_imc.cache_hits\000uncore_imc\000uncore\000Total cache hits. Unit: uncore_imc \000event=0x34\000\000\000\000\000\000Total cache hits\000 */
{ 441683 }, /* uncore_imc_free_running.cache_miss\000uncore_imc_free_running\000uncore\000Total cache misses. Unit: uncore_imc_free_running \000event=0x12\000\000\000\000\000\000Total cache misses\000 */
};

static const struct compact_pmu_event pmu_metrics__test_soc_cpu[] = {
{ 4885 }, /* CPI\000\000\0001 / IPC\000\000\000\000\000\000 */
{ 5564 }, /* DCache_L2_All\000\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000 */
{ 5625 }, /* DCache_L2_All_Hits\000\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000 */
{ 5716 }, /* DCache_L2_All_Miss\000\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000 */
{ 5847 }, /* DCache_L2_Hits\000\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000 */
{ 5912 }, /* DCache_L2_Misses\000\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000 */
{ 16594 }, /* Frontend_Bound_SMT\000\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000 */
{ 17774 }, /* IPC\000group1\000\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000 */
{ 18025 }, /* L1D_Cache_Fill_BW\000\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000 */
{ 20489 }, /* M1\000\000\000ipc + M2\000\000\000\000\000\000 */
{ 20508 }, /* M2\000\000\000ipc + M1\000\000\000\000\000\000 */
{ 20527 }, /* M3\000\000\0001 / M3\000\000\000\000\000\000 */
{ 36833 }, /* cache_miss_cycles\000group1\000\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000 */
{ 38970 }, /* dcache_miss_cpi\000\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000 */
{ 65839 }, /* icache_miss_cycles\000\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000 */
};


/* Struct used to make the PMU event table implementation opaque to callers. */
struct pmu_events_table {
        const struct compact_pmu_event *entries;
        size_t length;
};

/* Struct used to make the PMU metric table implementation opaque to callers. */
struct pmu_metrics_table {
        const struct compact_pmu_event *entries;
        size_t length;
};

/*
 * Map a CPU to its table of PMU events. The CPU is identified by the
 * cpuid field, which is an arch-specific identifier for the CPU.
 * The identifier specified in tools/perf/pmu-events/arch/xxx/mapfile
 * must match the get_cpuid_str() in tools/perf/arch/xxx/util/header.c)
 *
 * The  cpuid can contain any character other than the comma.
 */
struct pmu_events_map {
        const char *arch;
        const char *cpuid;
        struct pmu_events_table event_table;
        struct pmu_metrics_table metric_table;
};

/*
 * Global table mapping each known CPU for the architecture to its
 * table of PMU events.
 */
const struct pmu_events_map pmu_events_map[] = {
{
	.arch = "powerpc",
	.cpuid = "004[bcd][[:xdigit:]]{4}",
	.event_table = {
		.entries = pmu_events__power8,
		.length = ARRAY_SIZE(pmu_events__power8)
	},
	.metric_table = {
		.entries = pmu_metrics__power8,
		.length = ARRAY_SIZE(pmu_metrics__power8)
	}
},
{
	.arch = "powerpc",
	.cpuid = "004e[[:xdigit:]]{4}",
	.event_table = {
		.entries = pmu_events__power9,
		.length = ARRAY_SIZE(pmu_events__power9)
	},
	.metric_table = {
		.entries = pmu_metrics__power9,
		.length = ARRAY_SIZE(pmu_metrics__power9)
	}
},
{
	.arch = "powerpc",
	.cpuid = "0080[[:xdigit:]]{4}",
	.event_table = {
		.entries = pmu_events__power10,
		.length = ARRAY_SIZE(pmu_events__power10)
	},
	.metric_table = {
		.entries = pmu_metrics__power10,
		.length = ARRAY_SIZE(pmu_metrics__power10)
	}
},
{
	.arch = "testarch",
	.cpuid = "testcpu",
	.event_table = {
		.entries = pmu_events__test_soc_cpu,
		.length = ARRAY_SIZE(pmu_events__test_soc_cpu),
	},
	.metric_table = {
		.entries = pmu_metrics__test_soc_cpu,
		.length = ARRAY_SIZE(pmu_metrics__test_soc_cpu),
	}
},
{
	.arch = 0,
	.cpuid = 0,
	.event_table = { 0, 0 },
	.metric_table = { 0, 0 },
}
};

struct pmu_sys_events {
	const char *name;
	struct pmu_events_table event_table;
	struct pmu_metrics_table metric_table;
};

static const struct pmu_sys_events pmu_sys_event_tables[] = {
	{
		.event_table = {
			.entries = pmu_events__test_soc_sys,
			.length = ARRAY_SIZE(pmu_events__test_soc_sys)
		},
		.name = "pmu_events__test_soc_sys",
	},
	{
		.event_table = { 0, 0 },
		.metric_table = { 0, 0 },
	},
};

static void decompress_event(int offset, struct pmu_event *pe)
{
	const char *p = &big_c_string[offset];

	pe->name = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->pmu = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->topic = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->event = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->aggr_mode = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->deprecated = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->perpkg = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->long_desc = (*p == '\0' ? NULL : p);
}

static void decompress_metric(int offset, struct pmu_metric *pm)
{
	const char *p = &big_c_string[offset];

	pm->metric_name = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_group = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_constraint = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_expr = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->long_desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->aggr_mode = (*p == '\0' ? NULL : p);
}

int pmu_events_table_for_each_event(const struct pmu_events_table *table,
                                    pmu_event_iter_fn fn,
                                    void *data)
{
        for (size_t i = 0; i < table->length; i++) {
                struct pmu_event pe;
                int ret;

                decompress_event(table->entries[i].offset, &pe);
                if (!pe.name)
                        continue;
                ret = fn(&pe, table, data);
                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_metrics_table_for_each_metric(const struct pmu_metrics_table *table,
                                     pmu_metric_iter_fn fn,
                                     void *data)
{
        for (size_t i = 0; i < table->length; i++) {
                struct pmu_metric pm;
                int ret;

                decompress_metric(table->entries[i].offset, &pm);
                if (!pm.metric_expr)
                        continue;
                ret = fn(&pm, table, data);
                if (ret)
                        return ret;
        }
        return 0;
}

const struct pmu_events_table *perf_pmu__find_events_table(struct perf_pmu *pmu)
{
        const struct pmu_events_table *table = NULL;
        char *cpuid = perf_pmu__getcpuid(pmu);
        int i;

        /* on some platforms which uses cpus map, cpuid can be NULL for
         * PMUs other than CORE PMUs.
         */
        if (!cpuid)
                return NULL;

        i = 0;
        for (;;) {
                const struct pmu_events_map *map = &pmu_events_map[i++];
                if (!map->arch)
                        break;

                if (!strcmp_cpuid_str(map->cpuid, cpuid)) {
                        table = &map->event_table;
                        break;
                }
        }
        free(cpuid);
        return table;
}

const struct pmu_metrics_table *perf_pmu__find_metrics_table(struct perf_pmu *pmu)
{
        const struct pmu_metrics_table *table = NULL;
        char *cpuid = perf_pmu__getcpuid(pmu);
        int i;

        /* on some platforms which uses cpus map, cpuid can be NULL for
         * PMUs other than CORE PMUs.
         */
        if (!cpuid)
                return NULL;

        i = 0;
        for (;;) {
                const struct pmu_events_map *map = &pmu_events_map[i++];
                if (!map->arch)
                        break;

                if (!strcmp_cpuid_str(map->cpuid, cpuid)) {
                        table = &map->metric_table;
                        break;
                }
        }
        free(cpuid);
        return table;
}

const struct pmu_events_table *find_core_events_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->event_table;
        }
        return NULL;
}

const struct pmu_metrics_table *find_core_metrics_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->metric_table;
        }
        return NULL;
}

int pmu_for_each_core_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_events_table_for_each_event(&tables->event_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_core_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_metrics_table_for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

const struct pmu_events_table *find_sys_events_table(const char *name)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                if (!strcmp(tables->name, name))
                        return &tables->event_table;
        }
        return NULL;
}

int pmu_for_each_sys_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_events_table_for_each_event(&tables->event_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_sys_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_metrics_table_for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}
